--
-- CREATED BY:
-- 1. Creating a fresh chado instance and preparing it through the UI.
-- 2. Exporting it via pg_dump --data-only --file=fill_chado_test_prepare.sql --schema=chado --no-owner --inserts --user docker sitedb
-- 3. Remove all SQL Comments `--`
-- 4. Remove all empty lines.
-- 5. Remove all `CREATE INDEX` commands.
-- 6. Remove all `SELECT pg_catalog.setval(.*, 1, false)` statements
-- 7. Add in the `CREATE TABLE commands for the custom tables and mviews.
--
CREATE TABLE chado.analysis_organism (
    analysis_id bigint NOT NULL,
    organism_id bigint NOT NULL
);
COMMENT ON TABLE chado.analysis_organism IS 'This view is for associating an organism (via it''s associated features) to an analysis.';
CREATE TABLE chado.cv_root_mview (
    name character varying(255) NOT NULL,
    cvterm_id bigint NOT NULL,
    cv_id bigint NOT NULL,
    cv_name character varying(255) NOT NULL
);
COMMENT ON TABLE chado.cv_root_mview IS 'A list of the root terms for all controlled vocabularies. This is needed for viewing CV trees';
CREATE TABLE chado.db2cv_mview (
    cv_id integer NOT NULL,
    cvname character varying(255) NOT NULL,
    db_id integer NOT NULL,
    dbname character varying(255) NOT NULL,
    num_terms integer NOT NULL
);
COMMENT ON TABLE chado.db2cv_mview IS 'A table for quick lookup of the vocabularies and the databases they are associated with.';
CREATE TABLE chado.library_feature_count (
    library_id bigint NOT NULL,
    name character varying(255) NOT NULL,
    num_features integer NOT NULL,
    feature_type character varying(255) NOT NULL
);
COMMENT ON TABLE chado.library_feature_count IS 'Provides count of feature by type that are associated with all libraries';
CREATE TABLE chado.organism_feature_count (
    organism_id bigint NOT NULL,
    genus character varying(255) NOT NULL,
    species character varying(255) NOT NULL,
    common_name character varying(255),
    num_features integer NOT NULL,
    cvterm_id bigint NOT NULL,
    feature_type character varying(255) NOT NULL
);
COMMENT ON TABLE chado.organism_feature_count IS 'Stores the type and number of features per organism';
CREATE TABLE chado.organism_stock_count (
    organism_id bigint NOT NULL,
    genus character varying(255) NOT NULL,
    species character varying(255) NOT NULL,
    common_name character varying(255),
    num_stocks integer NOT NULL,
    cvterm_id bigint NOT NULL,
    stock_type character varying(255) NOT NULL
);
COMMENT ON TABLE chado.organism_stock_count IS 'Stores the type and number of stocks per organism';
CREATE TABLE chado.tripal_gff_temp (
    feature_id integer NOT NULL,
    organism_id integer NOT NULL,
    uniquename text NOT NULL,
    type_name character varying(1024) NOT NULL
);
CREATE TABLE chado.tripal_gffcds_temp (
    feature_id integer NOT NULL,
    parent_id integer NOT NULL,
    phase integer,
    strand integer NOT NULL,
    fmin integer NOT NULL,
    fmax integer NOT NULL
);
CREATE TABLE chado.tripal_gffprotein_temp (
    feature_id integer NOT NULL,
    parent_id integer NOT NULL,
    fmin integer NOT NULL,
    fmax integer NOT NULL
);
CREATE TABLE chado.tripal_obo_temp (
    id character varying(255) NOT NULL,
    stanza text NOT NULL,
    type character varying(50) NOT NULL
);
INSERT INTO chado.cv VALUES (3, 'Statistical Terms', 'Locally created terms for statistics');
INSERT INTO chado.cv VALUES (4, 'chado_properties', 'Terms that are used in the chadoprop table to describe the state of the database');
INSERT INTO chado.cv VALUES (5, 'germplasm_ontology', 'GCP germplasm ontology');
INSERT INTO chado.cv VALUES (6, 'dc', 'DCMI Metadata Terms');
INSERT INTO chado.cv VALUES (7, 'EDAM', 'Bioscientific data analysis ontology');
INSERT INTO chado.cv VALUES (8, 'efo', 'The Experimental Factor Ontology (EFO) provides a systematic description of many experimental variables available in EBI databases, and for external projects such as the NHGRI GWAS catalogue. It combines parts of several biological ontologies, such as anatomy, disease and chemical compounds. The scope of EFO is to support the annotation, analysis and visualization of data handled by many groups at the EBI and as the core ontology for OpenTargets.org');
INSERT INTO chado.cv VALUES (9, 'ero', 'The Eagle-I Research Resource Ontology models research resources such instruments. protocols, reagents, animal models and biospecimens. It has been developed in the context of the eagle-i project (http://eagle-i.net/).');
INSERT INTO chado.cv VALUES (10, 'OBCS', 'Ontology of Biological and Clinical Statistics');
INSERT INTO chado.cv VALUES (11, 'obi', 'Ontology for Biomedical Investigation. The Ontology for Biomedical Investigations (OBI) is build in a collaborative, international effort and will serve as a resource for annotating biomedical investigations, including the study design, protocols and instrumentation used, the data generated and the types of analysis performed on the data. This ontology arose from the Functional Genomics Investigation Ontology (FuGO) and will contain both terms that are common to all biomedical investigations, including functional genomics investigations and those that are more domain specific');
INSERT INTO chado.cv VALUES (12, 'ogi', 'Ontology for Biomedical Investigation. The Ontology for Biomedical Investigations (OBI) is build in a collaborative, international effort and will serve as a resource for annotating biomedical investigations, including the study design, protocols and instrumentation used, the data generated and the types of analysis performed on the data. This ontology arose from the Functional Genomics Investigation Ontology (FuGO) and will contain both terms that are common to all biomedical investigations, including functional genomics investigations and those that are more domain specific');
INSERT INTO chado.cv VALUES (13, 'IAO', 'Information Artifact Ontology');
INSERT INTO chado.cv VALUES (1, 'null', 'No vocabulary');
INSERT INTO chado.cv VALUES (2, 'local', 'Locally created terms');
INSERT INTO chado.cv VALUES (14, 'sbo', 'Systems Biology.  Terms commonly used in Systems Biology, and in particular in computational modeling.');
INSERT INTO chado.cv VALUES (15, 'swo', 'Bioinformatics operations, data types, formats, identifiers and topics');
INSERT INTO chado.cv VALUES (16, 'PMID', 'PubMed.');
INSERT INTO chado.cv VALUES (17, 'uo', 'Units of Measurement Ontology');
INSERT INTO chado.cv VALUES (18, 'ncit', 'NCI Thesaurus OBO Edition');
INSERT INTO chado.cv VALUES (19, 'ncbitaxon', 'NCBI organismal classification. An ontology representation of the NCBI organismal taxonomy');
INSERT INTO chado.cv VALUES (20, 'rdfs', 'Resource Description Framework Schema');
INSERT INTO chado.cv VALUES (21, 'ro', 'Relationship Ontology (legacy)');
INSERT INTO chado.cv VALUES (22, 'sequence', 'The Sequence Ontology');
INSERT INTO chado.cv VALUES (23, 'taxonomic_rank', 'Taxonomic Rank');
INSERT INTO chado.cv VALUES (24, 'tripal_contact', 'Tripal Contact Ontology');
INSERT INTO chado.cv VALUES (25, 'tripal_pub', 'Tripal Publication Ontology');
INSERT INTO chado.cv VALUES (26, 'hydra', 'A Vocabulary for Hypermedia-Driven Web APIs.');
INSERT INTO chado.cv VALUES (27, 'schema', 'Schema.org. Schema.org is sponsored by Google, Microsoft, Yahoo and Yandex. The vocabularies are developed by an open community process.');
INSERT INTO chado.cv VALUES (28, 'sep', 'A structured controlled vocabulary for the annotation of sample processing and separation techniques in scientific experiments.');
INSERT INTO chado.cv VALUES (29, 'SIO', 'The Semanticscience Integrated Ontology (SIO) provides a simple, integrated ontology of types and relations for rich description of objects, processes and their attributes.');
INSERT INTO chado.cv VALUES (30, 'cellular_component', NULL);
INSERT INTO chado.cv VALUES (31, 'synonym_type', NULL);
INSERT INTO chado.db VALUES (19, 'NCIT', 'The NCIt is a reference terminology that includes broad coverage of the cancer domain, including cancer related diseases, findings and abnormalities. NCIt OBO Edition releases should be considered experimental.', 'http://purl.obolibrary.org/obo/{db}_{accession}', 'http://purl.obolibrary.org/obo/ncit.owl');
INSERT INTO chado.db VALUES (2, 'CO_010', 'Crop Germplasm Ontology', 'http://www.cropontology.org/terms/CO_010:{accession}', 'http://www.cropontology.org/get-ontology/CO_010');
INSERT INTO chado.db VALUES (11, 'OBI', 'The Ontology for Biomedical Investigation', 'http://purl.obolibrary.org/obo/{db}_{accession}', 'http://obi-ontology.org/page/Main_Page');
INSERT INTO chado.db VALUES (3, 'dc', 'DCMI Metadata Terms', 'http://purl.org/dc/terms/{accession}', 'http://purl.org/dc/dcmitype/');
INSERT INTO chado.db VALUES (29, 'sep', 'Sample processing and separation techniques.', 'http://purl.obolibrary.org/obo/{db}_{accession}', 'http://psidev.info/index.php?q=node/312');
INSERT INTO chado.db VALUES (12, 'OGI', 'Ontology for genetic interval', 'http://purl.obolibrary.org/obo/{db}_{accession}', 'http://purl.bioontology.org/ontology/OGI');
INSERT INTO chado.db VALUES (20, 'NCBITaxon', 'NCBI organismal classification', 'https://www.ncbi.nlm.nih.gov/Taxonomy/Browser/wwwtax.cgi?id={accession}', 'http://www.berkeleybop.org/ontologies/ncbitaxon/');
INSERT INTO chado.db VALUES (25, 'TCONTACT', 'Tripal Contact Ontology. A temporary ontology until a more formal appropriate ontology an be identified.', 'cv/lookup/TCONTACT/{accession}', 'cv/lookup/TCONTACT');
INSERT INTO chado.db VALUES (13, 'IAO', 'Information Artifact Ontology', 'http://purl.obolibrary.org/obo/{db}_{accession}', 'https://github.com/information-artifact-ontology/IAO/');
INSERT INTO chado.db VALUES (4, 'data', 'Bioinformatics operations, data types, formats, identifiers and topics.', 'http://edamontology.org/{db}_{accession}', 'http://edamontology.org/page');
INSERT INTO chado.db VALUES (5, 'format', 'A defined way or layout of representing and structuring data in a computer file, blob, string, message, or elsewhere. The main focus in EDAM lies on formats as means of structuring data exchanged between different tools or resources.', 'http://edamontology.org/{db}_{accession}', 'http://edamontology.org/page');
INSERT INTO chado.db VALUES (6, 'operation', 'A function that processes a set of inputs and results in a set of outputs, or associates arguments (inputs) with values (outputs). Special cases are: a) An operation that consumes no input (has no input arguments).', 'http://edamontology.org/{db}_{accession}', 'http://edamontology.org/page');
INSERT INTO chado.db VALUES (21, 'rdfs', 'Resource Description Framework Schema', 'http://www.w3.org/2000/01/rdf-schema#{accession}', 'https://www.w3.org/TR/rdf-schema/');
INSERT INTO chado.db VALUES (7, 'topic', 'A category denoting a rather broad domain or field of interest, of study, application, work, data, or technology. Topics have no clearly defined borders between each other.', 'http://edamontology.org/{db}_{accession}', 'http://edamontology.org/page');
INSERT INTO chado.db VALUES (1, 'null', 'No database', 'cv/lookup/{db}/{accession}', 'cv/lookup/null');
INSERT INTO chado.db VALUES (8, 'EFO', 'Experimental Factor Ontology', 'http://www.ebi.ac.uk/efo/{db}_{accession}', 'http://www.ebi.ac.uk/efo/efo.owl');
INSERT INTO chado.db VALUES (14, 'local', 'Terms created for this site', 'cv/lookup/{db}/{accession}', 'cv/lookup/local');
INSERT INTO chado.db VALUES (9, 'ERO', 'The Eagle-I Research Resource Ontology', 'http://purl.bioontology.org/ontology/ERO/{db}:{accession}', 'http://purl.bioontology.org/ontology/ERO');
INSERT INTO chado.db VALUES (26, 'TPUB', 'Tripal Publication Ontology. A temporary ontology until a more formal appropriate ontology an be identified.', 'cv/lookup/TPUB/{accession}  ', 'cv/lookup/TPUB');
INSERT INTO chado.db VALUES (22, 'RO', 'Relationship Ontology (legacy)', 'cv/lookup/RO/{accession}', 'cv/lookup/RO');
INSERT INTO chado.db VALUES (10, 'OBCS', 'Ontology of Biological and Clinical Statistics', 'http://purl.obolibrary.org/obo/{db}_{accession}', 'https://github.com/obcs/obcs');
INSERT INTO chado.db VALUES (15, 'SBO', 'Systems Biology Ontology', 'http://purl.obolibrary.org/obo/{db}_{accession}', 'http://www.ebi.ac.uk/sbo/main/');
INSERT INTO chado.db VALUES (30, 'SIO', 'Semanticscience Integrated Ontology', 'http://semanticscience.org/resource/{db}_{accession}', 'http://sio.semanticscience.org/');
INSERT INTO chado.db VALUES (31, 'GO', NULL, NULL, NULL);
INSERT INTO chado.db VALUES (16, 'SWO', 'Bioinformatics operations, data types, formats, identifiers and topics', 'http://www.ebi.ac.uk/swo/{db}_{accession}', 'http://purl.obolibrary.org/obo/swo');
INSERT INTO chado.db VALUES (23, 'SO', 'The Sequence Ontology', 'http://www.sequenceontology.org/browser/current_svn/term/{db}:{accession}', 'http://www.sequenceontology.org');
INSERT INTO chado.db VALUES (32, 'synonym_type', NULL, NULL, NULL);
INSERT INTO chado.db VALUES (17, 'PMID', 'PubMed', 'http://www.ncbi.nlm.nih.gov/pubmed/{accession}', 'http://www.ncbi.nlm.nih.gov/pubmed');
INSERT INTO chado.db VALUES (27, 'hydra', 'A Vocabulary for Hypermedia-Driven Web APIs', 'http://www.w3.org/ns/hydra/core#{accession}', 'http://www.w3.org/ns/hydra/core');
INSERT INTO chado.db VALUES (24, 'TAXRANK', 'A vocabulary of taxonomic ranks (species, family, phylum, etc)', 'http://purl.obolibrary.org/obo/{db}_{accession}', 'http://www.obofoundry.org/ontology/taxrank.html');
INSERT INTO chado.db VALUES (18, 'UO', 'Units of Measurement Ontology', 'http://purl.obolibrary.org/obo/UO_{accession}', 'http://purl.obolibrary.org/obo/uo');
INSERT INTO chado.db VALUES (33, 'loinc', '', NULL, '');
INSERT INTO chado.db VALUES (34, 'BS', '', NULL, '');
INSERT INTO chado.db VALUES (35, 'RNAMOD', '', NULL, '');
INSERT INTO chado.db VALUES (28, 'schema', 'Schema.org', 'https://schema.org/{accession}', 'https://schema.org/');
INSERT INTO chado.db VALUES (36, 'MOD', '', NULL, '');
INSERT INTO chado.db VALUES (37, 'EBI', '', NULL, '');
INSERT INTO chado.db VALUES (38, 'XX', '', NULL, '');
INSERT INTO chado.db VALUES (39, 'WIKI', '', NULL, '');
INSERT INTO chado.db VALUES (40, 'https', '', NULL, '');
INSERT INTO chado.db VALUES (41, 'doi', '', NULL, '');
INSERT INTO chado.dbxref VALUES (1, 1, 'local:null', '', NULL);
INSERT INTO chado.dbxref VALUES (2, 1, 'chado_properties:version', '', NULL);
INSERT INTO chado.dbxref VALUES (3, 2, '0000044', '', NULL);
INSERT INTO chado.dbxref VALUES (4, 2, '0000255', '', NULL);
INSERT INTO chado.dbxref VALUES (5, 2, '0000029', '', NULL);
INSERT INTO chado.dbxref VALUES (6, 2, '0000162', '', NULL);
INSERT INTO chado.dbxref VALUES (7, 3, 'Service', '', NULL);
INSERT INTO chado.dbxref VALUES (8, 4, '1249', '', NULL);
INSERT INTO chado.dbxref VALUES (9, 4, '2190', '', NULL);
INSERT INTO chado.dbxref VALUES (10, 4, '2091', '', NULL);
INSERT INTO chado.dbxref VALUES (11, 4, '2044', '', NULL);
INSERT INTO chado.dbxref VALUES (12, 4, '0849', '', NULL);
INSERT INTO chado.dbxref VALUES (13, 4, '0842', '', NULL);
INSERT INTO chado.dbxref VALUES (14, 4, '2976', '', NULL);
INSERT INTO chado.dbxref VALUES (15, 4, '2968', '', NULL);
INSERT INTO chado.dbxref VALUES (16, 4, '1274', '', NULL);
INSERT INTO chado.dbxref VALUES (17, 4, '1278', '', NULL);
INSERT INTO chado.dbxref VALUES (18, 4, '1280', '', NULL);
INSERT INTO chado.dbxref VALUES (19, 4, '2012', '', NULL);
INSERT INTO chado.dbxref VALUES (20, 4, '1056', '', NULL);
INSERT INTO chado.dbxref VALUES (21, 4, '1048', '', NULL);
INSERT INTO chado.dbxref VALUES (22, 4, '1047', '', NULL);
INSERT INTO chado.dbxref VALUES (23, 4, '2336', '', NULL);
INSERT INTO chado.dbxref VALUES (24, 4, '0853', '', NULL);
INSERT INTO chado.dbxref VALUES (25, 4, '3002', '', NULL);
INSERT INTO chado.dbxref VALUES (26, 4, '0872', '', NULL);
INSERT INTO chado.dbxref VALUES (27, 4, '3272', '', NULL);
INSERT INTO chado.dbxref VALUES (28, 4, '3271', '', NULL);
INSERT INTO chado.dbxref VALUES (29, 6, '0567', '', NULL);
INSERT INTO chado.dbxref VALUES (30, 6, '0564', '', NULL);
INSERT INTO chado.dbxref VALUES (31, 6, '0525', '', NULL);
INSERT INTO chado.dbxref VALUES (32, 6, '0362', '', NULL);
INSERT INTO chado.dbxref VALUES (33, 6, '2945', '', NULL);
INSERT INTO chado.dbxref VALUES (34, 8, '0000548', '', NULL);
INSERT INTO chado.dbxref VALUES (35, 8, '0000269', '', NULL);
INSERT INTO chado.dbxref VALUES (36, 8, '0005522', '', NULL);
INSERT INTO chado.dbxref VALUES (37, 8, '0001728', '', NULL);
INSERT INTO chado.dbxref VALUES (38, 9, '0001716', '', NULL);
INSERT INTO chado.dbxref VALUES (39, 9, '0000387', '', NULL);
INSERT INTO chado.dbxref VALUES (40, 10, '0000117', '', NULL);
INSERT INTO chado.dbxref VALUES (41, 11, '0100026', '', NULL);
INSERT INTO chado.dbxref VALUES (42, 11, '0000070', '', NULL);
INSERT INTO chado.dbxref VALUES (43, 12, '0000021', '', NULL);
INSERT INTO chado.dbxref VALUES (44, 13, '0000115', '', NULL);
INSERT INTO chado.dbxref VALUES (45, 13, '0000129', '', NULL);
INSERT INTO chado.dbxref VALUES (46, 13, '0000064', '', NULL);
INSERT INTO chado.dbxref VALUES (47, 14, 'property', '', NULL);
INSERT INTO chado.dbxref VALUES (48, 14, 'timelastmodified', '', NULL);
INSERT INTO chado.dbxref VALUES (49, 14, 'timeaccessioned', '', NULL);
INSERT INTO chado.dbxref VALUES (50, 14, 'timeexecuted', '', NULL);
INSERT INTO chado.dbxref VALUES (51, 14, 'infraspecific_type', '', NULL);
INSERT INTO chado.dbxref VALUES (52, 14, 'abbreviation', '', NULL);
INSERT INTO chado.dbxref VALUES (53, 14, 'expression', '', NULL);
INSERT INTO chado.dbxref VALUES (54, 14, 'is_analysis', '', NULL);
INSERT INTO chado.dbxref VALUES (55, 14, 'is_obsolete', '', NULL);
INSERT INTO chado.dbxref VALUES (56, 14, 'is_current', '', NULL);
INSERT INTO chado.dbxref VALUES (57, 14, 'is_internal', '', NULL);
INSERT INTO chado.dbxref VALUES (58, 14, 'miniref', '', NULL);
INSERT INTO chado.dbxref VALUES (59, 14, 'array_batch_identifier', '', NULL);
INSERT INTO chado.dbxref VALUES (60, 14, 'relationship_subject', '', NULL);
INSERT INTO chado.dbxref VALUES (61, 14, 'relationship_object', '', NULL);
INSERT INTO chado.dbxref VALUES (62, 14, 'relationship_type', '', NULL);
INSERT INTO chado.dbxref VALUES (63, 14, 'fasta_definition', '', NULL);
INSERT INTO chado.dbxref VALUES (64, 14, 'Reference Feature', '', NULL);
INSERT INTO chado.dbxref VALUES (65, 14, 'fmin', '', NULL);
INSERT INTO chado.dbxref VALUES (66, 14, 'fmax', '', NULL);
INSERT INTO chado.dbxref VALUES (67, 14, 'analysis', '', NULL);
INSERT INTO chado.dbxref VALUES (68, 14, 'source_data', '', NULL);
INSERT INTO chado.dbxref VALUES (69, 14, 'contact', '', NULL);
INSERT INTO chado.dbxref VALUES (70, 14, 'relationship', '', NULL);
INSERT INTO chado.dbxref VALUES (71, 14, 'biomaterial', '', NULL);
INSERT INTO chado.dbxref VALUES (72, 14, 'array_dimensions', '', NULL);
INSERT INTO chado.dbxref VALUES (73, 14, 'element_dimensions', '', NULL);
INSERT INTO chado.dbxref VALUES (74, 14, 'num_of_elements', '', NULL);
INSERT INTO chado.dbxref VALUES (75, 14, 'num_array_columns', '', NULL);
INSERT INTO chado.dbxref VALUES (76, 14, 'num_array_rows', '', NULL);
INSERT INTO chado.dbxref VALUES (77, 14, 'num_grid_columns', '', NULL);
INSERT INTO chado.dbxref VALUES (78, 14, 'num_grid_rows', '', NULL);
INSERT INTO chado.dbxref VALUES (79, 14, 'num_sub_columns', '', NULL);
INSERT INTO chado.dbxref VALUES (80, 14, 'num_sub_rows', '', NULL);
INSERT INTO chado.dbxref VALUES (81, 14, 'Genome Project', '', NULL);
INSERT INTO chado.dbxref VALUES (82, 14, 'rank', '', NULL);
INSERT INTO chado.dbxref VALUES (83, 14, 'lineage', '', NULL);
INSERT INTO chado.dbxref VALUES (84, 14, 'genetic_code', '', NULL);
INSERT INTO chado.dbxref VALUES (85, 14, 'genetic_code_name', '', NULL);
INSERT INTO chado.dbxref VALUES (86, 14, 'mitochondrial_genetic_code', '', NULL);
INSERT INTO chado.dbxref VALUES (87, 14, 'mitochondrial_genetic_code_name', '', NULL);
INSERT INTO chado.dbxref VALUES (88, 14, 'division', '', NULL);
INSERT INTO chado.dbxref VALUES (89, 14, 'genbank_common_name', '', NULL);
INSERT INTO chado.dbxref VALUES (90, 14, 'synonym', '', NULL);
INSERT INTO chado.dbxref VALUES (91, 14, 'other_name', '', NULL);
INSERT INTO chado.dbxref VALUES (92, 14, 'equivalent_name', '', NULL);
INSERT INTO chado.dbxref VALUES (93, 14, 'anamorph', '', NULL);
INSERT INTO chado.dbxref VALUES (94, 14, 'Analysis Type', '', NULL);
INSERT INTO chado.dbxref VALUES (95, 14, 'phylo_leaf', '', NULL);
INSERT INTO chado.dbxref VALUES (96, 14, 'phylo_root', '', NULL);
INSERT INTO chado.dbxref VALUES (97, 14, 'phylo_interior', '', NULL);
INSERT INTO chado.dbxref VALUES (98, 14, 'taxonomy', '', NULL);
INSERT INTO chado.dbxref VALUES (99, 14, 'cM', '', NULL);
INSERT INTO chado.dbxref VALUES (100, 14, 'bp', '', NULL);
INSERT INTO chado.dbxref VALUES (101, 14, 'bin_unit', '', NULL);
INSERT INTO chado.dbxref VALUES (102, 14, 'marker_order', '', NULL);
INSERT INTO chado.dbxref VALUES (103, 14, 'undefined', '', NULL);
INSERT INTO chado.dbxref VALUES (104, 14, 'start', '', NULL);
INSERT INTO chado.dbxref VALUES (105, 14, 'stop', '', NULL);
INSERT INTO chado.dbxref VALUES (106, 14, 'Map Dbxref', '', NULL);
INSERT INTO chado.dbxref VALUES (107, 14, 'Map Type', '', NULL);
INSERT INTO chado.dbxref VALUES (108, 14, 'Genome Group', '', NULL);
INSERT INTO chado.dbxref VALUES (109, 14, 'URL', '', NULL);
INSERT INTO chado.dbxref VALUES (110, 14, 'Population Type', '', NULL);
INSERT INTO chado.dbxref VALUES (111, 14, 'Population Size', '', NULL);
INSERT INTO chado.dbxref VALUES (112, 14, 'Methods', '', NULL);
INSERT INTO chado.dbxref VALUES (113, 14, 'Software', '', NULL);
INSERT INTO chado.dbxref VALUES (114, 14, 'library', '', NULL);
INSERT INTO chado.dbxref VALUES (115, 14, 'library_description', '', NULL);
INSERT INTO chado.dbxref VALUES (116, 14, 'cdna_library', '', NULL);
INSERT INTO chado.dbxref VALUES (117, 14, 'bac_library', '', NULL);
INSERT INTO chado.dbxref VALUES (118, 14, 'fosmid_library', '', NULL);
INSERT INTO chado.dbxref VALUES (119, 14, 'cosmid_library', '', NULL);
INSERT INTO chado.dbxref VALUES (120, 14, 'yac_library', '', NULL);
INSERT INTO chado.dbxref VALUES (121, 14, 'genomic_library', '', NULL);
INSERT INTO chado.dbxref VALUES (122, 14, 'Project Description', '', NULL);
INSERT INTO chado.dbxref VALUES (123, 14, 'Project Type', '', NULL);
INSERT INTO chado.dbxref VALUES (124, 14, 'Study Type', '', NULL);
INSERT INTO chado.dbxref VALUES (125, 14, 'analysis_date', '', NULL);
INSERT INTO chado.dbxref VALUES (126, 14, 'analysis_short_name', '', NULL);
INSERT INTO chado.dbxref VALUES (127, 14, 'Genotyping', '', NULL);
INSERT INTO chado.dbxref VALUES (128, 14, 'Phenotyping', '', NULL);
INSERT INTO chado.dbxref VALUES (129, 14, 'Location', '', NULL);
INSERT INTO chado.dbxref VALUES (130, 15, '0000358', '', NULL);
INSERT INTO chado.dbxref VALUES (131, 15, '0000554', '', NULL);
INSERT INTO chado.dbxref VALUES (132, 15, '0000374', '', NULL);
INSERT INTO chado.dbxref VALUES (133, 16, '0000001', '', NULL);
INSERT INTO chado.dbxref VALUES (134, 18, '0000000', '', NULL);
INSERT INTO chado.dbxref VALUES (135, 19, 'C25164', '', NULL);
INSERT INTO chado.dbxref VALUES (136, 19, 'C48036', '', NULL);
INSERT INTO chado.dbxref VALUES (137, 19, 'C45378', '', NULL);
INSERT INTO chado.dbxref VALUES (138, 19, 'C25712', '', NULL);
INSERT INTO chado.dbxref VALUES (139, 19, 'C44170', '', NULL);
INSERT INTO chado.dbxref VALUES (140, 19, 'C48697', '', NULL);
INSERT INTO chado.dbxref VALUES (141, 19, 'C45559', '', NULL);
INSERT INTO chado.dbxref VALUES (142, 19, 'C80488', '', NULL);
INSERT INTO chado.dbxref VALUES (143, 19, 'C16977', '', NULL);
INSERT INTO chado.dbxref VALUES (144, 19, 'C16631', '', NULL);
INSERT INTO chado.dbxref VALUES (145, 19, 'C25341', '', NULL);
INSERT INTO chado.dbxref VALUES (146, 19, 'C802', '', NULL);
INSERT INTO chado.dbxref VALUES (147, 19, 'C16551', '', NULL);
INSERT INTO chado.dbxref VALUES (148, 19, 'C42765', '', NULL);
INSERT INTO chado.dbxref VALUES (149, 19, 'C15320', '', NULL);
INSERT INTO chado.dbxref VALUES (150, 19, 'C54131', '', NULL);
INSERT INTO chado.dbxref VALUES (151, 19, 'C47885', '', NULL);
INSERT INTO chado.dbxref VALUES (152, 19, 'C16223', '', NULL);
INSERT INTO chado.dbxref VALUES (153, 19, 'C85496', '', NULL);
INSERT INTO chado.dbxref VALUES (154, 19, 'C25693', '', NULL);
INSERT INTO chado.dbxref VALUES (155, 19, 'C42699', '', NULL);
INSERT INTO chado.dbxref VALUES (156, 19, 'C70699', '', NULL);
INSERT INTO chado.dbxref VALUES (157, 19, 'C47954', '', NULL);
INSERT INTO chado.dbxref VALUES (158, 20, 'common_name', '', NULL);
INSERT INTO chado.dbxref VALUES (159, 21, 'comment', '', NULL);
INSERT INTO chado.dbxref VALUES (160, 21, 'type', '', NULL);
INSERT INTO chado.dbxref VALUES (161, 21, 'label', '', NULL);
INSERT INTO chado.dbxref VALUES (162, 23, '0000110', '', NULL);
INSERT INTO chado.dbxref VALUES (163, 23, '0000704', '', NULL);
INSERT INTO chado.dbxref VALUES (164, 23, '0000234', '', NULL);
INSERT INTO chado.dbxref VALUES (165, 23, '0000771', '', NULL);
INSERT INTO chado.dbxref VALUES (166, 23, '0001060', '', NULL);
INSERT INTO chado.dbxref VALUES (167, 23, '0001645', '', NULL);
INSERT INTO chado.dbxref VALUES (168, 23, '0001500', '', NULL);
INSERT INTO chado.dbxref VALUES (169, 24, '0000005', '', NULL);
INSERT INTO chado.dbxref VALUES (170, 24, '0000006', '', NULL);
INSERT INTO chado.dbxref VALUES (171, 24, '0000045', '', NULL);
INSERT INTO chado.dbxref VALUES (172, 26, '0000002', '', NULL);
INSERT INTO chado.dbxref VALUES (173, 26, '0000003', '', NULL);
INSERT INTO chado.dbxref VALUES (174, 26, '0000015', '', NULL);
INSERT INTO chado.dbxref VALUES (175, 26, '0000243', '', NULL);
INSERT INTO chado.dbxref VALUES (176, 27, 'Collection', '', NULL);
INSERT INTO chado.dbxref VALUES (177, 27, 'member', '', NULL);
INSERT INTO chado.dbxref VALUES (178, 27, 'description', '', NULL);
INSERT INTO chado.dbxref VALUES (179, 27, 'totalItems', '', NULL);
INSERT INTO chado.dbxref VALUES (180, 27, 'title', '', NULL);
INSERT INTO chado.dbxref VALUES (181, 27, 'PartialCollectionView', '', NULL);
INSERT INTO chado.dbxref VALUES (182, 28, 'name', '', NULL);
INSERT INTO chado.dbxref VALUES (183, 28, 'alternateName', '', NULL);
INSERT INTO chado.dbxref VALUES (184, 28, 'comment', '', NULL);
INSERT INTO chado.dbxref VALUES (185, 28, 'description', '', NULL);
INSERT INTO chado.dbxref VALUES (186, 28, 'publication', '', NULL);
INSERT INTO chado.dbxref VALUES (187, 28, 'url', '', NULL);
INSERT INTO chado.dbxref VALUES (188, 28, 'additionalType', '', NULL);
INSERT INTO chado.dbxref VALUES (189, 28, 'ItemPage', '', NULL);
INSERT INTO chado.dbxref VALUES (190, 29, '00195', '', NULL);
INSERT INTO chado.dbxref VALUES (191, 29, '00101', '', NULL);
INSERT INTO chado.dbxref VALUES (192, 30, '000067', '', NULL);
INSERT INTO chado.dbxref VALUES (193, 30, '000493', '', NULL);
INSERT INTO chado.dbxref VALUES (194, 30, '000631', '', NULL);
INSERT INTO chado.dbxref VALUES (195, 30, '000056', '', NULL);
INSERT INTO chado.dbxref VALUES (196, 30, '001166', '', NULL);
INSERT INTO chado.dbxref VALUES (197, 30, '000281', '', NULL);
INSERT INTO chado.dbxref VALUES (198, 30, '000729', '', NULL);
INSERT INTO chado.dbxref VALUES (199, 30, '001080', '', NULL);
INSERT INTO chado.dbxref VALUES (200, 30, '001323', '', NULL);
INSERT INTO chado.dbxref VALUES (201, 30, '001007', '', NULL);
INSERT INTO chado.dbxref VALUES (202, 30, '010054', '', NULL);
INSERT INTO chado.dbxref VALUES (203, 30, '001066', '', NULL);
INSERT INTO chado.dbxref VALUES (204, 32, 'exact', '', NULL);
INSERT INTO chado.dbxref VALUES (205, 32, 'broad', '', NULL);
INSERT INTO chado.dbxref VALUES (206, 32, 'narrow', '', NULL);
INSERT INTO chado.dbxref VALUES (207, 32, 'related', '', NULL);
INSERT INTO chado.dbxref VALUES (208, 23, 'adjacent_to', '', NULL);
INSERT INTO chado.dbxref VALUES (209, 23, 'associated_with', '', NULL);
INSERT INTO chado.dbxref VALUES (210, 23, 'complete_evidence_for_feature', '', NULL);
INSERT INTO chado.dbxref VALUES (211, 23, 'is_a', '', NULL);
INSERT INTO chado.dbxref VALUES (212, 23, 'evidence_for_feature', '', NULL);
INSERT INTO chado.dbxref VALUES (213, 23, 'connects_on', '', NULL);
INSERT INTO chado.dbxref VALUES (214, 23, 'contained_by', '', NULL);
INSERT INTO chado.dbxref VALUES (215, 23, 'contains', '', NULL);
INSERT INTO chado.dbxref VALUES (216, 23, 'derives_from', '', NULL);
INSERT INTO chado.dbxref VALUES (217, 23, 'disconnected_from', '', NULL);
INSERT INTO chado.dbxref VALUES (218, 23, 'edited_from', '', NULL);
INSERT INTO chado.dbxref VALUES (219, 23, 'edited_to', '', NULL);
INSERT INTO chado.dbxref VALUES (220, 23, 'exemplar_of', '', NULL);
INSERT INTO chado.dbxref VALUES (221, 23, 'finished_by', '', NULL);
INSERT INTO chado.dbxref VALUES (222, 23, 'finishes', '', NULL);
INSERT INTO chado.dbxref VALUES (223, 23, 'gained', '', NULL);
INSERT INTO chado.dbxref VALUES (224, 23, 'genome_of', '', NULL);
INSERT INTO chado.dbxref VALUES (225, 23, 'guided_by', '', NULL);
INSERT INTO chado.dbxref VALUES (226, 23, 'guides', '', NULL);
INSERT INTO chado.dbxref VALUES (227, 23, 'has_integral_part', '', NULL);
INSERT INTO chado.dbxref VALUES (228, 23, 'has_part', '', NULL);
INSERT INTO chado.dbxref VALUES (229, 23, 'has_origin', '', NULL);
INSERT INTO chado.dbxref VALUES (230, 23, 'has_quality', '', NULL);
INSERT INTO chado.dbxref VALUES (231, 23, 'homologous_to', '', NULL);
INSERT INTO chado.dbxref VALUES (232, 23, 'similar_to', '', NULL);
INSERT INTO chado.dbxref VALUES (233, 23, 'integral_part_of', '', NULL);
INSERT INTO chado.dbxref VALUES (234, 23, 'part_of', '', NULL);
INSERT INTO chado.dbxref VALUES (235, 23, 'is_consecutive_sequence_of', '', NULL);
INSERT INTO chado.dbxref VALUES (236, 23, 'lost', '', NULL);
INSERT INTO chado.dbxref VALUES (237, 23, 'maximally_overlaps', '', NULL);
INSERT INTO chado.dbxref VALUES (238, 23, 'member_of', '', NULL);
INSERT INTO chado.dbxref VALUES (239, 23, 'non_functional_homolog_of', '', NULL);
INSERT INTO chado.dbxref VALUES (240, 23, 'orthologous_to', '', NULL);
INSERT INTO chado.dbxref VALUES (241, 23, 'overlaps', '', NULL);
INSERT INTO chado.dbxref VALUES (242, 23, 'paralogous_to', '', NULL);
INSERT INTO chado.dbxref VALUES (243, 23, 'partial_evidence_for_feature', '', NULL);
INSERT INTO chado.dbxref VALUES (244, 23, 'position_of', '', NULL);
INSERT INTO chado.dbxref VALUES (245, 23, 'processed_from', '', NULL);
INSERT INTO chado.dbxref VALUES (246, 23, 'processed_into', '', NULL);
INSERT INTO chado.dbxref VALUES (247, 23, 'recombined_from', '', NULL);
INSERT INTO chado.dbxref VALUES (248, 23, 'recombined_to', '', NULL);
INSERT INTO chado.dbxref VALUES (249, 23, 'sequence_of', '', NULL);
INSERT INTO chado.dbxref VALUES (250, 23, 'started_by', '', NULL);
INSERT INTO chado.dbxref VALUES (251, 23, 'starts', '', NULL);
INSERT INTO chado.dbxref VALUES (252, 23, 'trans_spliced_from', '', NULL);
INSERT INTO chado.dbxref VALUES (253, 23, 'trans_spliced_to', '', NULL);
INSERT INTO chado.dbxref VALUES (254, 23, 'transcribed_from', '', NULL);
INSERT INTO chado.dbxref VALUES (255, 23, 'transcribed_to', '', NULL);
INSERT INTO chado.dbxref VALUES (256, 23, 'translates_to', '', NULL);
INSERT INTO chado.dbxref VALUES (257, 23, 'translation_of', '', NULL);
INSERT INTO chado.dbxref VALUES (258, 23, 'variant_of', '', NULL);
INSERT INTO chado.dbxref VALUES (259, 23, '0000000', '', NULL);
INSERT INTO chado.dbxref VALUES (260, 23, '0000001', '', NULL);
INSERT INTO chado.dbxref VALUES (261, 23, '0000002', '', NULL);
INSERT INTO chado.dbxref VALUES (262, 23, '0001411', '', NULL);
INSERT INTO chado.dbxref VALUES (263, 23, '0000003', '', NULL);
INSERT INTO chado.dbxref VALUES (264, 23, '0000004', '', NULL);
INSERT INTO chado.dbxref VALUES (265, 23, '0000195', '', NULL);
INSERT INTO chado.dbxref VALUES (266, 23, '0000005', '', NULL);
INSERT INTO chado.dbxref VALUES (267, 23, '0000705', '', NULL);
INSERT INTO chado.dbxref VALUES (268, 23, '0000006', '', NULL);
INSERT INTO chado.dbxref VALUES (269, 23, '0000695', '', NULL);
INSERT INTO chado.dbxref VALUES (270, 23, '0000007', '', NULL);
INSERT INTO chado.dbxref VALUES (271, 23, '0000150', '', NULL);
INSERT INTO chado.dbxref VALUES (272, 23, '0000149', '', NULL);
INSERT INTO chado.dbxref VALUES (273, 23, '0001790', '', NULL);
INSERT INTO chado.dbxref VALUES (274, 23, '0000008', '', NULL);
INSERT INTO chado.dbxref VALUES (275, 23, '0000009', '', NULL);
INSERT INTO chado.dbxref VALUES (276, 23, '0000010', '', NULL);
INSERT INTO chado.dbxref VALUES (277, 23, '0000401', '', NULL);
INSERT INTO chado.dbxref VALUES (278, 23, '0000011', '', NULL);
INSERT INTO chado.dbxref VALUES (279, 23, '0000012', '', NULL);
INSERT INTO chado.dbxref VALUES (280, 23, '0000483', '', NULL);
INSERT INTO chado.dbxref VALUES (281, 23, '0000013', '', NULL);
INSERT INTO chado.dbxref VALUES (282, 23, '0000655', '', NULL);
INSERT INTO chado.dbxref VALUES (283, 23, '0000014', '', NULL);
INSERT INTO chado.dbxref VALUES (284, 23, '0001660', '', NULL);
INSERT INTO chado.dbxref VALUES (285, 23, '0001669', '', NULL);
INSERT INTO chado.dbxref VALUES (286, 23, '0000015', '', NULL);
INSERT INTO chado.dbxref VALUES (287, 23, '0000016', '', NULL);
INSERT INTO chado.dbxref VALUES (288, 23, '0000017', '', NULL);
INSERT INTO chado.dbxref VALUES (289, 23, '0000713', '', NULL);
INSERT INTO chado.dbxref VALUES (290, 23, '0000167', '', NULL);
INSERT INTO chado.dbxref VALUES (291, 23, '0000018', '', NULL);
INSERT INTO chado.dbxref VALUES (292, 23, '0000020', '', NULL);
INSERT INTO chado.dbxref VALUES (293, 23, '0000715', '', NULL);
INSERT INTO chado.dbxref VALUES (294, 23, '0000021', '', NULL);
INSERT INTO chado.dbxref VALUES (295, 23, '0000022', '', NULL);
INSERT INTO chado.dbxref VALUES (296, 23, '0000023', '', NULL);
INSERT INTO chado.dbxref VALUES (297, 23, '0000024', '', NULL);
INSERT INTO chado.dbxref VALUES (298, 23, '0000025', '', NULL);
INSERT INTO chado.dbxref VALUES (299, 23, '0000026', '', NULL);
INSERT INTO chado.dbxref VALUES (300, 23, '0000027', '', NULL);
INSERT INTO chado.dbxref VALUES (301, 23, '0000028', '', NULL);
INSERT INTO chado.dbxref VALUES (302, 23, '0000029', '', NULL);
INSERT INTO chado.dbxref VALUES (303, 23, '0000030', '', NULL);
INSERT INTO chado.dbxref VALUES (304, 23, '0000031', '', NULL);
INSERT INTO chado.dbxref VALUES (305, 23, '0000696', '', NULL);
INSERT INTO chado.dbxref VALUES (306, 23, '0000032', '', NULL);
INSERT INTO chado.dbxref VALUES (307, 23, '0000033', '', NULL);
INSERT INTO chado.dbxref VALUES (308, 23, '0000034', '', NULL);
INSERT INTO chado.dbxref VALUES (309, 23, '0001247', '', NULL);
INSERT INTO chado.dbxref VALUES (310, 23, '0001183', '', NULL);
INSERT INTO chado.dbxref VALUES (311, 23, '0000035', '', NULL);
INSERT INTO chado.dbxref VALUES (312, 23, '0000836', '', NULL);
INSERT INTO chado.dbxref VALUES (313, 23, '0000036', '', NULL);
INSERT INTO chado.dbxref VALUES (314, 23, '0000626', '', NULL);
INSERT INTO chado.dbxref VALUES (315, 23, '0000037', '', NULL);
INSERT INTO chado.dbxref VALUES (316, 23, '0000727', '', NULL);
INSERT INTO chado.dbxref VALUES (317, 23, '0000038', '', NULL);
INSERT INTO chado.dbxref VALUES (318, 23, '0000039', '', NULL);
INSERT INTO chado.dbxref VALUES (319, 23, '0001410', '', NULL);
INSERT INTO chado.dbxref VALUES (320, 23, '0000343', '', NULL);
INSERT INTO chado.dbxref VALUES (321, 23, '0000040', '', NULL);
INSERT INTO chado.dbxref VALUES (322, 23, '0000151', '', NULL);
INSERT INTO chado.dbxref VALUES (323, 23, '0000991', '', NULL);
INSERT INTO chado.dbxref VALUES (324, 23, '0000041', '', NULL);
INSERT INTO chado.dbxref VALUES (325, 23, '0000042', '', NULL);
INSERT INTO chado.dbxref VALUES (326, 23, '0000043', '', NULL);
INSERT INTO chado.dbxref VALUES (327, 23, '0000336', '', NULL);
INSERT INTO chado.dbxref VALUES (328, 23, '0000044', '', NULL);
INSERT INTO chado.dbxref VALUES (329, 23, '0001760', '', NULL);
INSERT INTO chado.dbxref VALUES (330, 23, '0000045', '', NULL);
INSERT INTO chado.dbxref VALUES (331, 23, '0000046', '', NULL);
INSERT INTO chado.dbxref VALUES (332, 23, '0000047', '', NULL);
INSERT INTO chado.dbxref VALUES (333, 23, '0000048', '', NULL);
INSERT INTO chado.dbxref VALUES (334, 23, '0000049', '', NULL);
INSERT INTO chado.dbxref VALUES (335, 23, '0000050', '', NULL);
INSERT INTO chado.dbxref VALUES (336, 23, '0000051', '', NULL);
INSERT INTO chado.dbxref VALUES (337, 23, '0000052', '', NULL);
INSERT INTO chado.dbxref VALUES (338, 23, '0000053', '', NULL);
INSERT INTO chado.dbxref VALUES (339, 23, '0000054', '', NULL);
INSERT INTO chado.dbxref VALUES (340, 23, '1000182', '', NULL);
INSERT INTO chado.dbxref VALUES (341, 23, '0000055', '', NULL);
INSERT INTO chado.dbxref VALUES (342, 23, '0000056', '', NULL);
INSERT INTO chado.dbxref VALUES (343, 23, '0000057', '', NULL);
INSERT INTO chado.dbxref VALUES (344, 23, '0001055', '', NULL);
INSERT INTO chado.dbxref VALUES (345, 23, '0000058', '', NULL);
INSERT INTO chado.dbxref VALUES (346, 23, '0000059', '', NULL);
INSERT INTO chado.dbxref VALUES (347, 23, '0001654', '', NULL);
INSERT INTO chado.dbxref VALUES (348, 23, '0000060', '', NULL);
INSERT INTO chado.dbxref VALUES (349, 23, '1000042', '', NULL);
INSERT INTO chado.dbxref VALUES (350, 23, '0000061', '', NULL);
INSERT INTO chado.dbxref VALUES (351, 23, '0000062', '', NULL);
INSERT INTO chado.dbxref VALUES (352, 23, '1000029', '', NULL);
INSERT INTO chado.dbxref VALUES (353, 23, '1000041', '', NULL);
INSERT INTO chado.dbxref VALUES (354, 23, '0000159', '', NULL);
INSERT INTO chado.dbxref VALUES (355, 23, '0000063', '', NULL);
INSERT INTO chado.dbxref VALUES (356, 23, '1000155', '', NULL);
INSERT INTO chado.dbxref VALUES (357, 23, '0000064', '', NULL);
INSERT INTO chado.dbxref VALUES (358, 23, '0000065', '', NULL);
INSERT INTO chado.dbxref VALUES (359, 23, '1000183', '', NULL);
INSERT INTO chado.dbxref VALUES (360, 23, '0000066', '', NULL);
INSERT INTO chado.dbxref VALUES (361, 23, '0000067', '', NULL);
INSERT INTO chado.dbxref VALUES (362, 23, '0000068', '', NULL);
INSERT INTO chado.dbxref VALUES (363, 23, '0000069', '', NULL);
INSERT INTO chado.dbxref VALUES (364, 23, '0000070', '', NULL);
INSERT INTO chado.dbxref VALUES (365, 23, '0000071', '', NULL);
INSERT INTO chado.dbxref VALUES (366, 23, '0000072', '', NULL);
INSERT INTO chado.dbxref VALUES (367, 23, '0000073', '', NULL);
INSERT INTO chado.dbxref VALUES (368, 23, '0000074', '', NULL);
INSERT INTO chado.dbxref VALUES (369, 23, '0000075', '', NULL);
INSERT INTO chado.dbxref VALUES (370, 23, '0000076', '', NULL);
INSERT INTO chado.dbxref VALUES (371, 23, '0000077', '', NULL);
INSERT INTO chado.dbxref VALUES (372, 23, '0000078', '', NULL);
INSERT INTO chado.dbxref VALUES (373, 23, '0000673', '', NULL);
INSERT INTO chado.dbxref VALUES (374, 23, '0000880', '', NULL);
INSERT INTO chado.dbxref VALUES (375, 23, '0000079', '', NULL);
INSERT INTO chado.dbxref VALUES (376, 23, '0000879', '', NULL);
INSERT INTO chado.dbxref VALUES (377, 23, '0000080', '', NULL);
INSERT INTO chado.dbxref VALUES (378, 23, '0000081', '', NULL);
INSERT INTO chado.dbxref VALUES (379, 23, '0000082', '', NULL);
INSERT INTO chado.dbxref VALUES (380, 23, '0000083', '', NULL);
INSERT INTO chado.dbxref VALUES (381, 23, '0000736', '', NULL);
INSERT INTO chado.dbxref VALUES (382, 23, '0000084', '', NULL);
INSERT INTO chado.dbxref VALUES (383, 23, '0000085', '', NULL);
INSERT INTO chado.dbxref VALUES (384, 23, '0000086', '', NULL);
INSERT INTO chado.dbxref VALUES (385, 23, '0000087', '', NULL);
INSERT INTO chado.dbxref VALUES (386, 23, '0000738', '', NULL);
INSERT INTO chado.dbxref VALUES (387, 23, '0000088', '', NULL);
INSERT INTO chado.dbxref VALUES (388, 23, '0000737', '', NULL);
INSERT INTO chado.dbxref VALUES (389, 23, '0000089', '', NULL);
INSERT INTO chado.dbxref VALUES (390, 23, '0000741', '', NULL);
INSERT INTO chado.dbxref VALUES (391, 23, '0000090', '', NULL);
INSERT INTO chado.dbxref VALUES (392, 23, '0000740', '', NULL);
INSERT INTO chado.dbxref VALUES (393, 23, '0000091', '', NULL);
INSERT INTO chado.dbxref VALUES (394, 23, '0000743', '', NULL);
INSERT INTO chado.dbxref VALUES (395, 23, '0000092', '', NULL);
INSERT INTO chado.dbxref VALUES (396, 23, '0000745', '', NULL);
INSERT INTO chado.dbxref VALUES (397, 23, '0000093', '', NULL);
INSERT INTO chado.dbxref VALUES (398, 23, '0000744', '', NULL);
INSERT INTO chado.dbxref VALUES (399, 23, '0000094', '', NULL);
INSERT INTO chado.dbxref VALUES (400, 23, '0000746', '', NULL);
INSERT INTO chado.dbxref VALUES (401, 23, '0000095', '', NULL);
INSERT INTO chado.dbxref VALUES (402, 23, '0000747', '', NULL);
INSERT INTO chado.dbxref VALUES (403, 23, '0000096', '', NULL);
INSERT INTO chado.dbxref VALUES (404, 23, '0000748', '', NULL);
INSERT INTO chado.dbxref VALUES (405, 23, '0000097', '', NULL);
INSERT INTO chado.dbxref VALUES (406, 23, '0000739', '', NULL);
INSERT INTO chado.dbxref VALUES (407, 23, '0000098', '', NULL);
INSERT INTO chado.dbxref VALUES (408, 23, '0000749', '', NULL);
INSERT INTO chado.dbxref VALUES (409, 23, '0000099', '', NULL);
INSERT INTO chado.dbxref VALUES (410, 23, '0000751', '', NULL);
INSERT INTO chado.dbxref VALUES (411, 23, '0000100', '', NULL);
INSERT INTO chado.dbxref VALUES (412, 23, '0000903', '', NULL);
INSERT INTO chado.dbxref VALUES (413, 23, '0000101', '', NULL);
INSERT INTO chado.dbxref VALUES (414, 23, '0001039', '', NULL);
INSERT INTO chado.dbxref VALUES (415, 23, '0000102', '', NULL);
INSERT INTO chado.dbxref VALUES (416, 23, '0000347', '', NULL);
INSERT INTO chado.dbxref VALUES (417, 23, '0000103', '', NULL);
INSERT INTO chado.dbxref VALUES (418, 23, '0000699', '', NULL);
INSERT INTO chado.dbxref VALUES (419, 23, '0000753', '', NULL);
INSERT INTO chado.dbxref VALUES (420, 23, '0000104', '', NULL);
INSERT INTO chado.dbxref VALUES (421, 23, '0000358', '', NULL);
INSERT INTO chado.dbxref VALUES (422, 23, '0000316', '', NULL);
INSERT INTO chado.dbxref VALUES (423, 23, '0000105', '', NULL);
INSERT INTO chado.dbxref VALUES (424, 23, '0000830', '', NULL);
INSERT INTO chado.dbxref VALUES (425, 23, '0000106', '', NULL);
INSERT INTO chado.dbxref VALUES (426, 23, '0000107', '', NULL);
INSERT INTO chado.dbxref VALUES (427, 23, '0000112', '', NULL);
INSERT INTO chado.dbxref VALUES (428, 23, '0000108', '', NULL);
INSERT INTO chado.dbxref VALUES (429, 23, '0000865', '', NULL);
INSERT INTO chado.dbxref VALUES (430, 23, '0000109', '', NULL);
INSERT INTO chado.dbxref VALUES (431, 23, '0000111', '', NULL);
INSERT INTO chado.dbxref VALUES (432, 23, '0000441', '', NULL);
INSERT INTO chado.dbxref VALUES (433, 23, '0000113', '', NULL);
INSERT INTO chado.dbxref VALUES (434, 23, '0000114', '', NULL);
INSERT INTO chado.dbxref VALUES (435, 23, '0000306', '', NULL);
INSERT INTO chado.dbxref VALUES (436, 23, '0001963', '', NULL);
INSERT INTO chado.dbxref VALUES (437, 23, '0000115', '', NULL);
INSERT INTO chado.dbxref VALUES (438, 23, '0000116', '', NULL);
INSERT INTO chado.dbxref VALUES (439, 23, '0000237', '', NULL);
INSERT INTO chado.dbxref VALUES (440, 23, '0000117', '', NULL);
INSERT INTO chado.dbxref VALUES (441, 23, '0000118', '', NULL);
INSERT INTO chado.dbxref VALUES (442, 23, '0000887', '', NULL);
INSERT INTO chado.dbxref VALUES (443, 23, '0000119', '', NULL);
INSERT INTO chado.dbxref VALUES (444, 23, '0000120', '', NULL);
INSERT INTO chado.dbxref VALUES (445, 23, '0000185', '', NULL);
INSERT INTO chado.dbxref VALUES (446, 23, '0000121', '', NULL);
INSERT INTO chado.dbxref VALUES (447, 23, '0001030', '', NULL);
INSERT INTO chado.dbxref VALUES (448, 23, '0000122', '', NULL);
INSERT INTO chado.dbxref VALUES (449, 23, '0000123', '', NULL);
INSERT INTO chado.dbxref VALUES (450, 23, '0000124', '', NULL);
INSERT INTO chado.dbxref VALUES (451, 23, '0000125', '', NULL);
INSERT INTO chado.dbxref VALUES (452, 23, '0000126', '', NULL);
INSERT INTO chado.dbxref VALUES (453, 23, '0000127', '', NULL);
INSERT INTO chado.dbxref VALUES (454, 23, '0000893', '', NULL);
INSERT INTO chado.dbxref VALUES (455, 23, '0000128', '', NULL);
INSERT INTO chado.dbxref VALUES (456, 23, '0000894', '', NULL);
INSERT INTO chado.dbxref VALUES (457, 23, '0000129', '', NULL);
INSERT INTO chado.dbxref VALUES (458, 23, '0000895', '', NULL);
INSERT INTO chado.dbxref VALUES (459, 23, '0000130', '', NULL);
INSERT INTO chado.dbxref VALUES (460, 23, '0000131', '', NULL);
INSERT INTO chado.dbxref VALUES (461, 23, '0000132', '', NULL);
INSERT INTO chado.dbxref VALUES (462, 23, '0001031', '', NULL);
INSERT INTO chado.dbxref VALUES (463, 23, '0000133', '', NULL);
INSERT INTO chado.dbxref VALUES (464, 23, '0000134', '', NULL);
INSERT INTO chado.dbxref VALUES (465, 23, '0000135', '', NULL);
INSERT INTO chado.dbxref VALUES (466, 23, '0000136', '', NULL);
INSERT INTO chado.dbxref VALUES (467, 23, '0000137', '', NULL);
INSERT INTO chado.dbxref VALUES (468, 23, '0000138', '', NULL);
INSERT INTO chado.dbxref VALUES (469, 23, '0000898', '', NULL);
INSERT INTO chado.dbxref VALUES (470, 23, '0000904', '', NULL);
INSERT INTO chado.dbxref VALUES (471, 23, '0000139', '', NULL);
INSERT INTO chado.dbxref VALUES (472, 23, '0000204', '', NULL);
INSERT INTO chado.dbxref VALUES (473, 23, '0000140', '', NULL);
INSERT INTO chado.dbxref VALUES (474, 23, '0001680', '', NULL);
INSERT INTO chado.dbxref VALUES (475, 23, '0000141', '', NULL);
INSERT INTO chado.dbxref VALUES (476, 23, '0000142', '', NULL);
INSERT INTO chado.dbxref VALUES (477, 23, '0000143', '', NULL);
INSERT INTO chado.dbxref VALUES (478, 23, '0000144', '', NULL);
INSERT INTO chado.dbxref VALUES (479, 23, '0000145', '', NULL);
INSERT INTO chado.dbxref VALUES (480, 23, '0000360', '', NULL);
INSERT INTO chado.dbxref VALUES (481, 23, '0000146', '', NULL);
INSERT INTO chado.dbxref VALUES (482, 23, '0000147', '', NULL);
INSERT INTO chado.dbxref VALUES (483, 23, '0000833', '', NULL);
INSERT INTO chado.dbxref VALUES (484, 23, '0000148', '', NULL);
INSERT INTO chado.dbxref VALUES (485, 23, '0001876', '', NULL);
INSERT INTO chado.dbxref VALUES (486, 23, '0000719', '', NULL);
INSERT INTO chado.dbxref VALUES (487, 23, '0000353', '', NULL);
INSERT INTO chado.dbxref VALUES (488, 23, '0000152', '', NULL);
INSERT INTO chado.dbxref VALUES (489, 23, '0000440', '', NULL);
INSERT INTO chado.dbxref VALUES (490, 23, '0000153', '', NULL);
INSERT INTO chado.dbxref VALUES (491, 23, '0000154', '', NULL);
INSERT INTO chado.dbxref VALUES (492, 23, '0000155', '', NULL);
INSERT INTO chado.dbxref VALUES (493, 23, '0001235', '', NULL);
INSERT INTO chado.dbxref VALUES (494, 23, '0000156', '', NULL);
INSERT INTO chado.dbxref VALUES (495, 23, '0000157', '', NULL);
INSERT INTO chado.dbxref VALUES (496, 23, '0000158', '', NULL);
INSERT INTO chado.dbxref VALUES (497, 23, '1000033', '', NULL);
INSERT INTO chado.dbxref VALUES (498, 33, 'LA6692-3', '', NULL);
INSERT INTO chado.dbxref VALUES (499, 23, '0001059', '', NULL);
INSERT INTO chado.dbxref VALUES (500, 23, '0000160', '', NULL);
INSERT INTO chado.dbxref VALUES (501, 23, '0000161', '', NULL);
INSERT INTO chado.dbxref VALUES (502, 23, '0001962', '', NULL);
INSERT INTO chado.dbxref VALUES (503, 23, '0000162', '', NULL);
INSERT INTO chado.dbxref VALUES (504, 23, '0000835', '', NULL);
INSERT INTO chado.dbxref VALUES (505, 23, '0000163', '', NULL);
INSERT INTO chado.dbxref VALUES (506, 23, '0001419', '', NULL);
INSERT INTO chado.dbxref VALUES (507, 23, '0000164', '', NULL);
INSERT INTO chado.dbxref VALUES (508, 23, '0000165', '', NULL);
INSERT INTO chado.dbxref VALUES (509, 23, '0000166', '', NULL);
INSERT INTO chado.dbxref VALUES (510, 23, '0000277', '', NULL);
INSERT INTO chado.dbxref VALUES (511, 23, '0000842', '', NULL);
INSERT INTO chado.dbxref VALUES (512, 23, '0000168', '', NULL);
INSERT INTO chado.dbxref VALUES (513, 23, '0000169', '', NULL);
INSERT INTO chado.dbxref VALUES (514, 23, '0002221', '', NULL);
INSERT INTO chado.dbxref VALUES (515, 23, '0000170', '', NULL);
INSERT INTO chado.dbxref VALUES (516, 23, '0000171', '', NULL);
INSERT INTO chado.dbxref VALUES (517, 23, '0000172', '', NULL);
INSERT INTO chado.dbxref VALUES (518, 23, '0000173', '', NULL);
INSERT INTO chado.dbxref VALUES (519, 23, '0001659', '', NULL);
INSERT INTO chado.dbxref VALUES (520, 23, '0000174', '', NULL);
INSERT INTO chado.dbxref VALUES (521, 23, '0000175', '', NULL);
INSERT INTO chado.dbxref VALUES (522, 23, '0001671', '', NULL);
INSERT INTO chado.dbxref VALUES (523, 23, '0001913', '', NULL);
INSERT INTO chado.dbxref VALUES (524, 23, '0000176', '', NULL);
INSERT INTO chado.dbxref VALUES (525, 23, '0000177', '', NULL);
INSERT INTO chado.dbxref VALUES (526, 23, '0000178', '', NULL);
INSERT INTO chado.dbxref VALUES (527, 23, '0005855', '', NULL);
INSERT INTO chado.dbxref VALUES (528, 23, '0000179', '', NULL);
INSERT INTO chado.dbxref VALUES (529, 23, '0000180', '', NULL);
INSERT INTO chado.dbxref VALUES (530, 23, '0000181', '', NULL);
INSERT INTO chado.dbxref VALUES (531, 23, '0000182', '', NULL);
INSERT INTO chado.dbxref VALUES (532, 23, '0000183', '', NULL);
INSERT INTO chado.dbxref VALUES (533, 23, '0000184', '', NULL);
INSERT INTO chado.dbxref VALUES (534, 23, '0000662', '', NULL);
INSERT INTO chado.dbxref VALUES (535, 23, '0000186', '', NULL);
INSERT INTO chado.dbxref VALUES (536, 23, '0000187', '', NULL);
INSERT INTO chado.dbxref VALUES (537, 23, '0000188', '', NULL);
INSERT INTO chado.dbxref VALUES (538, 23, '0000189', '', NULL);
INSERT INTO chado.dbxref VALUES (539, 23, '0000190', '', NULL);
INSERT INTO chado.dbxref VALUES (540, 23, '0000191', '', NULL);
INSERT INTO chado.dbxref VALUES (541, 23, '0000192', '', NULL);
INSERT INTO chado.dbxref VALUES (542, 23, '0000193', '', NULL);
INSERT INTO chado.dbxref VALUES (543, 23, '0000412', '', NULL);
INSERT INTO chado.dbxref VALUES (544, 23, '0000194', '', NULL);
INSERT INTO chado.dbxref VALUES (545, 23, '0000196', '', NULL);
INSERT INTO chado.dbxref VALUES (546, 23, '0001215', '', NULL);
INSERT INTO chado.dbxref VALUES (547, 23, '0000200', '', NULL);
INSERT INTO chado.dbxref VALUES (548, 23, '0000197', '', NULL);
INSERT INTO chado.dbxref VALUES (549, 23, '0000202', '', NULL);
INSERT INTO chado.dbxref VALUES (550, 23, '0000198', '', NULL);
INSERT INTO chado.dbxref VALUES (551, 23, '0000199', '', NULL);
INSERT INTO chado.dbxref VALUES (552, 23, '0001785', '', NULL);
INSERT INTO chado.dbxref VALUES (553, 23, '0000201', '', NULL);
INSERT INTO chado.dbxref VALUES (554, 23, '0000203', '', NULL);
INSERT INTO chado.dbxref VALUES (555, 23, '0000205', '', NULL);
INSERT INTO chado.dbxref VALUES (556, 23, '0000206', '', NULL);
INSERT INTO chado.dbxref VALUES (557, 23, '0000207', '', NULL);
INSERT INTO chado.dbxref VALUES (558, 23, '0000248', '', NULL);
INSERT INTO chado.dbxref VALUES (559, 23, '0000208', '', NULL);
INSERT INTO chado.dbxref VALUES (560, 23, '0000209', '', NULL);
INSERT INTO chado.dbxref VALUES (561, 23, '0000210', '', NULL);
INSERT INTO chado.dbxref VALUES (562, 23, '0000211', '', NULL);
INSERT INTO chado.dbxref VALUES (563, 23, '0000212', '', NULL);
INSERT INTO chado.dbxref VALUES (564, 23, '0000213', '', NULL);
INSERT INTO chado.dbxref VALUES (565, 23, '0000214', '', NULL);
INSERT INTO chado.dbxref VALUES (566, 23, '0000215', '', NULL);
INSERT INTO chado.dbxref VALUES (567, 23, '0000216', '', NULL);
INSERT INTO chado.dbxref VALUES (568, 23, '0000217', '', NULL);
INSERT INTO chado.dbxref VALUES (569, 23, '0000218', '', NULL);
INSERT INTO chado.dbxref VALUES (570, 23, '0000219', '', NULL);
INSERT INTO chado.dbxref VALUES (571, 23, '0000220', '', NULL);
INSERT INTO chado.dbxref VALUES (572, 23, '0000221', '', NULL);
INSERT INTO chado.dbxref VALUES (573, 23, '0000222', '', NULL);
INSERT INTO chado.dbxref VALUES (574, 23, '0000223', '', NULL);
INSERT INTO chado.dbxref VALUES (575, 23, '0000224', '', NULL);
INSERT INTO chado.dbxref VALUES (576, 23, '0000225', '', NULL);
INSERT INTO chado.dbxref VALUES (577, 23, '0000226', '', NULL);
INSERT INTO chado.dbxref VALUES (578, 23, '0000227', '', NULL);
INSERT INTO chado.dbxref VALUES (579, 23, '0000228', '', NULL);
INSERT INTO chado.dbxref VALUES (580, 23, '0000229', '', NULL);
INSERT INTO chado.dbxref VALUES (581, 23, '0000230', '', NULL);
INSERT INTO chado.dbxref VALUES (582, 23, '0000231', '', NULL);
INSERT INTO chado.dbxref VALUES (583, 23, '0000232', '', NULL);
INSERT INTO chado.dbxref VALUES (584, 23, '0000233', '', NULL);
INSERT INTO chado.dbxref VALUES (585, 23, '0000235', '', NULL);
INSERT INTO chado.dbxref VALUES (586, 23, '0000236', '', NULL);
INSERT INTO chado.dbxref VALUES (587, 23, '0000717', '', NULL);
INSERT INTO chado.dbxref VALUES (588, 23, '0000733', '', NULL);
INSERT INTO chado.dbxref VALUES (589, 23, '0000238', '', NULL);
INSERT INTO chado.dbxref VALUES (590, 23, '0000239', '', NULL);
INSERT INTO chado.dbxref VALUES (591, 23, '0001412', '', NULL);
INSERT INTO chado.dbxref VALUES (592, 23, '0000240', '', NULL);
INSERT INTO chado.dbxref VALUES (593, 23, '0001507', '', NULL);
INSERT INTO chado.dbxref VALUES (594, 23, '0001524', '', NULL);
INSERT INTO chado.dbxref VALUES (595, 23, '0000241', '', NULL);
INSERT INTO chado.dbxref VALUES (596, 23, '0000242', '', NULL);
INSERT INTO chado.dbxref VALUES (597, 23, '0000243', '', NULL);
INSERT INTO chado.dbxref VALUES (598, 23, '0000244', '', NULL);
INSERT INTO chado.dbxref VALUES (599, 23, '0000245', '', NULL);
INSERT INTO chado.dbxref VALUES (600, 23, '0000246', '', NULL);
INSERT INTO chado.dbxref VALUES (601, 23, '0000863', '', NULL);
INSERT INTO chado.dbxref VALUES (602, 23, '0000247', '', NULL);
INSERT INTO chado.dbxref VALUES (603, 23, '0000249', '', NULL);
INSERT INTO chado.dbxref VALUES (604, 23, '0000250', '', NULL);
INSERT INTO chado.dbxref VALUES (605, 23, '0001236', '', NULL);
INSERT INTO chado.dbxref VALUES (606, 23, '0000251', '', NULL);
INSERT INTO chado.dbxref VALUES (607, 23, '0000252', '', NULL);
INSERT INTO chado.dbxref VALUES (608, 23, '0000253', '', NULL);
INSERT INTO chado.dbxref VALUES (609, 23, '0002247', '', NULL);
INSERT INTO chado.dbxref VALUES (610, 23, '0000254', '', NULL);
INSERT INTO chado.dbxref VALUES (611, 23, '0000255', '', NULL);
INSERT INTO chado.dbxref VALUES (612, 23, '0000256', '', NULL);
INSERT INTO chado.dbxref VALUES (613, 23, '0000257', '', NULL);
INSERT INTO chado.dbxref VALUES (614, 23, '0000258', '', NULL);
INSERT INTO chado.dbxref VALUES (615, 23, '0000259', '', NULL);
INSERT INTO chado.dbxref VALUES (616, 23, '0000260', '', NULL);
INSERT INTO chado.dbxref VALUES (617, 23, '0000261', '', NULL);
INSERT INTO chado.dbxref VALUES (618, 23, '0000262', '', NULL);
INSERT INTO chado.dbxref VALUES (619, 23, '0000263', '', NULL);
INSERT INTO chado.dbxref VALUES (620, 23, '0000264', '', NULL);
INSERT INTO chado.dbxref VALUES (621, 23, '0000265', '', NULL);
INSERT INTO chado.dbxref VALUES (622, 23, '0000266', '', NULL);
INSERT INTO chado.dbxref VALUES (623, 23, '0000267', '', NULL);
INSERT INTO chado.dbxref VALUES (624, 23, '0000268', '', NULL);
INSERT INTO chado.dbxref VALUES (625, 23, '0000269', '', NULL);
INSERT INTO chado.dbxref VALUES (626, 23, '0000270', '', NULL);
INSERT INTO chado.dbxref VALUES (627, 23, '0000271', '', NULL);
INSERT INTO chado.dbxref VALUES (628, 23, '0000272', '', NULL);
INSERT INTO chado.dbxref VALUES (629, 23, '0000273', '', NULL);
INSERT INTO chado.dbxref VALUES (630, 23, '0000274', '', NULL);
INSERT INTO chado.dbxref VALUES (631, 23, '0000275', '', NULL);
INSERT INTO chado.dbxref VALUES (632, 23, '0000276', '', NULL);
INSERT INTO chado.dbxref VALUES (633, 23, '0000649', '', NULL);
INSERT INTO chado.dbxref VALUES (634, 23, '0000370', '', NULL);
INSERT INTO chado.dbxref VALUES (635, 23, '0001244', '', NULL);
INSERT INTO chado.dbxref VALUES (636, 23, '0000278', '', NULL);
INSERT INTO chado.dbxref VALUES (637, 23, '0000876', '', NULL);
INSERT INTO chado.dbxref VALUES (638, 23, '0000279', '', NULL);
INSERT INTO chado.dbxref VALUES (639, 23, '0000875', '', NULL);
INSERT INTO chado.dbxref VALUES (640, 23, '0000280', '', NULL);
INSERT INTO chado.dbxref VALUES (641, 23, '0000804', '', NULL);
INSERT INTO chado.dbxref VALUES (642, 23, '0000783', '', NULL);
INSERT INTO chado.dbxref VALUES (643, 23, '0000281', '', NULL);
INSERT INTO chado.dbxref VALUES (644, 23, '0000285', '', NULL);
INSERT INTO chado.dbxref VALUES (645, 23, '0000805', '', NULL);
INSERT INTO chado.dbxref VALUES (646, 23, '0000784', '', NULL);
INSERT INTO chado.dbxref VALUES (647, 23, '0000282', '', NULL);
INSERT INTO chado.dbxref VALUES (648, 23, '0000866', '', NULL);
INSERT INTO chado.dbxref VALUES (649, 23, '0000283', '', NULL);
INSERT INTO chado.dbxref VALUES (650, 23, '0000284', '', NULL);
INSERT INTO chado.dbxref VALUES (651, 23, '0000286', '', NULL);
INSERT INTO chado.dbxref VALUES (652, 23, '0000657', '', NULL);
INSERT INTO chado.dbxref VALUES (653, 23, '0000287', '', NULL);
INSERT INTO chado.dbxref VALUES (654, 23, '0000806', '', NULL);
INSERT INTO chado.dbxref VALUES (655, 23, '0000288', '', NULL);
INSERT INTO chado.dbxref VALUES (656, 23, '0000289', '', NULL);
INSERT INTO chado.dbxref VALUES (657, 23, '0000290', '', NULL);
INSERT INTO chado.dbxref VALUES (658, 23, '0000291', '', NULL);
INSERT INTO chado.dbxref VALUES (659, 23, '0000292', '', NULL);
INSERT INTO chado.dbxref VALUES (660, 23, '0000293', '', NULL);
INSERT INTO chado.dbxref VALUES (661, 23, '0000294', '', NULL);
INSERT INTO chado.dbxref VALUES (662, 23, '0000295', '', NULL);
INSERT INTO chado.dbxref VALUES (663, 23, '0000296', '', NULL);
INSERT INTO chado.dbxref VALUES (664, 23, '0000297', '', NULL);
INSERT INTO chado.dbxref VALUES (665, 23, '0000298', '', NULL);
INSERT INTO chado.dbxref VALUES (666, 23, '0000299', '', NULL);
INSERT INTO chado.dbxref VALUES (667, 23, '0000669', '', NULL);
INSERT INTO chado.dbxref VALUES (668, 23, '0000300', '', NULL);
INSERT INTO chado.dbxref VALUES (669, 23, '0000301', '', NULL);
INSERT INTO chado.dbxref VALUES (670, 23, '0000302', '', NULL);
INSERT INTO chado.dbxref VALUES (671, 23, '0000939', '', NULL);
INSERT INTO chado.dbxref VALUES (672, 23, '0000303', '', NULL);
INSERT INTO chado.dbxref VALUES (673, 23, '0000304', '', NULL);
INSERT INTO chado.dbxref VALUES (674, 23, '0000305', '', NULL);
INSERT INTO chado.dbxref VALUES (675, 23, '0001720', '', NULL);
INSERT INTO chado.dbxref VALUES (676, 23, '0000307', '', NULL);
INSERT INTO chado.dbxref VALUES (677, 23, '0000308', '', NULL);
INSERT INTO chado.dbxref VALUES (678, 23, '0000309', '', NULL);
INSERT INTO chado.dbxref VALUES (679, 23, '0000310', '', NULL);
INSERT INTO chado.dbxref VALUES (680, 23, '0000311', '', NULL);
INSERT INTO chado.dbxref VALUES (681, 23, '0000312', '', NULL);
INSERT INTO chado.dbxref VALUES (682, 23, '0000789', '', NULL);
INSERT INTO chado.dbxref VALUES (683, 23, '0000313', '', NULL);
INSERT INTO chado.dbxref VALUES (684, 23, '0000019', '', NULL);
INSERT INTO chado.dbxref VALUES (685, 23, '0000314', '', NULL);
INSERT INTO chado.dbxref VALUES (686, 23, '0000315', '', NULL);
INSERT INTO chado.dbxref VALUES (687, 23, '0002309', '', NULL);
INSERT INTO chado.dbxref VALUES (688, 23, '0000317', '', NULL);
INSERT INTO chado.dbxref VALUES (689, 23, '0000756', '', NULL);
INSERT INTO chado.dbxref VALUES (690, 23, '0000318', '', NULL);
INSERT INTO chado.dbxref VALUES (691, 23, '0000319', '', NULL);
INSERT INTO chado.dbxref VALUES (692, 23, '0000320', '', NULL);
INSERT INTO chado.dbxref VALUES (693, 23, '0000344', '', NULL);
INSERT INTO chado.dbxref VALUES (694, 23, '0000841', '', NULL);
INSERT INTO chado.dbxref VALUES (695, 23, '0000321', '', NULL);
INSERT INTO chado.dbxref VALUES (696, 23, '0000868', '', NULL);
INSERT INTO chado.dbxref VALUES (697, 23, '0000322', '', NULL);
INSERT INTO chado.dbxref VALUES (698, 23, '0000684', '', NULL);
INSERT INTO chado.dbxref VALUES (699, 23, '0002331', '', NULL);
INSERT INTO chado.dbxref VALUES (700, 23, '0000323', '', NULL);
INSERT INTO chado.dbxref VALUES (701, 23, '0000851', '', NULL);
INSERT INTO chado.dbxref VALUES (702, 23, '0000324', '', NULL);
INSERT INTO chado.dbxref VALUES (703, 23, '0000325', '', NULL);
INSERT INTO chado.dbxref VALUES (704, 23, '0000326', '', NULL);
INSERT INTO chado.dbxref VALUES (705, 23, '0000327', '', NULL);
INSERT INTO chado.dbxref VALUES (706, 23, '0000328', '', NULL);
INSERT INTO chado.dbxref VALUES (707, 23, '0000329', '', NULL);
INSERT INTO chado.dbxref VALUES (708, 23, '0000869', '', NULL);
INSERT INTO chado.dbxref VALUES (709, 23, '0000330', '', NULL);
INSERT INTO chado.dbxref VALUES (710, 23, '0000331', '', NULL);
INSERT INTO chado.dbxref VALUES (711, 23, '0000332', '', NULL);
INSERT INTO chado.dbxref VALUES (712, 23, '0000333', '', NULL);
INSERT INTO chado.dbxref VALUES (713, 23, '0000334', '', NULL);
INSERT INTO chado.dbxref VALUES (714, 23, '0000335', '', NULL);
INSERT INTO chado.dbxref VALUES (715, 23, '0000867', '', NULL);
INSERT INTO chado.dbxref VALUES (716, 23, '0000337', '', NULL);
INSERT INTO chado.dbxref VALUES (717, 23, '0000442', '', NULL);
INSERT INTO chado.dbxref VALUES (718, 23, '0000338', '', NULL);
INSERT INTO chado.dbxref VALUES (719, 23, '0000339', '', NULL);
INSERT INTO chado.dbxref VALUES (720, 23, '0000340', '', NULL);
INSERT INTO chado.dbxref VALUES (721, 23, '0000341', '', NULL);
INSERT INTO chado.dbxref VALUES (722, 23, '0000342', '', NULL);
INSERT INTO chado.dbxref VALUES (723, 23, '0001056', '', NULL);
INSERT INTO chado.dbxref VALUES (724, 23, '0000345', '', NULL);
INSERT INTO chado.dbxref VALUES (725, 23, '0000346', '', NULL);
INSERT INTO chado.dbxref VALUES (726, 23, '0000947', '', NULL);
INSERT INTO chado.dbxref VALUES (727, 23, '0000348', '', NULL);
INSERT INTO chado.dbxref VALUES (728, 23, '0000443', '', NULL);
INSERT INTO chado.dbxref VALUES (729, 23, '0000349', '', NULL);
INSERT INTO chado.dbxref VALUES (730, 23, '0000350', '', NULL);
INSERT INTO chado.dbxref VALUES (731, 23, '0000948', '', NULL);
INSERT INTO chado.dbxref VALUES (732, 23, '0000351', '', NULL);
INSERT INTO chado.dbxref VALUES (733, 23, '0000352', '', NULL);
INSERT INTO chado.dbxref VALUES (734, 23, '0001248', '', NULL);
INSERT INTO chado.dbxref VALUES (735, 23, '0000354', '', NULL);
INSERT INTO chado.dbxref VALUES (736, 23, '0000355', '', NULL);
INSERT INTO chado.dbxref VALUES (737, 23, '0000356', '', NULL);
INSERT INTO chado.dbxref VALUES (738, 23, '0000357', '', NULL);
INSERT INTO chado.dbxref VALUES (739, 23, '0000359', '', NULL);
INSERT INTO chado.dbxref VALUES (740, 23, '0000361', '', NULL);
INSERT INTO chado.dbxref VALUES (741, 23, '0000362', '', NULL);
INSERT INTO chado.dbxref VALUES (742, 23, '0000790', '', NULL);
INSERT INTO chado.dbxref VALUES (743, 23, '0000363', '', NULL);
INSERT INTO chado.dbxref VALUES (744, 23, '0000902', '', NULL);
INSERT INTO chado.dbxref VALUES (745, 23, '0000364', '', NULL);
INSERT INTO chado.dbxref VALUES (746, 23, '0000365', '', NULL);
INSERT INTO chado.dbxref VALUES (747, 23, '0000366', '', NULL);
INSERT INTO chado.dbxref VALUES (748, 23, '0000367', '', NULL);
INSERT INTO chado.dbxref VALUES (749, 23, '0000946', '', NULL);
INSERT INTO chado.dbxref VALUES (750, 23, '0000368', '', NULL);
INSERT INTO chado.dbxref VALUES (751, 23, '0000369', '', NULL);
INSERT INTO chado.dbxref VALUES (752, 23, '0000371', '', NULL);
INSERT INTO chado.dbxref VALUES (753, 23, '0000372', '', NULL);
INSERT INTO chado.dbxref VALUES (754, 23, '0001185', '', NULL);
INSERT INTO chado.dbxref VALUES (755, 23, '0000373', '', NULL);
INSERT INTO chado.dbxref VALUES (756, 23, '0000456', '', NULL);
INSERT INTO chado.dbxref VALUES (757, 23, '1000036', '', NULL);
INSERT INTO chado.dbxref VALUES (758, 23, '0000374', '', NULL);
INSERT INTO chado.dbxref VALUES (759, 23, '0001186', '', NULL);
INSERT INTO chado.dbxref VALUES (760, 23, '0000375', '', NULL);
INSERT INTO chado.dbxref VALUES (761, 23, '0000651', '', NULL);
INSERT INTO chado.dbxref VALUES (762, 23, '0002240', '', NULL);
INSERT INTO chado.dbxref VALUES (763, 23, '0000376', '', NULL);
INSERT INTO chado.dbxref VALUES (764, 23, '0000377', '', NULL);
INSERT INTO chado.dbxref VALUES (765, 23, '0000378', '', NULL);
INSERT INTO chado.dbxref VALUES (766, 23, '0000379', '', NULL);
INSERT INTO chado.dbxref VALUES (767, 23, '0000380', '', NULL);
INSERT INTO chado.dbxref VALUES (768, 23, '0000381', '', NULL);
INSERT INTO chado.dbxref VALUES (769, 23, '0000603', '', NULL);
INSERT INTO chado.dbxref VALUES (770, 23, '0000382', '', NULL);
INSERT INTO chado.dbxref VALUES (771, 23, '0000383', '', NULL);
INSERT INTO chado.dbxref VALUES (772, 23, '0000644', '', NULL);
INSERT INTO chado.dbxref VALUES (773, 23, '0000384', '', NULL);
INSERT INTO chado.dbxref VALUES (774, 23, '0000385', '', NULL);
INSERT INTO chado.dbxref VALUES (775, 23, '0000386', '', NULL);
INSERT INTO chado.dbxref VALUES (776, 23, '0000387', '', NULL);
INSERT INTO chado.dbxref VALUES (777, 23, '0000388', '', NULL);
INSERT INTO chado.dbxref VALUES (778, 23, '0000389', '', NULL);
INSERT INTO chado.dbxref VALUES (779, 23, '0000390', '', NULL);
INSERT INTO chado.dbxref VALUES (780, 23, '0000391', '', NULL);
INSERT INTO chado.dbxref VALUES (781, 23, '0000392', '', NULL);
INSERT INTO chado.dbxref VALUES (782, 23, '0000393', '', NULL);
INSERT INTO chado.dbxref VALUES (783, 23, '0000394', '', NULL);
INSERT INTO chado.dbxref VALUES (784, 23, '0000395', '', NULL);
INSERT INTO chado.dbxref VALUES (785, 23, '0000396', '', NULL);
INSERT INTO chado.dbxref VALUES (786, 23, '0000397', '', NULL);
INSERT INTO chado.dbxref VALUES (787, 23, '0000398', '', NULL);
INSERT INTO chado.dbxref VALUES (788, 23, '0000399', '', NULL);
INSERT INTO chado.dbxref VALUES (789, 23, '0000400', '', NULL);
INSERT INTO chado.dbxref VALUES (790, 23, '0000402', '', NULL);
INSERT INTO chado.dbxref VALUES (791, 23, '0000403', '', NULL);
INSERT INTO chado.dbxref VALUES (792, 23, '0005839', '', NULL);
INSERT INTO chado.dbxref VALUES (793, 23, '0000593', '', NULL);
INSERT INTO chado.dbxref VALUES (794, 23, '0005837', '', NULL);
INSERT INTO chado.dbxref VALUES (795, 23, '0000404', '', NULL);
INSERT INTO chado.dbxref VALUES (796, 23, '0000405', '', NULL);
INSERT INTO chado.dbxref VALUES (797, 23, '0000406', '', NULL);
INSERT INTO chado.dbxref VALUES (798, 23, '0000407', '', NULL);
INSERT INTO chado.dbxref VALUES (799, 23, '0000650', '', NULL);
INSERT INTO chado.dbxref VALUES (800, 23, '0002236', '', NULL);
INSERT INTO chado.dbxref VALUES (801, 23, '0000408', '', NULL);
INSERT INTO chado.dbxref VALUES (802, 23, '0000409', '', NULL);
INSERT INTO chado.dbxref VALUES (803, 34, '00033', '', NULL);
INSERT INTO chado.dbxref VALUES (804, 23, '0000410', '', NULL);
INSERT INTO chado.dbxref VALUES (805, 23, '0000411', '', NULL);
INSERT INTO chado.dbxref VALUES (806, 23, '0000814', '', NULL);
INSERT INTO chado.dbxref VALUES (807, 23, '0000413', '', NULL);
INSERT INTO chado.dbxref VALUES (808, 23, '0000700', '', NULL);
INSERT INTO chado.dbxref VALUES (809, 23, '0000414', '', NULL);
INSERT INTO chado.dbxref VALUES (810, 23, '0000415', '', NULL);
INSERT INTO chado.dbxref VALUES (811, 23, '0000416', '', NULL);
INSERT INTO chado.dbxref VALUES (812, 23, '0000417', '', NULL);
INSERT INTO chado.dbxref VALUES (813, 34, '00012', '', NULL);
INSERT INTO chado.dbxref VALUES (814, 34, '00134', '', NULL);
INSERT INTO chado.dbxref VALUES (815, 23, '0001069', '', NULL);
INSERT INTO chado.dbxref VALUES (816, 23, '0001070', '', NULL);
INSERT INTO chado.dbxref VALUES (817, 23, '0100021', '', NULL);
INSERT INTO chado.dbxref VALUES (818, 23, '0000418', '', NULL);
INSERT INTO chado.dbxref VALUES (819, 34, '00159', '', NULL);
INSERT INTO chado.dbxref VALUES (820, 23, '0001527', '', NULL);
INSERT INTO chado.dbxref VALUES (821, 23, '0002251', '', NULL);
INSERT INTO chado.dbxref VALUES (822, 23, '0001062', '', NULL);
INSERT INTO chado.dbxref VALUES (823, 23, '0000419', '', NULL);
INSERT INTO chado.dbxref VALUES (824, 34, '00149', '', NULL);
INSERT INTO chado.dbxref VALUES (825, 23, '0000839', '', NULL);
INSERT INTO chado.dbxref VALUES (826, 23, '0002249', '', NULL);
INSERT INTO chado.dbxref VALUES (827, 23, '0001063', '', NULL);
INSERT INTO chado.dbxref VALUES (828, 23, '0000420', '', NULL);
INSERT INTO chado.dbxref VALUES (829, 23, '0000481', '', NULL);
INSERT INTO chado.dbxref VALUES (830, 23, '0000421', '', NULL);
INSERT INTO chado.dbxref VALUES (831, 23, '0000422', '', NULL);
INSERT INTO chado.dbxref VALUES (832, 23, '0000848', '', NULL);
INSERT INTO chado.dbxref VALUES (833, 23, '0000423', '', NULL);
INSERT INTO chado.dbxref VALUES (834, 23, '0000424', '', NULL);
INSERT INTO chado.dbxref VALUES (835, 23, '0000425', '', NULL);
INSERT INTO chado.dbxref VALUES (836, 23, '0000426', '', NULL);
INSERT INTO chado.dbxref VALUES (837, 23, '0000427', '', NULL);
INSERT INTO chado.dbxref VALUES (838, 23, '0000850', '', NULL);
INSERT INTO chado.dbxref VALUES (839, 23, '0000428', '', NULL);
INSERT INTO chado.dbxref VALUES (840, 23, '0000429', '', NULL);
INSERT INTO chado.dbxref VALUES (841, 23, '0000430', '', NULL);
INSERT INTO chado.dbxref VALUES (842, 23, '0000849', '', NULL);
INSERT INTO chado.dbxref VALUES (843, 23, '0000431', '', NULL);
INSERT INTO chado.dbxref VALUES (844, 23, '0000432', '', NULL);
INSERT INTO chado.dbxref VALUES (845, 23, '0000433', '', NULL);
INSERT INTO chado.dbxref VALUES (846, 23, '0000840', '', NULL);
INSERT INTO chado.dbxref VALUES (847, 23, '0000434', '', NULL);
INSERT INTO chado.dbxref VALUES (848, 23, '0000435', '', NULL);
INSERT INTO chado.dbxref VALUES (849, 23, '0000436', '', NULL);
INSERT INTO chado.dbxref VALUES (850, 23, '0000437', '', NULL);
INSERT INTO chado.dbxref VALUES (851, 23, '0000438', '', NULL);
INSERT INTO chado.dbxref VALUES (852, 23, '0000439', '', NULL);
INSERT INTO chado.dbxref VALUES (853, 23, '1000030', '', NULL);
INSERT INTO chado.dbxref VALUES (854, 23, '1000045', '', NULL);
INSERT INTO chado.dbxref VALUES (855, 23, '0000444', '', NULL);
INSERT INTO chado.dbxref VALUES (856, 23, '0000445', '', NULL);
INSERT INTO chado.dbxref VALUES (857, 23, '0000446', '', NULL);
INSERT INTO chado.dbxref VALUES (858, 23, '0000447', '', NULL);
INSERT INTO chado.dbxref VALUES (859, 23, '0000448', '', NULL);
INSERT INTO chado.dbxref VALUES (860, 23, '0000449', '', NULL);
INSERT INTO chado.dbxref VALUES (861, 23, '0000450', '', NULL);
INSERT INTO chado.dbxref VALUES (862, 23, '0000451', '', NULL);
INSERT INTO chado.dbxref VALUES (863, 23, '0001217', '', NULL);
INSERT INTO chado.dbxref VALUES (864, 23, '0000871', '', NULL);
INSERT INTO chado.dbxref VALUES (865, 23, '0000452', '', NULL);
INSERT INTO chado.dbxref VALUES (866, 23, '0000453', '', NULL);
INSERT INTO chado.dbxref VALUES (867, 23, '0000454', '', NULL);
INSERT INTO chado.dbxref VALUES (868, 23, '0001035', '', NULL);
INSERT INTO chado.dbxref VALUES (869, 23, '0000455', '', NULL);
INSERT INTO chado.dbxref VALUES (870, 23, '0000940', '', NULL);
INSERT INTO chado.dbxref VALUES (871, 23, '0000457', '', NULL);
INSERT INTO chado.dbxref VALUES (872, 23, '1000037', '', NULL);
INSERT INTO chado.dbxref VALUES (873, 23, '0000458', '', NULL);
INSERT INTO chado.dbxref VALUES (874, 23, '0000460', '', NULL);
INSERT INTO chado.dbxref VALUES (875, 23, '0000459', '', NULL);
INSERT INTO chado.dbxref VALUES (876, 23, '0000479', '', NULL);
INSERT INTO chado.dbxref VALUES (877, 23, '0000461', '', NULL);
INSERT INTO chado.dbxref VALUES (878, 23, '0000462', '', NULL);
INSERT INTO chado.dbxref VALUES (879, 23, '0000463', '', NULL);
INSERT INTO chado.dbxref VALUES (880, 23, '0000464', '', NULL);
INSERT INTO chado.dbxref VALUES (881, 23, '0000465', '', NULL);
INSERT INTO chado.dbxref VALUES (882, 23, '1000038', '', NULL);
INSERT INTO chado.dbxref VALUES (883, 23, '0000466', '', NULL);
INSERT INTO chado.dbxref VALUES (884, 23, '0000467', '', NULL);
INSERT INTO chado.dbxref VALUES (885, 23, '0000468', '', NULL);
INSERT INTO chado.dbxref VALUES (886, 23, '0000688', '', NULL);
INSERT INTO chado.dbxref VALUES (887, 23, '0000469', '', NULL);
INSERT INTO chado.dbxref VALUES (888, 23, '0000470', '', NULL);
INSERT INTO chado.dbxref VALUES (889, 23, '0000471', '', NULL);
INSERT INTO chado.dbxref VALUES (890, 23, '0000472', '', NULL);
INSERT INTO chado.dbxref VALUES (891, 23, '0000473', '', NULL);
INSERT INTO chado.dbxref VALUES (892, 23, '0000474', '', NULL);
INSERT INTO chado.dbxref VALUES (893, 23, '0000475', '', NULL);
INSERT INTO chado.dbxref VALUES (894, 23, '0000476', '', NULL);
INSERT INTO chado.dbxref VALUES (895, 23, '0000477', '', NULL);
INSERT INTO chado.dbxref VALUES (896, 23, '0000478', '', NULL);
INSERT INTO chado.dbxref VALUES (897, 23, '0000870', '', NULL);
INSERT INTO chado.dbxref VALUES (898, 23, '0000480', '', NULL);
INSERT INTO chado.dbxref VALUES (899, 23, '0000482', '', NULL);
INSERT INTO chado.dbxref VALUES (900, 23, '0000484', '', NULL);
INSERT INTO chado.dbxref VALUES (901, 23, '0001214', '', NULL);
INSERT INTO chado.dbxref VALUES (902, 23, '0000485', '', NULL);
INSERT INTO chado.dbxref VALUES (903, 23, '0000938', '', NULL);
INSERT INTO chado.dbxref VALUES (904, 23, '0000572', '', NULL);
INSERT INTO chado.dbxref VALUES (905, 23, '0000486', '', NULL);
INSERT INTO chado.dbxref VALUES (906, 23, '0000487', '', NULL);
INSERT INTO chado.dbxref VALUES (907, 23, '0000574', '', NULL);
INSERT INTO chado.dbxref VALUES (908, 23, '0000488', '', NULL);
INSERT INTO chado.dbxref VALUES (909, 23, '0000489', '', NULL);
INSERT INTO chado.dbxref VALUES (910, 23, '0000576', '', NULL);
INSERT INTO chado.dbxref VALUES (911, 23, '0000490', '', NULL);
INSERT INTO chado.dbxref VALUES (912, 23, '0000491', '', NULL);
INSERT INTO chado.dbxref VALUES (913, 23, '0000492', '', NULL);
INSERT INTO chado.dbxref VALUES (914, 23, '0000493', '', NULL);
INSERT INTO chado.dbxref VALUES (915, 23, '0000561', '', NULL);
INSERT INTO chado.dbxref VALUES (916, 23, '0000570', '', NULL);
INSERT INTO chado.dbxref VALUES (917, 23, '0000494', '', NULL);
INSERT INTO chado.dbxref VALUES (918, 23, '0000562', '', NULL);
INSERT INTO chado.dbxref VALUES (919, 23, '0000495', '', NULL);
INSERT INTO chado.dbxref VALUES (920, 23, '0000563', '', NULL);
INSERT INTO chado.dbxref VALUES (921, 23, '0000496', '', NULL);
INSERT INTO chado.dbxref VALUES (922, 23, '0000556', '', NULL);
INSERT INTO chado.dbxref VALUES (923, 23, '0000497', '', NULL);
INSERT INTO chado.dbxref VALUES (924, 23, '0000498', '', NULL);
INSERT INTO chado.dbxref VALUES (925, 23, '0000499', '', NULL);
INSERT INTO chado.dbxref VALUES (926, 23, '0000500', '', NULL);
INSERT INTO chado.dbxref VALUES (927, 23, '0000501', '', NULL);
INSERT INTO chado.dbxref VALUES (928, 23, '0000502', '', NULL);
INSERT INTO chado.dbxref VALUES (929, 23, '0000503', '', NULL);
INSERT INTO chado.dbxref VALUES (930, 23, '0000504', '', NULL);
INSERT INTO chado.dbxref VALUES (931, 23, '0000505', '', NULL);
INSERT INTO chado.dbxref VALUES (932, 23, '0000506', '', NULL);
INSERT INTO chado.dbxref VALUES (933, 23, '0000507', '', NULL);
INSERT INTO chado.dbxref VALUES (934, 23, '0000516', '', NULL);
INSERT INTO chado.dbxref VALUES (935, 23, '0000508', '', NULL);
INSERT INTO chado.dbxref VALUES (936, 23, '0000509', '', NULL);
INSERT INTO chado.dbxref VALUES (937, 23, '0000510', '', NULL);
INSERT INTO chado.dbxref VALUES (938, 23, '0000936', '', NULL);
INSERT INTO chado.dbxref VALUES (939, 23, '0000511', '', NULL);
INSERT INTO chado.dbxref VALUES (940, 23, '0000512', '', NULL);
INSERT INTO chado.dbxref VALUES (941, 23, '0000513', '', NULL);
INSERT INTO chado.dbxref VALUES (942, 23, '0000514', '', NULL);
INSERT INTO chado.dbxref VALUES (943, 23, '0000515', '', NULL);
INSERT INTO chado.dbxref VALUES (944, 23, '0000517', '', NULL);
INSERT INTO chado.dbxref VALUES (945, 23, '0000518', '', NULL);
INSERT INTO chado.dbxref VALUES (946, 23, '0000519', '', NULL);
INSERT INTO chado.dbxref VALUES (947, 23, '0000520', '', NULL);
INSERT INTO chado.dbxref VALUES (948, 23, '0000521', '', NULL);
INSERT INTO chado.dbxref VALUES (949, 23, '0000522', '', NULL);
INSERT INTO chado.dbxref VALUES (950, 23, '0000523', '', NULL);
INSERT INTO chado.dbxref VALUES (951, 23, '0000524', '', NULL);
INSERT INTO chado.dbxref VALUES (952, 23, '0000525', '', NULL);
INSERT INTO chado.dbxref VALUES (953, 23, '0000526', '', NULL);
INSERT INTO chado.dbxref VALUES (954, 23, '0000527', '', NULL);
INSERT INTO chado.dbxref VALUES (955, 23, '0000528', '', NULL);
INSERT INTO chado.dbxref VALUES (956, 23, '0000529', '', NULL);
INSERT INTO chado.dbxref VALUES (957, 23, '0000530', '', NULL);
INSERT INTO chado.dbxref VALUES (958, 23, '0000531', '', NULL);
INSERT INTO chado.dbxref VALUES (959, 23, '0000532', '', NULL);
INSERT INTO chado.dbxref VALUES (960, 23, '0000533', '', NULL);
INSERT INTO chado.dbxref VALUES (961, 23, '0000538', '', NULL);
INSERT INTO chado.dbxref VALUES (962, 23, '0000534', '', NULL);
INSERT INTO chado.dbxref VALUES (963, 23, '0000535', '', NULL);
INSERT INTO chado.dbxref VALUES (964, 23, '0000536', '', NULL);
INSERT INTO chado.dbxref VALUES (965, 23, '0000537', '', NULL);
INSERT INTO chado.dbxref VALUES (966, 23, '0000539', '', NULL);
INSERT INTO chado.dbxref VALUES (967, 23, '0000540', '', NULL);
INSERT INTO chado.dbxref VALUES (968, 23, '0000541', '', NULL);
INSERT INTO chado.dbxref VALUES (969, 23, '0000542', '', NULL);
INSERT INTO chado.dbxref VALUES (970, 23, '0000543', '', NULL);
INSERT INTO chado.dbxref VALUES (971, 23, '0000544', '', NULL);
INSERT INTO chado.dbxref VALUES (972, 23, '0000545', '', NULL);
INSERT INTO chado.dbxref VALUES (973, 23, '0000591', '', NULL);
INSERT INTO chado.dbxref VALUES (974, 23, '1001268', '', NULL);
INSERT INTO chado.dbxref VALUES (975, 23, '0000546', '', NULL);
INSERT INTO chado.dbxref VALUES (976, 23, '0000547', '', NULL);
INSERT INTO chado.dbxref VALUES (977, 23, '0000548', '', NULL);
INSERT INTO chado.dbxref VALUES (978, 23, '0000873', '', NULL);
INSERT INTO chado.dbxref VALUES (979, 23, '0000549', '', NULL);
INSERT INTO chado.dbxref VALUES (980, 23, '0000550', '', NULL);
INSERT INTO chado.dbxref VALUES (981, 23, '0000551', '', NULL);
INSERT INTO chado.dbxref VALUES (982, 23, '0000552', '', NULL);
INSERT INTO chado.dbxref VALUES (983, 23, '0000553', '', NULL);
INSERT INTO chado.dbxref VALUES (984, 23, '0001430', '', NULL);
INSERT INTO chado.dbxref VALUES (985, 23, '0000554', '', NULL);
INSERT INTO chado.dbxref VALUES (986, 23, '0000555', '', NULL);
INSERT INTO chado.dbxref VALUES (987, 23, '0000557', '', NULL);
INSERT INTO chado.dbxref VALUES (988, 23, '0000558', '', NULL);
INSERT INTO chado.dbxref VALUES (989, 23, '0000559', '', NULL);
INSERT INTO chado.dbxref VALUES (990, 23, '0000560', '', NULL);
INSERT INTO chado.dbxref VALUES (991, 23, '0000564', '', NULL);
INSERT INTO chado.dbxref VALUES (992, 23, '0000565', '', NULL);
INSERT INTO chado.dbxref VALUES (993, 23, '0000566', '', NULL);
INSERT INTO chado.dbxref VALUES (994, 23, '0000567', '', NULL);
INSERT INTO chado.dbxref VALUES (995, 23, '0000568', '', NULL);
INSERT INTO chado.dbxref VALUES (996, 23, '0000569', '', NULL);
INSERT INTO chado.dbxref VALUES (997, 23, '0100042', '', NULL);
INSERT INTO chado.dbxref VALUES (998, 23, '0000571', '', NULL);
INSERT INTO chado.dbxref VALUES (999, 23, '0000573', '', NULL);
INSERT INTO chado.dbxref VALUES (1000, 23, '0000575', '', NULL);
INSERT INTO chado.dbxref VALUES (1001, 23, '0000577', '', NULL);
INSERT INTO chado.dbxref VALUES (1002, 23, '0000628', '', NULL);
INSERT INTO chado.dbxref VALUES (1003, 23, '0000578', '', NULL);
INSERT INTO chado.dbxref VALUES (1004, 23, '0000579', '', NULL);
INSERT INTO chado.dbxref VALUES (1005, 23, '0000580', '', NULL);
INSERT INTO chado.dbxref VALUES (1006, 23, '0000581', '', NULL);
INSERT INTO chado.dbxref VALUES (1007, 23, '0000582', '', NULL);
INSERT INTO chado.dbxref VALUES (1008, 23, '0000583', '', NULL);
INSERT INTO chado.dbxref VALUES (1009, 23, '0000584', '', NULL);
INSERT INTO chado.dbxref VALUES (1010, 23, '0000585', '', NULL);
INSERT INTO chado.dbxref VALUES (1011, 23, '0000586', '', NULL);
INSERT INTO chado.dbxref VALUES (1012, 23, '0000587', '', NULL);
INSERT INTO chado.dbxref VALUES (1013, 23, '0000588', '', NULL);
INSERT INTO chado.dbxref VALUES (1014, 23, '0000589', '', NULL);
INSERT INTO chado.dbxref VALUES (1015, 23, '0000590', '', NULL);
INSERT INTO chado.dbxref VALUES (1016, 23, '0000592', '', NULL);
INSERT INTO chado.dbxref VALUES (1017, 23, '0000595', '', NULL);
INSERT INTO chado.dbxref VALUES (1018, 23, '0000594', '', NULL);
INSERT INTO chado.dbxref VALUES (1019, 23, '0000596', '', NULL);
INSERT INTO chado.dbxref VALUES (1020, 23, '0000597', '', NULL);
INSERT INTO chado.dbxref VALUES (1021, 23, '0000598', '', NULL);
INSERT INTO chado.dbxref VALUES (1022, 23, '0000599', '', NULL);
INSERT INTO chado.dbxref VALUES (1023, 23, '0000600', '', NULL);
INSERT INTO chado.dbxref VALUES (1024, 23, '0000601', '', NULL);
INSERT INTO chado.dbxref VALUES (1025, 23, '0000602', '', NULL);
INSERT INTO chado.dbxref VALUES (1026, 23, '0000604', '', NULL);
INSERT INTO chado.dbxref VALUES (1027, 23, '0000605', '', NULL);
INSERT INTO chado.dbxref VALUES (1028, 23, '0000606', '', NULL);
INSERT INTO chado.dbxref VALUES (1029, 23, '0000607', '', NULL);
INSERT INTO chado.dbxref VALUES (1030, 23, '0000608', '', NULL);
INSERT INTO chado.dbxref VALUES (1031, 23, '0000609', '', NULL);
INSERT INTO chado.dbxref VALUES (1032, 23, '0000610', '', NULL);
INSERT INTO chado.dbxref VALUES (1033, 23, '0000611', '', NULL);
INSERT INTO chado.dbxref VALUES (1034, 23, '0000612', '', NULL);
INSERT INTO chado.dbxref VALUES (1035, 23, '0000613', '', NULL);
INSERT INTO chado.dbxref VALUES (1036, 23, '0002222', '', NULL);
INSERT INTO chado.dbxref VALUES (1037, 23, '0000614', '', NULL);
INSERT INTO chado.dbxref VALUES (1038, 23, '0000615', '', NULL);
INSERT INTO chado.dbxref VALUES (1039, 23, '0000951', '', NULL);
INSERT INTO chado.dbxref VALUES (1040, 23, '0000616', '', NULL);
INSERT INTO chado.dbxref VALUES (1041, 23, '0000617', '', NULL);
INSERT INTO chado.dbxref VALUES (1042, 23, '0000618', '', NULL);
INSERT INTO chado.dbxref VALUES (1043, 23, '0000619', '', NULL);
INSERT INTO chado.dbxref VALUES (1044, 23, '0000620', '', NULL);
INSERT INTO chado.dbxref VALUES (1045, 23, '0000621', '', NULL);
INSERT INTO chado.dbxref VALUES (1046, 23, '0000622', '', NULL);
INSERT INTO chado.dbxref VALUES (1047, 23, '0000623', '', NULL);
INSERT INTO chado.dbxref VALUES (1048, 23, '0000624', '', NULL);
INSERT INTO chado.dbxref VALUES (1049, 23, '0000625', '', NULL);
INSERT INTO chado.dbxref VALUES (1050, 23, '0000627', '', NULL);
INSERT INTO chado.dbxref VALUES (1051, 23, '0000629', '', NULL);
INSERT INTO chado.dbxref VALUES (1052, 23, '0000630', '', NULL);
INSERT INTO chado.dbxref VALUES (1053, 23, '0000837', '', NULL);
INSERT INTO chado.dbxref VALUES (1054, 23, '0000631', '', NULL);
INSERT INTO chado.dbxref VALUES (1055, 23, '0000632', '', NULL);
INSERT INTO chado.dbxref VALUES (1056, 23, '0000665', '', NULL);
INSERT INTO chado.dbxref VALUES (1057, 23, '0000878', '', NULL);
INSERT INTO chado.dbxref VALUES (1058, 23, '0000633', '', NULL);
INSERT INTO chado.dbxref VALUES (1059, 23, '0000634', '', NULL);
INSERT INTO chado.dbxref VALUES (1060, 23, '0000635', '', NULL);
INSERT INTO chado.dbxref VALUES (1061, 23, '0000636', '', NULL);
INSERT INTO chado.dbxref VALUES (1062, 23, '0000637', '', NULL);
INSERT INTO chado.dbxref VALUES (1063, 23, '0000638', '', NULL);
INSERT INTO chado.dbxref VALUES (1064, 23, '0000838', '', NULL);
INSERT INTO chado.dbxref VALUES (1065, 23, '0000639', '', NULL);
INSERT INTO chado.dbxref VALUES (1066, 23, '0000640', '', NULL);
INSERT INTO chado.dbxref VALUES (1067, 23, '0000641', '', NULL);
INSERT INTO chado.dbxref VALUES (1068, 23, '0000642', '', NULL);
INSERT INTO chado.dbxref VALUES (1069, 23, '0000643', '', NULL);
INSERT INTO chado.dbxref VALUES (1070, 23, '0000645', '', NULL);
INSERT INTO chado.dbxref VALUES (1071, 23, '0000646', '', NULL);
INSERT INTO chado.dbxref VALUES (1072, 23, '0000647', '', NULL);
INSERT INTO chado.dbxref VALUES (1073, 23, '0000648', '', NULL);
INSERT INTO chado.dbxref VALUES (1074, 23, '0002343', '', NULL);
INSERT INTO chado.dbxref VALUES (1075, 23, '0000652', '', NULL);
INSERT INTO chado.dbxref VALUES (1076, 23, '0002238', '', NULL);
INSERT INTO chado.dbxref VALUES (1077, 23, '0000653', '', NULL);
INSERT INTO chado.dbxref VALUES (1078, 23, '0002239', '', NULL);
INSERT INTO chado.dbxref VALUES (1079, 23, '0000654', '', NULL);
INSERT INTO chado.dbxref VALUES (1080, 23, '0000742', '', NULL);
INSERT INTO chado.dbxref VALUES (1081, 23, '0000656', '', NULL);
INSERT INTO chado.dbxref VALUES (1082, 23, '0000726', '', NULL);
INSERT INTO chado.dbxref VALUES (1083, 23, '0000658', '', NULL);
INSERT INTO chado.dbxref VALUES (1084, 23, '0000659', '', NULL);
INSERT INTO chado.dbxref VALUES (1085, 23, '0000660', '', NULL);
INSERT INTO chado.dbxref VALUES (1086, 23, '0000661', '', NULL);
INSERT INTO chado.dbxref VALUES (1087, 23, '0000663', '', NULL);
INSERT INTO chado.dbxref VALUES (1088, 23, '0000664', '', NULL);
INSERT INTO chado.dbxref VALUES (1089, 23, '0000666', '', NULL);
INSERT INTO chado.dbxref VALUES (1090, 23, '0001037', '', NULL);
INSERT INTO chado.dbxref VALUES (1091, 23, '0001234', '', NULL);
INSERT INTO chado.dbxref VALUES (1092, 23, '0000667', '', NULL);
INSERT INTO chado.dbxref VALUES (1093, 23, '1000034', '', NULL);
INSERT INTO chado.dbxref VALUES (1094, 33, 'LA6687-3', '', NULL);
INSERT INTO chado.dbxref VALUES (1095, 23, '0000668', '', NULL);
INSERT INTO chado.dbxref VALUES (1096, 23, '0000670', '', NULL);
INSERT INTO chado.dbxref VALUES (1097, 23, '0000671', '', NULL);
INSERT INTO chado.dbxref VALUES (1098, 23, '0000672', '', NULL);
INSERT INTO chado.dbxref VALUES (1099, 23, '0000831', '', NULL);
INSERT INTO chado.dbxref VALUES (1100, 23, '0002300', '', NULL);
INSERT INTO chado.dbxref VALUES (1101, 23, '0000674', '', NULL);
INSERT INTO chado.dbxref VALUES (1102, 23, '0000675', '', NULL);
INSERT INTO chado.dbxref VALUES (1103, 23, '0000676', '', NULL);
INSERT INTO chado.dbxref VALUES (1104, 23, '0000677', '', NULL);
INSERT INTO chado.dbxref VALUES (1105, 23, '0000678', '', NULL);
INSERT INTO chado.dbxref VALUES (1106, 23, '0000679', '', NULL);
INSERT INTO chado.dbxref VALUES (1107, 23, '0000680', '', NULL);
INSERT INTO chado.dbxref VALUES (1108, 23, '0000681', '', NULL);
INSERT INTO chado.dbxref VALUES (1109, 23, '0000682', '', NULL);
INSERT INTO chado.dbxref VALUES (1110, 23, '0000683', '', NULL);
INSERT INTO chado.dbxref VALUES (1111, 23, '0000685', '', NULL);
INSERT INTO chado.dbxref VALUES (1112, 23, '0000686', '', NULL);
INSERT INTO chado.dbxref VALUES (1113, 23, '1000044', '', NULL);
INSERT INTO chado.dbxref VALUES (1114, 23, '0000687', '', NULL);
INSERT INTO chado.dbxref VALUES (1115, 23, '0000689', '', NULL);
INSERT INTO chado.dbxref VALUES (1116, 23, '0000690', '', NULL);
INSERT INTO chado.dbxref VALUES (1117, 23, '0000691', '', NULL);
INSERT INTO chado.dbxref VALUES (1118, 34, '00067', '', NULL);
INSERT INTO chado.dbxref VALUES (1119, 23, '0100011', '', NULL);
INSERT INTO chado.dbxref VALUES (1120, 23, '0000692', '', NULL);
INSERT INTO chado.dbxref VALUES (1121, 23, '0000693', '', NULL);
INSERT INTO chado.dbxref VALUES (1122, 23, '0000881', '', NULL);
INSERT INTO chado.dbxref VALUES (1123, 23, '0000694', '', NULL);
INSERT INTO chado.dbxref VALUES (1124, 23, '0001483', '', NULL);
INSERT INTO chado.dbxref VALUES (1125, 23, '0001409', '', NULL);
INSERT INTO chado.dbxref VALUES (1126, 23, '0000697', '', NULL);
INSERT INTO chado.dbxref VALUES (1127, 23, '0000883', '', NULL);
INSERT INTO chado.dbxref VALUES (1128, 23, '0000698', '', NULL);
INSERT INTO chado.dbxref VALUES (1129, 23, '0000884', '', NULL);
INSERT INTO chado.dbxref VALUES (1130, 23, '0000701', '', NULL);
INSERT INTO chado.dbxref VALUES (1131, 23, '0000702', '', NULL);
INSERT INTO chado.dbxref VALUES (1132, 23, '0000703', '', NULL);
INSERT INTO chado.dbxref VALUES (1133, 23, '0000706', '', NULL);
INSERT INTO chado.dbxref VALUES (1134, 23, '0001420', '', NULL);
INSERT INTO chado.dbxref VALUES (1135, 23, '0000707', '', NULL);
INSERT INTO chado.dbxref VALUES (1136, 23, '0000708', '', NULL);
INSERT INTO chado.dbxref VALUES (1137, 23, '0000709', '', NULL);
INSERT INTO chado.dbxref VALUES (1138, 23, '0000710', '', NULL);
INSERT INTO chado.dbxref VALUES (1139, 23, '0000885', '', NULL);
INSERT INTO chado.dbxref VALUES (1140, 23, '0000711', '', NULL);
INSERT INTO chado.dbxref VALUES (1141, 23, '0000886', '', NULL);
INSERT INTO chado.dbxref VALUES (1142, 23, '0000712', '', NULL);
INSERT INTO chado.dbxref VALUES (1143, 23, '0000714', '', NULL);
INSERT INTO chado.dbxref VALUES (1144, 23, '0001683', '', NULL);
INSERT INTO chado.dbxref VALUES (1145, 23, '0000716', '', NULL);
INSERT INTO chado.dbxref VALUES (1146, 23, '0000718', '', NULL);
INSERT INTO chado.dbxref VALUES (1147, 23, '0000720', '', NULL);
INSERT INTO chado.dbxref VALUES (1148, 23, '0000721', '', NULL);
INSERT INTO chado.dbxref VALUES (1149, 23, '1001197', '', NULL);
INSERT INTO chado.dbxref VALUES (1150, 23, '0000722', '', NULL);
INSERT INTO chado.dbxref VALUES (1151, 23, '0000723', '', NULL);
INSERT INTO chado.dbxref VALUES (1152, 23, '0000724', '', NULL);
INSERT INTO chado.dbxref VALUES (1153, 23, '0000725', '', NULL);
INSERT INTO chado.dbxref VALUES (1154, 34, '00055', '', NULL);
INSERT INTO chado.dbxref VALUES (1155, 23, '0002252', '', NULL);
INSERT INTO chado.dbxref VALUES (1156, 23, '0000728', '', NULL);
INSERT INTO chado.dbxref VALUES (1157, 23, '0000729', '', NULL);
INSERT INTO chado.dbxref VALUES (1158, 23, '0000730', '', NULL);
INSERT INTO chado.dbxref VALUES (1159, 23, '0000731', '', NULL);
INSERT INTO chado.dbxref VALUES (1160, 23, '0000905', '', NULL);
INSERT INTO chado.dbxref VALUES (1161, 23, '0000732', '', NULL);
INSERT INTO chado.dbxref VALUES (1162, 23, '0000734', '', NULL);
INSERT INTO chado.dbxref VALUES (1163, 23, '0000864', '', NULL);
INSERT INTO chado.dbxref VALUES (1164, 23, '0000735', '', NULL);
INSERT INTO chado.dbxref VALUES (1165, 23, '0000826', '', NULL);
INSERT INTO chado.dbxref VALUES (1166, 23, '0001026', '', NULL);
INSERT INTO chado.dbxref VALUES (1167, 23, '0000980', '', NULL);
INSERT INTO chado.dbxref VALUES (1168, 23, '0000827', '', NULL);
INSERT INTO chado.dbxref VALUES (1169, 23, '0000750', '', NULL);
INSERT INTO chado.dbxref VALUES (1170, 23, '0000752', '', NULL);
INSERT INTO chado.dbxref VALUES (1171, 23, '0000754', '', NULL);
INSERT INTO chado.dbxref VALUES (1172, 23, '0000755', '', NULL);
INSERT INTO chado.dbxref VALUES (1173, 23, '0000757', '', NULL);
INSERT INTO chado.dbxref VALUES (1174, 23, '0000758', '', NULL);
INSERT INTO chado.dbxref VALUES (1175, 23, '0000759', '', NULL);
INSERT INTO chado.dbxref VALUES (1176, 23, '0000760', '', NULL);
INSERT INTO chado.dbxref VALUES (1177, 23, '0000761', '', NULL);
INSERT INTO chado.dbxref VALUES (1178, 23, '0000762', '', NULL);
INSERT INTO chado.dbxref VALUES (1179, 23, '0000763', '', NULL);
INSERT INTO chado.dbxref VALUES (1180, 23, '0000764', '', NULL);
INSERT INTO chado.dbxref VALUES (1181, 23, '0000765', '', NULL);
INSERT INTO chado.dbxref VALUES (1182, 23, '0000766', '', NULL);
INSERT INTO chado.dbxref VALUES (1183, 23, '0001178', '', NULL);
INSERT INTO chado.dbxref VALUES (1184, 23, '0000767', '', NULL);
INSERT INTO chado.dbxref VALUES (1185, 23, '0000768', '', NULL);
INSERT INTO chado.dbxref VALUES (1186, 23, '0000769', '', NULL);
INSERT INTO chado.dbxref VALUES (1187, 23, '0000847', '', NULL);
INSERT INTO chado.dbxref VALUES (1188, 23, '0000770', '', NULL);
INSERT INTO chado.dbxref VALUES (1189, 23, '0000772', '', NULL);
INSERT INTO chado.dbxref VALUES (1190, 23, '0000773', '', NULL);
INSERT INTO chado.dbxref VALUES (1191, 23, '0000774', '', NULL);
INSERT INTO chado.dbxref VALUES (1192, 23, '0000775', '', NULL);
INSERT INTO chado.dbxref VALUES (1193, 23, '0000776', '', NULL);
INSERT INTO chado.dbxref VALUES (1194, 23, '0000777', '', NULL);
INSERT INTO chado.dbxref VALUES (1195, 23, '0000778', '', NULL);
INSERT INTO chado.dbxref VALUES (1196, 23, '0000779', '', NULL);
INSERT INTO chado.dbxref VALUES (1197, 23, '0000780', '', NULL);
INSERT INTO chado.dbxref VALUES (1198, 23, '0000781', '', NULL);
INSERT INTO chado.dbxref VALUES (1199, 23, '0000782', '', NULL);
INSERT INTO chado.dbxref VALUES (1200, 23, '0000785', '', NULL);
INSERT INTO chado.dbxref VALUES (1201, 23, '0000786', '', NULL);
INSERT INTO chado.dbxref VALUES (1202, 23, '0000787', '', NULL);
INSERT INTO chado.dbxref VALUES (1203, 23, '0000788', '', NULL);
INSERT INTO chado.dbxref VALUES (1204, 23, '0000791', '', NULL);
INSERT INTO chado.dbxref VALUES (1205, 23, '0000792', '', NULL);
INSERT INTO chado.dbxref VALUES (1206, 23, '0000793', '', NULL);
INSERT INTO chado.dbxref VALUES (1207, 23, '0000794', '', NULL);
INSERT INTO chado.dbxref VALUES (1208, 23, '0000795', '', NULL);
INSERT INTO chado.dbxref VALUES (1209, 23, '0000815', '', NULL);
INSERT INTO chado.dbxref VALUES (1210, 23, '0000796', '', NULL);
INSERT INTO chado.dbxref VALUES (1211, 23, '0000797', '', NULL);
INSERT INTO chado.dbxref VALUES (1212, 23, '0001038', '', NULL);
INSERT INTO chado.dbxref VALUES (1213, 23, '0000798', '', NULL);
INSERT INTO chado.dbxref VALUES (1214, 23, '0000799', '', NULL);
INSERT INTO chado.dbxref VALUES (1215, 23, '0000800', '', NULL);
INSERT INTO chado.dbxref VALUES (1216, 23, '0001504', '', NULL);
INSERT INTO chado.dbxref VALUES (1217, 23, '0000801', '', NULL);
INSERT INTO chado.dbxref VALUES (1218, 23, '0000802', '', NULL);
INSERT INTO chado.dbxref VALUES (1219, 23, '0000803', '', NULL);
INSERT INTO chado.dbxref VALUES (1220, 23, '0000807', '', NULL);
INSERT INTO chado.dbxref VALUES (1221, 23, '0000808', '', NULL);
INSERT INTO chado.dbxref VALUES (1222, 23, '0000809', '', NULL);
INSERT INTO chado.dbxref VALUES (1223, 23, '0000810', '', NULL);
INSERT INTO chado.dbxref VALUES (1224, 23, '0000811', '', NULL);
INSERT INTO chado.dbxref VALUES (1225, 23, '0000812', '', NULL);
INSERT INTO chado.dbxref VALUES (1226, 23, '0000813', '', NULL);
INSERT INTO chado.dbxref VALUES (1227, 23, '0000816', '', NULL);
INSERT INTO chado.dbxref VALUES (1228, 23, '0000817', '', NULL);
INSERT INTO chado.dbxref VALUES (1229, 33, 'LA9658-1', '', NULL);
INSERT INTO chado.dbxref VALUES (1230, 23, '0000818', '', NULL);
INSERT INTO chado.dbxref VALUES (1231, 23, '0000819', '', NULL);
INSERT INTO chado.dbxref VALUES (1232, 23, '0000820', '', NULL);
INSERT INTO chado.dbxref VALUES (1233, 23, '0000821', '', NULL);
INSERT INTO chado.dbxref VALUES (1234, 23, '0000822', '', NULL);
INSERT INTO chado.dbxref VALUES (1235, 23, '0000823', '', NULL);
INSERT INTO chado.dbxref VALUES (1236, 23, '0000824', '', NULL);
INSERT INTO chado.dbxref VALUES (1237, 23, '0000825', '', NULL);
INSERT INTO chado.dbxref VALUES (1238, 23, '0000828', '', NULL);
INSERT INTO chado.dbxref VALUES (1239, 23, '0000829', '', NULL);
INSERT INTO chado.dbxref VALUES (1240, 23, '0000832', '', NULL);
INSERT INTO chado.dbxref VALUES (1241, 23, '0000834', '', NULL);
INSERT INTO chado.dbxref VALUES (1242, 34, '00124', '', NULL);
INSERT INTO chado.dbxref VALUES (1243, 34, '00331', '', NULL);
INSERT INTO chado.dbxref VALUES (1244, 23, '0000843', '', NULL);
INSERT INTO chado.dbxref VALUES (1245, 23, '0000844', '', NULL);
INSERT INTO chado.dbxref VALUES (1246, 23, '0000845', '', NULL);
INSERT INTO chado.dbxref VALUES (1247, 23, '0000846', '', NULL);
INSERT INTO chado.dbxref VALUES (1248, 23, '0000852', '', NULL);
INSERT INTO chado.dbxref VALUES (1249, 23, '0000853', '', NULL);
INSERT INTO chado.dbxref VALUES (1250, 23, '0000857', '', NULL);
INSERT INTO chado.dbxref VALUES (1251, 23, '0000854', '', NULL);
INSERT INTO chado.dbxref VALUES (1252, 23, '0000859', '', NULL);
INSERT INTO chado.dbxref VALUES (1253, 23, '0000855', '', NULL);
INSERT INTO chado.dbxref VALUES (1254, 23, '0000858', '', NULL);
INSERT INTO chado.dbxref VALUES (1255, 23, '0000856', '', NULL);
INSERT INTO chado.dbxref VALUES (1256, 23, '0000860', '', NULL);
INSERT INTO chado.dbxref VALUES (1257, 23, '0000861', '', NULL);
INSERT INTO chado.dbxref VALUES (1258, 23, '0000862', '', NULL);
INSERT INTO chado.dbxref VALUES (1259, 23, '0000872', '', NULL);
INSERT INTO chado.dbxref VALUES (1260, 23, '0000977', '', NULL);
INSERT INTO chado.dbxref VALUES (1261, 23, '0000874', '', NULL);
INSERT INTO chado.dbxref VALUES (1262, 23, '0000877', '', NULL);
INSERT INTO chado.dbxref VALUES (1263, 23, '0000882', '', NULL);
INSERT INTO chado.dbxref VALUES (1264, 23, '0000888', '', NULL);
INSERT INTO chado.dbxref VALUES (1265, 23, '0000889', '', NULL);
INSERT INTO chado.dbxref VALUES (1266, 23, '0000890', '', NULL);
INSERT INTO chado.dbxref VALUES (1267, 23, '0000891', '', NULL);
INSERT INTO chado.dbxref VALUES (1268, 23, '0000892', '', NULL);
INSERT INTO chado.dbxref VALUES (1269, 23, '0000896', '', NULL);
INSERT INTO chado.dbxref VALUES (1270, 23, '0000897', '', NULL);
INSERT INTO chado.dbxref VALUES (1271, 23, '0000899', '', NULL);
INSERT INTO chado.dbxref VALUES (1272, 23, '0000900', '', NULL);
INSERT INTO chado.dbxref VALUES (1273, 23, '0000901', '', NULL);
INSERT INTO chado.dbxref VALUES (1274, 23, '0000906', '', NULL);
INSERT INTO chado.dbxref VALUES (1275, 23, '0000907', '', NULL);
INSERT INTO chado.dbxref VALUES (1276, 23, '0000908', '', NULL);
INSERT INTO chado.dbxref VALUES (1277, 23, '0000909', '', NULL);
INSERT INTO chado.dbxref VALUES (1278, 23, '0000910', '', NULL);
INSERT INTO chado.dbxref VALUES (1279, 23, '0000911', '', NULL);
INSERT INTO chado.dbxref VALUES (1280, 23, '0000912', '', NULL);
INSERT INTO chado.dbxref VALUES (1281, 34, '00203', '', NULL);
INSERT INTO chado.dbxref VALUES (1282, 23, '0001128', '', NULL);
INSERT INTO chado.dbxref VALUES (1283, 23, '0000913', '', NULL);
INSERT INTO chado.dbxref VALUES (1284, 23, '0000914', '', NULL);
INSERT INTO chado.dbxref VALUES (1285, 23, '0000915', '', NULL);
INSERT INTO chado.dbxref VALUES (1286, 23, '0000916', '', NULL);
INSERT INTO chado.dbxref VALUES (1287, 23, '0000917', '', NULL);
INSERT INTO chado.dbxref VALUES (1288, 23, '0000918', '', NULL);
INSERT INTO chado.dbxref VALUES (1289, 23, '0000919', '', NULL);
INSERT INTO chado.dbxref VALUES (1290, 23, '0000920', '', NULL);
INSERT INTO chado.dbxref VALUES (1291, 23, '0000921', '', NULL);
INSERT INTO chado.dbxref VALUES (1292, 23, '0000922', '', NULL);
INSERT INTO chado.dbxref VALUES (1293, 23, '0000923', '', NULL);
INSERT INTO chado.dbxref VALUES (1294, 23, '0000924', '', NULL);
INSERT INTO chado.dbxref VALUES (1295, 23, '0000925', '', NULL);
INSERT INTO chado.dbxref VALUES (1296, 23, '0000926', '', NULL);
INSERT INTO chado.dbxref VALUES (1297, 23, '0000927', '', NULL);
INSERT INTO chado.dbxref VALUES (1298, 23, '0000928', '', NULL);
INSERT INTO chado.dbxref VALUES (1299, 23, '0000929', '', NULL);
INSERT INTO chado.dbxref VALUES (1300, 23, '0000930', '', NULL);
INSERT INTO chado.dbxref VALUES (1301, 23, '0000931', '', NULL);
INSERT INTO chado.dbxref VALUES (1302, 23, '0000932', '', NULL);
INSERT INTO chado.dbxref VALUES (1303, 23, '0000933', '', NULL);
INSERT INTO chado.dbxref VALUES (1304, 23, '0000934', '', NULL);
INSERT INTO chado.dbxref VALUES (1305, 23, '0001655', '', NULL);
INSERT INTO chado.dbxref VALUES (1306, 23, '0000935', '', NULL);
INSERT INTO chado.dbxref VALUES (1307, 23, '0000937', '', NULL);
INSERT INTO chado.dbxref VALUES (1308, 23, '0000941', '', NULL);
INSERT INTO chado.dbxref VALUES (1309, 23, '0000942', '', NULL);
INSERT INTO chado.dbxref VALUES (1310, 23, '0001042', '', NULL);
INSERT INTO chado.dbxref VALUES (1311, 23, '0000943', '', NULL);
INSERT INTO chado.dbxref VALUES (1312, 23, '0000944', '', NULL);
INSERT INTO chado.dbxref VALUES (1313, 23, '0000945', '', NULL);
INSERT INTO chado.dbxref VALUES (1314, 23, '0000949', '', NULL);
INSERT INTO chado.dbxref VALUES (1315, 23, '0000950', '', NULL);
INSERT INTO chado.dbxref VALUES (1316, 23, '0000952', '', NULL);
INSERT INTO chado.dbxref VALUES (1317, 23, '0000953', '', NULL);
INSERT INTO chado.dbxref VALUES (1318, 23, '0000954', '', NULL);
INSERT INTO chado.dbxref VALUES (1319, 23, '0000955', '', NULL);
INSERT INTO chado.dbxref VALUES (1320, 23, '0000985', '', NULL);
INSERT INTO chado.dbxref VALUES (1321, 23, '0000956', '', NULL);
INSERT INTO chado.dbxref VALUES (1322, 23, '0000984', '', NULL);
INSERT INTO chado.dbxref VALUES (1323, 23, '0000957', '', NULL);
INSERT INTO chado.dbxref VALUES (1324, 23, '0000987', '', NULL);
INSERT INTO chado.dbxref VALUES (1325, 23, '0000958', '', NULL);
INSERT INTO chado.dbxref VALUES (1326, 23, '0000988', '', NULL);
INSERT INTO chado.dbxref VALUES (1327, 23, '0000959', '', NULL);
INSERT INTO chado.dbxref VALUES (1328, 23, '0000960', '', NULL);
INSERT INTO chado.dbxref VALUES (1329, 23, '0000961', '', NULL);
INSERT INTO chado.dbxref VALUES (1330, 23, '0000962', '', NULL);
INSERT INTO chado.dbxref VALUES (1331, 23, '0000963', '', NULL);
INSERT INTO chado.dbxref VALUES (1332, 23, '0000964', '', NULL);
INSERT INTO chado.dbxref VALUES (1333, 23, '0000965', '', NULL);
INSERT INTO chado.dbxref VALUES (1334, 23, '0000966', '', NULL);
INSERT INTO chado.dbxref VALUES (1335, 23, '0000967', '', NULL);
INSERT INTO chado.dbxref VALUES (1336, 23, '0000968', '', NULL);
INSERT INTO chado.dbxref VALUES (1337, 23, '0000969', '', NULL);
INSERT INTO chado.dbxref VALUES (1338, 23, '0000970', '', NULL);
INSERT INTO chado.dbxref VALUES (1339, 23, '0000971', '', NULL);
INSERT INTO chado.dbxref VALUES (1340, 23, '0000972', '', NULL);
INSERT INTO chado.dbxref VALUES (1341, 23, '0000973', '', NULL);
INSERT INTO chado.dbxref VALUES (1342, 23, '0000975', '', NULL);
INSERT INTO chado.dbxref VALUES (1343, 23, '0000976', '', NULL);
INSERT INTO chado.dbxref VALUES (1344, 23, '0000978', '', NULL);
INSERT INTO chado.dbxref VALUES (1345, 23, '0000979', '', NULL);
INSERT INTO chado.dbxref VALUES (1346, 23, '0000974', '', NULL);
INSERT INTO chado.dbxref VALUES (1347, 23, '0000981', '', NULL);
INSERT INTO chado.dbxref VALUES (1348, 23, '0000982', '', NULL);
INSERT INTO chado.dbxref VALUES (1349, 23, '0000983', '', NULL);
INSERT INTO chado.dbxref VALUES (1350, 23, '0000986', '', NULL);
INSERT INTO chado.dbxref VALUES (1351, 23, '0000989', '', NULL);
INSERT INTO chado.dbxref VALUES (1352, 23, '0000990', '', NULL);
INSERT INTO chado.dbxref VALUES (1353, 23, '0000992', '', NULL);
INSERT INTO chado.dbxref VALUES (1354, 23, '0000993', '', NULL);
INSERT INTO chado.dbxref VALUES (1355, 23, '0000994', '', NULL);
INSERT INTO chado.dbxref VALUES (1356, 23, '0000995', '', NULL);
INSERT INTO chado.dbxref VALUES (1357, 23, '0000996', '', NULL);
INSERT INTO chado.dbxref VALUES (1358, 23, '0000997', '', NULL);
INSERT INTO chado.dbxref VALUES (1359, 23, '0000998', '', NULL);
INSERT INTO chado.dbxref VALUES (1360, 23, '0000999', '', NULL);
INSERT INTO chado.dbxref VALUES (1361, 23, '0001000', '', NULL);
INSERT INTO chado.dbxref VALUES (1362, 23, '0002237', '', NULL);
INSERT INTO chado.dbxref VALUES (1363, 23, '0001001', '', NULL);
INSERT INTO chado.dbxref VALUES (1364, 23, '0002243', '', NULL);
INSERT INTO chado.dbxref VALUES (1365, 23, '0001002', '', NULL);
INSERT INTO chado.dbxref VALUES (1366, 23, '0002242', '', NULL);
INSERT INTO chado.dbxref VALUES (1367, 23, '0001003', '', NULL);
INSERT INTO chado.dbxref VALUES (1368, 23, '0001004', '', NULL);
INSERT INTO chado.dbxref VALUES (1369, 23, '0001005', '', NULL);
INSERT INTO chado.dbxref VALUES (1370, 23, '0001006', '', NULL);
INSERT INTO chado.dbxref VALUES (1371, 23, '0001007', '', NULL);
INSERT INTO chado.dbxref VALUES (1372, 23, '0001008', '', NULL);
INSERT INTO chado.dbxref VALUES (1373, 23, '0001009', '', NULL);
INSERT INTO chado.dbxref VALUES (1374, 23, '0001010', '', NULL);
INSERT INTO chado.dbxref VALUES (1375, 23, '0001011', '', NULL);
INSERT INTO chado.dbxref VALUES (1376, 23, '0001184', '', NULL);
INSERT INTO chado.dbxref VALUES (1377, 23, '0001012', '', NULL);
INSERT INTO chado.dbxref VALUES (1378, 23, '0001013', '', NULL);
INSERT INTO chado.dbxref VALUES (1379, 23, '0002007', '', NULL);
INSERT INTO chado.dbxref VALUES (1380, 23, '0001014', '', NULL);
INSERT INTO chado.dbxref VALUES (1381, 23, '0001015', '', NULL);
INSERT INTO chado.dbxref VALUES (1382, 23, '0001016', '', NULL);
INSERT INTO chado.dbxref VALUES (1383, 23, '0001017', '', NULL);
INSERT INTO chado.dbxref VALUES (1384, 33, 'LA6700-4', '', NULL);
INSERT INTO chado.dbxref VALUES (1385, 23, '0001878', '', NULL);
INSERT INTO chado.dbxref VALUES (1386, 23, '0001018', '', NULL);
INSERT INTO chado.dbxref VALUES (1387, 23, '0001019', '', NULL);
INSERT INTO chado.dbxref VALUES (1388, 23, '0001020', '', NULL);
INSERT INTO chado.dbxref VALUES (1389, 23, '0001021', '', NULL);
INSERT INTO chado.dbxref VALUES (1390, 23, '0001242', '', NULL);
INSERT INTO chado.dbxref VALUES (1391, 23, '0001022', '', NULL);
INSERT INTO chado.dbxref VALUES (1392, 23, '0001023', '', NULL);
INSERT INTO chado.dbxref VALUES (1393, 23, '0001024', '', NULL);
INSERT INTO chado.dbxref VALUES (1394, 23, '0001025', '', NULL);
INSERT INTO chado.dbxref VALUES (1395, 23, '0001260', '', NULL);
INSERT INTO chado.dbxref VALUES (1396, 23, '0001027', '', NULL);
INSERT INTO chado.dbxref VALUES (1397, 23, '0001028', '', NULL);
INSERT INTO chado.dbxref VALUES (1398, 23, '0001029', '', NULL);
INSERT INTO chado.dbxref VALUES (1399, 23, '0001032', '', NULL);
INSERT INTO chado.dbxref VALUES (1400, 23, '0001033', '', NULL);
INSERT INTO chado.dbxref VALUES (1401, 23, '0001034', '', NULL);
INSERT INTO chado.dbxref VALUES (1402, 23, '0001036', '', NULL);
INSERT INTO chado.dbxref VALUES (1403, 23, '0001040', '', NULL);
INSERT INTO chado.dbxref VALUES (1404, 23, '0001041', '', NULL);
INSERT INTO chado.dbxref VALUES (1405, 23, '0001043', '', NULL);
INSERT INTO chado.dbxref VALUES (1406, 23, '0001044', '', NULL);
INSERT INTO chado.dbxref VALUES (1407, 23, '0001045', '', NULL);
INSERT INTO chado.dbxref VALUES (1408, 23, '0001046', '', NULL);
INSERT INTO chado.dbxref VALUES (1409, 23, '0001048', '', NULL);
INSERT INTO chado.dbxref VALUES (1410, 23, '0001047', '', NULL);
INSERT INTO chado.dbxref VALUES (1411, 23, '0001049', '', NULL);
INSERT INTO chado.dbxref VALUES (1412, 23, '0001050', '', NULL);
INSERT INTO chado.dbxref VALUES (1413, 23, '0001649', '', NULL);
INSERT INTO chado.dbxref VALUES (1414, 23, '0001051', '', NULL);
INSERT INTO chado.dbxref VALUES (1415, 23, '0001052', '', NULL);
INSERT INTO chado.dbxref VALUES (1416, 23, '0001053', '', NULL);
INSERT INTO chado.dbxref VALUES (1417, 23, '0001054', '', NULL);
INSERT INTO chado.dbxref VALUES (1418, 23, '0001648', '', NULL);
INSERT INTO chado.dbxref VALUES (1419, 23, '0005836', '', NULL);
INSERT INTO chado.dbxref VALUES (1420, 23, '0001057', '', NULL);
INSERT INTO chado.dbxref VALUES (1421, 23, '0001058', '', NULL);
INSERT INTO chado.dbxref VALUES (1422, 23, '1000004', '', NULL);
INSERT INTO chado.dbxref VALUES (1423, 23, '1000007', '', NULL);
INSERT INTO chado.dbxref VALUES (1424, 23, '0002072', '', NULL);
INSERT INTO chado.dbxref VALUES (1425, 23, '0001061', '', NULL);
INSERT INTO chado.dbxref VALUES (1426, 34, '00063', '', NULL);
INSERT INTO chado.dbxref VALUES (1427, 34, '00077', '', NULL);
INSERT INTO chado.dbxref VALUES (1428, 23, '0002250', '', NULL);
INSERT INTO chado.dbxref VALUES (1429, 34, '00129', '', NULL);
INSERT INTO chado.dbxref VALUES (1430, 23, '0001064', '', NULL);
INSERT INTO chado.dbxref VALUES (1431, 34, '00076', '', NULL);
INSERT INTO chado.dbxref VALUES (1432, 23, '0001066', '', NULL);
INSERT INTO chado.dbxref VALUES (1433, 34, '00068', '', NULL);
INSERT INTO chado.dbxref VALUES (1434, 23, '0001067', '', NULL);
INSERT INTO chado.dbxref VALUES (1435, 34, '00032', '', NULL);
INSERT INTO chado.dbxref VALUES (1436, 23, '0001068', '', NULL);
INSERT INTO chado.dbxref VALUES (1437, 34, '00070', '', NULL);
INSERT INTO chado.dbxref VALUES (1438, 34, '00337', '', NULL);
INSERT INTO chado.dbxref VALUES (1439, 23, '0001071', '', NULL);
INSERT INTO chado.dbxref VALUES (1440, 34, '00128', '', NULL);
INSERT INTO chado.dbxref VALUES (1441, 23, '0001072', '', NULL);
INSERT INTO chado.dbxref VALUES (1442, 34, '00154', '', NULL);
INSERT INTO chado.dbxref VALUES (1443, 23, '0001073', '', NULL);
INSERT INTO chado.dbxref VALUES (1444, 34, '00145', '', NULL);
INSERT INTO chado.dbxref VALUES (1445, 23, '0001074', '', NULL);
INSERT INTO chado.dbxref VALUES (1446, 34, '00144', '', NULL);
INSERT INTO chado.dbxref VALUES (1447, 23, '0001075', '', NULL);
INSERT INTO chado.dbxref VALUES (1448, 34, '00156', '', NULL);
INSERT INTO chado.dbxref VALUES (1449, 23, '0001076', '', NULL);
INSERT INTO chado.dbxref VALUES (1450, 34, '00155', '', NULL);
INSERT INTO chado.dbxref VALUES (1451, 23, '0001077', '', NULL);
INSERT INTO chado.dbxref VALUES (1452, 34, '00158', '', NULL);
INSERT INTO chado.dbxref VALUES (1453, 23, '0001078', '', NULL);
INSERT INTO chado.dbxref VALUES (1454, 34, '00003', '', NULL);
INSERT INTO chado.dbxref VALUES (1455, 23, '0001079', '', NULL);
INSERT INTO chado.dbxref VALUES (1456, 34, '0000338', '', NULL);
INSERT INTO chado.dbxref VALUES (1457, 23, '0001080', '', NULL);
INSERT INTO chado.dbxref VALUES (1458, 34, '00041', '', NULL);
INSERT INTO chado.dbxref VALUES (1459, 23, '0001081', '', NULL);
INSERT INTO chado.dbxref VALUES (1460, 34, '00147', '', NULL);
INSERT INTO chado.dbxref VALUES (1461, 23, '0001114', '', NULL);
INSERT INTO chado.dbxref VALUES (1462, 23, '0001082', '', NULL);
INSERT INTO chado.dbxref VALUES (1463, 34, '00125', '', NULL);
INSERT INTO chado.dbxref VALUES (1464, 23, '0001083', '', NULL);
INSERT INTO chado.dbxref VALUES (1465, 34, '00182', '', NULL);
INSERT INTO chado.dbxref VALUES (1466, 23, '0001084', '', NULL);
INSERT INTO chado.dbxref VALUES (1467, 34, '00072', '', NULL);
INSERT INTO chado.dbxref VALUES (1468, 23, '0001085', '', NULL);
INSERT INTO chado.dbxref VALUES (1469, 34, '00069', '', NULL);
INSERT INTO chado.dbxref VALUES (1470, 23, '0001086', '', NULL);
INSERT INTO chado.dbxref VALUES (1471, 34, '00181', '', NULL);
INSERT INTO chado.dbxref VALUES (1472, 23, '0001087', '', NULL);
INSERT INTO chado.dbxref VALUES (1473, 34, '00178', '', NULL);
INSERT INTO chado.dbxref VALUES (1474, 23, '0001088', '', NULL);
INSERT INTO chado.dbxref VALUES (1475, 34, '00028', '', NULL);
INSERT INTO chado.dbxref VALUES (1476, 23, '0001089', '', NULL);
INSERT INTO chado.dbxref VALUES (1477, 34, '00052', '', NULL);
INSERT INTO chado.dbxref VALUES (1478, 23, '0100001', '', NULL);
INSERT INTO chado.dbxref VALUES (1479, 23, '0001090', '', NULL);
INSERT INTO chado.dbxref VALUES (1480, 34, '00246', '', NULL);
INSERT INTO chado.dbxref VALUES (1481, 23, '0001091', '', NULL);
INSERT INTO chado.dbxref VALUES (1482, 34, '00029', '', NULL);
INSERT INTO chado.dbxref VALUES (1483, 23, '0001092', '', NULL);
INSERT INTO chado.dbxref VALUES (1484, 34, '00027', '', NULL);
INSERT INTO chado.dbxref VALUES (1485, 23, '0001656', '', NULL);
INSERT INTO chado.dbxref VALUES (1486, 23, '0100002', '', NULL);
INSERT INTO chado.dbxref VALUES (1487, 23, '0001093', '', NULL);
INSERT INTO chado.dbxref VALUES (1488, 34, '00131', '', NULL);
INSERT INTO chado.dbxref VALUES (1489, 23, '0001094', '', NULL);
INSERT INTO chado.dbxref VALUES (1490, 34, '00186', '', NULL);
INSERT INTO chado.dbxref VALUES (1491, 23, '0001095', '', NULL);
INSERT INTO chado.dbxref VALUES (1492, 34, '00136', '', NULL);
INSERT INTO chado.dbxref VALUES (1493, 23, '0001096', '', NULL);
INSERT INTO chado.dbxref VALUES (1494, 34, '00146', '', NULL);
INSERT INTO chado.dbxref VALUES (1495, 23, '0001097', '', NULL);
INSERT INTO chado.dbxref VALUES (1496, 34, '00137', '', NULL);
INSERT INTO chado.dbxref VALUES (1497, 23, '0001098', '', NULL);
INSERT INTO chado.dbxref VALUES (1498, 34, '00187', '', NULL);
INSERT INTO chado.dbxref VALUES (1499, 23, '0001099', '', NULL);
INSERT INTO chado.dbxref VALUES (1500, 34, '00140', '', NULL);
INSERT INTO chado.dbxref VALUES (1501, 23, '0001100', '', NULL);
INSERT INTO chado.dbxref VALUES (1502, 34, '00141', '', NULL);
INSERT INTO chado.dbxref VALUES (1503, 23, '0001101', '', NULL);
INSERT INTO chado.dbxref VALUES (1504, 34, '00142', '', NULL);
INSERT INTO chado.dbxref VALUES (1505, 23, '0001102', '', NULL);
INSERT INTO chado.dbxref VALUES (1506, 34, '00143', '', NULL);
INSERT INTO chado.dbxref VALUES (1507, 23, '0001103', '', NULL);
INSERT INTO chado.dbxref VALUES (1508, 34, '00185', '', NULL);
INSERT INTO chado.dbxref VALUES (1509, 23, '0001104', '', NULL);
INSERT INTO chado.dbxref VALUES (1510, 34, '00026', '', NULL);
INSERT INTO chado.dbxref VALUES (1511, 23, '0001237', '', NULL);
INSERT INTO chado.dbxref VALUES (1512, 23, '0100019', '', NULL);
INSERT INTO chado.dbxref VALUES (1513, 23, '0001105', '', NULL);
INSERT INTO chado.dbxref VALUES (1514, 34, '00157', '', NULL);
INSERT INTO chado.dbxref VALUES (1515, 23, '0001657', '', NULL);
INSERT INTO chado.dbxref VALUES (1516, 23, '0001106', '', NULL);
INSERT INTO chado.dbxref VALUES (1517, 34, '00202', '', NULL);
INSERT INTO chado.dbxref VALUES (1518, 23, '0001107', '', NULL);
INSERT INTO chado.dbxref VALUES (1519, 34, '00208', '', NULL);
INSERT INTO chado.dbxref VALUES (1520, 23, '0001108', '', NULL);
INSERT INTO chado.dbxref VALUES (1521, 34, '00209', '', NULL);
INSERT INTO chado.dbxref VALUES (1522, 23, '0001109', '', NULL);
INSERT INTO chado.dbxref VALUES (1523, 34, '00210', '', NULL);
INSERT INTO chado.dbxref VALUES (1524, 23, '0001110', '', NULL);
INSERT INTO chado.dbxref VALUES (1525, 34, '00211', '', NULL);
INSERT INTO chado.dbxref VALUES (1526, 23, '0001111', '', NULL);
INSERT INTO chado.dbxref VALUES (1527, 34, '00042', '', NULL);
INSERT INTO chado.dbxref VALUES (1528, 23, '0001112', '', NULL);
INSERT INTO chado.dbxref VALUES (1529, 34, '0000341', '', NULL);
INSERT INTO chado.dbxref VALUES (1530, 23, '0001113', '', NULL);
INSERT INTO chado.dbxref VALUES (1531, 34, '00151', '', NULL);
INSERT INTO chado.dbxref VALUES (1532, 34, '00152', '', NULL);
INSERT INTO chado.dbxref VALUES (1533, 23, '0001115', '', NULL);
INSERT INTO chado.dbxref VALUES (1534, 34, '00222', '', NULL);
INSERT INTO chado.dbxref VALUES (1535, 23, '0001116', '', NULL);
INSERT INTO chado.dbxref VALUES (1536, 34, '0000339', '', NULL);
INSERT INTO chado.dbxref VALUES (1537, 23, '0001117', '', NULL);
INSERT INTO chado.dbxref VALUES (1538, 34, '00040', '', NULL);
INSERT INTO chado.dbxref VALUES (1539, 23, '0001118', '', NULL);
INSERT INTO chado.dbxref VALUES (1540, 34, '00153', '', NULL);
INSERT INTO chado.dbxref VALUES (1541, 23, '0001119', '', NULL);
INSERT INTO chado.dbxref VALUES (1542, 34, '0000340', '', NULL);
INSERT INTO chado.dbxref VALUES (1543, 23, '0001120', '', NULL);
INSERT INTO chado.dbxref VALUES (1544, 34, '00223', '', NULL);
INSERT INTO chado.dbxref VALUES (1545, 23, '0001121', '', NULL);
INSERT INTO chado.dbxref VALUES (1546, 34, '00224', '', NULL);
INSERT INTO chado.dbxref VALUES (1547, 23, '0001122', '', NULL);
INSERT INTO chado.dbxref VALUES (1548, 34, '00225', '', NULL);
INSERT INTO chado.dbxref VALUES (1549, 23, '0001123', '', NULL);
INSERT INTO chado.dbxref VALUES (1550, 34, '00226', '', NULL);
INSERT INTO chado.dbxref VALUES (1551, 23, '0001124', '', NULL);
INSERT INTO chado.dbxref VALUES (1552, 34, '00228', '', NULL);
INSERT INTO chado.dbxref VALUES (1553, 23, '0001125', '', NULL);
INSERT INTO chado.dbxref VALUES (1554, 34, '00227', '', NULL);
INSERT INTO chado.dbxref VALUES (1555, 23, '0001126', '', NULL);
INSERT INTO chado.dbxref VALUES (1556, 34, '00229', '', NULL);
INSERT INTO chado.dbxref VALUES (1557, 23, '0001127', '', NULL);
INSERT INTO chado.dbxref VALUES (1558, 34, '00230', '', NULL);
INSERT INTO chado.dbxref VALUES (1559, 34, '00148', '', NULL);
INSERT INTO chado.dbxref VALUES (1560, 23, '0001129', '', NULL);
INSERT INTO chado.dbxref VALUES (1561, 34, '00206', '', NULL);
INSERT INTO chado.dbxref VALUES (1562, 23, '0001130', '', NULL);
INSERT INTO chado.dbxref VALUES (1563, 34, '00204', '', NULL);
INSERT INTO chado.dbxref VALUES (1564, 23, '0001131', '', NULL);
INSERT INTO chado.dbxref VALUES (1565, 34, '00205', '', NULL);
INSERT INTO chado.dbxref VALUES (1566, 23, '0001132', '', NULL);
INSERT INTO chado.dbxref VALUES (1567, 34, '00207', '', NULL);
INSERT INTO chado.dbxref VALUES (1568, 23, '0001133', '', NULL);
INSERT INTO chado.dbxref VALUES (1569, 34, '00212', '', NULL);
INSERT INTO chado.dbxref VALUES (1570, 23, '0001134', '', NULL);
INSERT INTO chado.dbxref VALUES (1571, 34, '00215', '', NULL);
INSERT INTO chado.dbxref VALUES (1572, 23, '0001135', '', NULL);
INSERT INTO chado.dbxref VALUES (1573, 34, '00213', '', NULL);
INSERT INTO chado.dbxref VALUES (1574, 23, '0001136', '', NULL);
INSERT INTO chado.dbxref VALUES (1575, 34, '00216', '', NULL);
INSERT INTO chado.dbxref VALUES (1576, 23, '0001137', '', NULL);
INSERT INTO chado.dbxref VALUES (1577, 34, '00214', '', NULL);
INSERT INTO chado.dbxref VALUES (1578, 23, '0001138', '', NULL);
INSERT INTO chado.dbxref VALUES (1579, 34, '00219', '', NULL);
INSERT INTO chado.dbxref VALUES (1580, 23, '0001139', '', NULL);
INSERT INTO chado.dbxref VALUES (1581, 34, '00220', '', NULL);
INSERT INTO chado.dbxref VALUES (1582, 23, '0001140', '', NULL);
INSERT INTO chado.dbxref VALUES (1583, 34, '00221', '', NULL);
INSERT INTO chado.dbxref VALUES (1584, 23, '0001141', '', NULL);
INSERT INTO chado.dbxref VALUES (1585, 34, '00231', '', NULL);
INSERT INTO chado.dbxref VALUES (1586, 23, '0001142', '', NULL);
INSERT INTO chado.dbxref VALUES (1587, 34, '00234', '', NULL);
INSERT INTO chado.dbxref VALUES (1588, 23, '0001143', '', NULL);
INSERT INTO chado.dbxref VALUES (1589, 34, '00232', '', NULL);
INSERT INTO chado.dbxref VALUES (1590, 23, '0001144', '', NULL);
INSERT INTO chado.dbxref VALUES (1591, 34, '00235', '', NULL);
INSERT INTO chado.dbxref VALUES (1592, 23, '0001145', '', NULL);
INSERT INTO chado.dbxref VALUES (1593, 34, '00233', '', NULL);
INSERT INTO chado.dbxref VALUES (1594, 23, '0001146', '', NULL);
INSERT INTO chado.dbxref VALUES (1595, 34, '00336', '', NULL);
INSERT INTO chado.dbxref VALUES (1596, 23, '0001147', '', NULL);
INSERT INTO chado.dbxref VALUES (1597, 34, '00071', '', NULL);
INSERT INTO chado.dbxref VALUES (1598, 23, '0001148', '', NULL);
INSERT INTO chado.dbxref VALUES (1599, 34, '00036', '', NULL);
INSERT INTO chado.dbxref VALUES (1600, 23, '0001149', '', NULL);
INSERT INTO chado.dbxref VALUES (1601, 34, '00073', '', NULL);
INSERT INTO chado.dbxref VALUES (1602, 23, '0001065', '', NULL);
INSERT INTO chado.dbxref VALUES (1603, 23, '0001150', '', NULL);
INSERT INTO chado.dbxref VALUES (1604, 23, '0001151', '', NULL);
INSERT INTO chado.dbxref VALUES (1605, 23, '0001152', '', NULL);
INSERT INTO chado.dbxref VALUES (1606, 23, '0001153', '', NULL);
INSERT INTO chado.dbxref VALUES (1607, 23, '0001154', '', NULL);
INSERT INTO chado.dbxref VALUES (1608, 23, '0001155', '', NULL);
INSERT INTO chado.dbxref VALUES (1609, 23, '0001156', '', NULL);
INSERT INTO chado.dbxref VALUES (1610, 23, '0001157', '', NULL);
INSERT INTO chado.dbxref VALUES (1611, 23, '0001158', '', NULL);
INSERT INTO chado.dbxref VALUES (1612, 23, '0001159', '', NULL);
INSERT INTO chado.dbxref VALUES (1613, 23, '0001160', '', NULL);
INSERT INTO chado.dbxref VALUES (1614, 23, '0001161', '', NULL);
INSERT INTO chado.dbxref VALUES (1615, 23, '0001162', '', NULL);
INSERT INTO chado.dbxref VALUES (1616, 23, '0001163', '', NULL);
INSERT INTO chado.dbxref VALUES (1617, 23, '0001164', '', NULL);
INSERT INTO chado.dbxref VALUES (1618, 23, '0001165', '', NULL);
INSERT INTO chado.dbxref VALUES (1619, 23, '0001166', '', NULL);
INSERT INTO chado.dbxref VALUES (1620, 23, '0001167', '', NULL);
INSERT INTO chado.dbxref VALUES (1621, 23, '0001168', '', NULL);
INSERT INTO chado.dbxref VALUES (1622, 23, '0001169', '', NULL);
INSERT INTO chado.dbxref VALUES (1623, 23, '0001170', '', NULL);
INSERT INTO chado.dbxref VALUES (1624, 23, '0001171', '', NULL);
INSERT INTO chado.dbxref VALUES (1625, 23, '0001172', '', NULL);
INSERT INTO chado.dbxref VALUES (1626, 23, '0001173', '', NULL);
INSERT INTO chado.dbxref VALUES (1627, 23, '0001174', '', NULL);
INSERT INTO chado.dbxref VALUES (1628, 23, '0001175', '', NULL);
INSERT INTO chado.dbxref VALUES (1629, 23, '0001176', '', NULL);
INSERT INTO chado.dbxref VALUES (1630, 23, '0001177', '', NULL);
INSERT INTO chado.dbxref VALUES (1631, 23, '0001179', '', NULL);
INSERT INTO chado.dbxref VALUES (1632, 23, '0001180', '', NULL);
INSERT INTO chado.dbxref VALUES (1633, 23, '0001181', '', NULL);
INSERT INTO chado.dbxref VALUES (1634, 23, '0001182', '', NULL);
INSERT INTO chado.dbxref VALUES (1635, 23, '0001187', '', NULL);
INSERT INTO chado.dbxref VALUES (1636, 23, '0001188', '', NULL);
INSERT INTO chado.dbxref VALUES (1637, 23, '0001189', '', NULL);
INSERT INTO chado.dbxref VALUES (1638, 23, '0001190', '', NULL);
INSERT INTO chado.dbxref VALUES (1639, 23, '0001191', '', NULL);
INSERT INTO chado.dbxref VALUES (1640, 23, '0001192', '', NULL);
INSERT INTO chado.dbxref VALUES (1641, 23, '0001193', '', NULL);
INSERT INTO chado.dbxref VALUES (1642, 23, '0001194', '', NULL);
INSERT INTO chado.dbxref VALUES (1643, 23, '0001195', '', NULL);
INSERT INTO chado.dbxref VALUES (1644, 23, '0001196', '', NULL);
INSERT INTO chado.dbxref VALUES (1645, 23, '0001197', '', NULL);
INSERT INTO chado.dbxref VALUES (1646, 23, '0001198', '', NULL);
INSERT INTO chado.dbxref VALUES (1647, 23, '0001199', '', NULL);
INSERT INTO chado.dbxref VALUES (1648, 23, '0001200', '', NULL);
INSERT INTO chado.dbxref VALUES (1649, 23, '0001201', '', NULL);
INSERT INTO chado.dbxref VALUES (1650, 23, '0001202', '', NULL);
INSERT INTO chado.dbxref VALUES (1651, 23, '0001203', '', NULL);
INSERT INTO chado.dbxref VALUES (1652, 23, '0001204', '', NULL);
INSERT INTO chado.dbxref VALUES (1653, 23, '0002311', '', NULL);
INSERT INTO chado.dbxref VALUES (1654, 23, '0001205', '', NULL);
INSERT INTO chado.dbxref VALUES (1655, 23, '0001206', '', NULL);
INSERT INTO chado.dbxref VALUES (1656, 23, '0001207', '', NULL);
INSERT INTO chado.dbxref VALUES (1657, 23, '0001208', '', NULL);
INSERT INTO chado.dbxref VALUES (1658, 23, '0001209', '', NULL);
INSERT INTO chado.dbxref VALUES (1659, 23, '0001210', '', NULL);
INSERT INTO chado.dbxref VALUES (1660, 23, '0001211', '', NULL);
INSERT INTO chado.dbxref VALUES (1661, 23, '0001212', '', NULL);
INSERT INTO chado.dbxref VALUES (1662, 23, '0001213', '', NULL);
INSERT INTO chado.dbxref VALUES (1663, 23, '0001216', '', NULL);
INSERT INTO chado.dbxref VALUES (1664, 23, '0001218', '', NULL);
INSERT INTO chado.dbxref VALUES (1665, 23, '0001219', '', NULL);
INSERT INTO chado.dbxref VALUES (1666, 23, '0001220', '', NULL);
INSERT INTO chado.dbxref VALUES (1667, 23, '0001221', '', NULL);
INSERT INTO chado.dbxref VALUES (1668, 23, '0001222', '', NULL);
INSERT INTO chado.dbxref VALUES (1669, 23, '0001223', '', NULL);
INSERT INTO chado.dbxref VALUES (1670, 23, '0001224', '', NULL);
INSERT INTO chado.dbxref VALUES (1671, 23, '0001225', '', NULL);
INSERT INTO chado.dbxref VALUES (1672, 23, '0001226', '', NULL);
INSERT INTO chado.dbxref VALUES (1673, 23, '0001227', '', NULL);
INSERT INTO chado.dbxref VALUES (1674, 23, '0001228', '', NULL);
INSERT INTO chado.dbxref VALUES (1675, 35, '051', '', NULL);
INSERT INTO chado.dbxref VALUES (1676, 23, '0001277', '', NULL);
INSERT INTO chado.dbxref VALUES (1677, 23, '0001229', '', NULL);
INSERT INTO chado.dbxref VALUES (1678, 35, '050', '', NULL);
INSERT INTO chado.dbxref VALUES (1679, 23, '0001230', '', NULL);
INSERT INTO chado.dbxref VALUES (1680, 23, '0001231', '', NULL);
INSERT INTO chado.dbxref VALUES (1681, 23, '0001232', '', NULL);
INSERT INTO chado.dbxref VALUES (1682, 23, '0001233', '', NULL);
INSERT INTO chado.dbxref VALUES (1683, 23, '0001274', '', NULL);
INSERT INTO chado.dbxref VALUES (1684, 23, '0001238', '', NULL);
INSERT INTO chado.dbxref VALUES (1685, 23, '0001239', '', NULL);
INSERT INTO chado.dbxref VALUES (1686, 23, '0001240', '', NULL);
INSERT INTO chado.dbxref VALUES (1687, 23, '0001241', '', NULL);
INSERT INTO chado.dbxref VALUES (1688, 23, '0001243', '', NULL);
INSERT INTO chado.dbxref VALUES (1689, 23, '0001245', '', NULL);
INSERT INTO chado.dbxref VALUES (1690, 23, '0001246', '', NULL);
INSERT INTO chado.dbxref VALUES (1691, 23, '0001249', '', NULL);
INSERT INTO chado.dbxref VALUES (1692, 23, '0001250', '', NULL);
INSERT INTO chado.dbxref VALUES (1693, 23, '0001251', '', NULL);
INSERT INTO chado.dbxref VALUES (1694, 23, '0001252', '', NULL);
INSERT INTO chado.dbxref VALUES (1695, 23, '0001253', '', NULL);
INSERT INTO chado.dbxref VALUES (1696, 23, '0001254', '', NULL);
INSERT INTO chado.dbxref VALUES (1697, 23, '0001255', '', NULL);
INSERT INTO chado.dbxref VALUES (1698, 23, '0001256', '', NULL);
INSERT INTO chado.dbxref VALUES (1699, 23, '0001257', '', NULL);
INSERT INTO chado.dbxref VALUES (1700, 23, '0001258', '', NULL);
INSERT INTO chado.dbxref VALUES (1701, 23, '0001259', '', NULL);
INSERT INTO chado.dbxref VALUES (1702, 23, '0001261', '', NULL);
INSERT INTO chado.dbxref VALUES (1703, 23, '0001262', '', NULL);
INSERT INTO chado.dbxref VALUES (1704, 23, '0001263', '', NULL);
INSERT INTO chado.dbxref VALUES (1705, 23, '0001264', '', NULL);
INSERT INTO chado.dbxref VALUES (1706, 23, '0001265', '', NULL);
INSERT INTO chado.dbxref VALUES (1707, 23, '0001270', '', NULL);
INSERT INTO chado.dbxref VALUES (1708, 23, '0002342', '', NULL);
INSERT INTO chado.dbxref VALUES (1709, 23, '0001266', '', NULL);
INSERT INTO chado.dbxref VALUES (1710, 23, '0001267', '', NULL);
INSERT INTO chado.dbxref VALUES (1711, 23, '0001268', '', NULL);
INSERT INTO chado.dbxref VALUES (1712, 23, '0001269', '', NULL);
INSERT INTO chado.dbxref VALUES (1713, 23, '0001271', '', NULL);
INSERT INTO chado.dbxref VALUES (1714, 23, '0001272', '', NULL);
INSERT INTO chado.dbxref VALUES (1715, 23, '0001273', '', NULL);
INSERT INTO chado.dbxref VALUES (1716, 23, '0001275', '', NULL);
INSERT INTO chado.dbxref VALUES (1717, 23, '0001276', '', NULL);
INSERT INTO chado.dbxref VALUES (1718, 23, '0001278', '', NULL);
INSERT INTO chado.dbxref VALUES (1719, 35, '018', '', NULL);
INSERT INTO chado.dbxref VALUES (1720, 23, '0001279', '', NULL);
INSERT INTO chado.dbxref VALUES (1721, 35, '019', '', NULL);
INSERT INTO chado.dbxref VALUES (1722, 23, '0001280', '', NULL);
INSERT INTO chado.dbxref VALUES (1723, 35, '081', '', NULL);
INSERT INTO chado.dbxref VALUES (1724, 23, '0001281', '', NULL);
INSERT INTO chado.dbxref VALUES (1725, 35, '020', '', NULL);
INSERT INTO chado.dbxref VALUES (1726, 23, '0001282', '', NULL);
INSERT INTO chado.dbxref VALUES (1727, 35, '021', '', NULL);
INSERT INTO chado.dbxref VALUES (1728, 23, '0001283', '', NULL);
INSERT INTO chado.dbxref VALUES (1729, 35, '022', '', NULL);
INSERT INTO chado.dbxref VALUES (1730, 23, '0001284', '', NULL);
INSERT INTO chado.dbxref VALUES (1731, 35, '023', '', NULL);
INSERT INTO chado.dbxref VALUES (1732, 23, '0001285', '', NULL);
INSERT INTO chado.dbxref VALUES (1733, 35, '024', '', NULL);
INSERT INTO chado.dbxref VALUES (1734, 23, '0001286', '', NULL);
INSERT INTO chado.dbxref VALUES (1735, 35, '025', '', NULL);
INSERT INTO chado.dbxref VALUES (1736, 23, '0001287', '', NULL);
INSERT INTO chado.dbxref VALUES (1737, 35, '026', '', NULL);
INSERT INTO chado.dbxref VALUES (1738, 23, '0001288', '', NULL);
INSERT INTO chado.dbxref VALUES (1739, 35, '027', '', NULL);
INSERT INTO chado.dbxref VALUES (1740, 23, '0001289', '', NULL);
INSERT INTO chado.dbxref VALUES (1741, 35, '028', '', NULL);
INSERT INTO chado.dbxref VALUES (1742, 23, '0001290', '', NULL);
INSERT INTO chado.dbxref VALUES (1743, 35, '082', '', NULL);
INSERT INTO chado.dbxref VALUES (1744, 23, '0001291', '', NULL);
INSERT INTO chado.dbxref VALUES (1745, 35, '083', '', NULL);
INSERT INTO chado.dbxref VALUES (1746, 23, '0001292', '', NULL);
INSERT INTO chado.dbxref VALUES (1747, 35, '084', '', NULL);
INSERT INTO chado.dbxref VALUES (1748, 23, '0001293', '', NULL);
INSERT INTO chado.dbxref VALUES (1749, 35, '095', '', NULL);
INSERT INTO chado.dbxref VALUES (1750, 23, '0001294', '', NULL);
INSERT INTO chado.dbxref VALUES (1751, 35, '107', '', NULL);
INSERT INTO chado.dbxref VALUES (1752, 23, '0001295', '', NULL);
INSERT INTO chado.dbxref VALUES (1753, 35, '001', '', NULL);
INSERT INTO chado.dbxref VALUES (1754, 23, '0001296', '', NULL);
INSERT INTO chado.dbxref VALUES (1755, 35, '002', '', NULL);
INSERT INTO chado.dbxref VALUES (1756, 23, '0001297', '', NULL);
INSERT INTO chado.dbxref VALUES (1757, 35, '003', '', NULL);
INSERT INTO chado.dbxref VALUES (1758, 23, '0001298', '', NULL);
INSERT INTO chado.dbxref VALUES (1759, 35, '004', '', NULL);
INSERT INTO chado.dbxref VALUES (1760, 23, '0001299', '', NULL);
INSERT INTO chado.dbxref VALUES (1761, 35, '005', '', NULL);
INSERT INTO chado.dbxref VALUES (1762, 23, '0001300', '', NULL);
INSERT INTO chado.dbxref VALUES (1763, 35, '006', '', NULL);
INSERT INTO chado.dbxref VALUES (1764, 23, '0001301', '', NULL);
INSERT INTO chado.dbxref VALUES (1765, 35, '007', '', NULL);
INSERT INTO chado.dbxref VALUES (1766, 23, '0001302', '', NULL);
INSERT INTO chado.dbxref VALUES (1767, 35, '008', '', NULL);
INSERT INTO chado.dbxref VALUES (1768, 23, '0001303', '', NULL);
INSERT INTO chado.dbxref VALUES (1769, 35, '009', '', NULL);
INSERT INTO chado.dbxref VALUES (1770, 23, '0001304', '', NULL);
INSERT INTO chado.dbxref VALUES (1771, 35, '010', '', NULL);
INSERT INTO chado.dbxref VALUES (1772, 23, '0001305', '', NULL);
INSERT INTO chado.dbxref VALUES (1773, 35, '011', '', NULL);
INSERT INTO chado.dbxref VALUES (1774, 23, '0001306', '', NULL);
INSERT INTO chado.dbxref VALUES (1775, 35, '012', '', NULL);
INSERT INTO chado.dbxref VALUES (1776, 23, '0001307', '', NULL);
INSERT INTO chado.dbxref VALUES (1777, 35, '013', '', NULL);
INSERT INTO chado.dbxref VALUES (1778, 23, '0001308', '', NULL);
INSERT INTO chado.dbxref VALUES (1779, 35, '014', '', NULL);
INSERT INTO chado.dbxref VALUES (1780, 23, '0001309', '', NULL);
INSERT INTO chado.dbxref VALUES (1781, 35, '015', '', NULL);
INSERT INTO chado.dbxref VALUES (1782, 23, '0001310', '', NULL);
INSERT INTO chado.dbxref VALUES (1783, 35, '016', '', NULL);
INSERT INTO chado.dbxref VALUES (1784, 23, '0001311', '', NULL);
INSERT INTO chado.dbxref VALUES (1785, 35, '080', '', NULL);
INSERT INTO chado.dbxref VALUES (1786, 23, '0001312', '', NULL);
INSERT INTO chado.dbxref VALUES (1787, 35, '088', '', NULL);
INSERT INTO chado.dbxref VALUES (1788, 23, '0001313', '', NULL);
INSERT INTO chado.dbxref VALUES (1789, 35, '089', '', NULL);
INSERT INTO chado.dbxref VALUES (1790, 23, '0001314', '', NULL);
INSERT INTO chado.dbxref VALUES (1791, 35, '097', '', NULL);
INSERT INTO chado.dbxref VALUES (1792, 23, '0001315', '', NULL);
INSERT INTO chado.dbxref VALUES (1793, 35, '102', '', NULL);
INSERT INTO chado.dbxref VALUES (1794, 23, '0001316', '', NULL);
INSERT INTO chado.dbxref VALUES (1795, 23, '0001317', '', NULL);
INSERT INTO chado.dbxref VALUES (1796, 35, '043', '', NULL);
INSERT INTO chado.dbxref VALUES (1797, 23, '0001318', '', NULL);
INSERT INTO chado.dbxref VALUES (1798, 35, '044', '', NULL);
INSERT INTO chado.dbxref VALUES (1799, 23, '0001319', '', NULL);
INSERT INTO chado.dbxref VALUES (1800, 35, '045', '', NULL);
INSERT INTO chado.dbxref VALUES (1801, 23, '0001320', '', NULL);
INSERT INTO chado.dbxref VALUES (1802, 35, '046', '', NULL);
INSERT INTO chado.dbxref VALUES (1803, 23, '0001321', '', NULL);
INSERT INTO chado.dbxref VALUES (1804, 35, '047', '', NULL);
INSERT INTO chado.dbxref VALUES (1805, 23, '0001322', '', NULL);
INSERT INTO chado.dbxref VALUES (1806, 35, '048', '', NULL);
INSERT INTO chado.dbxref VALUES (1807, 23, '0001323', '', NULL);
INSERT INTO chado.dbxref VALUES (1808, 35, '049', '', NULL);
INSERT INTO chado.dbxref VALUES (1809, 23, '0001324', '', NULL);
INSERT INTO chado.dbxref VALUES (1810, 35, '029', '', NULL);
INSERT INTO chado.dbxref VALUES (1811, 23, '0001325', '', NULL);
INSERT INTO chado.dbxref VALUES (1812, 35, '030', '', NULL);
INSERT INTO chado.dbxref VALUES (1813, 23, '0001326', '', NULL);
INSERT INTO chado.dbxref VALUES (1814, 35, '031', '', NULL);
INSERT INTO chado.dbxref VALUES (1815, 23, '0001327', '', NULL);
INSERT INTO chado.dbxref VALUES (1816, 35, '032', '', NULL);
INSERT INTO chado.dbxref VALUES (1817, 23, '0001328', '', NULL);
INSERT INTO chado.dbxref VALUES (1818, 35, '033', '', NULL);
INSERT INTO chado.dbxref VALUES (1819, 23, '0001329', '', NULL);
INSERT INTO chado.dbxref VALUES (1820, 35, '034', '', NULL);
INSERT INTO chado.dbxref VALUES (1821, 23, '0001330', '', NULL);
INSERT INTO chado.dbxref VALUES (1822, 35, '035', '', NULL);
INSERT INTO chado.dbxref VALUES (1823, 23, '0001331', '', NULL);
INSERT INTO chado.dbxref VALUES (1824, 35, '036', '', NULL);
INSERT INTO chado.dbxref VALUES (1825, 23, '0001332', '', NULL);
INSERT INTO chado.dbxref VALUES (1826, 35, '037', '', NULL);
INSERT INTO chado.dbxref VALUES (1827, 23, '0001333', '', NULL);
INSERT INTO chado.dbxref VALUES (1828, 35, '038', '', NULL);
INSERT INTO chado.dbxref VALUES (1829, 23, '0001334', '', NULL);
INSERT INTO chado.dbxref VALUES (1830, 35, '039', '', NULL);
INSERT INTO chado.dbxref VALUES (1831, 23, '0001335', '', NULL);
INSERT INTO chado.dbxref VALUES (1832, 35, '040', '', NULL);
INSERT INTO chado.dbxref VALUES (1833, 23, '0001336', '', NULL);
INSERT INTO chado.dbxref VALUES (1834, 35, '041', '', NULL);
INSERT INTO chado.dbxref VALUES (1835, 23, '0001337', '', NULL);
INSERT INTO chado.dbxref VALUES (1836, 35, '042', '', NULL);
INSERT INTO chado.dbxref VALUES (1837, 23, '0001338', '', NULL);
INSERT INTO chado.dbxref VALUES (1838, 35, '090', '', NULL);
INSERT INTO chado.dbxref VALUES (1839, 23, '0001339', '', NULL);
INSERT INTO chado.dbxref VALUES (1840, 35, '091', '', NULL);
INSERT INTO chado.dbxref VALUES (1841, 23, '0001340', '', NULL);
INSERT INTO chado.dbxref VALUES (1842, 35, '096', '', NULL);
INSERT INTO chado.dbxref VALUES (1843, 23, '0001341', '', NULL);
INSERT INTO chado.dbxref VALUES (1844, 35, '100', '', NULL);
INSERT INTO chado.dbxref VALUES (1845, 23, '0001342', '', NULL);
INSERT INTO chado.dbxref VALUES (1846, 35, '101', '', NULL);
INSERT INTO chado.dbxref VALUES (1847, 23, '0001343', '', NULL);
INSERT INTO chado.dbxref VALUES (1848, 35, '106', '', NULL);
INSERT INTO chado.dbxref VALUES (1849, 23, '0001344', '', NULL);
INSERT INTO chado.dbxref VALUES (1850, 35, '052', '', NULL);
INSERT INTO chado.dbxref VALUES (1851, 23, '0001345', '', NULL);
INSERT INTO chado.dbxref VALUES (1852, 35, '053', '', NULL);
INSERT INTO chado.dbxref VALUES (1853, 23, '0001346', '', NULL);
INSERT INTO chado.dbxref VALUES (1854, 35, '054', '', NULL);
INSERT INTO chado.dbxref VALUES (1855, 23, '0001347', '', NULL);
INSERT INTO chado.dbxref VALUES (1856, 35, '055', '', NULL);
INSERT INTO chado.dbxref VALUES (1857, 23, '0001348', '', NULL);
INSERT INTO chado.dbxref VALUES (1858, 35, '056', '', NULL);
INSERT INTO chado.dbxref VALUES (1859, 23, '0001349', '', NULL);
INSERT INTO chado.dbxref VALUES (1860, 35, '057', '', NULL);
INSERT INTO chado.dbxref VALUES (1861, 23, '0001350', '', NULL);
INSERT INTO chado.dbxref VALUES (1862, 35, '058', '', NULL);
INSERT INTO chado.dbxref VALUES (1863, 23, '0001351', '', NULL);
INSERT INTO chado.dbxref VALUES (1864, 35, '059', '', NULL);
INSERT INTO chado.dbxref VALUES (1865, 23, '0001352', '', NULL);
INSERT INTO chado.dbxref VALUES (1866, 35, '060', '', NULL);
INSERT INTO chado.dbxref VALUES (1867, 23, '0001353', '', NULL);
INSERT INTO chado.dbxref VALUES (1868, 35, '061', '', NULL);
INSERT INTO chado.dbxref VALUES (1869, 23, '0001354', '', NULL);
INSERT INTO chado.dbxref VALUES (1870, 23, '0001355', '', NULL);
INSERT INTO chado.dbxref VALUES (1871, 35, '063', '', NULL);
INSERT INTO chado.dbxref VALUES (1872, 23, '0001356', '', NULL);
INSERT INTO chado.dbxref VALUES (1873, 35, '064', '', NULL);
INSERT INTO chado.dbxref VALUES (1874, 23, '0001357', '', NULL);
INSERT INTO chado.dbxref VALUES (1875, 35, '065', '', NULL);
INSERT INTO chado.dbxref VALUES (1876, 23, '0001358', '', NULL);
INSERT INTO chado.dbxref VALUES (1877, 35, '066', '', NULL);
INSERT INTO chado.dbxref VALUES (1878, 23, '0001359', '', NULL);
INSERT INTO chado.dbxref VALUES (1879, 35, '067', '', NULL);
INSERT INTO chado.dbxref VALUES (1880, 23, '0001360', '', NULL);
INSERT INTO chado.dbxref VALUES (1881, 35, '068', '', NULL);
INSERT INTO chado.dbxref VALUES (1882, 23, '0001361', '', NULL);
INSERT INTO chado.dbxref VALUES (1883, 35, '069', '', NULL);
INSERT INTO chado.dbxref VALUES (1884, 23, '0001362', '', NULL);
INSERT INTO chado.dbxref VALUES (1885, 35, '070', '', NULL);
INSERT INTO chado.dbxref VALUES (1886, 23, '0001363', '', NULL);
INSERT INTO chado.dbxref VALUES (1887, 35, '071', '', NULL);
INSERT INTO chado.dbxref VALUES (1888, 23, '0001364', '', NULL);
INSERT INTO chado.dbxref VALUES (1889, 35, '072', '', NULL);
INSERT INTO chado.dbxref VALUES (1890, 23, '0001365', '', NULL);
INSERT INTO chado.dbxref VALUES (1891, 35, '073', '', NULL);
INSERT INTO chado.dbxref VALUES (1892, 23, '0001366', '', NULL);
INSERT INTO chado.dbxref VALUES (1893, 35, '074', '', NULL);
INSERT INTO chado.dbxref VALUES (1894, 23, '0001367', '', NULL);
INSERT INTO chado.dbxref VALUES (1895, 35, '075', '', NULL);
INSERT INTO chado.dbxref VALUES (1896, 23, '0001368', '', NULL);
INSERT INTO chado.dbxref VALUES (1897, 35, '076', '', NULL);
INSERT INTO chado.dbxref VALUES (1898, 23, '0001369', '', NULL);
INSERT INTO chado.dbxref VALUES (1899, 35, '077', '', NULL);
INSERT INTO chado.dbxref VALUES (1900, 23, '0001370', '', NULL);
INSERT INTO chado.dbxref VALUES (1901, 35, '078', '', NULL);
INSERT INTO chado.dbxref VALUES (1902, 23, '0001371', '', NULL);
INSERT INTO chado.dbxref VALUES (1903, 35, '079', '', NULL);
INSERT INTO chado.dbxref VALUES (1904, 23, '0001372', '', NULL);
INSERT INTO chado.dbxref VALUES (1905, 35, '085', '', NULL);
INSERT INTO chado.dbxref VALUES (1906, 23, '0001373', '', NULL);
INSERT INTO chado.dbxref VALUES (1907, 35, '086', '', NULL);
INSERT INTO chado.dbxref VALUES (1908, 23, '0001374', '', NULL);
INSERT INTO chado.dbxref VALUES (1909, 35, '087', '', NULL);
INSERT INTO chado.dbxref VALUES (1910, 23, '0001375', '', NULL);
INSERT INTO chado.dbxref VALUES (1911, 35, '092', '', NULL);
INSERT INTO chado.dbxref VALUES (1912, 23, '0001376', '', NULL);
INSERT INTO chado.dbxref VALUES (1913, 35, '093', '', NULL);
INSERT INTO chado.dbxref VALUES (1914, 23, '0001377', '', NULL);
INSERT INTO chado.dbxref VALUES (1915, 35, '094', '', NULL);
INSERT INTO chado.dbxref VALUES (1916, 23, '0001378', '', NULL);
INSERT INTO chado.dbxref VALUES (1917, 35, '098', '', NULL);
INSERT INTO chado.dbxref VALUES (1918, 23, '0001379', '', NULL);
INSERT INTO chado.dbxref VALUES (1919, 35, '099', '', NULL);
INSERT INTO chado.dbxref VALUES (1920, 23, '0001380', '', NULL);
INSERT INTO chado.dbxref VALUES (1921, 35, '103', '', NULL);
INSERT INTO chado.dbxref VALUES (1922, 23, '0001381', '', NULL);
INSERT INTO chado.dbxref VALUES (1923, 35, '104', '', NULL);
INSERT INTO chado.dbxref VALUES (1924, 23, '0001382', '', NULL);
INSERT INTO chado.dbxref VALUES (1925, 35, '105', '', NULL);
INSERT INTO chado.dbxref VALUES (1926, 23, '0001383', '', NULL);
INSERT INTO chado.dbxref VALUES (1927, 23, '0001384', '', NULL);
INSERT INTO chado.dbxref VALUES (1928, 23, '0001385', '', NULL);
INSERT INTO chado.dbxref VALUES (1929, 23, '0001386', '', NULL);
INSERT INTO chado.dbxref VALUES (1930, 36, '00908', '', NULL);
INSERT INTO chado.dbxref VALUES (1931, 23, '0001387', '', NULL);
INSERT INTO chado.dbxref VALUES (1932, 36, '00901', '', NULL);
INSERT INTO chado.dbxref VALUES (1933, 23, '0001388', '', NULL);
INSERT INTO chado.dbxref VALUES (1934, 36, '00903', '', NULL);
INSERT INTO chado.dbxref VALUES (1935, 23, '0001389', '', NULL);
INSERT INTO chado.dbxref VALUES (1936, 36, '00904', '', NULL);
INSERT INTO chado.dbxref VALUES (1937, 23, '0001390', '', NULL);
INSERT INTO chado.dbxref VALUES (1938, 36, '00905', '', NULL);
INSERT INTO chado.dbxref VALUES (1939, 23, '0001391', '', NULL);
INSERT INTO chado.dbxref VALUES (1940, 36, '00906', '', NULL);
INSERT INTO chado.dbxref VALUES (1941, 23, '0001392', '', NULL);
INSERT INTO chado.dbxref VALUES (1942, 36, '00917', '', NULL);
INSERT INTO chado.dbxref VALUES (1943, 23, '0001393', '', NULL);
INSERT INTO chado.dbxref VALUES (1944, 36, '00918', '', NULL);
INSERT INTO chado.dbxref VALUES (1945, 23, '0001394', '', NULL);
INSERT INTO chado.dbxref VALUES (1946, 36, '00907', '', NULL);
INSERT INTO chado.dbxref VALUES (1947, 23, '0001395', '', NULL);
INSERT INTO chado.dbxref VALUES (1948, 36, '00913', '', NULL);
INSERT INTO chado.dbxref VALUES (1949, 23, '0001396', '', NULL);
INSERT INTO chado.dbxref VALUES (1950, 36, '00910', '', NULL);
INSERT INTO chado.dbxref VALUES (1951, 23, '0001397', '', NULL);
INSERT INTO chado.dbxref VALUES (1952, 36, '00914', '', NULL);
INSERT INTO chado.dbxref VALUES (1953, 23, '0001398', '', NULL);
INSERT INTO chado.dbxref VALUES (1954, 36, '00909', '', NULL);
INSERT INTO chado.dbxref VALUES (1955, 23, '0001399', '', NULL);
INSERT INTO chado.dbxref VALUES (1956, 36, '00916', '', NULL);
INSERT INTO chado.dbxref VALUES (1957, 23, '0001400', '', NULL);
INSERT INTO chado.dbxref VALUES (1958, 36, '00912', '', NULL);
INSERT INTO chado.dbxref VALUES (1959, 23, '0001401', '', NULL);
INSERT INTO chado.dbxref VALUES (1960, 36, '00911', '', NULL);
INSERT INTO chado.dbxref VALUES (1961, 23, '0001402', '', NULL);
INSERT INTO chado.dbxref VALUES (1962, 36, '01158', '', NULL);
INSERT INTO chado.dbxref VALUES (1963, 23, '0001403', '', NULL);
INSERT INTO chado.dbxref VALUES (1964, 36, '00920', '', NULL);
INSERT INTO chado.dbxref VALUES (1965, 23, '0001404', '', NULL);
INSERT INTO chado.dbxref VALUES (1966, 36, '00915', '', NULL);
INSERT INTO chado.dbxref VALUES (1967, 23, '0001405', '', NULL);
INSERT INTO chado.dbxref VALUES (1968, 36, '00919', '', NULL);
INSERT INTO chado.dbxref VALUES (1969, 23, '0001406', '', NULL);
INSERT INTO chado.dbxref VALUES (1970, 36, '00902', '', NULL);
INSERT INTO chado.dbxref VALUES (1971, 23, '0001407', '', NULL);
INSERT INTO chado.dbxref VALUES (1972, 23, '0001408', '', NULL);
INSERT INTO chado.dbxref VALUES (1973, 23, '0001413', '', NULL);
INSERT INTO chado.dbxref VALUES (1974, 23, '0001414', '', NULL);
INSERT INTO chado.dbxref VALUES (1975, 23, '0001415', '', NULL);
INSERT INTO chado.dbxref VALUES (1976, 23, '0001416', '', NULL);
INSERT INTO chado.dbxref VALUES (1977, 23, '0001417', '', NULL);
INSERT INTO chado.dbxref VALUES (1978, 23, '0001418', '', NULL);
INSERT INTO chado.dbxref VALUES (1979, 23, '0001421', '', NULL);
INSERT INTO chado.dbxref VALUES (1980, 23, '0001422', '', NULL);
INSERT INTO chado.dbxref VALUES (1981, 23, '0001423', '', NULL);
INSERT INTO chado.dbxref VALUES (1982, 23, '0001424', '', NULL);
INSERT INTO chado.dbxref VALUES (1983, 23, '0001425', '', NULL);
INSERT INTO chado.dbxref VALUES (1984, 23, '0001426', '', NULL);
INSERT INTO chado.dbxref VALUES (1985, 23, '0001427', '', NULL);
INSERT INTO chado.dbxref VALUES (1986, 23, '0001428', '', NULL);
INSERT INTO chado.dbxref VALUES (1987, 23, '0001429', '', NULL);
INSERT INTO chado.dbxref VALUES (1988, 23, '0001431', '', NULL);
INSERT INTO chado.dbxref VALUES (1989, 23, '0001432', '', NULL);
INSERT INTO chado.dbxref VALUES (1990, 23, '0001433', '', NULL);
INSERT INTO chado.dbxref VALUES (1991, 23, '0001434', '', NULL);
INSERT INTO chado.dbxref VALUES (1992, 23, '0001435', '', NULL);
INSERT INTO chado.dbxref VALUES (1993, 23, '0001436', '', NULL);
INSERT INTO chado.dbxref VALUES (1994, 23, '0001437', '', NULL);
INSERT INTO chado.dbxref VALUES (1995, 23, '0001438', '', NULL);
INSERT INTO chado.dbxref VALUES (1996, 23, '0001439', '', NULL);
INSERT INTO chado.dbxref VALUES (1997, 23, '0001440', '', NULL);
INSERT INTO chado.dbxref VALUES (1998, 23, '0001441', '', NULL);
INSERT INTO chado.dbxref VALUES (1999, 23, '0001442', '', NULL);
INSERT INTO chado.dbxref VALUES (2000, 23, '0001443', '', NULL);
INSERT INTO chado.dbxref VALUES (2001, 23, '0001444', '', NULL);
INSERT INTO chado.dbxref VALUES (2002, 23, '0001445', '', NULL);
INSERT INTO chado.dbxref VALUES (2003, 23, '0001446', '', NULL);
INSERT INTO chado.dbxref VALUES (2004, 23, '0001447', '', NULL);
INSERT INTO chado.dbxref VALUES (2005, 23, '0001448', '', NULL);
INSERT INTO chado.dbxref VALUES (2006, 23, '0001449', '', NULL);
INSERT INTO chado.dbxref VALUES (2007, 23, '0001450', '', NULL);
INSERT INTO chado.dbxref VALUES (2008, 23, '0001451', '', NULL);
INSERT INTO chado.dbxref VALUES (2009, 23, '0001452', '', NULL);
INSERT INTO chado.dbxref VALUES (2010, 23, '0001453', '', NULL);
INSERT INTO chado.dbxref VALUES (2011, 23, '0001454', '', NULL);
INSERT INTO chado.dbxref VALUES (2012, 23, '0001455', '', NULL);
INSERT INTO chado.dbxref VALUES (2013, 23, '0001456', '', NULL);
INSERT INTO chado.dbxref VALUES (2014, 23, '0001457', '', NULL);
INSERT INTO chado.dbxref VALUES (2015, 23, '0001458', '', NULL);
INSERT INTO chado.dbxref VALUES (2016, 23, '0001459', '', NULL);
INSERT INTO chado.dbxref VALUES (2017, 23, '0001460', '', NULL);
INSERT INTO chado.dbxref VALUES (2018, 23, '0001461', '', NULL);
INSERT INTO chado.dbxref VALUES (2019, 23, '0001462', '', NULL);
INSERT INTO chado.dbxref VALUES (2020, 23, '0001463', '', NULL);
INSERT INTO chado.dbxref VALUES (2021, 23, '0001877', '', NULL);
INSERT INTO chado.dbxref VALUES (2022, 23, '0001464', '', NULL);
INSERT INTO chado.dbxref VALUES (2023, 23, '0001465', '', NULL);
INSERT INTO chado.dbxref VALUES (2024, 23, '0001466', '', NULL);
INSERT INTO chado.dbxref VALUES (2025, 23, '0001467', '', NULL);
INSERT INTO chado.dbxref VALUES (2026, 23, '0001468', '', NULL);
INSERT INTO chado.dbxref VALUES (2027, 23, '0001469', '', NULL);
INSERT INTO chado.dbxref VALUES (2028, 23, '0001470', '', NULL);
INSERT INTO chado.dbxref VALUES (2029, 23, '0001471', '', NULL);
INSERT INTO chado.dbxref VALUES (2030, 23, '0001472', '', NULL);
INSERT INTO chado.dbxref VALUES (2031, 23, '0001473', '', NULL);
INSERT INTO chado.dbxref VALUES (2032, 23, '0001474', '', NULL);
INSERT INTO chado.dbxref VALUES (2033, 23, '0001475', '', NULL);
INSERT INTO chado.dbxref VALUES (2034, 23, '0001476', '', NULL);
INSERT INTO chado.dbxref VALUES (2035, 23, '0001477', '', NULL);
INSERT INTO chado.dbxref VALUES (2036, 23, '0001478', '', NULL);
INSERT INTO chado.dbxref VALUES (2037, 23, '0001479', '', NULL);
INSERT INTO chado.dbxref VALUES (2038, 23, '0001480', '', NULL);
INSERT INTO chado.dbxref VALUES (2039, 23, '0001481', '', NULL);
INSERT INTO chado.dbxref VALUES (2040, 23, '0001482', '', NULL);
INSERT INTO chado.dbxref VALUES (2041, 23, '1000002', '', NULL);
INSERT INTO chado.dbxref VALUES (2042, 23, '0001484', '', NULL);
INSERT INTO chado.dbxref VALUES (2043, 23, '0001485', '', NULL);
INSERT INTO chado.dbxref VALUES (2044, 23, '0001486', '', NULL);
INSERT INTO chado.dbxref VALUES (2045, 23, '0001499', '', NULL);
INSERT INTO chado.dbxref VALUES (2046, 23, '0001487', '', NULL);
INSERT INTO chado.dbxref VALUES (2047, 23, '0001488', '', NULL);
INSERT INTO chado.dbxref VALUES (2048, 23, '0001489', '', NULL);
INSERT INTO chado.dbxref VALUES (2049, 23, '0001490', '', NULL);
INSERT INTO chado.dbxref VALUES (2050, 23, '0001491', '', NULL);
INSERT INTO chado.dbxref VALUES (2051, 23, '0001492', '', NULL);
INSERT INTO chado.dbxref VALUES (2052, 23, '0001493', '', NULL);
INSERT INTO chado.dbxref VALUES (2053, 23, '0001794', '', NULL);
INSERT INTO chado.dbxref VALUES (2054, 23, '0001494', '', NULL);
INSERT INTO chado.dbxref VALUES (2055, 23, '0001495', '', NULL);
INSERT INTO chado.dbxref VALUES (2056, 23, '0001496', '', NULL);
INSERT INTO chado.dbxref VALUES (2057, 23, '0001497', '', NULL);
INSERT INTO chado.dbxref VALUES (2058, 23, '0001498', '', NULL);
INSERT INTO chado.dbxref VALUES (2059, 23, '0001501', '', NULL);
INSERT INTO chado.dbxref VALUES (2060, 23, '0001502', '', NULL);
INSERT INTO chado.dbxref VALUES (2061, 23, '0001503', '', NULL);
INSERT INTO chado.dbxref VALUES (2062, 23, '0001505', '', NULL);
INSERT INTO chado.dbxref VALUES (2063, 23, '0001506', '', NULL);
INSERT INTO chado.dbxref VALUES (2064, 23, '0001508', '', NULL);
INSERT INTO chado.dbxref VALUES (2065, 23, '0001509', '', NULL);
INSERT INTO chado.dbxref VALUES (2066, 23, '0001510', '', NULL);
INSERT INTO chado.dbxref VALUES (2067, 23, '0001511', '', NULL);
INSERT INTO chado.dbxref VALUES (2068, 23, '0001512', '', NULL);
INSERT INTO chado.dbxref VALUES (2069, 23, '0001513', '', NULL);
INSERT INTO chado.dbxref VALUES (2070, 23, '0001514', '', NULL);
INSERT INTO chado.dbxref VALUES (2071, 23, '0001515', '', NULL);
INSERT INTO chado.dbxref VALUES (2072, 23, '0001516', '', NULL);
INSERT INTO chado.dbxref VALUES (2073, 23, '0001523', '', NULL);
INSERT INTO chado.dbxref VALUES (2074, 23, '0001517', '', NULL);
INSERT INTO chado.dbxref VALUES (2075, 23, '0001518', '', NULL);
INSERT INTO chado.dbxref VALUES (2076, 23, '0001519', '', NULL);
INSERT INTO chado.dbxref VALUES (2077, 23, '0001520', '', NULL);
INSERT INTO chado.dbxref VALUES (2078, 23, '0001521', '', NULL);
INSERT INTO chado.dbxref VALUES (2079, 23, '0001522', '', NULL);
INSERT INTO chado.dbxref VALUES (2080, 23, '0001525', '', NULL);
INSERT INTO chado.dbxref VALUES (2081, 23, '0001526', '', NULL);
INSERT INTO chado.dbxref VALUES (2082, 23, '0001528', '', NULL);
INSERT INTO chado.dbxref VALUES (2083, 23, '0001529', '', NULL);
INSERT INTO chado.dbxref VALUES (2084, 23, '0001530', '', NULL);
INSERT INTO chado.dbxref VALUES (2085, 23, '0001531', '', NULL);
INSERT INTO chado.dbxref VALUES (2086, 23, '0001532', '', NULL);
INSERT INTO chado.dbxref VALUES (2087, 23, '0001533', '', NULL);
INSERT INTO chado.dbxref VALUES (2088, 23, '0001534', '', NULL);
INSERT INTO chado.dbxref VALUES (2089, 17, '16027110', '', NULL);
INSERT INTO chado.dbxref VALUES (2090, 23, '0001535', '', NULL);
INSERT INTO chado.dbxref VALUES (2091, 23, '0001536', '', NULL);
INSERT INTO chado.dbxref VALUES (2092, 23, '0001537', '', NULL);
INSERT INTO chado.dbxref VALUES (2093, 23, '0001538', '', NULL);
INSERT INTO chado.dbxref VALUES (2094, 23, '0002218', '', NULL);
INSERT INTO chado.dbxref VALUES (2095, 23, '0001539', '', NULL);
INSERT INTO chado.dbxref VALUES (2096, 23, '0001540', '', NULL);
INSERT INTO chado.dbxref VALUES (2097, 23, '0001541', '', NULL);
INSERT INTO chado.dbxref VALUES (2098, 23, '0001542', '', NULL);
INSERT INTO chado.dbxref VALUES (2099, 23, '0001543', '', NULL);
INSERT INTO chado.dbxref VALUES (2100, 23, '0001544', '', NULL);
INSERT INTO chado.dbxref VALUES (2101, 23, '0001545', '', NULL);
INSERT INTO chado.dbxref VALUES (2102, 23, '0001546', '', NULL);
INSERT INTO chado.dbxref VALUES (2103, 23, '0001547', '', NULL);
INSERT INTO chado.dbxref VALUES (2104, 23, '0001548', '', NULL);
INSERT INTO chado.dbxref VALUES (2105, 23, '0001549', '', NULL);
INSERT INTO chado.dbxref VALUES (2106, 23, '0001550', '', NULL);
INSERT INTO chado.dbxref VALUES (2107, 23, '0001551', '', NULL);
INSERT INTO chado.dbxref VALUES (2108, 23, '0001552', '', NULL);
INSERT INTO chado.dbxref VALUES (2109, 23, '0001553', '', NULL);
INSERT INTO chado.dbxref VALUES (2110, 23, '0001554', '', NULL);
INSERT INTO chado.dbxref VALUES (2111, 23, '0001555', '', NULL);
INSERT INTO chado.dbxref VALUES (2112, 23, '0001556', '', NULL);
INSERT INTO chado.dbxref VALUES (2113, 23, '0001557', '', NULL);
INSERT INTO chado.dbxref VALUES (2114, 23, '0001558', '', NULL);
INSERT INTO chado.dbxref VALUES (2115, 23, '0001559', '', NULL);
INSERT INTO chado.dbxref VALUES (2116, 23, '0001560', '', NULL);
INSERT INTO chado.dbxref VALUES (2117, 23, '0001561', '', NULL);
INSERT INTO chado.dbxref VALUES (2118, 23, '0001562', '', NULL);
INSERT INTO chado.dbxref VALUES (2119, 23, '0001563', '', NULL);
INSERT INTO chado.dbxref VALUES (2120, 23, '0002160', '', NULL);
INSERT INTO chado.dbxref VALUES (2121, 23, '0001564', '', NULL);
INSERT INTO chado.dbxref VALUES (2122, 23, '0001565', '', NULL);
INSERT INTO chado.dbxref VALUES (2123, 23, '0001882', '', NULL);
INSERT INTO chado.dbxref VALUES (2124, 23, '0001566', '', NULL);
INSERT INTO chado.dbxref VALUES (2125, 23, '0001567', '', NULL);
INSERT INTO chado.dbxref VALUES (2126, 23, '0001590', '', NULL);
INSERT INTO chado.dbxref VALUES (2127, 23, '0001819', '', NULL);
INSERT INTO chado.dbxref VALUES (2128, 23, '0001568', '', NULL);
INSERT INTO chado.dbxref VALUES (2129, 37, 'www.ebi.ac.uk/mutations/recommendations/mutevent.html', '', NULL);
INSERT INTO chado.dbxref VALUES (2130, 23, '0001576', '', NULL);
INSERT INTO chado.dbxref VALUES (2131, 23, '0001569', '', NULL);
INSERT INTO chado.dbxref VALUES (2132, 23, '0001570', '', NULL);
INSERT INTO chado.dbxref VALUES (2133, 23, '0001571', '', NULL);
INSERT INTO chado.dbxref VALUES (2134, 23, '0001572', '', NULL);
INSERT INTO chado.dbxref VALUES (2135, 23, '0001573', '', NULL);
INSERT INTO chado.dbxref VALUES (2136, 23, '0001574', '', NULL);
INSERT INTO chado.dbxref VALUES (2137, 23, '0001629', '', NULL);
INSERT INTO chado.dbxref VALUES (2138, 23, '0001575', '', NULL);
INSERT INTO chado.dbxref VALUES (2139, 23, '0001577', '', NULL);
INSERT INTO chado.dbxref VALUES (2140, 23, '0001578', '', NULL);
INSERT INTO chado.dbxref VALUES (2141, 23, '0001907', '', NULL);
INSERT INTO chado.dbxref VALUES (2142, 23, '0001992', '', NULL);
INSERT INTO chado.dbxref VALUES (2143, 23, '0001579', '', NULL);
INSERT INTO chado.dbxref VALUES (2144, 23, '0001580', '', NULL);
INSERT INTO chado.dbxref VALUES (2145, 23, '0001581', '', NULL);
INSERT INTO chado.dbxref VALUES (2146, 23, '0001791', '', NULL);
INSERT INTO chado.dbxref VALUES (2147, 23, '0001968', '', NULL);
INSERT INTO chado.dbxref VALUES (2148, 23, '0001582', '', NULL);
INSERT INTO chado.dbxref VALUES (2149, 33, 'LA6695-6', '', NULL);
INSERT INTO chado.dbxref VALUES (2150, 23, '0001583', '', NULL);
INSERT INTO chado.dbxref VALUES (2151, 23, '0001584', '', NULL);
INSERT INTO chado.dbxref VALUES (2152, 23, '0001783', '', NULL);
INSERT INTO chado.dbxref VALUES (2153, 33, 'LA6698-0', '', NULL);
INSERT INTO chado.dbxref VALUES (2154, 23, '0001585', '', NULL);
INSERT INTO chado.dbxref VALUES (2155, 23, '0001586', '', NULL);
INSERT INTO chado.dbxref VALUES (2156, 23, '0001587', '', NULL);
INSERT INTO chado.dbxref VALUES (2157, 33, 'LA6699-8', '', NULL);
INSERT INTO chado.dbxref VALUES (2158, 23, '0001906', '', NULL);
INSERT INTO chado.dbxref VALUES (2159, 23, '0001589', '', NULL);
INSERT INTO chado.dbxref VALUES (2160, 33, 'LA6694-9', '', NULL);
INSERT INTO chado.dbxref VALUES (2161, 23, '0001818', '', NULL);
INSERT INTO chado.dbxref VALUES (2162, 23, '0001625', '', NULL);
INSERT INTO chado.dbxref VALUES (2163, 33, 'LA6700-2', '', NULL);
INSERT INTO chado.dbxref VALUES (2164, 23, '0001591', '', NULL);
INSERT INTO chado.dbxref VALUES (2165, 23, '0001592', '', NULL);
INSERT INTO chado.dbxref VALUES (2166, 23, '0001593', '', NULL);
INSERT INTO chado.dbxref VALUES (2167, 23, '0001594', '', NULL);
INSERT INTO chado.dbxref VALUES (2168, 23, '0001595', '', NULL);
INSERT INTO chado.dbxref VALUES (2169, 23, '0001596', '', NULL);
INSERT INTO chado.dbxref VALUES (2170, 23, '0001597', '', NULL);
INSERT INTO chado.dbxref VALUES (2171, 23, '0001598', '', NULL);
INSERT INTO chado.dbxref VALUES (2172, 23, '0001599', '', NULL);
INSERT INTO chado.dbxref VALUES (2173, 23, '0001600', '', NULL);
INSERT INTO chado.dbxref VALUES (2174, 23, '0001601', '', NULL);
INSERT INTO chado.dbxref VALUES (2175, 23, '0001602', '', NULL);
INSERT INTO chado.dbxref VALUES (2176, 23, '0001603', '', NULL);
INSERT INTO chado.dbxref VALUES (2177, 23, '0001604', '', NULL);
INSERT INTO chado.dbxref VALUES (2178, 23, '0001605', '', NULL);
INSERT INTO chado.dbxref VALUES (2179, 23, '0001606', '', NULL);
INSERT INTO chado.dbxref VALUES (2180, 23, '0001607', '', NULL);
INSERT INTO chado.dbxref VALUES (2181, 23, '0001608', '', NULL);
INSERT INTO chado.dbxref VALUES (2182, 23, '0001609', '', NULL);
INSERT INTO chado.dbxref VALUES (2183, 23, '0001610', '', NULL);
INSERT INTO chado.dbxref VALUES (2184, 23, '0002229', '', NULL);
INSERT INTO chado.dbxref VALUES (2185, 23, '0001611', '', NULL);
INSERT INTO chado.dbxref VALUES (2186, 23, '0002228', '', NULL);
INSERT INTO chado.dbxref VALUES (2187, 23, '0001612', '', NULL);
INSERT INTO chado.dbxref VALUES (2188, 23, '0001613', '', NULL);
INSERT INTO chado.dbxref VALUES (2189, 23, '0001614', '', NULL);
INSERT INTO chado.dbxref VALUES (2190, 23, '0001615', '', NULL);
INSERT INTO chado.dbxref VALUES (2191, 23, '0001616', '', NULL);
INSERT INTO chado.dbxref VALUES (2192, 23, '0001617', '', NULL);
INSERT INTO chado.dbxref VALUES (2193, 23, '0001618', '', NULL);
INSERT INTO chado.dbxref VALUES (2194, 23, '0001619', '', NULL);
INSERT INTO chado.dbxref VALUES (2195, 23, '0001620', '', NULL);
INSERT INTO chado.dbxref VALUES (2196, 38, 'www.ensembl.org/info/genome/variation/predicted_data.html#consequences', '', NULL);
INSERT INTO chado.dbxref VALUES (2197, 23, '0001621', '', NULL);
INSERT INTO chado.dbxref VALUES (2198, 23, '0001622', '', NULL);
INSERT INTO chado.dbxref VALUES (2199, 23, '0001623', '', NULL);
INSERT INTO chado.dbxref VALUES (2200, 23, '0001624', '', NULL);
INSERT INTO chado.dbxref VALUES (2201, 23, '0001626', '', NULL);
INSERT INTO chado.dbxref VALUES (2202, 23, '0001650', '', NULL);
INSERT INTO chado.dbxref VALUES (2203, 23, '0001627', '', NULL);
INSERT INTO chado.dbxref VALUES (2204, 23, '0001628', '', NULL);
INSERT INTO chado.dbxref VALUES (2205, 23, '0001630', '', NULL);
INSERT INTO chado.dbxref VALUES (2206, 23, '0001631', '', NULL);
INSERT INTO chado.dbxref VALUES (2207, 23, '0001632', '', NULL);
INSERT INTO chado.dbxref VALUES (2208, 23, '0001633', '', NULL);
INSERT INTO chado.dbxref VALUES (2209, 23, '0001634', '', NULL);
INSERT INTO chado.dbxref VALUES (2210, 23, '0001635', '', NULL);
INSERT INTO chado.dbxref VALUES (2211, 23, '0001636', '', NULL);
INSERT INTO chado.dbxref VALUES (2212, 23, '0001637', '', NULL);
INSERT INTO chado.dbxref VALUES (2213, 23, '0001638', '', NULL);
INSERT INTO chado.dbxref VALUES (2214, 23, '0001639', '', NULL);
INSERT INTO chado.dbxref VALUES (2215, 23, '0002180', '', NULL);
INSERT INTO chado.dbxref VALUES (2216, 23, '0001640', '', NULL);
INSERT INTO chado.dbxref VALUES (2217, 23, '0001641', '', NULL);
INSERT INTO chado.dbxref VALUES (2218, 23, '0002127', '', NULL);
INSERT INTO chado.dbxref VALUES (2219, 23, '0001642', '', NULL);
INSERT INTO chado.dbxref VALUES (2220, 23, '0001643', '', NULL);
INSERT INTO chado.dbxref VALUES (2221, 23, '0001644', '', NULL);
INSERT INTO chado.dbxref VALUES (2222, 23, '0001646', '', NULL);
INSERT INTO chado.dbxref VALUES (2223, 23, '0001647', '', NULL);
INSERT INTO chado.dbxref VALUES (2224, 23, '0001653', '', NULL);
INSERT INTO chado.dbxref VALUES (2225, 23, '0001658', '', NULL);
INSERT INTO chado.dbxref VALUES (2226, 23, '0001661', '', NULL);
INSERT INTO chado.dbxref VALUES (2227, 23, '0001662', '', NULL);
INSERT INTO chado.dbxref VALUES (2228, 23, '0001663', '', NULL);
INSERT INTO chado.dbxref VALUES (2229, 23, '0001664', '', NULL);
INSERT INTO chado.dbxref VALUES (2230, 23, '0001665', '', NULL);
INSERT INTO chado.dbxref VALUES (2231, 23, '0001666', '', NULL);
INSERT INTO chado.dbxref VALUES (2232, 23, '0001667', '', NULL);
INSERT INTO chado.dbxref VALUES (2233, 23, '0001668', '', NULL);
INSERT INTO chado.dbxref VALUES (2234, 23, '0001678', '', NULL);
INSERT INTO chado.dbxref VALUES (2235, 23, '0001670', '', NULL);
INSERT INTO chado.dbxref VALUES (2236, 23, '0001672', '', NULL);
INSERT INTO chado.dbxref VALUES (2237, 23, '0001673', '', NULL);
INSERT INTO chado.dbxref VALUES (2238, 23, '0001674', '', NULL);
INSERT INTO chado.dbxref VALUES (2239, 23, '0001675', '', NULL);
INSERT INTO chado.dbxref VALUES (2240, 23, '0001676', '', NULL);
INSERT INTO chado.dbxref VALUES (2241, 23, '0001677', '', NULL);
INSERT INTO chado.dbxref VALUES (2242, 23, '0001679', '', NULL);
INSERT INTO chado.dbxref VALUES (2243, 23, '0001681', '', NULL);
INSERT INTO chado.dbxref VALUES (2244, 23, '0001682', '', NULL);
INSERT INTO chado.dbxref VALUES (2245, 23, '0001684', '', NULL);
INSERT INTO chado.dbxref VALUES (2246, 23, '0001685', '', NULL);
INSERT INTO chado.dbxref VALUES (2247, 23, '0001686', '', NULL);
INSERT INTO chado.dbxref VALUES (2248, 23, '0001687', '', NULL);
INSERT INTO chado.dbxref VALUES (2249, 23, '0001954', '', NULL);
INSERT INTO chado.dbxref VALUES (2250, 23, '0001688', '', NULL);
INSERT INTO chado.dbxref VALUES (2251, 23, '0002204', '', NULL);
INSERT INTO chado.dbxref VALUES (2252, 23, '0001689', '', NULL);
INSERT INTO chado.dbxref VALUES (2253, 23, '0001694', '', NULL);
INSERT INTO chado.dbxref VALUES (2254, 23, '0001692', '', NULL);
INSERT INTO chado.dbxref VALUES (2255, 23, '0001690', '', NULL);
INSERT INTO chado.dbxref VALUES (2256, 23, '0001691', '', NULL);
INSERT INTO chado.dbxref VALUES (2257, 23, '0001693', '', NULL);
INSERT INTO chado.dbxref VALUES (2258, 23, '0001695', '', NULL);
INSERT INTO chado.dbxref VALUES (2259, 23, '0001696', '', NULL);
INSERT INTO chado.dbxref VALUES (2260, 23, '0001697', '', NULL);
INSERT INTO chado.dbxref VALUES (2261, 23, '0001698', '', NULL);
INSERT INTO chado.dbxref VALUES (2262, 23, '0001699', '', NULL);
INSERT INTO chado.dbxref VALUES (2263, 23, '0001700', '', NULL);
INSERT INTO chado.dbxref VALUES (2264, 23, '0001701', '', NULL);
INSERT INTO chado.dbxref VALUES (2265, 23, '0001702', '', NULL);
INSERT INTO chado.dbxref VALUES (2266, 23, '0001703', '', NULL);
INSERT INTO chado.dbxref VALUES (2267, 23, '0001973', '', NULL);
INSERT INTO chado.dbxref VALUES (2268, 23, '0001704', '', NULL);
INSERT INTO chado.dbxref VALUES (2269, 23, '0001705', '', NULL);
INSERT INTO chado.dbxref VALUES (2270, 23, '0001734', '', NULL);
INSERT INTO chado.dbxref VALUES (2271, 23, '0001706', '', NULL);
INSERT INTO chado.dbxref VALUES (2272, 23, '0001707', '', NULL);
INSERT INTO chado.dbxref VALUES (2273, 23, '0001736', '', NULL);
INSERT INTO chado.dbxref VALUES (2274, 23, '0001708', '', NULL);
INSERT INTO chado.dbxref VALUES (2275, 23, '0001732', '', NULL);
INSERT INTO chado.dbxref VALUES (2276, 23, '0001709', '', NULL);
INSERT INTO chado.dbxref VALUES (2277, 23, '0001710', '', NULL);
INSERT INTO chado.dbxref VALUES (2278, 23, '0001735', '', NULL);
INSERT INTO chado.dbxref VALUES (2279, 23, '0001711', '', NULL);
INSERT INTO chado.dbxref VALUES (2280, 23, '0001712', '', NULL);
INSERT INTO chado.dbxref VALUES (2281, 23, '0001713', '', NULL);
INSERT INTO chado.dbxref VALUES (2282, 23, '0001714', '', NULL);
INSERT INTO chado.dbxref VALUES (2283, 23, '0001715', '', NULL);
INSERT INTO chado.dbxref VALUES (2284, 23, '0001716', '', NULL);
INSERT INTO chado.dbxref VALUES (2285, 23, '0001717', '', NULL);
INSERT INTO chado.dbxref VALUES (2286, 23, '0001718', '', NULL);
INSERT INTO chado.dbxref VALUES (2287, 23, '0001719', '', NULL);
INSERT INTO chado.dbxref VALUES (2288, 23, '0001721', '', NULL);
INSERT INTO chado.dbxref VALUES (2289, 23, '0001722', '', NULL);
INSERT INTO chado.dbxref VALUES (2290, 23, '0001733', '', NULL);
INSERT INTO chado.dbxref VALUES (2291, 23, '0001723', '', NULL);
INSERT INTO chado.dbxref VALUES (2292, 23, '0001724', '', NULL);
INSERT INTO chado.dbxref VALUES (2293, 23, '0001725', '', NULL);
INSERT INTO chado.dbxref VALUES (2294, 23, '0001726', '', NULL);
INSERT INTO chado.dbxref VALUES (2295, 23, '0001727', '', NULL);
INSERT INTO chado.dbxref VALUES (2296, 23, '0001728', '', NULL);
INSERT INTO chado.dbxref VALUES (2297, 23, '0001729', '', NULL);
INSERT INTO chado.dbxref VALUES (2298, 23, '0001972', '', NULL);
INSERT INTO chado.dbxref VALUES (2299, 23, '0001730', '', NULL);
INSERT INTO chado.dbxref VALUES (2300, 23, '0001731', '', NULL);
INSERT INTO chado.dbxref VALUES (2301, 23, '0001737', '', NULL);
INSERT INTO chado.dbxref VALUES (2302, 23, '0001738', '', NULL);
INSERT INTO chado.dbxref VALUES (2303, 23, '0001739', '', NULL);
INSERT INTO chado.dbxref VALUES (2304, 23, '0001740', '', NULL);
INSERT INTO chado.dbxref VALUES (2305, 23, '0001741', '', NULL);
INSERT INTO chado.dbxref VALUES (2306, 23, '3000000', '', NULL);
INSERT INTO chado.dbxref VALUES (2307, 23, '0001742', '', NULL);
INSERT INTO chado.dbxref VALUES (2308, 23, '0001743', '', NULL);
INSERT INTO chado.dbxref VALUES (2309, 23, '0001744', '', NULL);
INSERT INTO chado.dbxref VALUES (2310, 23, '0001745', '', NULL);
INSERT INTO chado.dbxref VALUES (2311, 23, '0001746', '', NULL);
INSERT INTO chado.dbxref VALUES (2312, 23, '0001747', '', NULL);
INSERT INTO chado.dbxref VALUES (2313, 23, '0001748', '', NULL);
INSERT INTO chado.dbxref VALUES (2314, 23, '0001749', '', NULL);
INSERT INTO chado.dbxref VALUES (2315, 23, '0001750', '', NULL);
INSERT INTO chado.dbxref VALUES (2316, 23, '0001751', '', NULL);
INSERT INTO chado.dbxref VALUES (2317, 23, '0001752', '', NULL);
INSERT INTO chado.dbxref VALUES (2318, 23, '0001753', '', NULL);
INSERT INTO chado.dbxref VALUES (2319, 23, '0001754', '', NULL);
INSERT INTO chado.dbxref VALUES (2320, 23, '0001755', '', NULL);
INSERT INTO chado.dbxref VALUES (2321, 23, '0001756', '', NULL);
INSERT INTO chado.dbxref VALUES (2322, 23, '0001757', '', NULL);
INSERT INTO chado.dbxref VALUES (2323, 23, '0001758', '', NULL);
INSERT INTO chado.dbxref VALUES (2324, 23, '0001759', '', NULL);
INSERT INTO chado.dbxref VALUES (2325, 23, '0001761', '', NULL);
INSERT INTO chado.dbxref VALUES (2326, 23, '0001762', '', NULL);
INSERT INTO chado.dbxref VALUES (2327, 23, '0001763', '', NULL);
INSERT INTO chado.dbxref VALUES (2328, 23, '0001764', '', NULL);
INSERT INTO chado.dbxref VALUES (2329, 23, '0001765', '', NULL);
INSERT INTO chado.dbxref VALUES (2330, 23, '0001766', '', NULL);
INSERT INTO chado.dbxref VALUES (2331, 23, '0001767', '', NULL);
INSERT INTO chado.dbxref VALUES (2332, 23, '0001768', '', NULL);
INSERT INTO chado.dbxref VALUES (2333, 23, '0001769', '', NULL);
INSERT INTO chado.dbxref VALUES (2334, 23, '0001770', '', NULL);
INSERT INTO chado.dbxref VALUES (2335, 23, '0001771', '', NULL);
INSERT INTO chado.dbxref VALUES (2336, 23, '0001772', '', NULL);
INSERT INTO chado.dbxref VALUES (2337, 23, '0001773', '', NULL);
INSERT INTO chado.dbxref VALUES (2338, 23, '0001774', '', NULL);
INSERT INTO chado.dbxref VALUES (2339, 23, '0001775', '', NULL);
INSERT INTO chado.dbxref VALUES (2340, 23, '0001776', '', NULL);
INSERT INTO chado.dbxref VALUES (2341, 23, '0001777', '', NULL);
INSERT INTO chado.dbxref VALUES (2342, 23, '0001778', '', NULL);
INSERT INTO chado.dbxref VALUES (2343, 23, '0001779', '', NULL);
INSERT INTO chado.dbxref VALUES (2344, 23, '0001780', '', NULL);
INSERT INTO chado.dbxref VALUES (2345, 23, '0001781', '', NULL);
INSERT INTO chado.dbxref VALUES (2346, 23, '0001782', '', NULL);
INSERT INTO chado.dbxref VALUES (2347, 23, '0001784', '', NULL);
INSERT INTO chado.dbxref VALUES (2348, 23, '1000146', '', NULL);
INSERT INTO chado.dbxref VALUES (2349, 23, '0001786', '', NULL);
INSERT INTO chado.dbxref VALUES (2350, 23, '0001787', '', NULL);
INSERT INTO chado.dbxref VALUES (2351, 23, '0001788', '', NULL);
INSERT INTO chado.dbxref VALUES (2352, 23, '0001789', '', NULL);
INSERT INTO chado.dbxref VALUES (2353, 23, '0001792', '', NULL);
INSERT INTO chado.dbxref VALUES (2354, 23, '0001793', '', NULL);
INSERT INTO chado.dbxref VALUES (2355, 23, '0001795', '', NULL);
INSERT INTO chado.dbxref VALUES (2356, 23, '0001796', '', NULL);
INSERT INTO chado.dbxref VALUES (2357, 23, '0001797', '', NULL);
INSERT INTO chado.dbxref VALUES (2358, 23, '0001798', '', NULL);
INSERT INTO chado.dbxref VALUES (2359, 23, '0001799', '', NULL);
INSERT INTO chado.dbxref VALUES (2360, 23, '0001800', '', NULL);
INSERT INTO chado.dbxref VALUES (2361, 23, '0001801', '', NULL);
INSERT INTO chado.dbxref VALUES (2362, 23, '0001802', '', NULL);
INSERT INTO chado.dbxref VALUES (2363, 23, '0001803', '', NULL);
INSERT INTO chado.dbxref VALUES (2364, 23, '0001804', '', NULL);
INSERT INTO chado.dbxref VALUES (2365, 23, '0001805', '', NULL);
INSERT INTO chado.dbxref VALUES (2366, 23, '0100017', '', NULL);
INSERT INTO chado.dbxref VALUES (2367, 23, '0001806', '', NULL);
INSERT INTO chado.dbxref VALUES (2368, 23, '0001807', '', NULL);
INSERT INTO chado.dbxref VALUES (2369, 23, '0001808', '', NULL);
INSERT INTO chado.dbxref VALUES (2370, 23, '0001809', '', NULL);
INSERT INTO chado.dbxref VALUES (2371, 23, '0001810', '', NULL);
INSERT INTO chado.dbxref VALUES (2372, 23, '0001811', '', NULL);
INSERT INTO chado.dbxref VALUES (2373, 23, '0001812', '', NULL);
INSERT INTO chado.dbxref VALUES (2374, 23, '0001813', '', NULL);
INSERT INTO chado.dbxref VALUES (2375, 23, '0001814', '', NULL);
INSERT INTO chado.dbxref VALUES (2376, 23, '0001815', '', NULL);
INSERT INTO chado.dbxref VALUES (2377, 23, '0001816', '', NULL);
INSERT INTO chado.dbxref VALUES (2378, 23, '0001817', '', NULL);
INSERT INTO chado.dbxref VALUES (2379, 23, '0001588', '', NULL);
INSERT INTO chado.dbxref VALUES (2380, 23, '0001820', '', NULL);
INSERT INTO chado.dbxref VALUES (2381, 23, '0001821', '', NULL);
INSERT INTO chado.dbxref VALUES (2382, 23, '0001651', '', NULL);
INSERT INTO chado.dbxref VALUES (2383, 23, '0001908', '', NULL);
INSERT INTO chado.dbxref VALUES (2384, 23, '0001822', '', NULL);
INSERT INTO chado.dbxref VALUES (2385, 23, '0001652', '', NULL);
INSERT INTO chado.dbxref VALUES (2386, 23, '0001823', '', NULL);
INSERT INTO chado.dbxref VALUES (2387, 23, '0001824', '', NULL);
INSERT INTO chado.dbxref VALUES (2388, 23, '0001825', '', NULL);
INSERT INTO chado.dbxref VALUES (2389, 23, '0001826', '', NULL);
INSERT INTO chado.dbxref VALUES (2390, 23, '0001827', '', NULL);
INSERT INTO chado.dbxref VALUES (2391, 23, '0001828', '', NULL);
INSERT INTO chado.dbxref VALUES (2392, 23, '0001829', '', NULL);
INSERT INTO chado.dbxref VALUES (2393, 23, '0001830', '', NULL);
INSERT INTO chado.dbxref VALUES (2394, 23, '0001831', '', NULL);
INSERT INTO chado.dbxref VALUES (2395, 23, '0001832', '', NULL);
INSERT INTO chado.dbxref VALUES (2396, 23, '0001833', '', NULL);
INSERT INTO chado.dbxref VALUES (2397, 23, '0001834', '', NULL);
INSERT INTO chado.dbxref VALUES (2398, 23, '0001835', '', NULL);
INSERT INTO chado.dbxref VALUES (2399, 23, '0001836', '', NULL);
INSERT INTO chado.dbxref VALUES (2400, 23, '0001837', '', NULL);
INSERT INTO chado.dbxref VALUES (2401, 23, '0001838', '', NULL);
INSERT INTO chado.dbxref VALUES (2402, 23, '0001839', '', NULL);
INSERT INTO chado.dbxref VALUES (2403, 23, '0001840', '', NULL);
INSERT INTO chado.dbxref VALUES (2404, 23, '0001841', '', NULL);
INSERT INTO chado.dbxref VALUES (2405, 23, '0001842', '', NULL);
INSERT INTO chado.dbxref VALUES (2406, 23, '0001843', '', NULL);
INSERT INTO chado.dbxref VALUES (2407, 23, '0001900', '', NULL);
INSERT INTO chado.dbxref VALUES (2408, 23, '0001844', '', NULL);
INSERT INTO chado.dbxref VALUES (2409, 23, '0001845', '', NULL);
INSERT INTO chado.dbxref VALUES (2410, 23, '0001846', '', NULL);
INSERT INTO chado.dbxref VALUES (2411, 23, '0001847', '', NULL);
INSERT INTO chado.dbxref VALUES (2412, 23, '0001848', '', NULL);
INSERT INTO chado.dbxref VALUES (2413, 23, '0001849', '', NULL);
INSERT INTO chado.dbxref VALUES (2414, 23, '0001850', '', NULL);
INSERT INTO chado.dbxref VALUES (2415, 23, '0001851', '', NULL);
INSERT INTO chado.dbxref VALUES (2416, 23, '0001852', '', NULL);
INSERT INTO chado.dbxref VALUES (2417, 23, '0001853', '', NULL);
INSERT INTO chado.dbxref VALUES (2418, 23, '0001854', '', NULL);
INSERT INTO chado.dbxref VALUES (2419, 23, '0001855', '', NULL);
INSERT INTO chado.dbxref VALUES (2420, 23, '0001856', '', NULL);
INSERT INTO chado.dbxref VALUES (2421, 23, '0001857', '', NULL);
INSERT INTO chado.dbxref VALUES (2422, 23, '0001858', '', NULL);
INSERT INTO chado.dbxref VALUES (2423, 23, '0001859', '', NULL);
INSERT INTO chado.dbxref VALUES (2424, 23, '0001860', '', NULL);
INSERT INTO chado.dbxref VALUES (2425, 23, '0001861', '', NULL);
INSERT INTO chado.dbxref VALUES (2426, 23, '0001862', '', NULL);
INSERT INTO chado.dbxref VALUES (2427, 23, '0001863', '', NULL);
INSERT INTO chado.dbxref VALUES (2428, 23, '0001864', '', NULL);
INSERT INTO chado.dbxref VALUES (2429, 23, '0001865', '', NULL);
INSERT INTO chado.dbxref VALUES (2430, 23, '0001866', '', NULL);
INSERT INTO chado.dbxref VALUES (2431, 23, '0001867', '', NULL);
INSERT INTO chado.dbxref VALUES (2432, 23, '0001868', '', NULL);
INSERT INTO chado.dbxref VALUES (2433, 23, '0001869', '', NULL);
INSERT INTO chado.dbxref VALUES (2434, 23, '0001870', '', NULL);
INSERT INTO chado.dbxref VALUES (2435, 23, '0001871', '', NULL);
INSERT INTO chado.dbxref VALUES (2436, 23, '0001872', '', NULL);
INSERT INTO chado.dbxref VALUES (2437, 23, '0001873', '', NULL);
INSERT INTO chado.dbxref VALUES (2438, 23, '0001874', '', NULL);
INSERT INTO chado.dbxref VALUES (2439, 23, '0001875', '', NULL);
INSERT INTO chado.dbxref VALUES (2440, 23, '0001879', '', NULL);
INSERT INTO chado.dbxref VALUES (2441, 23, '0001880', '', NULL);
INSERT INTO chado.dbxref VALUES (2442, 23, '0001881', '', NULL);
INSERT INTO chado.dbxref VALUES (2443, 23, '0001883', '', NULL);
INSERT INTO chado.dbxref VALUES (2444, 23, '0001884', '', NULL);
INSERT INTO chado.dbxref VALUES (2445, 23, '0001885', '', NULL);
INSERT INTO chado.dbxref VALUES (2446, 23, '0001886', '', NULL);
INSERT INTO chado.dbxref VALUES (2447, 23, '0001887', '', NULL);
INSERT INTO chado.dbxref VALUES (2448, 23, '0001888', '', NULL);
INSERT INTO chado.dbxref VALUES (2449, 23, '0001889', '', NULL);
INSERT INTO chado.dbxref VALUES (2450, 23, '0001890', '', NULL);
INSERT INTO chado.dbxref VALUES (2451, 23, '0001891', '', NULL);
INSERT INTO chado.dbxref VALUES (2452, 23, '0001892', '', NULL);
INSERT INTO chado.dbxref VALUES (2453, 23, '0001893', '', NULL);
INSERT INTO chado.dbxref VALUES (2454, 23, '0001894', '', NULL);
INSERT INTO chado.dbxref VALUES (2455, 23, '0001895', '', NULL);
INSERT INTO chado.dbxref VALUES (2456, 23, '0001896', '', NULL);
INSERT INTO chado.dbxref VALUES (2457, 23, '0001897', '', NULL);
INSERT INTO chado.dbxref VALUES (2458, 23, '0001898', '', NULL);
INSERT INTO chado.dbxref VALUES (2459, 23, '0001899', '', NULL);
INSERT INTO chado.dbxref VALUES (2460, 23, '0001901', '', NULL);
INSERT INTO chado.dbxref VALUES (2461, 23, '0001902', '', NULL);
INSERT INTO chado.dbxref VALUES (2462, 23, '0001904', '', NULL);
INSERT INTO chado.dbxref VALUES (2463, 23, '0001905', '', NULL);
INSERT INTO chado.dbxref VALUES (2464, 23, '0001909', '', NULL);
INSERT INTO chado.dbxref VALUES (2465, 23, '0001910', '', NULL);
INSERT INTO chado.dbxref VALUES (2466, 23, '0001911', '', NULL);
INSERT INTO chado.dbxref VALUES (2467, 23, '0001912', '', NULL);
INSERT INTO chado.dbxref VALUES (2468, 23, '0001914', '', NULL);
INSERT INTO chado.dbxref VALUES (2469, 23, '0001915', '', NULL);
INSERT INTO chado.dbxref VALUES (2470, 23, '0001916', '', NULL);
INSERT INTO chado.dbxref VALUES (2471, 23, '0001917', '', NULL);
INSERT INTO chado.dbxref VALUES (2472, 23, '0001918', '', NULL);
INSERT INTO chado.dbxref VALUES (2473, 23, '0001919', '', NULL);
INSERT INTO chado.dbxref VALUES (2474, 23, '0001920', '', NULL);
INSERT INTO chado.dbxref VALUES (2475, 23, '0001921', '', NULL);
INSERT INTO chado.dbxref VALUES (2476, 23, '0001922', '', NULL);
INSERT INTO chado.dbxref VALUES (2477, 23, '0001923', '', NULL);
INSERT INTO chado.dbxref VALUES (2478, 23, '0001927', '', NULL);
INSERT INTO chado.dbxref VALUES (2479, 23, '0001924', '', NULL);
INSERT INTO chado.dbxref VALUES (2480, 23, '0001925', '', NULL);
INSERT INTO chado.dbxref VALUES (2481, 23, '0001926', '', NULL);
INSERT INTO chado.dbxref VALUES (2482, 23, '0001928', '', NULL);
INSERT INTO chado.dbxref VALUES (2483, 23, '1000035', '', NULL);
INSERT INTO chado.dbxref VALUES (2484, 23, '0001929', '', NULL);
INSERT INTO chado.dbxref VALUES (2485, 23, '0001930', '', NULL);
INSERT INTO chado.dbxref VALUES (2486, 23, '0001931', '', NULL);
INSERT INTO chado.dbxref VALUES (2487, 23, '0001932', '', NULL);
INSERT INTO chado.dbxref VALUES (2488, 23, '0001933', '', NULL);
INSERT INTO chado.dbxref VALUES (2489, 23, '0001934', '', NULL);
INSERT INTO chado.dbxref VALUES (2490, 23, '0001935', '', NULL);
INSERT INTO chado.dbxref VALUES (2491, 23, '0001936', '', NULL);
INSERT INTO chado.dbxref VALUES (2492, 23, '0001937', '', NULL);
INSERT INTO chado.dbxref VALUES (2493, 23, '0002143', '', NULL);
INSERT INTO chado.dbxref VALUES (2494, 23, '0001938', '', NULL);
INSERT INTO chado.dbxref VALUES (2495, 23, '0002142', '', NULL);
INSERT INTO chado.dbxref VALUES (2496, 23, '0001939', '', NULL);
INSERT INTO chado.dbxref VALUES (2497, 23, '0001940', '', NULL);
INSERT INTO chado.dbxref VALUES (2498, 23, '0001941', '', NULL);
INSERT INTO chado.dbxref VALUES (2499, 23, '0001942', '', NULL);
INSERT INTO chado.dbxref VALUES (2500, 23, '0001943', '', NULL);
INSERT INTO chado.dbxref VALUES (2501, 23, '0001944', '', NULL);
INSERT INTO chado.dbxref VALUES (2502, 23, '0001945', '', NULL);
INSERT INTO chado.dbxref VALUES (2503, 23, '0001946', '', NULL);
INSERT INTO chado.dbxref VALUES (2504, 23, '0001947', '', NULL);
INSERT INTO chado.dbxref VALUES (2505, 23, '0001948', '', NULL);
INSERT INTO chado.dbxref VALUES (2506, 23, '0001949', '', NULL);
INSERT INTO chado.dbxref VALUES (2507, 23, '0001950', '', NULL);
INSERT INTO chado.dbxref VALUES (2508, 23, '0001951', '', NULL);
INSERT INTO chado.dbxref VALUES (2509, 23, '0001952', '', NULL);
INSERT INTO chado.dbxref VALUES (2510, 23, '0001953', '', NULL);
INSERT INTO chado.dbxref VALUES (2511, 23, '0001955', '', NULL);
INSERT INTO chado.dbxref VALUES (2512, 23, '0001956', '', NULL);
INSERT INTO chado.dbxref VALUES (2513, 23, '0001957', '', NULL);
INSERT INTO chado.dbxref VALUES (2514, 23, '0001958', '', NULL);
INSERT INTO chado.dbxref VALUES (2515, 23, '0001959', '', NULL);
INSERT INTO chado.dbxref VALUES (2516, 23, '0001960', '', NULL);
INSERT INTO chado.dbxref VALUES (2517, 23, '0001961', '', NULL);
INSERT INTO chado.dbxref VALUES (2518, 23, '0001964', '', NULL);
INSERT INTO chado.dbxref VALUES (2519, 23, '0001965', '', NULL);
INSERT INTO chado.dbxref VALUES (2520, 23, '0001966', '', NULL);
INSERT INTO chado.dbxref VALUES (2521, 23, '0001967', '', NULL);
INSERT INTO chado.dbxref VALUES (2522, 23, '0001969', '', NULL);
INSERT INTO chado.dbxref VALUES (2523, 23, '0001970', '', NULL);
INSERT INTO chado.dbxref VALUES (2524, 23, '0001971', '', NULL);
INSERT INTO chado.dbxref VALUES (2525, 23, '0001974', '', NULL);
INSERT INTO chado.dbxref VALUES (2526, 23, '0001975', '', NULL);
INSERT INTO chado.dbxref VALUES (2527, 23, '0001976', '', NULL);
INSERT INTO chado.dbxref VALUES (2528, 23, '0001977', '', NULL);
INSERT INTO chado.dbxref VALUES (2529, 23, '0001978', '', NULL);
INSERT INTO chado.dbxref VALUES (2530, 23, '0001979', '', NULL);
INSERT INTO chado.dbxref VALUES (2531, 23, '0001980', '', NULL);
INSERT INTO chado.dbxref VALUES (2532, 23, '0001981', '', NULL);
INSERT INTO chado.dbxref VALUES (2533, 23, '0001982', '', NULL);
INSERT INTO chado.dbxref VALUES (2534, 23, '0001983', '', NULL);
INSERT INTO chado.dbxref VALUES (2535, 23, '0001984', '', NULL);
INSERT INTO chado.dbxref VALUES (2536, 23, '0005854', '', NULL);
INSERT INTO chado.dbxref VALUES (2537, 23, '0001985', '', NULL);
INSERT INTO chado.dbxref VALUES (2538, 23, '0001986', '', NULL);
INSERT INTO chado.dbxref VALUES (2539, 23, '0001987', '', NULL);
INSERT INTO chado.dbxref VALUES (2540, 23, '0001988', '', NULL);
INSERT INTO chado.dbxref VALUES (2541, 23, '0001989', '', NULL);
INSERT INTO chado.dbxref VALUES (2542, 23, '0001990', '', NULL);
INSERT INTO chado.dbxref VALUES (2543, 23, '0001991', '', NULL);
INSERT INTO chado.dbxref VALUES (2544, 23, '0001993', '', NULL);
INSERT INTO chado.dbxref VALUES (2545, 23, '0001994', '', NULL);
INSERT INTO chado.dbxref VALUES (2546, 23, '0001995', '', NULL);
INSERT INTO chado.dbxref VALUES (2547, 23, '0001996', '', NULL);
INSERT INTO chado.dbxref VALUES (2548, 23, '0001997', '', NULL);
INSERT INTO chado.dbxref VALUES (2549, 23, '0001998', '', NULL);
INSERT INTO chado.dbxref VALUES (2550, 23, '0001999', '', NULL);
INSERT INTO chado.dbxref VALUES (2551, 23, '0002001', '', NULL);
INSERT INTO chado.dbxref VALUES (2552, 23, '0002002', '', NULL);
INSERT INTO chado.dbxref VALUES (2553, 23, '0002003', '', NULL);
INSERT INTO chado.dbxref VALUES (2554, 23, '0002004', '', NULL);
INSERT INTO chado.dbxref VALUES (2555, 23, '0002005', '', NULL);
INSERT INTO chado.dbxref VALUES (2556, 23, '0002006', '', NULL);
INSERT INTO chado.dbxref VALUES (2557, 23, '0002008', '', NULL);
INSERT INTO chado.dbxref VALUES (2558, 23, '0002009', '', NULL);
INSERT INTO chado.dbxref VALUES (2559, 23, '0002010', '', NULL);
INSERT INTO chado.dbxref VALUES (2560, 23, '0002011', '', NULL);
INSERT INTO chado.dbxref VALUES (2561, 23, '0002012', '', NULL);
INSERT INTO chado.dbxref VALUES (2562, 23, '0002013', '', NULL);
INSERT INTO chado.dbxref VALUES (2563, 23, '0002014', '', NULL);
INSERT INTO chado.dbxref VALUES (2564, 23, '0002015', '', NULL);
INSERT INTO chado.dbxref VALUES (2565, 23, '0002016', '', NULL);
INSERT INTO chado.dbxref VALUES (2566, 23, '0002017', '', NULL);
INSERT INTO chado.dbxref VALUES (2567, 23, '0002018', '', NULL);
INSERT INTO chado.dbxref VALUES (2568, 23, '0002019', '', NULL);
INSERT INTO chado.dbxref VALUES (2569, 23, '0002020', '', NULL);
INSERT INTO chado.dbxref VALUES (2570, 23, '0002021', '', NULL);
INSERT INTO chado.dbxref VALUES (2571, 23, '0002022', '', NULL);
INSERT INTO chado.dbxref VALUES (2572, 23, '0002023', '', NULL);
INSERT INTO chado.dbxref VALUES (2573, 23, '0002024', '', NULL);
INSERT INTO chado.dbxref VALUES (2574, 23, '0002000', '', NULL);
INSERT INTO chado.dbxref VALUES (2575, 23, '0002025', '', NULL);
INSERT INTO chado.dbxref VALUES (2576, 23, '0002026', '', NULL);
INSERT INTO chado.dbxref VALUES (2577, 23, '0002027', '', NULL);
INSERT INTO chado.dbxref VALUES (2578, 17, '26684391', '', NULL);
INSERT INTO chado.dbxref VALUES (2579, 23, '0002028', '', NULL);
INSERT INTO chado.dbxref VALUES (2580, 23, '0002029', '', NULL);
INSERT INTO chado.dbxref VALUES (2581, 23, '0002030', '', NULL);
INSERT INTO chado.dbxref VALUES (2582, 23, '0002031', '', NULL);
INSERT INTO chado.dbxref VALUES (2583, 23, '0002032', '', NULL);
INSERT INTO chado.dbxref VALUES (2584, 23, '0002033', '', NULL);
INSERT INTO chado.dbxref VALUES (2585, 23, '0002034', '', NULL);
INSERT INTO chado.dbxref VALUES (2586, 23, '0002035', '', NULL);
INSERT INTO chado.dbxref VALUES (2587, 23, '0002036', '', NULL);
INSERT INTO chado.dbxref VALUES (2588, 23, '0002037', '', NULL);
INSERT INTO chado.dbxref VALUES (2589, 23, '0002038', '', NULL);
INSERT INTO chado.dbxref VALUES (2590, 23, '0002039', '', NULL);
INSERT INTO chado.dbxref VALUES (2591, 23, '0002040', '', NULL);
INSERT INTO chado.dbxref VALUES (2592, 23, '0002041', '', NULL);
INSERT INTO chado.dbxref VALUES (2593, 23, '0002042', '', NULL);
INSERT INTO chado.dbxref VALUES (2594, 23, '0002043', '', NULL);
INSERT INTO chado.dbxref VALUES (2595, 23, '0002044', '', NULL);
INSERT INTO chado.dbxref VALUES (2596, 23, '0002045', '', NULL);
INSERT INTO chado.dbxref VALUES (2597, 23, '0002046', '', NULL);
INSERT INTO chado.dbxref VALUES (2598, 23, '0002047', '', NULL);
INSERT INTO chado.dbxref VALUES (2599, 23, '0002048', '', NULL);
INSERT INTO chado.dbxref VALUES (2600, 23, '0002049', '', NULL);
INSERT INTO chado.dbxref VALUES (2601, 23, '0002050', '', NULL);
INSERT INTO chado.dbxref VALUES (2602, 23, '0002051', '', NULL);
INSERT INTO chado.dbxref VALUES (2603, 23, '0002052', '', NULL);
INSERT INTO chado.dbxref VALUES (2604, 23, '0002053', '', NULL);
INSERT INTO chado.dbxref VALUES (2605, 23, '0002054', '', NULL);
INSERT INTO chado.dbxref VALUES (2606, 23, '0002055', '', NULL);
INSERT INTO chado.dbxref VALUES (2607, 23, '0002056', '', NULL);
INSERT INTO chado.dbxref VALUES (2608, 23, '0002057', '', NULL);
INSERT INTO chado.dbxref VALUES (2609, 23, '0002058', '', NULL);
INSERT INTO chado.dbxref VALUES (2610, 23, '0002059', '', NULL);
INSERT INTO chado.dbxref VALUES (2611, 23, '0002060', '', NULL);
INSERT INTO chado.dbxref VALUES (2612, 23, '0002061', '', NULL);
INSERT INTO chado.dbxref VALUES (2613, 23, '0002062', '', NULL);
INSERT INTO chado.dbxref VALUES (2614, 23, '0002063', '', NULL);
INSERT INTO chado.dbxref VALUES (2615, 23, '0002064', '', NULL);
INSERT INTO chado.dbxref VALUES (2616, 23, '0002272', '', NULL);
INSERT INTO chado.dbxref VALUES (2617, 23, '0002065', '', NULL);
INSERT INTO chado.dbxref VALUES (2618, 23, '0002066', '', NULL);
INSERT INTO chado.dbxref VALUES (2619, 23, '0002067', '', NULL);
INSERT INTO chado.dbxref VALUES (2620, 23, '0002268', '', NULL);
INSERT INTO chado.dbxref VALUES (2621, 23, '0002068', '', NULL);
INSERT INTO chado.dbxref VALUES (2622, 23, '0002069', '', NULL);
INSERT INTO chado.dbxref VALUES (2623, 23, '0002070', '', NULL);
INSERT INTO chado.dbxref VALUES (2624, 23, '0002071', '', NULL);
INSERT INTO chado.dbxref VALUES (2625, 23, '1001251', '', NULL);
INSERT INTO chado.dbxref VALUES (2626, 23, '0002073', '', NULL);
INSERT INTO chado.dbxref VALUES (2627, 23, '0002074', '', NULL);
INSERT INTO chado.dbxref VALUES (2628, 23, '0002075', '', NULL);
INSERT INTO chado.dbxref VALUES (2629, 23, '0002076', '', NULL);
INSERT INTO chado.dbxref VALUES (2630, 23, '0002077', '', NULL);
INSERT INTO chado.dbxref VALUES (2631, 23, '0002078', '', NULL);
INSERT INTO chado.dbxref VALUES (2632, 23, '0002079', '', NULL);
INSERT INTO chado.dbxref VALUES (2633, 23, '0002080', '', NULL);
INSERT INTO chado.dbxref VALUES (2634, 23, '0002081', '', NULL);
INSERT INTO chado.dbxref VALUES (2635, 23, '0002082', '', NULL);
INSERT INTO chado.dbxref VALUES (2636, 23, '0002083', '', NULL);
INSERT INTO chado.dbxref VALUES (2637, 23, '0002084', '', NULL);
INSERT INTO chado.dbxref VALUES (2638, 23, '0002085', '', NULL);
INSERT INTO chado.dbxref VALUES (2639, 23, '0002086', '', NULL);
INSERT INTO chado.dbxref VALUES (2640, 23, '0002087', '', NULL);
INSERT INTO chado.dbxref VALUES (2641, 23, '0002088', '', NULL);
INSERT INTO chado.dbxref VALUES (2642, 23, '0002089', '', NULL);
INSERT INTO chado.dbxref VALUES (2643, 23, '0002090', '', NULL);
INSERT INTO chado.dbxref VALUES (2644, 23, '0002091', '', NULL);
INSERT INTO chado.dbxref VALUES (2645, 23, '0002092', '', NULL);
INSERT INTO chado.dbxref VALUES (2646, 23, '0002093', '', NULL);
INSERT INTO chado.dbxref VALUES (2647, 23, '0002094', '', NULL);
INSERT INTO chado.dbxref VALUES (2648, 23, '0002095', '', NULL);
INSERT INTO chado.dbxref VALUES (2649, 23, '0002096', '', NULL);
INSERT INTO chado.dbxref VALUES (2650, 23, '0002097', '', NULL);
INSERT INTO chado.dbxref VALUES (2651, 23, '0002098', '', NULL);
INSERT INTO chado.dbxref VALUES (2652, 23, '0002099', '', NULL);
INSERT INTO chado.dbxref VALUES (2653, 23, '0002100', '', NULL);
INSERT INTO chado.dbxref VALUES (2654, 23, '0002101', '', NULL);
INSERT INTO chado.dbxref VALUES (2655, 23, '0002102', '', NULL);
INSERT INTO chado.dbxref VALUES (2656, 23, '0002103', '', NULL);
INSERT INTO chado.dbxref VALUES (2657, 23, '0002104', '', NULL);
INSERT INTO chado.dbxref VALUES (2658, 23, '0002105', '', NULL);
INSERT INTO chado.dbxref VALUES (2659, 23, '0002106', '', NULL);
INSERT INTO chado.dbxref VALUES (2660, 23, '0002107', '', NULL);
INSERT INTO chado.dbxref VALUES (2661, 23, '0002108', '', NULL);
INSERT INTO chado.dbxref VALUES (2662, 23, '0002109', '', NULL);
INSERT INTO chado.dbxref VALUES (2663, 23, '0002110', '', NULL);
INSERT INTO chado.dbxref VALUES (2664, 23, '0002111', '', NULL);
INSERT INTO chado.dbxref VALUES (2665, 23, '0002112', '', NULL);
INSERT INTO chado.dbxref VALUES (2666, 23, '0002113', '', NULL);
INSERT INTO chado.dbxref VALUES (2667, 23, '0002114', '', NULL);
INSERT INTO chado.dbxref VALUES (2668, 23, '0002115', '', NULL);
INSERT INTO chado.dbxref VALUES (2669, 23, '0002116', '', NULL);
INSERT INTO chado.dbxref VALUES (2670, 23, '0002117', '', NULL);
INSERT INTO chado.dbxref VALUES (2671, 23, '0002118', '', NULL);
INSERT INTO chado.dbxref VALUES (2672, 23, '0002119', '', NULL);
INSERT INTO chado.dbxref VALUES (2673, 39, 'https\://en.wikipedia.org/wiki/Allele_frequency', '', NULL);
INSERT INTO chado.dbxref VALUES (2674, 23, '0002120', '', NULL);
INSERT INTO chado.dbxref VALUES (2675, 23, '0002121', '', NULL);
INSERT INTO chado.dbxref VALUES (2676, 23, '0002122', '', NULL);
INSERT INTO chado.dbxref VALUES (2677, 23, '0002123', '', NULL);
INSERT INTO chado.dbxref VALUES (2678, 23, '0002124', '', NULL);
INSERT INTO chado.dbxref VALUES (2679, 23, '0002125', '', NULL);
INSERT INTO chado.dbxref VALUES (2680, 23, '0002126', '', NULL);
INSERT INTO chado.dbxref VALUES (2681, 23, '0002128', '', NULL);
INSERT INTO chado.dbxref VALUES (2682, 23, '0002129', '', NULL);
INSERT INTO chado.dbxref VALUES (2683, 23, '0002130', '', NULL);
INSERT INTO chado.dbxref VALUES (2684, 23, '0002131', '', NULL);
INSERT INTO chado.dbxref VALUES (2685, 23, '0001903', '', NULL);
INSERT INTO chado.dbxref VALUES (2686, 23, '0002132', '', NULL);
INSERT INTO chado.dbxref VALUES (2687, 23, '0002133', '', NULL);
INSERT INTO chado.dbxref VALUES (2688, 23, '0002134', '', NULL);
INSERT INTO chado.dbxref VALUES (2689, 23, '0002135', '', NULL);
INSERT INTO chado.dbxref VALUES (2690, 23, '0002136', '', NULL);
INSERT INTO chado.dbxref VALUES (2691, 23, '0002137', '', NULL);
INSERT INTO chado.dbxref VALUES (2692, 23, '0002138', '', NULL);
INSERT INTO chado.dbxref VALUES (2693, 23, '0002139', '', NULL);
INSERT INTO chado.dbxref VALUES (2694, 23, '0002140', '', NULL);
INSERT INTO chado.dbxref VALUES (2695, 23, '0002141', '', NULL);
INSERT INTO chado.dbxref VALUES (2696, 23, '0002144', '', NULL);
INSERT INTO chado.dbxref VALUES (2697, 23, '0002145', '', NULL);
INSERT INTO chado.dbxref VALUES (2698, 23, '0002146', '', NULL);
INSERT INTO chado.dbxref VALUES (2699, 23, '0002147', '', NULL);
INSERT INTO chado.dbxref VALUES (2700, 23, '0002148', '', NULL);
INSERT INTO chado.dbxref VALUES (2701, 23, '0002149', '', NULL);
INSERT INTO chado.dbxref VALUES (2702, 23, '0002150', '', NULL);
INSERT INTO chado.dbxref VALUES (2703, 23, '0002151', '', NULL);
INSERT INTO chado.dbxref VALUES (2704, 23, '0002152', '', NULL);
INSERT INTO chado.dbxref VALUES (2705, 23, '0002153', '', NULL);
INSERT INTO chado.dbxref VALUES (2706, 23, '0002154', '', NULL);
INSERT INTO chado.dbxref VALUES (2707, 23, '0002155', '', NULL);
INSERT INTO chado.dbxref VALUES (2708, 23, '0002156', '', NULL);
INSERT INTO chado.dbxref VALUES (2709, 23, '0002157', '', NULL);
INSERT INTO chado.dbxref VALUES (2710, 23, '0002158', '', NULL);
INSERT INTO chado.dbxref VALUES (2711, 23, '0002159', '', NULL);
INSERT INTO chado.dbxref VALUES (2712, 23, '0002161', '', NULL);
INSERT INTO chado.dbxref VALUES (2713, 23, '0002162', '', NULL);
INSERT INTO chado.dbxref VALUES (2714, 23, '0002163', '', NULL);
INSERT INTO chado.dbxref VALUES (2715, 23, '0002164', '', NULL);
INSERT INTO chado.dbxref VALUES (2716, 23, '0002165', '', NULL);
INSERT INTO chado.dbxref VALUES (2717, 23, '0002166', '', NULL);
INSERT INTO chado.dbxref VALUES (2718, 23, '0002167', '', NULL);
INSERT INTO chado.dbxref VALUES (2719, 23, '0002168', '', NULL);
INSERT INTO chado.dbxref VALUES (2720, 40, '//en.wikipedia.org/wiki/RNA_thermometer', '', NULL);
INSERT INTO chado.dbxref VALUES (2721, 23, '0002169', '', NULL);
INSERT INTO chado.dbxref VALUES (2722, 23, '0002170', '', NULL);
INSERT INTO chado.dbxref VALUES (2723, 23, '0002171', '', NULL);
INSERT INTO chado.dbxref VALUES (2724, 23, '0002172', '', NULL);
INSERT INTO chado.dbxref VALUES (2725, 23, '0002173', '', NULL);
INSERT INTO chado.dbxref VALUES (2726, 23, '0002174', '', NULL);
INSERT INTO chado.dbxref VALUES (2727, 23, '0002175', '', NULL);
INSERT INTO chado.dbxref VALUES (2728, 23, '0002176', '', NULL);
INSERT INTO chado.dbxref VALUES (2729, 23, '0002177', '', NULL);
INSERT INTO chado.dbxref VALUES (2730, 23, '0002178', '', NULL);
INSERT INTO chado.dbxref VALUES (2731, 23, '0002179', '', NULL);
INSERT INTO chado.dbxref VALUES (2732, 23, '0002181', '', NULL);
INSERT INTO chado.dbxref VALUES (2733, 23, '0002182', '', NULL);
INSERT INTO chado.dbxref VALUES (2734, 23, '0002183', '', NULL);
INSERT INTO chado.dbxref VALUES (2735, 23, '0002184', '', NULL);
INSERT INTO chado.dbxref VALUES (2736, 23, '0002185', '', NULL);
INSERT INTO chado.dbxref VALUES (2737, 23, '0002186', '', NULL);
INSERT INTO chado.dbxref VALUES (2738, 23, '0002187', '', NULL);
INSERT INTO chado.dbxref VALUES (2739, 23, '0002188', '', NULL);
INSERT INTO chado.dbxref VALUES (2740, 23, '0002189', '', NULL);
INSERT INTO chado.dbxref VALUES (2741, 23, '0002190', '', NULL);
INSERT INTO chado.dbxref VALUES (2742, 23, '0002191', '', NULL);
INSERT INTO chado.dbxref VALUES (2743, 23, '0002192', '', NULL);
INSERT INTO chado.dbxref VALUES (2744, 23, '0002193', '', NULL);
INSERT INTO chado.dbxref VALUES (2745, 23, '0002194', '', NULL);
INSERT INTO chado.dbxref VALUES (2746, 23, '0002195', '', NULL);
INSERT INTO chado.dbxref VALUES (2747, 23, '0002196', '', NULL);
INSERT INTO chado.dbxref VALUES (2748, 23, '0002197', '', NULL);
INSERT INTO chado.dbxref VALUES (2749, 23, '0002198', '', NULL);
INSERT INTO chado.dbxref VALUES (2750, 23, '0002199', '', NULL);
INSERT INTO chado.dbxref VALUES (2751, 23, '0002200', '', NULL);
INSERT INTO chado.dbxref VALUES (2752, 23, '0002201', '', NULL);
INSERT INTO chado.dbxref VALUES (2753, 23, '0002202', '', NULL);
INSERT INTO chado.dbxref VALUES (2754, 23, '0002203', '', NULL);
INSERT INTO chado.dbxref VALUES (2755, 23, '0002205', '', NULL);
INSERT INTO chado.dbxref VALUES (2756, 23, '0002206', '', NULL);
INSERT INTO chado.dbxref VALUES (2757, 23, '0002207', '', NULL);
INSERT INTO chado.dbxref VALUES (2758, 23, '0002208', '', NULL);
INSERT INTO chado.dbxref VALUES (2759, 23, '0002209', '', NULL);
INSERT INTO chado.dbxref VALUES (2760, 23, '0002210', '', NULL);
INSERT INTO chado.dbxref VALUES (2761, 23, '0002211', '', NULL);
INSERT INTO chado.dbxref VALUES (2762, 23, '0002212', '', NULL);
INSERT INTO chado.dbxref VALUES (2763, 23, '0002213', '', NULL);
INSERT INTO chado.dbxref VALUES (2764, 23, '0002214', '', NULL);
INSERT INTO chado.dbxref VALUES (2765, 23, '0002215', '', NULL);
INSERT INTO chado.dbxref VALUES (2766, 23, '0002216', '', NULL);
INSERT INTO chado.dbxref VALUES (2767, 23, '0002217', '', NULL);
INSERT INTO chado.dbxref VALUES (2768, 23, '0002219', '', NULL);
INSERT INTO chado.dbxref VALUES (2769, 23, '0002220', '', NULL);
INSERT INTO chado.dbxref VALUES (2770, 23, '0002223', '', NULL);
INSERT INTO chado.dbxref VALUES (2771, 41, '10.1101/584664', '', NULL);
INSERT INTO chado.dbxref VALUES (2772, 23, '0002224', '', NULL);
INSERT INTO chado.dbxref VALUES (2773, 23, '0002225', '', NULL);
INSERT INTO chado.dbxref VALUES (2774, 23, '0002226', '', NULL);
INSERT INTO chado.dbxref VALUES (2775, 23, '0002227', '', NULL);
INSERT INTO chado.dbxref VALUES (2776, 23, '0002230', '', NULL);
INSERT INTO chado.dbxref VALUES (2777, 23, '0002231', '', NULL);
INSERT INTO chado.dbxref VALUES (2778, 23, '0002232', '', NULL);
INSERT INTO chado.dbxref VALUES (2779, 23, '0002233', '', NULL);
INSERT INTO chado.dbxref VALUES (2780, 23, '0002234', '', NULL);
INSERT INTO chado.dbxref VALUES (2781, 23, '0002235', '', NULL);
INSERT INTO chado.dbxref VALUES (2782, 23, '0002362', '', NULL);
INSERT INTO chado.dbxref VALUES (2783, 23, '0002361', '', NULL);
INSERT INTO chado.dbxref VALUES (2784, 23, '0002241', '', NULL);
INSERT INTO chado.dbxref VALUES (2785, 23, '0002244', '', NULL);
INSERT INTO chado.dbxref VALUES (2786, 23, '0002245', '', NULL);
INSERT INTO chado.dbxref VALUES (2787, 23, '0002246', '', NULL);
INSERT INTO chado.dbxref VALUES (2788, 23, '0002248', '', NULL);
INSERT INTO chado.dbxref VALUES (2789, 23, '0002253', '', NULL);
INSERT INTO chado.dbxref VALUES (2790, 23, '0002254', '', NULL);
INSERT INTO chado.dbxref VALUES (2791, 23, '0002255', '', NULL);
INSERT INTO chado.dbxref VALUES (2792, 23, '0002256', '', NULL);
INSERT INTO chado.dbxref VALUES (2793, 23, '0002257', '', NULL);
INSERT INTO chado.dbxref VALUES (2794, 23, '0002258', '', NULL);
INSERT INTO chado.dbxref VALUES (2795, 23, '0002259', '', NULL);
INSERT INTO chado.dbxref VALUES (2796, 23, '0002260', '', NULL);
INSERT INTO chado.dbxref VALUES (2797, 23, '0002261', '', NULL);
INSERT INTO chado.dbxref VALUES (2798, 23, '0002262', '', NULL);
INSERT INTO chado.dbxref VALUES (2799, 23, '0002263', '', NULL);
INSERT INTO chado.dbxref VALUES (2800, 23, '0002264', '', NULL);
INSERT INTO chado.dbxref VALUES (2801, 23, '0002265', '', NULL);
INSERT INTO chado.dbxref VALUES (2802, 23, '0002266', '', NULL);
INSERT INTO chado.dbxref VALUES (2803, 23, '0002267', '', NULL);
INSERT INTO chado.dbxref VALUES (2804, 23, '0002269', '', NULL);
INSERT INTO chado.dbxref VALUES (2805, 23, '0002270', '', NULL);
INSERT INTO chado.dbxref VALUES (2806, 23, '0002271', '', NULL);
INSERT INTO chado.dbxref VALUES (2807, 23, '0002273', '', NULL);
INSERT INTO chado.dbxref VALUES (2808, 40, '//www.sciencedirect.com/topics/biochemistry-genetics-and-molecular-biology/long-interspersed-nuclear-element', '', NULL);
INSERT INTO chado.dbxref VALUES (2809, 23, '0002274', '', NULL);
INSERT INTO chado.dbxref VALUES (2810, 23, '0002275', '', NULL);
INSERT INTO chado.dbxref VALUES (2811, 23, '0002276', '', NULL);
INSERT INTO chado.dbxref VALUES (2812, 23, '0002277', '', NULL);
INSERT INTO chado.dbxref VALUES (2813, 23, '0002278', '', NULL);
INSERT INTO chado.dbxref VALUES (2814, 23, '0002279', '', NULL);
INSERT INTO chado.dbxref VALUES (2815, 23, '0002280', '', NULL);
INSERT INTO chado.dbxref VALUES (2816, 23, '0002281', '', NULL);
INSERT INTO chado.dbxref VALUES (2817, 23, '0002282', '', NULL);
INSERT INTO chado.dbxref VALUES (2818, 23, '0002283', '', NULL);
INSERT INTO chado.dbxref VALUES (2819, 23, '0002284', '', NULL);
INSERT INTO chado.dbxref VALUES (2820, 23, '0002285', '', NULL);
INSERT INTO chado.dbxref VALUES (2821, 23, '0002286', '', NULL);
INSERT INTO chado.dbxref VALUES (2822, 23, '0002287', '', NULL);
INSERT INTO chado.dbxref VALUES (2823, 23, '0002288', '', NULL);
INSERT INTO chado.dbxref VALUES (2824, 23, '0002289', '', NULL);
INSERT INTO chado.dbxref VALUES (2825, 23, '0002290', '', NULL);
INSERT INTO chado.dbxref VALUES (2826, 23, '0002291', '', NULL);
INSERT INTO chado.dbxref VALUES (2827, 23, '0002292', '', NULL);
INSERT INTO chado.dbxref VALUES (2828, 23, '0002293', '', NULL);
INSERT INTO chado.dbxref VALUES (2829, 40, '//en.wikipedia.org/wiki/MtDNA_control_region', '', NULL);
INSERT INTO chado.dbxref VALUES (2830, 23, '0002294', '', NULL);
INSERT INTO chado.dbxref VALUES (2831, 23, '0002295', '', NULL);
INSERT INTO chado.dbxref VALUES (2832, 23, '0002296', '', NULL);
INSERT INTO chado.dbxref VALUES (2833, 23, '0002297', '', NULL);
INSERT INTO chado.dbxref VALUES (2834, 23, '0002298', '', NULL);
INSERT INTO chado.dbxref VALUES (2835, 23, '0002299', '', NULL);
INSERT INTO chado.dbxref VALUES (2836, 23, '0002301', '', NULL);
INSERT INTO chado.dbxref VALUES (2837, 23, '0002302', '', NULL);
INSERT INTO chado.dbxref VALUES (2838, 23, '1001284', '', NULL);
INSERT INTO chado.dbxref VALUES (2839, 23, '0002303', '', NULL);
INSERT INTO chado.dbxref VALUES (2840, 23, '0002304', '', NULL);
INSERT INTO chado.dbxref VALUES (2841, 23, '0002305', '', NULL);
INSERT INTO chado.dbxref VALUES (2842, 23, '0002306', '', NULL);
INSERT INTO chado.dbxref VALUES (2843, 23, '0002307', '', NULL);
INSERT INTO chado.dbxref VALUES (2844, 23, '0002308', '', NULL);
INSERT INTO chado.dbxref VALUES (2845, 23, '0002310', '', NULL);
INSERT INTO chado.dbxref VALUES (2846, 23, '0002312', '', NULL);
INSERT INTO chado.dbxref VALUES (2847, 23, '0002313', '', NULL);
INSERT INTO chado.dbxref VALUES (2848, 23, '0002314', '', NULL);
INSERT INTO chado.dbxref VALUES (2849, 23, '0002315', '', NULL);
INSERT INTO chado.dbxref VALUES (2850, 23, '0002316', '', NULL);
INSERT INTO chado.dbxref VALUES (2851, 23, '0002317', '', NULL);
INSERT INTO chado.dbxref VALUES (2852, 23, '0002318', '', NULL);
INSERT INTO chado.dbxref VALUES (2853, 23, '0002319', '', NULL);
INSERT INTO chado.dbxref VALUES (2854, 23, '0002320', '', NULL);
INSERT INTO chado.dbxref VALUES (2855, 23, '0002321', '', NULL);
INSERT INTO chado.dbxref VALUES (2856, 23, '0002322', '', NULL);
INSERT INTO chado.dbxref VALUES (2857, 23, '0002323', '', NULL);
INSERT INTO chado.dbxref VALUES (2858, 23, '0002324', '', NULL);
INSERT INTO chado.dbxref VALUES (2859, 23, '0002325', '', NULL);
INSERT INTO chado.dbxref VALUES (2860, 23, '0002326', '', NULL);
INSERT INTO chado.dbxref VALUES (2861, 23, '0002327', '', NULL);
INSERT INTO chado.dbxref VALUES (2862, 23, '0002328', '', NULL);
INSERT INTO chado.dbxref VALUES (2863, 23, '0002329', '', NULL);
INSERT INTO chado.dbxref VALUES (2864, 23, '0002330', '', NULL);
INSERT INTO chado.dbxref VALUES (2865, 23, '0002332', '', NULL);
INSERT INTO chado.dbxref VALUES (2866, 40, '//epi.grants.cancer.gov/epigen/#\:~\:text=mail.nih.gov-\,Overview\,a%20cell%20or%20entire%20organism.', '', NULL);
INSERT INTO chado.dbxref VALUES (2867, 23, '0002333', '', NULL);
INSERT INTO chado.dbxref VALUES (2868, 23, '0002334', '', NULL);
INSERT INTO chado.dbxref VALUES (2869, 23, '0002335', '', NULL);
INSERT INTO chado.dbxref VALUES (2870, 23, '0002336', '', NULL);
INSERT INTO chado.dbxref VALUES (2871, 23, '0002337', '', NULL);
INSERT INTO chado.dbxref VALUES (2872, 23, '0002338', '', NULL);
INSERT INTO chado.dbxref VALUES (2873, 23, '0002339', '', NULL);
INSERT INTO chado.dbxref VALUES (2874, 23, '0002340', '', NULL);
INSERT INTO chado.dbxref VALUES (2875, 23, '0002341', '', NULL);
INSERT INTO chado.dbxref VALUES (2876, 23, '0002344', '', NULL);
INSERT INTO chado.dbxref VALUES (2877, 23, '0002345', '', NULL);
INSERT INTO chado.dbxref VALUES (2878, 23, '0002346', '', NULL);
INSERT INTO chado.dbxref VALUES (2879, 23, '0002347', '', NULL);
INSERT INTO chado.dbxref VALUES (2880, 23, '0002348', '', NULL);
INSERT INTO chado.dbxref VALUES (2881, 23, '0002349', '', NULL);
INSERT INTO chado.dbxref VALUES (2882, 23, '0002350', '', NULL);
INSERT INTO chado.dbxref VALUES (2883, 23, '0002351', '', NULL);
INSERT INTO chado.dbxref VALUES (2884, 23, '0002352', '', NULL);
INSERT INTO chado.dbxref VALUES (2885, 23, '0002353', '', NULL);
INSERT INTO chado.dbxref VALUES (2886, 23, '0002354', '', NULL);
INSERT INTO chado.dbxref VALUES (2887, 23, '0002355', '', NULL);
INSERT INTO chado.dbxref VALUES (2888, 23, '0002356', '', NULL);
INSERT INTO chado.dbxref VALUES (2889, 23, '0002357', '', NULL);
INSERT INTO chado.dbxref VALUES (2890, 23, '0002358', '', NULL);
INSERT INTO chado.dbxref VALUES (2891, 23, '0002359', '', NULL);
INSERT INTO chado.dbxref VALUES (2892, 23, '0002360', '', NULL);
INSERT INTO chado.dbxref VALUES (2893, 23, '0002363', '', NULL);
INSERT INTO chado.dbxref VALUES (2894, 23, '0002364', '', NULL);
INSERT INTO chado.dbxref VALUES (2895, 23, '0002365', '', NULL);
INSERT INTO chado.dbxref VALUES (2896, 23, '0002366', '', NULL);
INSERT INTO chado.dbxref VALUES (2897, 23, '0002367', '', NULL);
INSERT INTO chado.dbxref VALUES (2898, 23, '0002368', '', NULL);
INSERT INTO chado.dbxref VALUES (2899, 23, '0002369', '', NULL);
INSERT INTO chado.dbxref VALUES (2900, 23, '0002370', '', NULL);
INSERT INTO chado.dbxref VALUES (2901, 23, '0002371', '', NULL);
INSERT INTO chado.dbxref VALUES (2902, 23, '0002372', '', NULL);
INSERT INTO chado.dbxref VALUES (2903, 23, '0002373', '', NULL);
INSERT INTO chado.dbxref VALUES (2904, 23, '0002374', '', NULL);
INSERT INTO chado.dbxref VALUES (2905, 23, '0002375', '', NULL);
INSERT INTO chado.dbxref VALUES (2906, 23, '0002376', '', NULL);
INSERT INTO chado.dbxref VALUES (2907, 23, '0002377', '', NULL);
INSERT INTO chado.dbxref VALUES (2908, 23, '0002378', '', NULL);
INSERT INTO chado.dbxref VALUES (2909, 23, '0002379', '', NULL);
INSERT INTO chado.dbxref VALUES (2910, 23, '0002380', '', NULL);
INSERT INTO chado.dbxref VALUES (2911, 23, '0002381', '', NULL);
INSERT INTO chado.dbxref VALUES (2912, 23, '0005841', '', NULL);
INSERT INTO chado.dbxref VALUES (2913, 23, '0005843', '', NULL);
INSERT INTO chado.dbxref VALUES (2914, 23, '0005845', '', NULL);
INSERT INTO chado.dbxref VALUES (2915, 23, '0005847', '', NULL);
INSERT INTO chado.dbxref VALUES (2916, 23, '0005848', '', NULL);
INSERT INTO chado.dbxref VALUES (2917, 23, '0005849', '', NULL);
INSERT INTO chado.dbxref VALUES (2918, 23, '0005850', '', NULL);
INSERT INTO chado.dbxref VALUES (2919, 23, '0005851', '', NULL);
INSERT INTO chado.dbxref VALUES (2920, 23, '0005852', '', NULL);
INSERT INTO chado.dbxref VALUES (2921, 23, '0005853', '', NULL);
INSERT INTO chado.dbxref VALUES (2922, 23, '0005856', '', NULL);
INSERT INTO chado.dbxref VALUES (2923, 23, '0005857', '', NULL);
INSERT INTO chado.dbxref VALUES (2924, 23, '0005858', '', NULL);
INSERT INTO chado.dbxref VALUES (2925, 23, '0100003', '', NULL);
INSERT INTO chado.dbxref VALUES (2926, 23, '0100004', '', NULL);
INSERT INTO chado.dbxref VALUES (2927, 23, '0100005', '', NULL);
INSERT INTO chado.dbxref VALUES (2928, 23, '0100006', '', NULL);
INSERT INTO chado.dbxref VALUES (2929, 23, '0100007', '', NULL);
INSERT INTO chado.dbxref VALUES (2930, 23, '0100008', '', NULL);
INSERT INTO chado.dbxref VALUES (2931, 23, '0100009', '', NULL);
INSERT INTO chado.dbxref VALUES (2932, 23, '0100010', '', NULL);
INSERT INTO chado.dbxref VALUES (2933, 23, '0100012', '', NULL);
INSERT INTO chado.dbxref VALUES (2934, 23, '0100013', '', NULL);
INSERT INTO chado.dbxref VALUES (2935, 23, '0100014', '', NULL);
INSERT INTO chado.dbxref VALUES (2936, 23, '0100015', '', NULL);
INSERT INTO chado.dbxref VALUES (2937, 23, '0100016', '', NULL);
INSERT INTO chado.dbxref VALUES (2938, 23, '0100018', '', NULL);
INSERT INTO chado.dbxref VALUES (2939, 23, '0100020', '', NULL);
INSERT INTO chado.dbxref VALUES (2940, 33, 'LA6690-7', '', NULL);
INSERT INTO chado.dbxref VALUES (2941, 23, '1000005', '', NULL);
INSERT INTO chado.dbxref VALUES (2942, 23, '1000008', '', NULL);
INSERT INTO chado.dbxref VALUES (2943, 23, '1000009', '', NULL);
INSERT INTO chado.dbxref VALUES (2944, 23, '1000010', '', NULL);
INSERT INTO chado.dbxref VALUES (2945, 23, '1000011', '', NULL);
INSERT INTO chado.dbxref VALUES (2946, 23, '1000012', '', NULL);
INSERT INTO chado.dbxref VALUES (2947, 23, '1000013', '', NULL);
INSERT INTO chado.dbxref VALUES (2948, 23, '1000014', '', NULL);
INSERT INTO chado.dbxref VALUES (2949, 23, '1000015', '', NULL);
INSERT INTO chado.dbxref VALUES (2950, 23, '1000016', '', NULL);
INSERT INTO chado.dbxref VALUES (2951, 23, '1000017', '', NULL);
INSERT INTO chado.dbxref VALUES (2952, 23, '1000018', '', NULL);
INSERT INTO chado.dbxref VALUES (2953, 23, '1000019', '', NULL);
INSERT INTO chado.dbxref VALUES (2954, 23, '1000020', '', NULL);
INSERT INTO chado.dbxref VALUES (2955, 23, '1000021', '', NULL);
INSERT INTO chado.dbxref VALUES (2956, 23, '1000022', '', NULL);
INSERT INTO chado.dbxref VALUES (2957, 23, '1000023', '', NULL);
INSERT INTO chado.dbxref VALUES (2958, 23, '1000024', '', NULL);
INSERT INTO chado.dbxref VALUES (2959, 23, '1000025', '', NULL);
INSERT INTO chado.dbxref VALUES (2960, 23, '1000026', '', NULL);
INSERT INTO chado.dbxref VALUES (2961, 23, '1000027', '', NULL);
INSERT INTO chado.dbxref VALUES (2962, 23, '1000028', '', NULL);
INSERT INTO chado.dbxref VALUES (2963, 23, '1000031', '', NULL);
INSERT INTO chado.dbxref VALUES (2964, 23, '1000032', '', NULL);
INSERT INTO chado.dbxref VALUES (2965, 33, 'LA9659-9', '', NULL);
INSERT INTO chado.dbxref VALUES (2966, 33, 'LA6686-5', '', NULL);
INSERT INTO chado.dbxref VALUES (2967, 33, 'LA6689-9', '', NULL);
INSERT INTO chado.dbxref VALUES (2968, 23, '1000039', '', NULL);
INSERT INTO chado.dbxref VALUES (2969, 23, '1000173', '', NULL);
INSERT INTO chado.dbxref VALUES (2970, 23, '1000040', '', NULL);
INSERT INTO chado.dbxref VALUES (2971, 23, '1000043', '', NULL);
INSERT INTO chado.dbxref VALUES (2972, 23, '1000046', '', NULL);
INSERT INTO chado.dbxref VALUES (2973, 23, '1000047', '', NULL);
INSERT INTO chado.dbxref VALUES (2974, 23, '1000048', '', NULL);
INSERT INTO chado.dbxref VALUES (2975, 23, '1000049', '', NULL);
INSERT INTO chado.dbxref VALUES (2976, 23, '1000177', '', NULL);
INSERT INTO chado.dbxref VALUES (2977, 23, '1000179', '', NULL);
INSERT INTO chado.dbxref VALUES (2978, 23, '1000050', '', NULL);
INSERT INTO chado.dbxref VALUES (2979, 23, '1000054', '', NULL);
INSERT INTO chado.dbxref VALUES (2980, 23, '1000055', '', NULL);
INSERT INTO chado.dbxref VALUES (2981, 23, '1000056', '', NULL);
INSERT INTO chado.dbxref VALUES (2982, 23, '1000057', '', NULL);
INSERT INTO chado.dbxref VALUES (2983, 23, '1000058', '', NULL);
INSERT INTO chado.dbxref VALUES (2984, 23, '1000059', '', NULL);
INSERT INTO chado.dbxref VALUES (2985, 23, '1000060', '', NULL);
INSERT INTO chado.dbxref VALUES (2986, 23, '1000061', '', NULL);
INSERT INTO chado.dbxref VALUES (2987, 23, '1000062', '', NULL);
INSERT INTO chado.dbxref VALUES (2988, 23, '1000063', '', NULL);
INSERT INTO chado.dbxref VALUES (2989, 23, '1000064', '', NULL);
INSERT INTO chado.dbxref VALUES (2990, 23, '1000065', '', NULL);
INSERT INTO chado.dbxref VALUES (2991, 23, '1000066', '', NULL);
INSERT INTO chado.dbxref VALUES (2992, 23, '1000067', '', NULL);
INSERT INTO chado.dbxref VALUES (2993, 23, '1000068', '', NULL);
INSERT INTO chado.dbxref VALUES (2994, 23, '1000069', '', NULL);
INSERT INTO chado.dbxref VALUES (2995, 23, '1000070', '', NULL);
INSERT INTO chado.dbxref VALUES (2996, 23, '1000071', '', NULL);
INSERT INTO chado.dbxref VALUES (2997, 23, '1000072', '', NULL);
INSERT INTO chado.dbxref VALUES (2998, 23, '1000073', '', NULL);
INSERT INTO chado.dbxref VALUES (2999, 23, '1000074', '', NULL);
INSERT INTO chado.dbxref VALUES (3000, 23, '1000075', '', NULL);
INSERT INTO chado.dbxref VALUES (3001, 23, '1000076', '', NULL);
INSERT INTO chado.dbxref VALUES (3002, 23, '1000078', '', NULL);
INSERT INTO chado.dbxref VALUES (3003, 23, '1000079', '', NULL);
INSERT INTO chado.dbxref VALUES (3004, 23, '1000080', '', NULL);
INSERT INTO chado.dbxref VALUES (3005, 23, '1000081', '', NULL);
INSERT INTO chado.dbxref VALUES (3006, 23, '1000082', '', NULL);
INSERT INTO chado.dbxref VALUES (3007, 23, '1000083', '', NULL);
INSERT INTO chado.dbxref VALUES (3008, 23, '1000084', '', NULL);
INSERT INTO chado.dbxref VALUES (3009, 23, '1000085', '', NULL);
INSERT INTO chado.dbxref VALUES (3010, 23, '1000086', '', NULL);
INSERT INTO chado.dbxref VALUES (3011, 23, '1000087', '', NULL);
INSERT INTO chado.dbxref VALUES (3012, 23, '1000088', '', NULL);
INSERT INTO chado.dbxref VALUES (3013, 23, '1000090', '', NULL);
INSERT INTO chado.dbxref VALUES (3014, 23, '1000091', '', NULL);
INSERT INTO chado.dbxref VALUES (3015, 23, '1000089', '', NULL);
INSERT INTO chado.dbxref VALUES (3016, 23, '1000092', '', NULL);
INSERT INTO chado.dbxref VALUES (3017, 23, '1000093', '', NULL);
INSERT INTO chado.dbxref VALUES (3018, 23, '1000094', '', NULL);
INSERT INTO chado.dbxref VALUES (3019, 23, '1000095', '', NULL);
INSERT INTO chado.dbxref VALUES (3020, 23, '1000096', '', NULL);
INSERT INTO chado.dbxref VALUES (3021, 23, '1000097', '', NULL);
INSERT INTO chado.dbxref VALUES (3022, 23, '1000098', '', NULL);
INSERT INTO chado.dbxref VALUES (3023, 23, '1000099', '', NULL);
INSERT INTO chado.dbxref VALUES (3024, 23, '1000100', '', NULL);
INSERT INTO chado.dbxref VALUES (3025, 23, '1000101', '', NULL);
INSERT INTO chado.dbxref VALUES (3026, 23, '1000102', '', NULL);
INSERT INTO chado.dbxref VALUES (3027, 23, '1000103', '', NULL);
INSERT INTO chado.dbxref VALUES (3028, 23, '1000104', '', NULL);
INSERT INTO chado.dbxref VALUES (3029, 23, '1000105', '', NULL);
INSERT INTO chado.dbxref VALUES (3030, 23, '1000106', '', NULL);
INSERT INTO chado.dbxref VALUES (3031, 23, '1000107', '', NULL);
INSERT INTO chado.dbxref VALUES (3032, 23, '1000108', '', NULL);
INSERT INTO chado.dbxref VALUES (3033, 23, '1000109', '', NULL);
INSERT INTO chado.dbxref VALUES (3034, 23, '1000110', '', NULL);
INSERT INTO chado.dbxref VALUES (3035, 23, '1000111', '', NULL);
INSERT INTO chado.dbxref VALUES (3036, 23, '1000113', '', NULL);
INSERT INTO chado.dbxref VALUES (3037, 23, '1000114', '', NULL);
INSERT INTO chado.dbxref VALUES (3038, 23, '1000112', '', NULL);
INSERT INTO chado.dbxref VALUES (3039, 23, '1000115', '', NULL);
INSERT INTO chado.dbxref VALUES (3040, 23, '1000116', '', NULL);
INSERT INTO chado.dbxref VALUES (3041, 23, '1000117', '', NULL);
INSERT INTO chado.dbxref VALUES (3042, 23, '1000118', '', NULL);
INSERT INTO chado.dbxref VALUES (3043, 23, '1000119', '', NULL);
INSERT INTO chado.dbxref VALUES (3044, 23, '1000120', '', NULL);
INSERT INTO chado.dbxref VALUES (3045, 23, '1000121', '', NULL);
INSERT INTO chado.dbxref VALUES (3046, 23, '1000122', '', NULL);
INSERT INTO chado.dbxref VALUES (3047, 23, '1000123', '', NULL);
INSERT INTO chado.dbxref VALUES (3048, 23, '1000124', '', NULL);
INSERT INTO chado.dbxref VALUES (3049, 23, '1000125', '', NULL);
INSERT INTO chado.dbxref VALUES (3050, 23, '1000126', '', NULL);
INSERT INTO chado.dbxref VALUES (3051, 23, '1000127', '', NULL);
INSERT INTO chado.dbxref VALUES (3052, 23, '1000132', '', NULL);
INSERT INTO chado.dbxref VALUES (3053, 23, '1000134', '', NULL);
INSERT INTO chado.dbxref VALUES (3054, 23, '1000136', '', NULL);
INSERT INTO chado.dbxref VALUES (3055, 23, '1000138', '', NULL);
INSERT INTO chado.dbxref VALUES (3056, 23, '1000140', '', NULL);
INSERT INTO chado.dbxref VALUES (3057, 23, '1000141', '', NULL);
INSERT INTO chado.dbxref VALUES (3058, 23, '1000142', '', NULL);
INSERT INTO chado.dbxref VALUES (3059, 23, '1000143', '', NULL);
INSERT INTO chado.dbxref VALUES (3060, 23, '1000144', '', NULL);
INSERT INTO chado.dbxref VALUES (3061, 23, '1000145', '', NULL);
INSERT INTO chado.dbxref VALUES (3062, 23, '1000147', '', NULL);
INSERT INTO chado.dbxref VALUES (3063, 23, '1000148', '', NULL);
INSERT INTO chado.dbxref VALUES (3064, 23, '1000149', '', NULL);
INSERT INTO chado.dbxref VALUES (3065, 23, '1000150', '', NULL);
INSERT INTO chado.dbxref VALUES (3066, 23, '1000151', '', NULL);
INSERT INTO chado.dbxref VALUES (3067, 23, '1000152', '', NULL);
INSERT INTO chado.dbxref VALUES (3068, 23, '1000154', '', NULL);
INSERT INTO chado.dbxref VALUES (3069, 23, '1000153', '', NULL);
INSERT INTO chado.dbxref VALUES (3070, 23, '1000156', '', NULL);
INSERT INTO chado.dbxref VALUES (3071, 23, '1000157', '', NULL);
INSERT INTO chado.dbxref VALUES (3072, 23, '1000158', '', NULL);
INSERT INTO chado.dbxref VALUES (3073, 23, '1000159', '', NULL);
INSERT INTO chado.dbxref VALUES (3074, 23, '1000160', '', NULL);
INSERT INTO chado.dbxref VALUES (3075, 23, '1000161', '', NULL);
INSERT INTO chado.dbxref VALUES (3076, 23, '1000162', '', NULL);
INSERT INTO chado.dbxref VALUES (3077, 23, '1000170', '', NULL);
INSERT INTO chado.dbxref VALUES (3078, 23, '1000171', '', NULL);
INSERT INTO chado.dbxref VALUES (3079, 23, '1000175', '', NULL);
INSERT INTO chado.dbxref VALUES (3080, 23, '1000180', '', NULL);
INSERT INTO chado.dbxref VALUES (3081, 23, '1000181', '', NULL);
INSERT INTO chado.dbxref VALUES (3082, 23, '1000184', '', NULL);
INSERT INTO chado.dbxref VALUES (3083, 23, '1000185', '', NULL);
INSERT INTO chado.dbxref VALUES (3084, 23, '1000186', '', NULL);
INSERT INTO chado.dbxref VALUES (3085, 23, '1001186', '', NULL);
INSERT INTO chado.dbxref VALUES (3086, 23, '1001187', '', NULL);
INSERT INTO chado.dbxref VALUES (3087, 23, '1001188', '', NULL);
INSERT INTO chado.dbxref VALUES (3088, 23, '1001189', '', NULL);
INSERT INTO chado.dbxref VALUES (3089, 23, '1001190', '', NULL);
INSERT INTO chado.dbxref VALUES (3090, 23, '1001195', '', NULL);
INSERT INTO chado.dbxref VALUES (3091, 23, '1001191', '', NULL);
INSERT INTO chado.dbxref VALUES (3092, 23, '1001192', '', NULL);
INSERT INTO chado.dbxref VALUES (3093, 23, '1001193', '', NULL);
INSERT INTO chado.dbxref VALUES (3094, 23, '1001194', '', NULL);
INSERT INTO chado.dbxref VALUES (3095, 23, '1001196', '', NULL);
INSERT INTO chado.dbxref VALUES (3096, 23, '1001217', '', NULL);
INSERT INTO chado.dbxref VALUES (3097, 23, '1001244', '', NULL);
INSERT INTO chado.dbxref VALUES (3098, 23, '1001246', '', NULL);
INSERT INTO chado.dbxref VALUES (3099, 23, '1001247', '', NULL);
INSERT INTO chado.dbxref VALUES (3100, 23, '1001254', '', NULL);
INSERT INTO chado.dbxref VALUES (3101, 23, '1001249', '', NULL);
INSERT INTO chado.dbxref VALUES (3102, 23, '1001255', '', NULL);
INSERT INTO chado.dbxref VALUES (3103, 23, '1001259', '', NULL);
INSERT INTO chado.dbxref VALUES (3104, 23, '1001260', '', NULL);
INSERT INTO chado.dbxref VALUES (3105, 23, '1001261', '', NULL);
INSERT INTO chado.dbxref VALUES (3106, 23, '1001262', '', NULL);
INSERT INTO chado.dbxref VALUES (3107, 23, '1001263', '', NULL);
INSERT INTO chado.dbxref VALUES (3108, 23, '1001264', '', NULL);
INSERT INTO chado.dbxref VALUES (3109, 23, '1001265', '', NULL);
INSERT INTO chado.dbxref VALUES (3110, 23, '1001266', '', NULL);
INSERT INTO chado.dbxref VALUES (3111, 23, '1001267', '', NULL);
INSERT INTO chado.dbxref VALUES (3112, 23, '1001269', '', NULL);
INSERT INTO chado.dbxref VALUES (3113, 23, '1001270', '', NULL);
INSERT INTO chado.dbxref VALUES (3114, 23, '1001271', '', NULL);
INSERT INTO chado.dbxref VALUES (3115, 23, '1001272', '', NULL);
INSERT INTO chado.dbxref VALUES (3116, 23, '1001273', '', NULL);
INSERT INTO chado.dbxref VALUES (3117, 23, '1001274', '', NULL);
INSERT INTO chado.dbxref VALUES (3118, 23, '1001275', '', NULL);
INSERT INTO chado.dbxref VALUES (3119, 23, '1001277', '', NULL);
INSERT INTO chado.dbxref VALUES (3120, 23, '1001279', '', NULL);
INSERT INTO chado.dbxref VALUES (3121, 23, '1001280', '', NULL);
INSERT INTO chado.dbxref VALUES (3122, 23, '1001281', '', NULL);
INSERT INTO chado.dbxref VALUES (3123, 23, '1001282', '', NULL);
INSERT INTO chado.dbxref VALUES (3124, 23, '1001288', '', NULL);
INSERT INTO chado.dbxref VALUES (3125, 23, '1001283', '', NULL);
INSERT INTO chado.dbxref VALUES (3126, 23, '1001285', '', NULL);
INSERT INTO chado.dbxref VALUES (3127, 23, '1001286', '', NULL);
INSERT INTO chado.dbxref VALUES (3128, 23, '1001287', '', NULL);
INSERT INTO chado.dbxref VALUES (3129, 23, '2000061', '', NULL);
INSERT INTO chado.dbxref VALUES (3130, 24, '1000000', '', NULL);
INSERT INTO chado.dbxref VALUES (3131, 24, 'is_a', '', NULL);
INSERT INTO chado.dbxref VALUES (3132, 24, '0000000', '', NULL);
INSERT INTO chado.dbxref VALUES (3133, 24, '0000001', '', NULL);
INSERT INTO chado.dbxref VALUES (3134, 20, 'phylum', '', NULL);
INSERT INTO chado.dbxref VALUES (3135, 24, '0000002', '', NULL);
INSERT INTO chado.dbxref VALUES (3136, 20, 'class', '', NULL);
INSERT INTO chado.dbxref VALUES (3137, 24, '0000003', '', NULL);
INSERT INTO chado.dbxref VALUES (3138, 20, 'order', '', NULL);
INSERT INTO chado.dbxref VALUES (3139, 24, '0000004', '', NULL);
INSERT INTO chado.dbxref VALUES (3140, 20, 'family', '', NULL);
INSERT INTO chado.dbxref VALUES (3141, 20, 'genus', '', NULL);
INSERT INTO chado.dbxref VALUES (3142, 20, 'species', '', NULL);
INSERT INTO chado.dbxref VALUES (3143, 24, '0000007', '', NULL);
INSERT INTO chado.dbxref VALUES (3144, 20, 'subclass', '', NULL);
INSERT INTO chado.dbxref VALUES (3145, 24, '0000008', '', NULL);
INSERT INTO chado.dbxref VALUES (3146, 20, 'subphylum', '', NULL);
INSERT INTO chado.dbxref VALUES (3147, 24, '0000009', '', NULL);
INSERT INTO chado.dbxref VALUES (3148, 20, 'subgenus', '', NULL);
INSERT INTO chado.dbxref VALUES (3149, 24, '0000010', '', NULL);
INSERT INTO chado.dbxref VALUES (3150, 20, 'species_group', '', NULL);
INSERT INTO chado.dbxref VALUES (3151, 24, '0000011', '', NULL);
INSERT INTO chado.dbxref VALUES (3152, 20, 'species_subgroup', '', NULL);
INSERT INTO chado.dbxref VALUES (3153, 24, '0000012', '', NULL);
INSERT INTO chado.dbxref VALUES (3154, 24, '0000013', '', NULL);
INSERT INTO chado.dbxref VALUES (3155, 20, 'infraorder', '', NULL);
INSERT INTO chado.dbxref VALUES (3156, 24, '0000014', '', NULL);
INSERT INTO chado.dbxref VALUES (3157, 20, 'suborder', '', NULL);
INSERT INTO chado.dbxref VALUES (3158, 24, '0000015', '', NULL);
INSERT INTO chado.dbxref VALUES (3159, 20, 'superclass', '', NULL);
INSERT INTO chado.dbxref VALUES (3160, 24, '0000016', '', NULL);
INSERT INTO chado.dbxref VALUES (3161, 20, 'varietas', '', NULL);
INSERT INTO chado.dbxref VALUES (3162, 24, '0000017', '', NULL);
INSERT INTO chado.dbxref VALUES (3163, 20, 'kingdom', '', NULL);
INSERT INTO chado.dbxref VALUES (3164, 24, '0000018', '', NULL);
INSERT INTO chado.dbxref VALUES (3165, 20, 'superfamily', '', NULL);
INSERT INTO chado.dbxref VALUES (3166, 24, '0000019', '', NULL);
INSERT INTO chado.dbxref VALUES (3167, 20, 'infraclass', '', NULL);
INSERT INTO chado.dbxref VALUES (3168, 24, '0000020', '', NULL);
INSERT INTO chado.dbxref VALUES (3169, 20, 'superorder', '', NULL);
INSERT INTO chado.dbxref VALUES (3170, 24, '0000021', '', NULL);
INSERT INTO chado.dbxref VALUES (3171, 20, 'parvorder', '', NULL);
INSERT INTO chado.dbxref VALUES (3172, 24, '0000022', '', NULL);
INSERT INTO chado.dbxref VALUES (3173, 20, 'superkingdom', '', NULL);
INSERT INTO chado.dbxref VALUES (3174, 24, '0000023', '', NULL);
INSERT INTO chado.dbxref VALUES (3175, 20, 'subspecies', '', NULL);
INSERT INTO chado.dbxref VALUES (3176, 24, '0000024', '', NULL);
INSERT INTO chado.dbxref VALUES (3177, 20, 'subfamily', '', NULL);
INSERT INTO chado.dbxref VALUES (3178, 24, '0000025', '', NULL);
INSERT INTO chado.dbxref VALUES (3179, 20, 'tribe', '', NULL);
INSERT INTO chado.dbxref VALUES (3180, 24, '0000026', '', NULL);
INSERT INTO chado.dbxref VALUES (3181, 20, 'forma', '', NULL);
INSERT INTO chado.dbxref VALUES (3182, 24, '0000027', '', NULL);
INSERT INTO chado.dbxref VALUES (3183, 20, 'superphylum', '', NULL);
INSERT INTO chado.dbxref VALUES (3184, 24, '0000028', '', NULL);
INSERT INTO chado.dbxref VALUES (3185, 20, 'subtribe', '', NULL);
INSERT INTO chado.dbxref VALUES (3186, 24, '0000029', '', NULL);
INSERT INTO chado.dbxref VALUES (3187, 20, 'subkingdom', '', NULL);
INSERT INTO chado.dbxref VALUES (3188, 24, '0000030', '', NULL);
INSERT INTO chado.dbxref VALUES (3189, 24, '0000031', '', NULL);
INSERT INTO chado.dbxref VALUES (3190, 24, '0000032', '', NULL);
INSERT INTO chado.dbxref VALUES (3191, 24, '0000033', '', NULL);
INSERT INTO chado.dbxref VALUES (3192, 24, '0000034', '', NULL);
INSERT INTO chado.dbxref VALUES (3193, 24, '0000035', '', NULL);
INSERT INTO chado.dbxref VALUES (3194, 24, '0000036', '', NULL);
INSERT INTO chado.dbxref VALUES (3195, 24, '0000037', '', NULL);
INSERT INTO chado.dbxref VALUES (3196, 24, '0000038', '', NULL);
INSERT INTO chado.dbxref VALUES (3197, 24, '0000039', '', NULL);
INSERT INTO chado.dbxref VALUES (3198, 24, '0000040', '', NULL);
INSERT INTO chado.dbxref VALUES (3199, 24, '0000041', '', NULL);
INSERT INTO chado.dbxref VALUES (3200, 24, '0000042', '', NULL);
INSERT INTO chado.dbxref VALUES (3201, 24, '0000043', '', NULL);
INSERT INTO chado.dbxref VALUES (3202, 24, '0000044', '', NULL);
INSERT INTO chado.dbxref VALUES (3203, 24, '0000046', '', NULL);
INSERT INTO chado.dbxref VALUES (3204, 24, '0000047', '', NULL);
INSERT INTO chado.dbxref VALUES (3205, 24, '0000048', '', NULL);
INSERT INTO chado.dbxref VALUES (3206, 24, '0000049', '', NULL);
INSERT INTO chado.dbxref VALUES (3207, 24, '0000050', '', NULL);
INSERT INTO chado.dbxref VALUES (3208, 24, '0000051', '', NULL);
INSERT INTO chado.dbxref VALUES (3209, 24, '0000052', '', NULL);
INSERT INTO chado.dbxref VALUES (3210, 24, '0000053', '', NULL);
INSERT INTO chado.dbxref VALUES (3211, 24, '0000054', '', NULL);
INSERT INTO chado.dbxref VALUES (3212, 24, '0000055', '', NULL);
INSERT INTO chado.dbxref VALUES (3213, 24, '0000056', '', NULL);
INSERT INTO chado.dbxref VALUES (3214, 24, '0000057', '', NULL);
INSERT INTO chado.dbxref VALUES (3215, 24, '0000058', '', NULL);
INSERT INTO chado.dbxref VALUES (3216, 24, '0000059', '', NULL);
INSERT INTO chado.dbxref VALUES (3217, 24, '0000060', '', NULL);
INSERT INTO chado.dbxref VALUES (3218, 25, 'is_a', '', NULL);
INSERT INTO chado.dbxref VALUES (3219, 25, 'part_of', '', NULL);
INSERT INTO chado.dbxref VALUES (3220, 25, '0000001', '', NULL);
INSERT INTO chado.dbxref VALUES (3221, 25, '0000002', '', NULL);
INSERT INTO chado.dbxref VALUES (3222, 25, '0000003', '', NULL);
INSERT INTO chado.dbxref VALUES (3223, 25, '0000004', '', NULL);
INSERT INTO chado.dbxref VALUES (3224, 25, '0000005', '', NULL);
INSERT INTO chado.dbxref VALUES (3225, 25, '0000006', '', NULL);
INSERT INTO chado.dbxref VALUES (3226, 25, '0000007', '', NULL);
INSERT INTO chado.dbxref VALUES (3227, 25, '0000008', '', NULL);
INSERT INTO chado.dbxref VALUES (3228, 25, '0000009', '', NULL);
INSERT INTO chado.dbxref VALUES (3229, 25, '0000010', '', NULL);
INSERT INTO chado.dbxref VALUES (3230, 25, '0000011', '', NULL);
INSERT INTO chado.dbxref VALUES (3231, 25, '0000012', '', NULL);
INSERT INTO chado.dbxref VALUES (3232, 25, '0000013', '', NULL);
INSERT INTO chado.dbxref VALUES (3233, 25, '0000014', '', NULL);
INSERT INTO chado.dbxref VALUES (3234, 25, '0000015', '', NULL);
INSERT INTO chado.dbxref VALUES (3235, 25, '0000016', '', NULL);
INSERT INTO chado.dbxref VALUES (3236, 25, '0000017', '', NULL);
INSERT INTO chado.dbxref VALUES (3237, 25, '0000018', '', NULL);
INSERT INTO chado.dbxref VALUES (3238, 25, '0000019', '', NULL);
INSERT INTO chado.dbxref VALUES (3239, 25, '0000020', '', NULL);
INSERT INTO chado.dbxref VALUES (3240, 25, '0000021', '', NULL);
INSERT INTO chado.dbxref VALUES (3241, 25, '0000022', '', NULL);
INSERT INTO chado.dbxref VALUES (3242, 25, '0000023', '', NULL);
INSERT INTO chado.dbxref VALUES (3243, 25, '0000024', '', NULL);
INSERT INTO chado.dbxref VALUES (3244, 25, '0000025', '', NULL);
INSERT INTO chado.dbxref VALUES (3245, 25, '0000026', '', NULL);
INSERT INTO chado.dbxref VALUES (3246, 25, '0000027', '', NULL);
INSERT INTO chado.dbxref VALUES (3247, 25, '0000028', '', NULL);
INSERT INTO chado.dbxref VALUES (3248, 26, 'is_a', '', NULL);
INSERT INTO chado.dbxref VALUES (3249, 26, 'part_of', '', NULL);
INSERT INTO chado.dbxref VALUES (3250, 26, '0000001', '', NULL);
INSERT INTO chado.dbxref VALUES (3251, 26, '0000037', '', NULL);
INSERT INTO chado.dbxref VALUES (3252, 26, '0000004', '', NULL);
INSERT INTO chado.dbxref VALUES (3253, 26, '0000005', '', NULL);
INSERT INTO chado.dbxref VALUES (3254, 26, '0000006', '', NULL);
INSERT INTO chado.dbxref VALUES (3255, 26, '0000016', '', NULL);
INSERT INTO chado.dbxref VALUES (3256, 26, '0000007', '', NULL);
INSERT INTO chado.dbxref VALUES (3257, 26, '0000008', '', NULL);
INSERT INTO chado.dbxref VALUES (3258, 26, '0000009', '', NULL);
INSERT INTO chado.dbxref VALUES (3259, 26, '0000010', '', NULL);
INSERT INTO chado.dbxref VALUES (3260, 26, '0000046', '', NULL);
INSERT INTO chado.dbxref VALUES (3261, 26, '0000011', '', NULL);
INSERT INTO chado.dbxref VALUES (3262, 26, '0000012', '', NULL);
INSERT INTO chado.dbxref VALUES (3263, 26, '0000013', '', NULL);
INSERT INTO chado.dbxref VALUES (3264, 26, '0000014', '', NULL);
INSERT INTO chado.dbxref VALUES (3265, 26, '0000035', '', NULL);
INSERT INTO chado.dbxref VALUES (3266, 26, '0000036', '', NULL);
INSERT INTO chado.dbxref VALUES (3267, 26, '0000038', '', NULL);
INSERT INTO chado.dbxref VALUES (3268, 26, '0000257', '', NULL);
INSERT INTO chado.dbxref VALUES (3269, 26, '0000039', '', NULL);
INSERT INTO chado.dbxref VALUES (3270, 26, '0000040', '', NULL);
INSERT INTO chado.dbxref VALUES (3271, 26, '0000041', '', NULL);
INSERT INTO chado.dbxref VALUES (3272, 26, '0000042', '', NULL);
INSERT INTO chado.dbxref VALUES (3273, 26, '0000043', '', NULL);
INSERT INTO chado.dbxref VALUES (3274, 26, '0000044', '', NULL);
INSERT INTO chado.dbxref VALUES (3275, 26, '0000045', '', NULL);
INSERT INTO chado.dbxref VALUES (3276, 26, '0000047', '', NULL);
INSERT INTO chado.dbxref VALUES (3277, 26, '0000048', '', NULL);
INSERT INTO chado.dbxref VALUES (3278, 26, '0000049', '', NULL);
INSERT INTO chado.dbxref VALUES (3279, 26, '0000080', '', NULL);
INSERT INTO chado.dbxref VALUES (3280, 26, '0000050', '', NULL);
INSERT INTO chado.dbxref VALUES (3281, 26, '0000051', '', NULL);
INSERT INTO chado.dbxref VALUES (3282, 26, '0000052', '', NULL);
INSERT INTO chado.dbxref VALUES (3283, 26, '0000053', '', NULL);
INSERT INTO chado.dbxref VALUES (3284, 26, '0000059', '', NULL);
INSERT INTO chado.dbxref VALUES (3285, 26, '0000064', '', NULL);
INSERT INTO chado.dbxref VALUES (3286, 26, '0000065', '', NULL);
INSERT INTO chado.dbxref VALUES (3287, 26, '0000066', '', NULL);
INSERT INTO chado.dbxref VALUES (3288, 26, '0000067', '', NULL);
INSERT INTO chado.dbxref VALUES (3289, 26, '0000068', '', NULL);
INSERT INTO chado.dbxref VALUES (3290, 26, '0000069', '', NULL);
INSERT INTO chado.dbxref VALUES (3291, 26, '0000070', '', NULL);
INSERT INTO chado.dbxref VALUES (3292, 26, '0000072', '', NULL);
INSERT INTO chado.dbxref VALUES (3293, 26, '0000073', '', NULL);
INSERT INTO chado.dbxref VALUES (3294, 26, '0000074', '', NULL);
INSERT INTO chado.dbxref VALUES (3295, 26, '0000075', '', NULL);
INSERT INTO chado.dbxref VALUES (3296, 26, '0000256', '', NULL);
INSERT INTO chado.dbxref VALUES (3297, 26, '0000076', '', NULL);
INSERT INTO chado.dbxref VALUES (3298, 26, '0000077', '', NULL);
INSERT INTO chado.dbxref VALUES (3299, 26, '0000078', '', NULL);
INSERT INTO chado.dbxref VALUES (3300, 26, '0000079', '', NULL);
INSERT INTO chado.dbxref VALUES (3301, 26, '0000081', '', NULL);
INSERT INTO chado.dbxref VALUES (3302, 26, '0000082', '', NULL);
INSERT INTO chado.dbxref VALUES (3303, 26, '0000083', '', NULL);
INSERT INTO chado.dbxref VALUES (3304, 26, '0000084', '', NULL);
INSERT INTO chado.dbxref VALUES (3305, 26, '0000085', '', NULL);
INSERT INTO chado.dbxref VALUES (3306, 26, '0000087', '', NULL);
INSERT INTO chado.dbxref VALUES (3307, 26, '0000100', '', NULL);
INSERT INTO chado.dbxref VALUES (3308, 26, '0000101', '', NULL);
INSERT INTO chado.dbxref VALUES (3309, 26, '0000102', '', NULL);
INSERT INTO chado.dbxref VALUES (3310, 26, '0000103', '', NULL);
INSERT INTO chado.dbxref VALUES (3311, 26, '0000104', '', NULL);
INSERT INTO chado.dbxref VALUES (3312, 26, '0000105', '', NULL);
INSERT INTO chado.dbxref VALUES (3313, 26, '0000106', '', NULL);
INSERT INTO chado.dbxref VALUES (3314, 26, '0000107', '', NULL);
INSERT INTO chado.dbxref VALUES (3315, 26, '0000108', '', NULL);
INSERT INTO chado.dbxref VALUES (3316, 26, '0000109', '', NULL);
INSERT INTO chado.dbxref VALUES (3317, 26, '0000110', '', NULL);
INSERT INTO chado.dbxref VALUES (3318, 26, '0000111', '', NULL);
INSERT INTO chado.dbxref VALUES (3319, 26, '0000112', '', NULL);
INSERT INTO chado.dbxref VALUES (3320, 26, '0000113', '', NULL);
INSERT INTO chado.dbxref VALUES (3321, 26, '0000114', '', NULL);
INSERT INTO chado.dbxref VALUES (3322, 26, '0000115', '', NULL);
INSERT INTO chado.dbxref VALUES (3323, 26, '0000116', '', NULL);
INSERT INTO chado.dbxref VALUES (3324, 26, '0000117', '', NULL);
INSERT INTO chado.dbxref VALUES (3325, 26, '0000118', '', NULL);
INSERT INTO chado.dbxref VALUES (3326, 26, '0000119', '', NULL);
INSERT INTO chado.dbxref VALUES (3327, 26, '0000120', '', NULL);
INSERT INTO chado.dbxref VALUES (3328, 26, '0000121', '', NULL);
INSERT INTO chado.dbxref VALUES (3329, 26, '0000122', '', NULL);
INSERT INTO chado.dbxref VALUES (3330, 26, '0000123', '', NULL);
INSERT INTO chado.dbxref VALUES (3331, 26, '0000124', '', NULL);
INSERT INTO chado.dbxref VALUES (3332, 26, '0000125', '', NULL);
INSERT INTO chado.dbxref VALUES (3333, 26, '0000126', '', NULL);
INSERT INTO chado.dbxref VALUES (3334, 26, '0000127', '', NULL);
INSERT INTO chado.dbxref VALUES (3335, 26, '0000128', '', NULL);
INSERT INTO chado.dbxref VALUES (3336, 26, '0000129', '', NULL);
INSERT INTO chado.dbxref VALUES (3337, 26, '0000130', '', NULL);
INSERT INTO chado.dbxref VALUES (3338, 26, '0000131', '', NULL);
INSERT INTO chado.dbxref VALUES (3339, 26, '0000132', '', NULL);
INSERT INTO chado.dbxref VALUES (3340, 26, '0000133', '', NULL);
INSERT INTO chado.dbxref VALUES (3341, 26, '0000134', '', NULL);
INSERT INTO chado.dbxref VALUES (3342, 26, '0000135', '', NULL);
INSERT INTO chado.dbxref VALUES (3343, 26, '0000136', '', NULL);
INSERT INTO chado.dbxref VALUES (3344, 26, '0000137', '', NULL);
INSERT INTO chado.dbxref VALUES (3345, 26, '0000138', '', NULL);
INSERT INTO chado.dbxref VALUES (3346, 26, '0000139', '', NULL);
INSERT INTO chado.dbxref VALUES (3347, 26, '0000140', '', NULL);
INSERT INTO chado.dbxref VALUES (3348, 26, '0000141', '', NULL);
INSERT INTO chado.dbxref VALUES (3349, 26, '0000142', '', NULL);
INSERT INTO chado.dbxref VALUES (3350, 26, '0000143', '', NULL);
INSERT INTO chado.dbxref VALUES (3351, 26, '0000144', '', NULL);
INSERT INTO chado.dbxref VALUES (3352, 26, '0000145', '', NULL);
INSERT INTO chado.dbxref VALUES (3353, 26, '0000146', '', NULL);
INSERT INTO chado.dbxref VALUES (3354, 26, '0000147', '', NULL);
INSERT INTO chado.dbxref VALUES (3355, 26, '0000148', '', NULL);
INSERT INTO chado.dbxref VALUES (3356, 26, '0000149', '', NULL);
INSERT INTO chado.dbxref VALUES (3357, 26, '0000150', '', NULL);
INSERT INTO chado.dbxref VALUES (3358, 26, '0000151', '', NULL);
INSERT INTO chado.dbxref VALUES (3359, 26, '0000152', '', NULL);
INSERT INTO chado.dbxref VALUES (3360, 26, '0000153', '', NULL);
INSERT INTO chado.dbxref VALUES (3361, 26, '0000154', '', NULL);
INSERT INTO chado.dbxref VALUES (3362, 26, '0000155', '', NULL);
INSERT INTO chado.dbxref VALUES (3363, 26, '0000156', '', NULL);
INSERT INTO chado.dbxref VALUES (3364, 26, '0000157', '', NULL);
INSERT INTO chado.dbxref VALUES (3365, 26, '0000158', '', NULL);
INSERT INTO chado.dbxref VALUES (3366, 26, '0000159', '', NULL);
INSERT INTO chado.dbxref VALUES (3367, 26, '0000160', '', NULL);
INSERT INTO chado.dbxref VALUES (3368, 26, '0000161', '', NULL);
INSERT INTO chado.dbxref VALUES (3369, 26, '0000162', '', NULL);
INSERT INTO chado.dbxref VALUES (3370, 26, '0000163', '', NULL);
INSERT INTO chado.dbxref VALUES (3371, 26, '0000164', '', NULL);
INSERT INTO chado.dbxref VALUES (3372, 26, '0000165', '', NULL);
INSERT INTO chado.dbxref VALUES (3373, 26, '0000166', '', NULL);
INSERT INTO chado.dbxref VALUES (3374, 26, '0000167', '', NULL);
INSERT INTO chado.dbxref VALUES (3375, 26, '0000168', '', NULL);
INSERT INTO chado.dbxref VALUES (3376, 26, '0000169', '', NULL);
INSERT INTO chado.dbxref VALUES (3377, 26, '0000170', '', NULL);
INSERT INTO chado.dbxref VALUES (3378, 26, '0000171', '', NULL);
INSERT INTO chado.dbxref VALUES (3379, 26, '0000172', '', NULL);
INSERT INTO chado.dbxref VALUES (3380, 26, '0000173', '', NULL);
INSERT INTO chado.dbxref VALUES (3381, 26, '0000174', '', NULL);
INSERT INTO chado.dbxref VALUES (3382, 26, '0000175', '', NULL);
INSERT INTO chado.dbxref VALUES (3383, 26, '0000176', '', NULL);
INSERT INTO chado.dbxref VALUES (3384, 26, '0000177', '', NULL);
INSERT INTO chado.dbxref VALUES (3385, 26, '0000178', '', NULL);
INSERT INTO chado.dbxref VALUES (3386, 26, '0000179', '', NULL);
INSERT INTO chado.dbxref VALUES (3387, 26, '0000180', '', NULL);
INSERT INTO chado.dbxref VALUES (3388, 26, '0000181', '', NULL);
INSERT INTO chado.dbxref VALUES (3389, 26, '0000182', '', NULL);
INSERT INTO chado.dbxref VALUES (3390, 26, '0000183', '', NULL);
INSERT INTO chado.dbxref VALUES (3391, 26, '0000184', '', NULL);
INSERT INTO chado.dbxref VALUES (3392, 26, '0000185', '', NULL);
INSERT INTO chado.dbxref VALUES (3393, 26, '0000186', '', NULL);
INSERT INTO chado.dbxref VALUES (3394, 26, '0000187', '', NULL);
INSERT INTO chado.dbxref VALUES (3395, 26, '0000188', '', NULL);
INSERT INTO chado.dbxref VALUES (3396, 26, '0000189', '', NULL);
INSERT INTO chado.dbxref VALUES (3397, 26, '0000190', '', NULL);
INSERT INTO chado.dbxref VALUES (3398, 26, '0000191', '', NULL);
INSERT INTO chado.dbxref VALUES (3399, 26, '0000192', '', NULL);
INSERT INTO chado.dbxref VALUES (3400, 26, '0000193', '', NULL);
INSERT INTO chado.dbxref VALUES (3401, 26, '0000194', '', NULL);
INSERT INTO chado.dbxref VALUES (3402, 26, '0000195', '', NULL);
INSERT INTO chado.dbxref VALUES (3403, 26, '0000196', '', NULL);
INSERT INTO chado.dbxref VALUES (3404, 26, '0000197', '', NULL);
INSERT INTO chado.dbxref VALUES (3405, 26, '0000198', '', NULL);
INSERT INTO chado.dbxref VALUES (3406, 26, '0000199', '', NULL);
INSERT INTO chado.dbxref VALUES (3407, 26, '0000200', '', NULL);
INSERT INTO chado.dbxref VALUES (3408, 26, '0000201', '', NULL);
INSERT INTO chado.dbxref VALUES (3409, 26, '0000202', '', NULL);
INSERT INTO chado.dbxref VALUES (3410, 26, '0000203', '', NULL);
INSERT INTO chado.dbxref VALUES (3411, 26, '0000204', '', NULL);
INSERT INTO chado.dbxref VALUES (3412, 26, '0000205', '', NULL);
INSERT INTO chado.dbxref VALUES (3413, 26, '0000206', '', NULL);
INSERT INTO chado.dbxref VALUES (3414, 26, '0000207', '', NULL);
INSERT INTO chado.dbxref VALUES (3415, 26, '0000208', '', NULL);
INSERT INTO chado.dbxref VALUES (3416, 26, '0000209', '', NULL);
INSERT INTO chado.dbxref VALUES (3417, 26, '0000210', '', NULL);
INSERT INTO chado.dbxref VALUES (3418, 26, '0000211', '', NULL);
INSERT INTO chado.dbxref VALUES (3419, 26, '0000212', '', NULL);
INSERT INTO chado.dbxref VALUES (3420, 26, '0000213', '', NULL);
INSERT INTO chado.dbxref VALUES (3421, 26, '0000214', '', NULL);
INSERT INTO chado.dbxref VALUES (3422, 26, '0000215', '', NULL);
INSERT INTO chado.dbxref VALUES (3423, 26, '0000216', '', NULL);
INSERT INTO chado.dbxref VALUES (3424, 26, '0000217', '', NULL);
INSERT INTO chado.dbxref VALUES (3425, 26, '0000218', '', NULL);
INSERT INTO chado.dbxref VALUES (3426, 26, '0000219', '', NULL);
INSERT INTO chado.dbxref VALUES (3427, 26, '0000220', '', NULL);
INSERT INTO chado.dbxref VALUES (3428, 26, '0000221', '', NULL);
INSERT INTO chado.dbxref VALUES (3429, 26, '0000222', '', NULL);
INSERT INTO chado.dbxref VALUES (3430, 26, '0000223', '', NULL);
INSERT INTO chado.dbxref VALUES (3431, 26, '0000224', '', NULL);
INSERT INTO chado.dbxref VALUES (3432, 26, '0000225', '', NULL);
INSERT INTO chado.dbxref VALUES (3433, 26, '0000226', '', NULL);
INSERT INTO chado.dbxref VALUES (3434, 26, '0000227', '', NULL);
INSERT INTO chado.dbxref VALUES (3435, 26, '0000228', '', NULL);
INSERT INTO chado.dbxref VALUES (3436, 26, '0000229', '', NULL);
INSERT INTO chado.dbxref VALUES (3437, 26, '0000230', '', NULL);
INSERT INTO chado.dbxref VALUES (3438, 26, '0000231', '', NULL);
INSERT INTO chado.dbxref VALUES (3439, 26, '0000232', '', NULL);
INSERT INTO chado.dbxref VALUES (3440, 26, '0000233', '', NULL);
INSERT INTO chado.dbxref VALUES (3441, 26, '0000234', '', NULL);
INSERT INTO chado.dbxref VALUES (3442, 26, '0000235', '', NULL);
INSERT INTO chado.dbxref VALUES (3443, 26, '0000236', '', NULL);
INSERT INTO chado.dbxref VALUES (3444, 26, '0000237', '', NULL);
INSERT INTO chado.dbxref VALUES (3445, 26, '0000238', '', NULL);
INSERT INTO chado.dbxref VALUES (3446, 26, '0000239', '', NULL);
INSERT INTO chado.dbxref VALUES (3447, 26, '0000241', '', NULL);
INSERT INTO chado.dbxref VALUES (3448, 26, '0000242', '', NULL);
INSERT INTO chado.dbxref VALUES (3449, 26, '0000244', '', NULL);
INSERT INTO chado.dbxref VALUES (3450, 26, '0000245', '', NULL);
INSERT INTO chado.dbxref VALUES (3451, 26, '0000246', '', NULL);
INSERT INTO chado.dbxref VALUES (3452, 26, '0000247', '', NULL);
INSERT INTO chado.dbxref VALUES (3453, 26, '0000248', '', NULL);
INSERT INTO chado.dbxref VALUES (3454, 26, '0000249', '', NULL);
INSERT INTO chado.dbxref VALUES (3455, 26, '0000250', '', NULL);
INSERT INTO chado.dbxref VALUES (3456, 26, '0000251', '', NULL);
INSERT INTO chado.dbxref VALUES (3457, 26, '0000252', '', NULL);
INSERT INTO chado.dbxref VALUES (3458, 26, '0000253', '', NULL);
INSERT INTO chado.dbxref VALUES (3459, 26, '0000254', '', NULL);
INSERT INTO chado.dbxref VALUES (3460, 26, '0000255', '', NULL);
INSERT INTO chado.cvterm VALUES (1, 1, 'null', NULL, 1, 0, 0);
INSERT INTO chado.cvterm VALUES (2, 4, 'version', 'Chado schema version', 2, 0, 0);
INSERT INTO chado.cvterm VALUES (3, 5, 'accession', '', 3, 0, 0);
INSERT INTO chado.cvterm VALUES (4, 5, 'generated germplasm', '', 4, 0, 0);
INSERT INTO chado.cvterm VALUES (5, 5, 'cultivar', '', 5, 0, 0);
INSERT INTO chado.cvterm VALUES (6, 5, '414 inbred line', '', 6, 0, 0);
INSERT INTO chado.cvterm VALUES (7, 6, 'Service', 'A system that provides one or more functions.', 7, 0, 0);
INSERT INTO chado.cvterm VALUES (8, 7, 'Sequence length', 'The size (length) of a sequence, subsequence or region in a sequence, or range(s) of lengths.', 8, 0, 0);
INSERT INTO chado.cvterm VALUES (9, 7, 'Sequence checksum', 'A fixed-size datum calculated (by using a hash function) for a molecular sequence, typically for purposes of error detection or indexing.', 9, 0, 0);
INSERT INTO chado.cvterm VALUES (10, 7, 'Accession', 'A persistent (stable) and unique identifier, typically identifying an object (entry) from a database.', 10, 0, 0);
INSERT INTO chado.cvterm VALUES (11, 7, 'Sequence', 'One or more molecular sequences, possibly with associated annotation.', 11, 0, 0);
INSERT INTO chado.cvterm VALUES (12, 7, 'Sequence record', 'A molecular sequence and associated metadata.', 12, 0, 0);
INSERT INTO chado.cvterm VALUES (13, 7, 'Identifier', 'A text token, number or something else which identifies an entity, but which may not be persistent (stable) or unique (the same identifier may identify multiple things).', 13, 0, 0);
INSERT INTO chado.cvterm VALUES (14, 7, 'Protein sequence', 'One or more protein sequences, possibly with associated annotation.', 14, 0, 0);
INSERT INTO chado.cvterm VALUES (15, 7, 'Image', 'Biological or biomedical data has been rendered into an image, typically for display on screen.', 15, 0, 0);
INSERT INTO chado.cvterm VALUES (16, 7, 'Map', 'A map of (typically one) DNA sequence annotated with positional or non-positional features.', 16, 0, 0);
INSERT INTO chado.cvterm VALUES (17, 7, 'Genetic map', 'A map showing the relative positions of genetic markers in a nucleic acid sequence, based on estimation of non-physical distance such as recombination frequencies.', 17, 0, 0);
INSERT INTO chado.cvterm VALUES (18, 7, 'Physical map', 'A map of DNA (linear or circular) annotated with physical features or landmarks such as restriction sites, cloned DNA fragments, genes or genetic markers, along with the physical distances between them. Distance in a physical map is measured in base pairs. A physical map might be ordered relative to a reference map (typically a genetic map) in the process of genome sequencing.', 18, 0, 0);
INSERT INTO chado.cvterm VALUES (19, 7, 'Sequence coordinates', 'A position in a map (for example a genetic map), either a single position (point) or a region / interval.', 19, 0, 0);
INSERT INTO chado.cvterm VALUES (20, 7, 'Database name', 'The name of a biological or bioinformatics database.', 20, 0, 0);
INSERT INTO chado.cvterm VALUES (21, 7, 'Database ID', 'An identifier of a biological or bioinformatics database.', 21, 0, 0);
INSERT INTO chado.cvterm VALUES (22, 7, 'URI', 'The name of a biological or bioinformatics database.', 22, 0, 0);
INSERT INTO chado.cvterm VALUES (23, 7, 'Translation phase specification', 'Phase for translation of DNA (0, 1 or 2) relative to a fragment of the coding sequence.', 23, 0, 0);
INSERT INTO chado.cvterm VALUES (24, 7, 'DNA sense specification', 'The strand of a DNA sequence (forward or reverse).', 24, 0, 0);
INSERT INTO chado.cvterm VALUES (25, 7, 'Annotation track', 'Annotation of one particular positional feature on a biomolecular (typically genome) sequence, suitable for import and display in a genome browser. Synonym: Sequence annotation track.', 25, 0, 0);
INSERT INTO chado.cvterm VALUES (26, 7, 'Phylogenetic tree', 'The raw data (not just an image) from which a phylogenetic tree is directly generated or plotted, such as topology, lengths (in time or in expected amounts of variance) and a confidence interval for each length.', 26, 0, 0);
INSERT INTO chado.cvterm VALUES (27, 7, 'Species tree', 'A phylogenetic tree that reflects phylogeny of the taxa from which the characters (used in calculating the tree) were sampled.', 27, 0, 0);
INSERT INTO chado.cvterm VALUES (28, 7, 'Gene tree', 'A phylogenetic tree that is an estimate of the character''s phylogeny.', 28, 0, 0);
INSERT INTO chado.cvterm VALUES (29, 7, 'Phylogenetic tree visualisation', 'A phylogenetic tree that is an estimate of the character''s phylogeny.', 29, 0, 0);
INSERT INTO chado.cvterm VALUES (30, 7, 'Sequence visualisation', 'Visualise, format or render a molecular sequence or sequences such as a sequence alignment, possibly with sequence features or properties shown.', 30, 0, 0);
INSERT INTO chado.cvterm VALUES (31, 7, 'genome assembly', '', 31, 0, 0);
INSERT INTO chado.cvterm VALUES (32, 7, 'Genome annotation ', '', 32, 0, 0);
INSERT INTO chado.cvterm VALUES (33, 7, 'Analysis', 'Apply analytical methods to existing data of a specific type.', 33, 0, 0);
INSERT INTO chado.cvterm VALUES (34, 8, 'instrument', 'An instrument is a device which provides a mechanical or electronic function.', 34, 0, 0);
INSERT INTO chado.cvterm VALUES (36, 8, 'substrate type', 'Controlled terms for descriptors of types of array substrates.', 36, 0, 0);
INSERT INTO chado.cvterm VALUES (37, 8, 'array manufacturer', '', 37, 0, 0);
INSERT INTO chado.cvterm VALUES (35, 8, 'array design', 'An instrument design which describes the design of the array.', 35, 0, 0);
INSERT INTO chado.cvterm VALUES (38, 9, 'database', 'A database is an organized collection of data, today typically in digital form.', 38, 0, 0);
INSERT INTO chado.cvterm VALUES (39, 9, 'data acquisition', 'A technique that samples real world physical conditions and conversion of the resulting samples into digital numeric values that can be manipulated by a computer.', 39, 0, 0);
INSERT INTO chado.cvterm VALUES (40, 10, 'rank order', 'A data item that represents an arrangement according to a rank, i.e., the position of a particular case relative to other cases on a defined scale.', 40, 0, 0);
INSERT INTO chado.cvterm VALUES (41, 11, 'organism', 'A material entity that is an individual living system, such as animal, plant, bacteria or virus, that is capable of replicating or reproducing, growth and maintenance in the right environment. An organism may be unicellular or made up, like humans, of many billions of cells divided into specialized tissues and organs.', 41, 0, 0);
INSERT INTO chado.cvterm VALUES (42, 11, 'assay', 'A planned process with the objective to produce information about the material entity that is the evaluant, by physically examining it or its proxies.', 42, 0, 0);
INSERT INTO chado.cvterm VALUES (43, 12, 'location on map', '', 43, 0, 0);
INSERT INTO chado.cvterm VALUES (44, 13, 'definition', 'The official OBI definition, explaining the meaning of a class or property. Shall be Aristotelian, formalized and normalized. Can be augmented with colloquial definitions.', 44, 0, 0);
INSERT INTO chado.cvterm VALUES (45, 13, 'version number', 'A version number is an information content entity which is a sequence of characters borne by part of each of a class of manufactured products or its packaging and indicates its order within a set of other products having the same name.', 45, 0, 0);
INSERT INTO chado.cvterm VALUES (46, 13, 'algorithm', 'An algorithm is a set of instructions for performing a particular calculation.', 46, 0, 0);
INSERT INTO chado.cvterm VALUES (47, 2, 'property', 'A generic term indicating that represents an attribute, quality or characteristic of something.', 47, 0, 0);
INSERT INTO chado.cvterm VALUES (48, 2, 'time_last_modified', 'The time at which the record was last modified.', 48, 0, 0);
INSERT INTO chado.cvterm VALUES (49, 2, 'time_accessioned', 'The time at which the record was first added.', 49, 0, 0);
INSERT INTO chado.cvterm VALUES (50, 2, 'time_executed', 'The time when the task was executed.', 50, 0, 0);
INSERT INTO chado.cvterm VALUES (51, 2, 'infraspecific_type', 'The connector type (e.g. subspecies, varietas, forma, etc.) for the infraspecific name', 51, 0, 0);
INSERT INTO chado.cvterm VALUES (52, 2, 'abbreviation', 'A shortened name (or abbreviation) for the item.', 52, 0, 0);
INSERT INTO chado.cvterm VALUES (53, 2, 'expression', 'Curated expression data', 53, 0, 0);
INSERT INTO chado.cvterm VALUES (54, 2, 'is_analysis', 'Indicates if this feature was predicted computationally using another feature.', 54, 0, 0);
INSERT INTO chado.cvterm VALUES (55, 2, 'is_obsolete', 'Indicates if this record is obsolete.', 55, 0, 0);
INSERT INTO chado.cvterm VALUES (56, 2, 'is_current', 'Indicates if this record is current.', 56, 0, 0);
INSERT INTO chado.cvterm VALUES (57, 2, 'is_internal', 'Indicates if this record is internal and not normally available outside of a local setting.', 57, 0, 0);
INSERT INTO chado.cvterm VALUES (58, 2, 'Mini-ref', 'A small in-house unique identifier for a publication.', 58, 0, 0);
INSERT INTO chado.cvterm VALUES (59, 2, 'Array Batch Identifier', 'A unique identifier for an array batch.', 59, 0, 0);
INSERT INTO chado.cvterm VALUES (60, 2, 'clause subject', 'The subject of a relationship clause.', 60, 0, 0);
INSERT INTO chado.cvterm VALUES (61, 2, 'clause predicate', 'The object of a relationship clause.', 61, 0, 0);
INSERT INTO chado.cvterm VALUES (62, 2, 'relationship type', 'The relationship type.', 62, 0, 0);
INSERT INTO chado.cvterm VALUES (63, 2, 'fasta_definition', 'The definition line for a FASTA formatted sequence', 63, 0, 0);
INSERT INTO chado.cvterm VALUES (64, 2, 'Reference Feature', 'A genomic or genetic feature on which other features are mapped.', 64, 0, 0);
INSERT INTO chado.cvterm VALUES (65, 2, 'minimal boundary', 'The leftmost, minimal boundary in the linear range represented by the feature location. Sometimes this is called start although this is confusing because it does not necessarily represent the 5-prime coordinate.', 65, 0, 0);
INSERT INTO chado.cvterm VALUES (66, 2, 'maximal boundary', 'The rightmost, maximal boundary in the linear range represented by the featureloc. Sometimes this is called end although this is confusing because it does not necessarily represent the 3-prime coordinate', 66, 0, 0);
INSERT INTO chado.cvterm VALUES (67, 2, 'analysis', 'A process as a method of studying the nature of something or of determining its essential features and their relations. (Random House Kernerman Webster''s College Dictionary, © 2010 K Dictionaries Ltd).', 67, 0, 0);
INSERT INTO chado.cvterm VALUES (68, 2, 'source_data', 'The location where data that is being used come from.', 68, 0, 0);
INSERT INTO chado.cvterm VALUES (69, 2, 'contact', 'An entity (e.g. individual or organization) through whom a person can gain access to information, favors, influential people, and the like.', 69, 0, 0);
INSERT INTO chado.cvterm VALUES (70, 2, 'relationship', 'The way in which two things are connected.', 70, 0, 0);
INSERT INTO chado.cvterm VALUES (71, 2, 'biomaterial', 'A biomaterial represents the MAGE concept of BioSource, BioSample, and LabeledExtract. It is essentially some biological material (tissue, cells, serum) that may have been processed. Processed biomaterials should be traceable back to raw biomaterials via the biomaterialrelationship table.', 71, 0, 0);
INSERT INTO chado.cvterm VALUES (72, 2, 'array_dimensions', 'The dimensions of an array.', 72, 0, 0);
INSERT INTO chado.cvterm VALUES (73, 2, 'element_dimensions', 'The dimensions of an element.', 73, 0, 0);
INSERT INTO chado.cvterm VALUES (74, 2, 'num_of_elements', 'The number of elements.', 74, 0, 0);
INSERT INTO chado.cvterm VALUES (75, 2, 'num_array_columns', 'The number of columns in an array.', 75, 0, 0);
INSERT INTO chado.cvterm VALUES (76, 2, 'num_array_rows', 'The number of rows in an array.', 76, 0, 0);
INSERT INTO chado.cvterm VALUES (77, 2, 'num_grid_columns', 'The number of columns in a grid.', 77, 0, 0);
INSERT INTO chado.cvterm VALUES (78, 2, 'num_grid_rows', 'The number of rows in a grid.', 78, 0, 0);
INSERT INTO chado.cvterm VALUES (79, 2, 'num_sub_columns', 'The number of sub columns.', 79, 0, 0);
INSERT INTO chado.cvterm VALUES (80, 2, 'num_sub_rows', 'The number of sub rows.', 80, 0, 0);
INSERT INTO chado.cvterm VALUES (81, 2, 'Genome Project', 'A project for whole genome analysis that can include assembly and annotation.', 81, 0, 0);
INSERT INTO chado.cvterm VALUES (82, 2, 'rank', 'A taxonmic rank', 82, 0, 0);
INSERT INTO chado.cvterm VALUES (83, 2, 'lineage', '', 83, 0, 0);
INSERT INTO chado.cvterm VALUES (84, 2, 'genetic_code', '', 84, 0, 0);
INSERT INTO chado.cvterm VALUES (85, 2, 'genetic_code_name', '', 85, 0, 0);
INSERT INTO chado.cvterm VALUES (86, 2, 'mitochondrial_genetic_code', '', 86, 0, 0);
INSERT INTO chado.cvterm VALUES (87, 2, 'mitochondrial_genetic_code_name', '', 87, 0, 0);
INSERT INTO chado.cvterm VALUES (88, 2, 'division', '', 88, 0, 0);
INSERT INTO chado.cvterm VALUES (89, 2, 'genbank_common_name', '', 89, 0, 0);
INSERT INTO chado.cvterm VALUES (90, 2, 'synonym', '', 90, 0, 0);
INSERT INTO chado.cvterm VALUES (91, 2, 'other_name', '', 91, 0, 0);
INSERT INTO chado.cvterm VALUES (92, 2, 'equivalent_name', '', 92, 0, 0);
INSERT INTO chado.cvterm VALUES (93, 2, 'anamorph', '', 93, 0, 0);
INSERT INTO chado.cvterm VALUES (94, 2, 'Analysis Type', 'The type of analysis that was performed.', 94, 0, 0);
INSERT INTO chado.cvterm VALUES (95, 2, 'phylo_leaf', 'A leaf node in a phylogenetic tree.', 95, 0, 0);
INSERT INTO chado.cvterm VALUES (96, 2, 'phylo_root', 'The root node of a phylogenetic tree.', 96, 0, 0);
INSERT INTO chado.cvterm VALUES (97, 2, 'phylo_interior', 'An interior node in a phylogenetic tree.', 97, 0, 0);
INSERT INTO chado.cvterm VALUES (98, 2, 'taxonomy', 'Deprecated: A term used to indicate if a phylotree is a taxonomic tree', 98, 0, 0);
INSERT INTO chado.cvterm VALUES (99, 2, 'cM', 'Centimorgan units', 99, 0, 0);
INSERT INTO chado.cvterm VALUES (100, 2, 'bp', 'Base pairs units', 100, 0, 0);
INSERT INTO chado.cvterm VALUES (101, 2, 'bin_unit', 'The bin unit', 101, 0, 0);
INSERT INTO chado.cvterm VALUES (102, 2, 'marker_order', 'Units simply to define marker order.', 102, 0, 0);
INSERT INTO chado.cvterm VALUES (103, 2, 'undefined', 'A catch-all for an undefined unit type', 103, 0, 0);
INSERT INTO chado.cvterm VALUES (104, 2, 'start', 'The start coordinate for a map feature.', 104, 0, 0);
INSERT INTO chado.cvterm VALUES (105, 2, 'stop', 'The end coordinate for a map feature', 105, 0, 0);
INSERT INTO chado.cvterm VALUES (106, 2, 'Map Dbxref', 'A unique identifer for the map in a remote database.  The format is a database abbreviation and a unique accession separated by a colon.  (e.g. Gramene:tsh1996a)', 106, 0, 0);
INSERT INTO chado.cvterm VALUES (107, 2, 'Map Type', 'The type of Map (e.g. QTL, Physical, etc.)', 107, 0, 0);
INSERT INTO chado.cvterm VALUES (108, 2, 'Genome Group', '', 108, 0, 0);
INSERT INTO chado.cvterm VALUES (109, 2, 'URL', 'A univeral resource locator (URL) reference where the publication can be found.  For maps found online, this would be the web address for the map.', 109, 0, 0);
INSERT INTO chado.cvterm VALUES (110, 2, 'Population Type', 'A brief description of the population type used to generate the map (e.g. RIL, F2, BC1, etc).', 110, 0, 0);
INSERT INTO chado.cvterm VALUES (111, 2, 'Population Size', 'The size of the population used to construct the map.', 111, 0, 0);
INSERT INTO chado.cvterm VALUES (112, 2, 'Methods', 'A brief description of the methods used to construct the map.', 112, 0, 0);
INSERT INTO chado.cvterm VALUES (113, 2, 'Software', 'The software used to construct the map.', 113, 0, 0);
INSERT INTO chado.cvterm VALUES (114, 2, 'Library', 'A group of physical entities organized into a collection', 114, 0, 0);
INSERT INTO chado.cvterm VALUES (115, 2, 'Library Description', 'Description of a library', 115, 0, 0);
INSERT INTO chado.cvterm VALUES (116, 2, 'cdna_library', 'cDNA library', 116, 0, 0);
INSERT INTO chado.cvterm VALUES (117, 2, 'bac_library', 'Bacterial Artifical Chromsome (BAC) library', 117, 0, 0);
INSERT INTO chado.cvterm VALUES (118, 2, 'fosmid_library', 'Fosmid library', 118, 0, 0);
INSERT INTO chado.cvterm VALUES (119, 2, 'cosmid_library', 'Cosmid library', 119, 0, 0);
INSERT INTO chado.cvterm VALUES (120, 2, 'yac_library', 'Yeast Artificial Chromosome (YAC) library', 120, 0, 0);
INSERT INTO chado.cvterm VALUES (121, 2, 'genomic_library', 'Genomic Library', 121, 0, 0);
INSERT INTO chado.cvterm VALUES (122, 2, 'Project Description', 'Description of a project', 122, 0, 0);
INSERT INTO chado.cvterm VALUES (123, 2, 'Project Type', 'A type of project', 123, 0, 0);
INSERT INTO chado.cvterm VALUES (124, 2, 'Study Type', 'A type of study', 124, 0, 0);
INSERT INTO chado.cvterm VALUES (125, 2, 'analysis_date', 'The date that an analysis was performed.', 125, 0, 0);
INSERT INTO chado.cvterm VALUES (126, 2, 'analysis_short_name', 'A computer legible (no spaces or special characters) abbreviation for the analysis.', 126, 0, 0);
INSERT INTO chado.cvterm VALUES (127, 2, 'Genotyping', 'An experiment where genotypes of individuals are identified.', 127, 0, 0);
INSERT INTO chado.cvterm VALUES (128, 2, 'Phenotyping', 'An experiment where phenotypes of individuals are identified.', 128, 0, 0);
INSERT INTO chado.cvterm VALUES (129, 2, 'Location', 'The name of the location.', 129, 0, 0);
INSERT INTO chado.cvterm VALUES (130, 14, 'phenotype', 'A biochemical network can generate phenotypes or affects biological processes. Such processes can take place at different levels and are independent of the biochemical network itself.', 130, 0, 0);
INSERT INTO chado.cvterm VALUES (131, 14, 'database cross reference', 'An annotation which directs one to information contained within a database.', 131, 0, 0);
INSERT INTO chado.cvterm VALUES (132, 14, 'relationship', 'Connectedness between entities and/or interactions representing their relatedness or influence.', 132, 0, 0);
INSERT INTO chado.cvterm VALUES (133, 15, 'software', 'Computer software, or generally just software, is any set of machine-readable instructions (most often in the form of a computer program) that conform to a given syntax (sometimes referred to as a language) that is interpretable by a given processor and that directs a computer''s processor to perform specific operations.', 133, 0, 0);
INSERT INTO chado.cvterm VALUES (134, 17, 'unit', 'A unit of measurement is a standardized quantity of a physical quality.', 134, 0, 0);
INSERT INTO chado.cvterm VALUES (135, 18, 'Date', 'The particular day, month and year an event has happened or will happen.', 135, 0, 0);
INSERT INTO chado.cvterm VALUES (136, 18, 'Operator', 'A person that operates some apparatus or machine', 136, 0, 0);
INSERT INTO chado.cvterm VALUES (137, 18, 'Technology Platform', 'The specific version (manufacturer, model, etc.) of a technology that is used to carry out a laboratory or computational experiment.', 137, 0, 0);
INSERT INTO chado.cvterm VALUES (138, 18, 'Value', 'A numerical quantity measured or assigned or computed.', 138, 0, 0);
INSERT INTO chado.cvterm VALUES (139, 18, 'Channel', 'An independent acquisition scheme, i.e., a route or conduit through which flows data consisting of one particular measurement using one particular parameter.', 139, 0, 0);
INSERT INTO chado.cvterm VALUES (140, 18, 'Controlled Vocabulary', 'A set of terms that are selected and defined based on the requirements set out by the user group, usually a set of vocabulary is chosen to promote consistency across data collection projects. [ NCI ]', 140, 0, 0);
INSERT INTO chado.cvterm VALUES (141, 18, 'Term', 'A word or expression used for some particular thing. [ NCI ]', 141, 0, 0);
INSERT INTO chado.cvterm VALUES (142, 18, 'Expression', 'A combination of symbols that represents a value. [ NCI ]', 142, 0, 0);
INSERT INTO chado.cvterm VALUES (143, 18, 'Phenotype', 'The assemblage of traits or outward appearance of an individual. It is the product of interactions between genes and between genes and the environment. [ NCI ]', 143, 0, 0);
INSERT INTO chado.cvterm VALUES (144, 18, 'Genotype', 'The genetic constitution of an organism or cell, as distinct from its expressed features or phenotype. [ NCI ]', 144, 0, 0);
INSERT INTO chado.cvterm VALUES (145, 18, 'Location', 'A position, site, or point in space where something can be found. [ NCI ]', 145, 0, 0);
INSERT INTO chado.cvterm VALUES (146, 18, 'Reagent', 'Any natural or synthetic substance used in a chemical or biological reaction in order to produce, identify, or measure another substance. [ NCI ]', 146, 0, 0);
INSERT INTO chado.cvterm VALUES (147, 18, 'Environment', 'The totality of surrounding conditions. [ NCI ]', 147, 0, 0);
INSERT INTO chado.cvterm VALUES (148, 18, 'Tree Node', 'A term that refers to any individual item or entity in a hierarchy or pedigree. [ NCI ]', 148, 0, 0);
INSERT INTO chado.cvterm VALUES (149, 18, 'Study Design', 'A plan detailing how a study will be performed in order to represent the phenomenon under examination, to answer the research questions that have been asked, and defining the methods of data analysis. Study design is driven by research hypothesis being posed, study subject/population/sample available, logistics/resources: technology, support, networking, collaborative support, etc. [ NCI ]', 149, 0, 0);
INSERT INTO chado.cvterm VALUES (150, 18, 'Company', 'Any formal business entity for profit, which may be a corporation, a partnership, association or individual proprietorship.', 150, 0, 0);
INSERT INTO chado.cvterm VALUES (151, 18, 'Project', 'Any specifically defined piece of work that is undertaken or attempted to meet a single requirement.', 151, 0, 0);
INSERT INTO chado.cvterm VALUES (152, 18, 'DNA Library', 'A collection of DNA molecules that have been cloned in vectors.', 152, 0, 0);
INSERT INTO chado.cvterm VALUES (153, 18, 'Trait', 'Any genetically determined characteristic.', 153, 0, 0);
INSERT INTO chado.cvterm VALUES (154, 18, 'Subgroup', 'A subdivision of a larger group with members often exhibiting similar characteristics. [ NCI ]', 154, 0, 0);
INSERT INTO chado.cvterm VALUES (155, 18, 'Namespace', 'In general, a namespace is an abstract container, which is or could be filled by names, or technical terms, or words, and these represent or stand for real-world things. A description logic terminology namespace is a collection of Kind, Role, Property and Concept definitions. As in computer programming, context namespaces are intended to allow multiple knowledge bases to reside in the same physical database. (from Apelon) [ NCI ]', 155, 0, 0);
INSERT INTO chado.cvterm VALUES (156, 18, 'Biospecimen', 'Any material sample taken from a biological entity for testing, diagnostic, propagation, treatment or research purposes, including a sample obtained from a living organism or taken from the biological object after halting of all its life functions.', 156, 0, 0);
INSERT INTO chado.cvterm VALUES (157, 18, 'Communication Contact', 'A channel for communication between groups.', 157, 0, 0);
INSERT INTO chado.cvterm VALUES (158, 19, 'common name', '', 158, 0, 0);
INSERT INTO chado.cvterm VALUES (159, 20, 'comment', 'A human-readable description of a resource.', 159, 0, 0);
INSERT INTO chado.cvterm VALUES (160, 20, 'type', 'The type of resource.', 160, 0, 0);
INSERT INTO chado.cvterm VALUES (161, 20, 'label', 'A human-readable version of a resource''s name.', 161, 0, 0);
INSERT INTO chado.cvterm VALUES (176, 26, 'Collection', 'A collection holding references to a number of related resources.', 176, 0, 0);
INSERT INTO chado.cvterm VALUES (177, 26, 'member', 'A member of the collection', 177, 0, 0);
INSERT INTO chado.cvterm VALUES (178, 26, 'description', 'A description.', 178, 0, 0);
INSERT INTO chado.cvterm VALUES (179, 26, 'totalItems', 'The total number of items referenced by a collection.', 179, 0, 0);
INSERT INTO chado.cvterm VALUES (180, 26, 'title', 'A title, often used along with a description.', 180, 0, 0);
INSERT INTO chado.cvterm VALUES (181, 26, 'PartialCollectionView', 'A PartialCollectionView describes a partial view of a Collection. Multiple PartialCollectionViews can be connected with the the next/previous properties to allow a client to retrieve all members of the collection.', 181, 0, 0);
INSERT INTO chado.cvterm VALUES (182, 27, 'name', 'The name of the item.', 182, 0, 0);
INSERT INTO chado.cvterm VALUES (183, 27, 'alternateName', 'An alias for the item.', 183, 0, 0);
INSERT INTO chado.cvterm VALUES (184, 27, 'comment', 'Comments, typically from users.', 184, 0, 0);
INSERT INTO chado.cvterm VALUES (185, 27, 'description', 'A description of the item.', 185, 0, 0);
INSERT INTO chado.cvterm VALUES (186, 27, 'publication', 'A publication event associated with the item.', 186, 0, 0);
INSERT INTO chado.cvterm VALUES (187, 27, 'url', 'URL of the item.', 187, 0, 0);
INSERT INTO chado.cvterm VALUES (188, 27, 'additionalType', 'An additional type for the item, typically used for adding more specific types from external vocabularies in microdata syntax. This is a relationship between something and a class that the thing is in.', 188, 0, 0);
INSERT INTO chado.cvterm VALUES (189, 27, 'ItemPage', 'A page devoted to a single item, such as a particular product or hotel.', 189, 0, 0);
INSERT INTO chado.cvterm VALUES (190, 28, 'biological sample', 'A biological sample analysed by a particular technology.', 190, 0, 0);
INSERT INTO chado.cvterm VALUES (191, 28, 'protocol', 'A protocol is a process which is a parameterizable description of a process.', 191, 0, 0);
INSERT INTO chado.cvterm VALUES (192, 29, 'namespace', 'A namespace is an informational entity that defines a logical container for a set of symbols or identifiers.', 192, 0, 0);
INSERT INTO chado.cvterm VALUES (193, 29, 'clause', 'A clause consists of a subject and a predicate.', 193, 0, 0);
INSERT INTO chado.cvterm VALUES (194, 29, 'references', 'references is a relation between one entity and the entity that it makes reference to by name, but is not described by it.', 194, 0, 0);
INSERT INTO chado.cvterm VALUES (195, 29, 'position', 'A measurement of a spatial location relative to a frame of reference or other objects.', 195, 0, 0);
INSERT INTO chado.cvterm VALUES (196, 29, 'annotation', 'An annotation is a written explanatory or critical description, or other in-context information (e.g., pattern, motif, link), that has been associated with data or other types of information.', 196, 0, 0);
INSERT INTO chado.cvterm VALUES (197, 29, 'negation', 'NOT is a logical operator in that has the value true if its operand is false.', 197, 0, 0);
INSERT INTO chado.cvterm VALUES (198, 29, 'record identifier', 'A record identifier is an identifier for a database entry.', 198, 0, 0);
INSERT INTO chado.cvterm VALUES (199, 29, 'vocabulary', 'A vocabulary is a collection of terms.', 199, 0, 0);
INSERT INTO chado.cvterm VALUES (200, 29, 'email address', 'an email address is an identifier to send mail to particular electronic mailbox.', 200, 0, 0);
INSERT INTO chado.cvterm VALUES (201, 29, 'assay', 'An assay is an investigative (analytic) procedure in laboratory medicine, pharmacology, environmental biology, and molecular biology for qualitatively assessing or quantitatively measuring the presence or amount or the functional activity of a target entity (the analyte) which can be a drug or biochemical substance or a cell in an organism or organic sample.', 201, 0, 0);
INSERT INTO chado.cvterm VALUES (202, 29, 'cell line', 'A cell line is a collection of genetically identifical cells.', 202, 0, 0);
INSERT INTO chado.cvterm VALUES (203, 29, 'study', 'A study is a process that realizes the steps of a study design.', 203, 0, 0);
INSERT INTO chado.cvterm VALUES (208, 22, 'adjacent_to', 'A geometric operator, specified in Egenhofer 1989. Two features meet if they share a junction on the sequence. X adjacent_to Y iff X and Y share a boundary but do not overlap. [PMID:20226267, SO:ke]', 208, 0, 1);
INSERT INTO chado.cvterm VALUES (209, 22, 'associated_with', '', 209, 0, 1);
INSERT INTO chado.cvterm VALUES (210, 22, 'complete_evidence_for_feature', 'B is complete_evidence_for_feature A if the extent (5'' and 3'' boundaries) and internal boundaries of B fully support the extent and internal boundaries of A. [SO:ke]', 210, 0, 1);
INSERT INTO chado.cvterm VALUES (211, 22, 'is_a', '', 211, 0, 1);
INSERT INTO chado.cvterm VALUES (212, 22, 'evidence_for_feature', 'B is evidence_for_feature A, if an instance of B supports the existence of A. [SO:ke]', 212, 0, 1);
INSERT INTO chado.cvterm VALUES (163, 22, 'gene', 'A region (or regions) that includes all of the sequence elements necessary to encode a functional transcript. A gene may include regulatory regions, transcribed regions and/or other functional sequence regions. [SO:immuno_workshop]', 163, 0, 0);
INSERT INTO chado.cvterm VALUES (166, 22, 'sequence_variant', 'A sequence_variant is a non exact copy of a sequence_feature or genome exhibiting one or more sequence_alteration. [SO:ke]', 166, 0, 0);
INSERT INTO chado.cvterm VALUES (168, 22, 'heritable_phenotypic_marker', 'A biological_region characterized as a single heritable trait in a phenotype screen. The heritable phenotype may be mapped to a chromosome but generally has not been characterized to a specific gene locus. [JAX:hdene]', 168, 0, 0);
INSERT INTO chado.cvterm VALUES (167, 22, 'genetic_marker', 'A measurable sequence feature that varies within a population. [SO:db]', 167, 0, 0);
INSERT INTO chado.cvterm VALUES (206, 31, 'narrow', '', 206, 0, 0);
INSERT INTO chado.cvterm VALUES (207, 31, 'related', '', 207, 0, 0);
INSERT INTO chado.cvterm VALUES (172, 25, 'Publication', '', 172, 0, 0);
INSERT INTO chado.cvterm VALUES (204, 31, 'exact', '', 204, 0, 0);
INSERT INTO chado.cvterm VALUES (169, 23, 'genus', '', 169, 0, 0);
INSERT INTO chado.cvterm VALUES (170, 23, 'species', '', 170, 0, 0);
INSERT INTO chado.cvterm VALUES (171, 23, 'infraspecies', '', 171, 0, 0);
INSERT INTO chado.cvterm VALUES (205, 31, 'broad', '', 205, 0, 0);
INSERT INTO chado.cvterm VALUES (173, 25, 'Citation', 'Biblographic reference for the publication.', 173, 0, 0);
INSERT INTO chado.cvterm VALUES (174, 25, 'Publication Type', '', 174, 0, 0);
INSERT INTO chado.cvterm VALUES (175, 25, 'Volume Title', '', 175, 0, 0);
INSERT INTO chado.cvterm VALUES (213, 22, 'connects_on', 'X connects_on Y, Z, R iff whenever Z is on a R, X is adjacent to a Y and adjacent to a Z. [PMID:20226267]', 213, 0, 1);
INSERT INTO chado.cvterm VALUES (214, 22, 'contained_by', 'X contained_by Y iff X starts after start of Y and X ends before end of Y. [PMID:20226267]', 214, 0, 1);
INSERT INTO chado.cvterm VALUES (215, 22, 'contains', 'The inverse of contained_by. [PMID:20226267]', 215, 0, 1);
INSERT INTO chado.cvterm VALUES (216, 22, 'derives_from', '', 216, 0, 1);
INSERT INTO chado.cvterm VALUES (217, 22, 'disconnected_from', 'X is disconnected_from Y iff it is not the case that X overlaps Y. [PMID:20226267]', 217, 0, 1);
INSERT INTO chado.cvterm VALUES (218, 22, 'edited_from', '', 218, 0, 1);
INSERT INTO chado.cvterm VALUES (219, 22, 'edited_to', '', 219, 0, 1);
INSERT INTO chado.cvterm VALUES (220, 22, 'exemplar_of', 'X is exemplar of Y if X is the best evidence for Y. [SO:ke]', 220, 0, 1);
INSERT INTO chado.cvterm VALUES (221, 22, 'finished_by', 'Xy is finished_by Y if Y part of X, and X and Y share a 3'' boundary. [PMID:20226267]', 221, 0, 1);
INSERT INTO chado.cvterm VALUES (222, 22, 'finishes', 'X finishes Y if X is part_of Y and X and Y share a 3'' or C terminal boundary. [PMID:20226267]', 222, 0, 1);
INSERT INTO chado.cvterm VALUES (223, 22, 'gained', 'X gained Y if X is a variant_of X'' and Y part of X but not X''. [SO:ke]', 223, 0, 1);
INSERT INTO chado.cvterm VALUES (224, 22, 'genome_of', '', 224, 0, 1);
INSERT INTO chado.cvterm VALUES (225, 22, 'guided_by', '', 225, 0, 1);
INSERT INTO chado.cvterm VALUES (226, 22, 'guides', '', 226, 0, 1);
INSERT INTO chado.cvterm VALUES (227, 22, 'has_integral_part', 'X has_integral_part Y if and only if: X has_part Y and Y part_of X. [http://precedings.nature.com/documents/3495/version/1]', 227, 0, 1);
INSERT INTO chado.cvterm VALUES (228, 22, 'has_part', 'Inverse of part_of. [http://precedings.nature.com/documents/3495/version/1]', 228, 0, 1);
INSERT INTO chado.cvterm VALUES (229, 22, 'has_origin', '', 229, 0, 1);
INSERT INTO chado.cvterm VALUES (230, 22, 'has_quality', '', 230, 0, 1);
INSERT INTO chado.cvterm VALUES (231, 22, 'homologous_to', '', 231, 0, 1);
INSERT INTO chado.cvterm VALUES (232, 22, 'similar_to', '', 232, 0, 1);
INSERT INTO chado.cvterm VALUES (233, 22, 'integral_part_of', 'X integral_part_of Y if and only if: X part_of Y and Y has_part X. [http://precedings.nature.com/documents/3495/version/1]', 233, 0, 1);
INSERT INTO chado.cvterm VALUES (234, 22, 'part_of', 'X part_of Y if X is a subregion of Y. [http://precedings.nature.com/documents/3495/version/1]', 234, 0, 1);
INSERT INTO chado.cvterm VALUES (235, 22, 'is_consecutive_sequence_of', 'R is_consecutive_sequence_of R iff every instance of R is equivalent to a collection of instances of U:u1, u2, un, such that no pair of ux uy is overlapping and for all ux, it is adjacent to ux-1 and ux+1, with the exception of the initial and terminal u1,and un (which may be identical). [PMID:20226267]', 235, 0, 1);
INSERT INTO chado.cvterm VALUES (236, 22, 'lost', 'X lost Y if X is a variant_of X'' and Y part of X'' but not X. [SO:ke]', 236, 0, 1);
INSERT INTO chado.cvterm VALUES (237, 22, 'maximally_overlaps', 'A maximally_overlaps X iff all parts of A (including A itself) overlap both A and Y. [PMID:20226267]', 237, 0, 1);
INSERT INTO chado.cvterm VALUES (238, 22, 'member_of', '', 238, 0, 1);
INSERT INTO chado.cvterm VALUES (239, 22, 'non_functional_homolog_of', 'A relationship between a pseudogenic feature and its functional ancestor. [SO:ke]', 239, 0, 1);
INSERT INTO chado.cvterm VALUES (240, 22, 'orthologous_to', '', 240, 0, 1);
INSERT INTO chado.cvterm VALUES (241, 22, 'overlaps', 'X overlaps Y iff there exists some Z such that Z contained_by X and Z contained_by Y. [PMID:20226267]', 241, 0, 1);
INSERT INTO chado.cvterm VALUES (242, 22, 'paralogous_to', '', 242, 0, 1);
INSERT INTO chado.cvterm VALUES (243, 22, 'partial_evidence_for_feature', 'B is partial_evidence_for_feature A if the extent of B supports part_of but not all of A. [SO:ke]', 243, 0, 1);
INSERT INTO chado.cvterm VALUES (244, 22, 'position_of', '', 244, 0, 1);
INSERT INTO chado.cvterm VALUES (245, 22, 'processed_from', 'Inverse of processed_into. [http://precedings.nature.com/documents/3495/version/1]', 245, 0, 1);
INSERT INTO chado.cvterm VALUES (246, 22, 'processed_into', 'X is processed_into Y if a region X is modified to create Y. [http://precedings.nature.com/documents/3495/version/1]', 246, 0, 1);
INSERT INTO chado.cvterm VALUES (247, 22, 'recombined_from', '', 247, 0, 1);
INSERT INTO chado.cvterm VALUES (248, 22, 'recombined_to', '', 248, 0, 1);
INSERT INTO chado.cvterm VALUES (249, 22, 'sequence_of', '', 249, 0, 1);
INSERT INTO chado.cvterm VALUES (250, 22, 'started_by', 'X is strted_by Y if Y is part_of X and X and Y share a 5'' boundary. [PMID:20226267]', 250, 0, 1);
INSERT INTO chado.cvterm VALUES (251, 22, 'starts', 'X starts Y if X is part of Y, and A and Y share a 5'' or N-terminal boundary. [PMID:20226267]', 251, 0, 1);
INSERT INTO chado.cvterm VALUES (252, 22, 'trans_spliced_from', '', 252, 0, 1);
INSERT INTO chado.cvterm VALUES (253, 22, 'trans_spliced_to', '', 253, 0, 1);
INSERT INTO chado.cvterm VALUES (254, 22, 'transcribed_from', 'X is transcribed_from Y if X is synthesized from template Y. [http://precedings.nature.com/documents/3495/version/1]', 254, 0, 1);
INSERT INTO chado.cvterm VALUES (255, 22, 'transcribed_to', 'Inverse of transcribed_from. [http://precedings.nature.com/documents/3495/version/1]', 255, 0, 1);
INSERT INTO chado.cvterm VALUES (256, 22, 'translates_to', 'Inverse of translation _of. [http://precedings.nature.com/documents/3495/version/1]', 256, 0, 1);
INSERT INTO chado.cvterm VALUES (257, 22, 'translation_of', 'X is translation of Y if Y is translated by ribosome to create X. [http://precedings.nature.com/documents/3495/version/1]', 257, 0, 1);
INSERT INTO chado.cvterm VALUES (258, 22, 'variant_of', 'A'' is a variant (mutation) of A = definition every instance of A'' is either an immediate mutation of some instance of A, or there is a chain of immediate mutation processes linking A'' to some instance of A. [SO:immuno_workshop]', 258, 0, 1);
INSERT INTO chado.cvterm VALUES (259, 22, 'Sequence_Ontology', '', 259, 1, 0);
INSERT INTO chado.cvterm VALUES (260, 22, 'region', 'A sequence_feature with an extent greater than zero. A nucleotide region is composed of bases and a polypeptide region is composed of amino acids. [SO:ke]', 260, 0, 0);
INSERT INTO chado.cvterm VALUES (162, 22, 'sequence_feature', 'Any extent of continuous biological sequence. [LAMHDI:mb, SO:ke]', 162, 0, 0);
INSERT INTO chado.cvterm VALUES (261, 22, 'sequence_secondary_structure', 'A folded sequence. [SO:ke]', 261, 0, 0);
INSERT INTO chado.cvterm VALUES (262, 22, 'biological_region', 'A region defined by its disposition to be involved in a biological process. [SO:cb]', 262, 0, 0);
INSERT INTO chado.cvterm VALUES (263, 22, 'G_quartet', 'G-quartets are unusual nucleic acid structures consisting of a planar arrangement where each guanine is hydrogen bonded by hoogsteen pairing to another guanine in the quartet. [http://www.ncbi.nlm.nih.gov/pubmed/7919797?dopt=Abstract]', 263, 0, 0);
INSERT INTO chado.cvterm VALUES (264, 22, 'interior_coding_exon', 'A coding exon that is not the most 3-prime or the most 5-prime in a given transcript. []', 264, 0, 0);
INSERT INTO chado.cvterm VALUES (265, 22, 'coding_exon', 'An exon whereby at least one base is part of a codon (here, ''codon'' is inclusive of the stop_codon). [SO:ke]', 265, 0, 0);
INSERT INTO chado.cvterm VALUES (266, 22, 'satellite_DNA', 'The many tandem repeats (identical or related) of a short basic repeating unit; many have a base composition or other property different from the genome average that allows them to be separated from the bulk (main band) genomic DNA. [http://www.insdc.org/files/feature_table.html]', 266, 0, 0);
INSERT INTO chado.cvterm VALUES (267, 22, 'tandem_repeat', 'Two or more adjacent copies of a region (of length greater than 1). [SO:ke]', 267, 0, 0);
INSERT INTO chado.cvterm VALUES (268, 22, 'PCR_product', 'A region amplified by a PCR reaction. [SO:ke]', 268, 0, 0);
INSERT INTO chado.cvterm VALUES (269, 22, 'reagent', 'A sequence used in experiment. [SO:ke]', 269, 0, 0);
INSERT INTO chado.cvterm VALUES (270, 22, 'read_pair', 'One of a pair of sequencing reads in which the two members of the pair are related by originating at either end of a clone insert. [SO:ls]', 270, 0, 0);
INSERT INTO chado.cvterm VALUES (271, 22, 'read', 'A sequence obtained from a single sequencing experiment. Typically a read is produced when a base calling program interprets information from a chromatogram trace file produced from a sequencing machine. [SO:rd]', 271, 0, 0);
INSERT INTO chado.cvterm VALUES (272, 22, 'contig', 'A contiguous sequence derived from sequence assembly. Has no gaps, but may contain N''s from unavailable bases. [SO:ls]', 272, 0, 0);
INSERT INTO chado.cvterm VALUES (273, 22, 'paired_end_fragment', 'An assembly region that has been sequenced from both ends resulting in a read_pair (mate_pair). [SO:ke]', 273, 0, 0);
INSERT INTO chado.cvterm VALUES (274, 22, 'gene_sensu_your_favorite_organism', '', 274, 1, 0);
INSERT INTO chado.cvterm VALUES (275, 22, 'gene_class', '', 275, 1, 0);
INSERT INTO chado.cvterm VALUES (276, 22, 'protein_coding', 'A gene which, when transcribed, can be translated into a protein. []', 276, 0, 0);
INSERT INTO chado.cvterm VALUES (277, 22, 'gene_attribute', 'An attribute describing a gene. []', 277, 0, 0);
INSERT INTO chado.cvterm VALUES (278, 22, 'non_protein_coding', 'A gene which can be transcribed, but will not be translated into a protein. []', 278, 0, 0);
INSERT INTO chado.cvterm VALUES (279, 22, 'scRNA_primary_transcript', 'The primary transcript of any one of several small cytoplasmic RNA molecules present in the cytoplasm and sometimes nucleus of a Eukaryote. [http://www.ebi.ac.uk/embl/WebFeat/align/scRNA_s.html]', 279, 0, 0);
INSERT INTO chado.cvterm VALUES (280, 22, 'nc_primary_transcript', 'A primary transcript that is never translated into a protein. [SO:ke]', 280, 0, 0);
INSERT INTO chado.cvterm VALUES (281, 22, 'scRNA', 'A small non coding RNA sequence, present in the cytoplasm. [SO:ke]', 281, 0, 0);
INSERT INTO chado.cvterm VALUES (282, 22, 'ncRNA', 'An RNA transcript that does not encode for a protein rather the RNA molecule is the gene product. [SO:ke]', 282, 0, 0);
INSERT INTO chado.cvterm VALUES (283, 22, 'INR_motif', 'A sequence element characteristic of some RNA polymerase II promoters required for the correct positioning of the polymerase for the start of transcription. Overlaps the TSS. The mammalian consensus sequence is YYAN(T|A)YY; the Drosophila consensus sequence is TCA(G|T)t(T|C). In each the A is at position +1 with respect to the TSS. Functionally similar to the TATA box element. [PMID:12651739, PMID:16858867]', 283, 0, 0);
INSERT INTO chado.cvterm VALUES (284, 22, 'core_eukaryotic_promoter_element', 'An element that only exists within the promoter region of a eukaryotic gene. [GREEKC:cl]', 284, 0, 0);
INSERT INTO chado.cvterm VALUES (285, 22, 'RNApol_II_core_promoter', 'The minimal portion of the promoter required to properly initiate transcription in RNA polymerase II transcribed genes. [PMID:16858867]', 285, 0, 0);
INSERT INTO chado.cvterm VALUES (286, 22, 'DPE_motif', 'A sequence element characteristic of some RNA polymerase II promoters; Positioned from +28 to +32 with respect to the TSS (+1). Experimental results suggest that the DPE acts in conjunction with the INR_motif to provide a binding site for TFIID in the absence of a TATA box to mediate transcription of TATA-less promoters. Consensus sequence (A|G)G(A|T)(C|T)(G|A|C). [PMID:12515390, PMID:12537576, PMID:12651739, PMID:16858867]', 286, 0, 0);
INSERT INTO chado.cvterm VALUES (287, 22, 'BREu_motif', 'A sequence element characteristic of some RNA polymerase II promoters, located immediately upstream of some TATA box elements at -37 to -32 with respect to the TSS (+1). Consensus sequence is (G|C)(G|C)(G|A)CGCC. Binds TFIIB. [PMID:12651739, PMID:16858867]', 287, 0, 0);
INSERT INTO chado.cvterm VALUES (288, 22, 'PSE_motif', 'A sequence element characteristic of the promoters of snRNA genes transcribed by RNA polymerase II or by RNA polymerase III. Located between -45 and -60 relative to the TSS. The human PSE_motif consensus sequence is TCACCNTNA(C|G)TNAAAAG(T|G). The basal transcription factor, snRNA-activating protein complex (SNAPc), binds the PSE_motif and is required for the transcription of both RNA polymerase II and III transcribed small-nuclear RNA genes. [PMID:11390411, PMID:12621023, PMID:12651739, PMID:23166507, PMID:8339931]', 288, 0, 0);
INSERT INTO chado.cvterm VALUES (289, 22, 'DNA_motif', 'A motif that is active in the DNA form of the sequence. [SO:ke]', 289, 0, 0);
INSERT INTO chado.cvterm VALUES (290, 22, 'promoter', 'A regulatory_region composed of the TSS(s) and binding sites for TF_complexes of the core transcription machinery. A region (DNA) to which RNA polymerase binds, to begin transcription. [SO:regcreative]', 290, 0, 0);
INSERT INTO chado.cvterm VALUES (291, 22, 'linkage_group', 'A group of loci that can be grouped in a linear order representing the different degrees of linkage among the genes concerned. [ISBN:038752046]', 291, 0, 0);
INSERT INTO chado.cvterm VALUES (292, 22, 'RNA_internal_loop', 'A region of double stranded RNA where the bases do not conform to WC base pairing. The loop is closed on both sides by canonical base pairing. If the interruption to base pairing occurs on one strand only, it is known as a bulge. [SO:ke]', 292, 0, 0);
INSERT INTO chado.cvterm VALUES (293, 22, 'RNA_motif', 'A motif that is active in RNA sequence. [SO:ke]', 293, 0, 0);
INSERT INTO chado.cvterm VALUES (294, 22, 'asymmetric_RNA_internal_loop', 'An internal RNA loop where one of the strands includes more bases than the corresponding region on the other strand. [SO:ke]', 294, 0, 0);
INSERT INTO chado.cvterm VALUES (295, 22, 'A_minor_RNA_motif', 'A region forming a motif, composed of adenines, where the minor groove edges are inserted into the minor groove of another helix. [SO:ke]', 295, 0, 0);
INSERT INTO chado.cvterm VALUES (296, 22, 'K_turn_RNA_motif', 'The kink turn (K-turn) is an RNA structural motif that creates a sharp (~120 degree) bend between two continuous helices. [SO:ke]', 296, 0, 0);
INSERT INTO chado.cvterm VALUES (297, 22, 'sarcin_like_RNA_motif', 'A loop in ribosomal RNA containing the sites of attack for ricin and sarcin. [http://www.ncbi.nlm.nih.gov/pubmed/7897662]', 297, 0, 0);
INSERT INTO chado.cvterm VALUES (298, 22, 'symmetric_RNA_internal_loop', 'An internal RNA loop where the extent of the loop on both stands is the same size. [SO:ke]', 298, 0, 0);
INSERT INTO chado.cvterm VALUES (299, 22, 'RNA_junction_loop', '', 299, 0, 0);
INSERT INTO chado.cvterm VALUES (300, 22, 'RNA_hook_turn', '', 300, 0, 0);
INSERT INTO chado.cvterm VALUES (301, 22, 'base_pair', 'Two bases paired opposite each other by hydrogen bonds creating a secondary structure. []', 301, 0, 0);
INSERT INTO chado.cvterm VALUES (302, 22, 'WC_base_pair', 'The canonical base pair, where two bases interact via WC edges, with glycosidic bonds oriented cis relative to the axis of orientation. [PMID:12177293]', 302, 0, 0);
INSERT INTO chado.cvterm VALUES (303, 22, 'sugar_edge_base_pair', 'A type of non-canonical base-pairing. [PMID:12177293]', 303, 0, 0);
INSERT INTO chado.cvterm VALUES (304, 22, 'aptamer', 'DNA or RNA molecules that have been selected from random pools based on their ability to bind other molecules. [http://aptamer.icmb.utexas.edu]', 304, 0, 0);
INSERT INTO chado.cvterm VALUES (2911, 24, 'Contact Type', '', 3220, 0, 0);
INSERT INTO chado.cvterm VALUES (305, 22, 'oligo', 'A short oligonucleotide sequence, of length on the order of 10''s of bases; either single or double stranded. [SO:ma]', 305, 0, 0);
INSERT INTO chado.cvterm VALUES (306, 22, 'DNA_aptamer', 'DNA molecules that have been selected from random pools based on their ability to bind other molecules. [http:aptamer.icmb.utexas.edu]', 306, 0, 0);
INSERT INTO chado.cvterm VALUES (307, 22, 'RNA_aptamer', 'RNA molecules that have been selected from random pools based on their ability to bind other molecules. [http://aptamer.icmb.utexas.edu]', 307, 0, 0);
INSERT INTO chado.cvterm VALUES (308, 22, 'morpholino_oligo', 'Morpholino oligos are synthesized from four different Morpholino subunits, each of which contains one of the four genetic bases (A, C, G, T) linked to a 6-membered morpholine ring. Eighteen to 25 subunits of these four subunit types are joined in a specific order by non-ionic phosphorodiamidate intersubunit linkages to give a Morpholino. [http://www.gene-tools.com/]', 308, 0, 0);
INSERT INTO chado.cvterm VALUES (309, 22, 'synthetic_oligo', 'An oligo composed of synthetic nucleotides. [SO:ke]', 309, 0, 0);
INSERT INTO chado.cvterm VALUES (310, 22, 'morpholino_backbone', 'An attribute describing a sequence composed of nucleobases bound to a morpholino backbone. A morpholino backbone consists of morpholine (CHEBI:34856) rings connected by phosphorodiamidate linkages. [RSC:cb]', 310, 0, 0);
INSERT INTO chado.cvterm VALUES (311, 22, 'riboswitch', 'A riboswitch is a part of an mRNA that can act as a direct sensor of small molecules to control their own expression. A riboswitch is a cis element in the 5'' end of an mRNA, that acts as a direct sensor of metabolites. [PMID:2820954]', 311, 0, 0);
INSERT INTO chado.cvterm VALUES (312, 22, 'mRNA_region', 'A region of an mRNA. [SO:cb]', 312, 0, 0);
INSERT INTO chado.cvterm VALUES (164, 22, 'mRNA', 'Messenger RNA is the intermediate molecule between DNA and protein. It includes UTR and coding sequences. It does not contain introns. [SO:ma]', 164, 0, 0);
INSERT INTO chado.cvterm VALUES (313, 22, 'matrix_attachment_site', 'A DNA region that is required for the binding of chromatin to the nuclear matrix. [SO:ma]', 313, 0, 0);
INSERT INTO chado.cvterm VALUES (314, 22, 'chromosomal_regulatory_element', 'Regions of the chromosome that are important for regulating binding of chromosomes to the nuclear matrix. []', 314, 0, 0);
INSERT INTO chado.cvterm VALUES (315, 22, 'locus_control_region', 'A DNA region that includes DNAse hypersensitive sites located near a gene that confers the high-level, position-independent, and copy number-dependent expression to that gene. [SO:ma]', 315, 0, 0);
INSERT INTO chado.cvterm VALUES (316, 22, 'cis_regulatory_module', 'A regulatory region where transcription factor binding sites are clustered to regulate various aspects of transcription activities. (CRMs can be located a few kb to hundreds of kb upstream of the core promoter, in the coding sequence, within introns, or in the untranslated regions (UTR) sequences, and even on a different chromosome). A single gene can be regulated by multiple CRMs to give precise control of its spatial and temporal expression. CRMs function as nodes in large, intertwined regulatory network. CRM DNA accessibility is subject to regulation by dbTFs and transcription co-TFs. [PMID:19660565, SO:SG]', 316, 0, 0);
INSERT INTO chado.cvterm VALUES (317, 22, 'match_set', 'A collection of match parts. [SO:ke]', 317, 1, 0);
INSERT INTO chado.cvterm VALUES (318, 22, 'match_part', 'A part of a match, for example an hsp from blast is a match_part. [SO:ke]', 318, 0, 0);
INSERT INTO chado.cvterm VALUES (319, 22, 'experimental_feature', 'A region which is the result of some arbitrary experimental procedure. The procedure may be carried out with biological material or inside a computer. [SO:cb]', 319, 0, 0);
INSERT INTO chado.cvterm VALUES (320, 22, 'match', 'A region of sequence, aligned to another sequence with some statistical significance, using an algorithm such as BLAST or SIM4. [SO:ke]', 320, 0, 0);
INSERT INTO chado.cvterm VALUES (321, 22, 'genomic_clone', 'A clone of a DNA region of a genome. [SO:ma]', 321, 0, 0);
INSERT INTO chado.cvterm VALUES (322, 22, 'clone', 'A piece of DNA that has been inserted in a vector so that it can be propagated in a host bacterium or some other organism. [SO:ke]', 322, 0, 0);
INSERT INTO chado.cvterm VALUES (323, 22, 'genomic_DNA', 'DNA located in the genome and able to be transmitted to the offspring. [BCS:etrwz]', 323, 0, 0);
INSERT INTO chado.cvterm VALUES (324, 22, 'sequence_operation', 'An operation that can be applied to a sequence, that results in a change. [SO:ke]', 324, 1, 0);
INSERT INTO chado.cvterm VALUES (325, 22, 'pseudogene_attribute', 'An attribute of a pseudogene (SO:0000336). [SO:ma]', 325, 1, 0);
INSERT INTO chado.cvterm VALUES (326, 22, 'processed_pseudogene', 'A pseudogene created via retrotranposition of the mRNA of a functional protein-coding parent gene followed by accumulation of deleterious mutations lacking introns and promoters, often including a polyA tail. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 326, 0, 0);
INSERT INTO chado.cvterm VALUES (327, 22, 'pseudogene', 'A sequence that closely resembles a known functional gene, at another locus within a genome, that is non-functional as a consequence of (usually several) mutations that prevent either its transcription or translation (or both). In general, pseudogenes result from either reverse transcription of a transcript of their \"normal\" paralog (SO:0000043) (in which case the pseudogene typically lacks introns and includes a poly(A) tail) or from recombination (SO:0000044) (in which case the pseudogene is typically a tandem duplication of its \"normal\" paralog). [http://www.ucl.ac.uk/~ucbhjow/b241/glossary.html]', 327, 0, 0);
INSERT INTO chado.cvterm VALUES (328, 22, 'pseudogene_by_unequal_crossing_over', 'A pseudogene caused by unequal crossing over at recombination. [SO:ke]', 328, 0, 0);
INSERT INTO chado.cvterm VALUES (329, 22, 'non_processed_pseudogene', 'A pseudogene that arose from a means other than retrotransposition. A pseudogene created via genomic duplication of a functional protein-coding parent gene followed by accumulation of deleterious mutations. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, SO:ke]', 329, 0, 0);
INSERT INTO chado.cvterm VALUES (330, 22, 'delete', 'To remove a subsection of sequence. [SO:ke]', 330, 1, 0);
INSERT INTO chado.cvterm VALUES (331, 22, 'insert', 'To insert a subsection of sequence. [SO:ke]', 331, 1, 0);
INSERT INTO chado.cvterm VALUES (332, 22, 'invert', 'To invert a subsection of sequence. [SO:ke]', 332, 1, 0);
INSERT INTO chado.cvterm VALUES (333, 22, 'substitute', 'To substitute a subsection of sequence for another. [SO:ke]', 333, 1, 0);
INSERT INTO chado.cvterm VALUES (334, 22, 'translocate', 'To translocate a subsection of sequence. [SO:ke]', 334, 1, 0);
INSERT INTO chado.cvterm VALUES (335, 22, 'gene_part', 'A part of a gene, that has no other route in the ontology back to region. This concept is necessary for logical inference as these parts must have the properties of region. It also allows us to associate all the parts of genes with a gene. [SO:ke]', 335, 1, 0);
INSERT INTO chado.cvterm VALUES (336, 22, 'probe', 'A DNA sequence used experimentally to detect the presence or absence of a complementary nucleic acid. [SO:ma]', 336, 0, 0);
INSERT INTO chado.cvterm VALUES (337, 22, 'assortment_derived_deficiency', '', 337, 1, 0);
INSERT INTO chado.cvterm VALUES (338, 22, 'sequence_variant_affecting_regulatory_region', 'A sequence_variant_effect which changes the regulatory region of a gene. [SO:ke]', 338, 1, 0);
INSERT INTO chado.cvterm VALUES (388, 22, 'mitochondrial_sequence', 'DNA belonging to the genome of a mitochondria. []', 388, 0, 0);
INSERT INTO chado.cvterm VALUES (339, 22, 'aneuploid', 'A kind of chromosome variation where the chromosome complement is not an exact multiple of the haploid number. [SO:ke]', 339, 0, 0);
INSERT INTO chado.cvterm VALUES (340, 22, 'chromosome_number_variation', 'A kind of chromosome variation where the chromosome complement is not an exact multiple of the haploid number. [SO:ke]', 340, 0, 0);
INSERT INTO chado.cvterm VALUES (341, 22, 'hyperploid', 'A kind of chromosome variation where the chromosome complement is not an exact multiple of the haploid number as extra chromosomes are present. [SO:ke]', 341, 0, 0);
INSERT INTO chado.cvterm VALUES (342, 22, 'hypoploid', 'A kind of chromosome variation where the chromosome complement is not an exact multiple of the haploid number as some chromosomes are missing. [SO:ke]', 342, 0, 0);
INSERT INTO chado.cvterm VALUES (343, 22, 'operator', 'A regulatory element of an operon to which activators or repressors bind thereby effecting translation of genes in that operon. [SO:ma]', 343, 0, 0);
INSERT INTO chado.cvterm VALUES (344, 22, 'transcriptional_cis_regulatory_region', 'A regulatory_region that modulates the transcription of a gene or genes. [PMID:9679020, SO:regcreative]', 344, 0, 0);
INSERT INTO chado.cvterm VALUES (345, 22, 'assortment_derived_aneuploid', '', 345, 1, 0);
INSERT INTO chado.cvterm VALUES (346, 22, 'nuclease_binding_site', 'A binding site that, of a nucleotide molecule, that interacts selectively and non-covalently with polypeptide residues of a nuclease. [SO:cb]', 346, 0, 0);
INSERT INTO chado.cvterm VALUES (347, 22, 'nucleotide_to_protein_binding_site', 'A binding site that, in the nucleotide molecule, interacts selectively and non-covalently with polypeptide residues. [SO:ke]', 347, 0, 0);
INSERT INTO chado.cvterm VALUES (348, 22, 'compound_chromosome_arm', 'One arm of a compound chromosome. []', 348, 0, 0);
INSERT INTO chado.cvterm VALUES (349, 22, 'compound_chromosome', 'A chromosome structure variant where a monocentric element is caused by the fusion of two chromosome arms. [SO:ke]', 349, 0, 0);
INSERT INTO chado.cvterm VALUES (350, 22, 'restriction_enzyme_binding_site', 'A binding site that, in the nucleotide molecule, interacts selectively and non-covalently with polypeptide residues of a restriction enzyme. [SO:cb]', 350, 0, 0);
INSERT INTO chado.cvterm VALUES (351, 22, 'deficient_intrachromosomal_transposition', 'An intrachromosomal transposition whereby a translocation in which one of the four broken ends loses a segment before re-joining. [FB:reference_manual]', 351, 0, 0);
INSERT INTO chado.cvterm VALUES (352, 22, 'chromosomal_deletion', 'An incomplete chromosome. [SO:ke]', 352, 0, 0);
INSERT INTO chado.cvterm VALUES (353, 22, 'intrachromosomal_transposition', 'A chromosome structure variation whereby a transposition occurred within a chromosome. [SO:ke]', 353, 0, 0);
INSERT INTO chado.cvterm VALUES (354, 22, 'deletion', 'The point at which one or more contiguous nucleotides were excised. [SO:ke]', 354, 0, 0);
INSERT INTO chado.cvterm VALUES (355, 22, 'deficient_interchromosomal_transposition', 'An interchromosomal transposition whereby a translocation in which one of the four broken ends loses a segment before re-joining. [SO:ke]', 355, 0, 0);
INSERT INTO chado.cvterm VALUES (356, 22, 'interchromosomal_transposition', 'A chromosome structure variation whereby a transposition occurred between chromosomes. [SO:ke]', 356, 0, 0);
INSERT INTO chado.cvterm VALUES (357, 22, 'gene_by_transcript_attribute', '', 357, 1, 0);
INSERT INTO chado.cvterm VALUES (358, 22, 'free_chromosome_arm', 'A chromosome structure variation whereby an arm exists as an individual chromosome element. [SO:ke]', 358, 0, 0);
INSERT INTO chado.cvterm VALUES (359, 22, 'chromosome_structure_variation', 'An alteration of the genome that leads to a change in the structure or number of one or more chromosomes. []', 359, 0, 0);
INSERT INTO chado.cvterm VALUES (360, 22, 'gene_by_polyadenylation_attribute', '', 360, 1, 0);
INSERT INTO chado.cvterm VALUES (361, 22, 'gene_to_gene_feature', '', 361, 0, 0);
INSERT INTO chado.cvterm VALUES (362, 22, 'overlapping', 'An attribute describing a gene that has a sequence that overlaps the sequence of another gene. [SO:ke]', 362, 0, 0);
INSERT INTO chado.cvterm VALUES (363, 22, 'inside_intron', 'An attribute to describe a gene when it is located within the intron of another gene. [SO:ke]', 363, 0, 0);
INSERT INTO chado.cvterm VALUES (364, 22, 'inside_intron_antiparallel', 'An attribute to describe a gene when it is located within the intron of another gene and on the opposite strand. [SO:ke]', 364, 0, 0);
INSERT INTO chado.cvterm VALUES (365, 22, 'inside_intron_parallel', 'An attribute to describe a gene when it is located within the intron of another gene and on the same strand. [SO:ke]', 365, 0, 0);
INSERT INTO chado.cvterm VALUES (366, 22, 'end_overlapping_gene', '', 366, 1, 0);
INSERT INTO chado.cvterm VALUES (367, 22, 'five_prime_three_prime_overlap', 'An attribute to describe a gene when the five prime region overlaps with another gene''s 3'' region. [SO:ke]', 367, 0, 0);
INSERT INTO chado.cvterm VALUES (368, 22, 'five_prime_five_prime_overlap', 'An attribute to describe a gene when the five prime region overlaps with another gene''s five prime region. [SO:ke]', 368, 0, 0);
INSERT INTO chado.cvterm VALUES (369, 22, 'three_prime_three_prime_overlap', 'An attribute to describe a gene when the 3'' region overlaps with another gene''s 3'' region. [SO:ke]', 369, 0, 0);
INSERT INTO chado.cvterm VALUES (370, 22, 'three_prime_five_prime_overlap', 'An attribute to describe a gene when the 3'' region overlaps with another gene''s 5'' region. [SO:ke]', 370, 0, 0);
INSERT INTO chado.cvterm VALUES (371, 22, 'antisense', 'A region sequence that is complementary to a sequence of messenger RNA. [SO:ke]', 371, 0, 0);
INSERT INTO chado.cvterm VALUES (372, 22, 'polycistronic_transcript', 'A transcript that is polycistronic. [SO:xp]', 372, 0, 0);
INSERT INTO chado.cvterm VALUES (373, 22, 'transcript', 'An RNA synthesized on a DNA or RNA template by an RNA polymerase. [SO:ma]', 373, 0, 0);
INSERT INTO chado.cvterm VALUES (374, 22, 'polycistronic', 'An attribute describing a sequence that contains the code for more than one gene product. [SO:ke]', 374, 0, 0);
INSERT INTO chado.cvterm VALUES (375, 22, 'dicistronic_transcript', 'A transcript that is dicistronic. [SO:ke]', 375, 0, 0);
INSERT INTO chado.cvterm VALUES (376, 22, 'dicistronic', 'An attribute describing a sequence that contains the code for two gene products. [SO:ke]', 376, 0, 0);
INSERT INTO chado.cvterm VALUES (377, 22, 'operon_member', 'A gene that is a member of an operon, which is a set of genes transcribed together as a unit. []', 377, 0, 0);
INSERT INTO chado.cvterm VALUES (378, 22, 'gene_array_member', '', 378, 0, 0);
INSERT INTO chado.cvterm VALUES (379, 22, 'processed_transcript_attribute', '', 379, 1, 0);
INSERT INTO chado.cvterm VALUES (380, 22, 'macronuclear_sequence', 'DNA belonging to the macronuclei of ciliates. []', 380, 0, 0);
INSERT INTO chado.cvterm VALUES (381, 22, 'organelle_sequence', 'A sequence of DNA that originates from a an organelle. []', 381, 0, 0);
INSERT INTO chado.cvterm VALUES (382, 22, 'micronuclear_sequence', 'DNA belonging to the micronuclei of a cell. []', 382, 0, 0);
INSERT INTO chado.cvterm VALUES (383, 22, 'gene_by_genome_location', '', 383, 1, 0);
INSERT INTO chado.cvterm VALUES (384, 22, 'gene_by_organelle_of_genome', '', 384, 1, 0);
INSERT INTO chado.cvterm VALUES (385, 22, 'nuclear_gene', 'A gene from nuclear sequence. [SO:xp]', 385, 0, 0);
INSERT INTO chado.cvterm VALUES (386, 22, 'nuclear_sequence', 'DNA belonging to the nuclear genome of cell. []', 386, 0, 0);
INSERT INTO chado.cvterm VALUES (387, 22, 'mt_gene', 'A gene located in mitochondrial sequence. [SO:xp]', 387, 0, 0);
INSERT INTO chado.cvterm VALUES (389, 22, 'kinetoplast_gene', 'A gene located in kinetoplast sequence. [SO:xp]', 389, 0, 0);
INSERT INTO chado.cvterm VALUES (390, 22, 'kinetoplast', 'A kinetoplast is an interlocked network of thousands of minicircles and tens of maxicircles, located near the base of the flagellum of some protozoan species. [PMID:8395055]', 390, 0, 0);
INSERT INTO chado.cvterm VALUES (391, 22, 'plastid_gene', 'A gene from plastid sequence. [SO:xp]', 391, 0, 0);
INSERT INTO chado.cvterm VALUES (392, 22, 'plastid_sequence', 'DNA belonging to the genome of a plastid such as a chloroplast. []', 392, 0, 0);
INSERT INTO chado.cvterm VALUES (393, 22, 'apicoplast_gene', 'A gene from apicoplast sequence. [SO:xp]', 393, 0, 0);
INSERT INTO chado.cvterm VALUES (394, 22, 'apicoplast_sequence', 'DNA belonging to the genome of an apicoplast, a non-photosynthetic plastid. []', 394, 0, 0);
INSERT INTO chado.cvterm VALUES (395, 22, 'ct_gene', 'A gene from chloroplast sequence. [SO:xp]', 395, 0, 0);
INSERT INTO chado.cvterm VALUES (396, 22, 'chloroplast_sequence', 'DNA belonging to the genome of a chloroplast, a green plastid for photosynthesis. []', 396, 0, 0);
INSERT INTO chado.cvterm VALUES (397, 22, 'chromoplast_gene', 'A gene from chromoplast_sequence. [SO:xp]', 397, 0, 0);
INSERT INTO chado.cvterm VALUES (398, 22, 'chromoplast_sequence', 'DNA belonging to the genome of a chromoplast, a colored plastid for synthesis and storage of pigments. []', 398, 0, 0);
INSERT INTO chado.cvterm VALUES (399, 22, 'cyanelle_gene', 'A gene from cyanelle sequence. [SO:xp]', 399, 0, 0);
INSERT INTO chado.cvterm VALUES (400, 22, 'cyanelle_sequence', 'DNA belonging to the genome of a cyanelle, a photosynthetic plastid found in algae. []', 400, 0, 0);
INSERT INTO chado.cvterm VALUES (401, 22, 'leucoplast_gene', 'A plastid gene from leucoplast sequence. [SO:xp]', 401, 0, 0);
INSERT INTO chado.cvterm VALUES (402, 22, 'leucoplast_sequence', 'DNA belonging to the genome of a leucoplast, a colorless plastid generally containing starch or oil. []', 402, 0, 0);
INSERT INTO chado.cvterm VALUES (403, 22, 'proplastid_gene', 'A gene from proplastid sequence. [SO:ke]', 403, 0, 0);
INSERT INTO chado.cvterm VALUES (404, 22, 'proplastid_sequence', 'DNA belonging to the genome of a proplastid such as an immature chloroplast. []', 404, 0, 0);
INSERT INTO chado.cvterm VALUES (405, 22, 'nucleomorph_gene', 'A gene from nucleomorph sequence. [SO:xp]', 405, 0, 0);
INSERT INTO chado.cvterm VALUES (406, 22, 'nucleomorphic_sequence', 'DNA belonging to the genome of a plastid such as a chloroplast. The nucleomorph is the nuclei of the plastic. []', 406, 0, 0);
INSERT INTO chado.cvterm VALUES (407, 22, 'plasmid_gene', 'A gene from plasmid sequence. [SO:xp]', 407, 0, 0);
INSERT INTO chado.cvterm VALUES (408, 22, 'plasmid_location', 'The location of DNA that has come from a plasmid sequence. []', 408, 0, 0);
INSERT INTO chado.cvterm VALUES (409, 22, 'proviral_gene', 'A gene from proviral sequence. [SO:xp]', 409, 0, 0);
INSERT INTO chado.cvterm VALUES (410, 22, 'proviral_location', 'The location of DNA that has come from a viral origin. []', 410, 0, 0);
INSERT INTO chado.cvterm VALUES (411, 22, 'endogenous_retroviral_gene', 'A proviral gene with origin endogenous retrovirus. [SO:xp]', 411, 0, 0);
INSERT INTO chado.cvterm VALUES (412, 22, 'endogenous_retroviral_sequence', 'Endogenous DNA sequence that are likely to have arisen from retroviruses. []', 412, 0, 0);
INSERT INTO chado.cvterm VALUES (413, 22, 'transposable_element', 'A transposon or insertion sequence. An element that can insert in a variety of DNA sequences. [http://www.sci.sdsu.edu/~smaloy/Glossary/T.html]', 413, 0, 0);
INSERT INTO chado.cvterm VALUES (414, 22, 'integrated_mobile_genetic_element', 'An MGE that is integrated into the host chromosome. [SO:ke]', 414, 0, 0);
INSERT INTO chado.cvterm VALUES (415, 22, 'expressed_sequence_match', 'A match to an EST or cDNA sequence. [SO:ke]', 415, 0, 0);
INSERT INTO chado.cvterm VALUES (416, 22, 'nucleotide_match', 'A match against a nucleotide sequence. [SO:ke]', 416, 0, 0);
INSERT INTO chado.cvterm VALUES (417, 22, 'clone_insert_end', 'The end of the clone insert. [SO:ke]', 417, 0, 0);
INSERT INTO chado.cvterm VALUES (418, 22, 'junction', 'A sequence_feature with an extent of zero. [SO:ke]', 418, 0, 0);
INSERT INTO chado.cvterm VALUES (419, 22, 'clone_insert', 'The region of sequence that has been inserted and is being propagated by the clone. [SO:ke]', 419, 0, 0);
INSERT INTO chado.cvterm VALUES (420, 22, 'polypeptide', 'A sequence of amino acids linked by peptide bonds which may lack appreciable tertiary structure and may not be liable to irreversible denaturation. [SO:ma]', 420, 0, 0);
INSERT INTO chado.cvterm VALUES (421, 22, 'CDS', 'A contiguous sequence which begins with, and includes, a start codon and ends with, and includes, a stop codon. [SO:ma]', 422, 0, 0);
INSERT INTO chado.cvterm VALUES (422, 22, 'chromosome_arm', 'A region of the chromosome between the centromere and the telomere. Human chromosomes have two arms, the p arm (short) and the q arm (long) which are separated from each other by the centromere. [http://www.medterms.com/script/main/art.asp?articlekey=5152]', 423, 0, 0);
INSERT INTO chado.cvterm VALUES (423, 22, 'chromosome_part', 'A region of a chromosome. [SO:ke]', 424, 0, 0);
INSERT INTO chado.cvterm VALUES (424, 22, 'non_capped_primary_transcript', '', 425, 1, 0);
INSERT INTO chado.cvterm VALUES (425, 22, 'sequencing_primer', 'A single stranded oligo used for polymerase chain reaction. []', 426, 0, 0);
INSERT INTO chado.cvterm VALUES (426, 22, 'primer', 'An oligo to which new deoxyribonucleotides can be added by DNA polymerase. [SO:ke]', 427, 0, 0);
INSERT INTO chado.cvterm VALUES (427, 22, 'mRNA_with_frameshift', 'An mRNA with a frameshift. [SO:xp]', 428, 0, 0);
INSERT INTO chado.cvterm VALUES (428, 22, 'frameshift', 'An attribute describing a sequence that contains a mutation involving the deletion or insertion of one or more bases, where this number is not divisible by 3. [SO:ke]', 429, 0, 0);
INSERT INTO chado.cvterm VALUES (429, 22, 'sequence_variant_obs', 'A sequence_variant is a non exact copy of a sequence_feature or genome exhibiting one or more sequence_alteration. [SO:ke]', 430, 1, 0);
INSERT INTO chado.cvterm VALUES (430, 22, 'transposable_element_gene', 'A gene encoded within a transposable element. For example gag, int, env and pol are the transposable element genes of the TY element in yeast. [SO:ke]', 431, 0, 0);
INSERT INTO chado.cvterm VALUES (431, 22, 'ss_oligo', 'A single stranded oligonucleotide. [SO:ke]', 432, 0, 0);
INSERT INTO chado.cvterm VALUES (432, 22, 'proviral_region', 'A viral sequence which has integrated into a host genome. [SO:ke]', 433, 0, 0);
INSERT INTO chado.cvterm VALUES (433, 22, 'methylated_cytosine', 'A methylated deoxy-cytosine. [SO:ke]', 434, 0, 0);
INSERT INTO chado.cvterm VALUES (434, 22, 'methylated_DNA_base_feature', 'A nucleotide modified by methylation. [SO:ke]', 435, 0, 0);
INSERT INTO chado.cvterm VALUES (435, 22, 'modified_cytosine', 'A modified cytosine DNA base feature. [SO:ke]', 436, 0, 0);
INSERT INTO chado.cvterm VALUES (436, 22, 'transcript_feature', '', 437, 1, 0);
INSERT INTO chado.cvterm VALUES (437, 22, 'edited', 'An attribute describing a sequence that is modified by editing. [SO:ke]', 438, 0, 0);
INSERT INTO chado.cvterm VALUES (438, 22, 'transcript_attribute', 'An attribute describing a transcript. []', 439, 0, 0);
INSERT INTO chado.cvterm VALUES (439, 22, 'transcript_with_readthrough_stop_codon', '', 440, 1, 0);
INSERT INTO chado.cvterm VALUES (440, 22, 'transcript_with_translational_frameshift', 'A transcript with a translational frameshift. [SO:xp]', 441, 0, 0);
INSERT INTO chado.cvterm VALUES (441, 22, 'translationally_frameshifted', 'Recoding by frameshifting a particular site. [SO:ke]', 442, 0, 0);
INSERT INTO chado.cvterm VALUES (442, 22, 'regulated', 'An attribute to describe a sequence that is regulated. [SO:ke]', 443, 0, 0);
INSERT INTO chado.cvterm VALUES (443, 22, 'protein_coding_primary_transcript', 'A primary transcript that, at least in part, encodes one or more proteins. [SO:ke]', 444, 0, 0);
INSERT INTO chado.cvterm VALUES (444, 22, 'primary_transcript', 'A transcript that in its initial state requires modification to be functional. [SO:ma]', 445, 0, 0);
INSERT INTO chado.cvterm VALUES (445, 22, 'forward_primer', 'A single stranded oligo used for polymerase chain reaction. [http://mged.sourceforge.net/ontologies/MGEDontology.php]', 446, 0, 0);
INSERT INTO chado.cvterm VALUES (446, 22, 'forward', 'Forward is an attribute of the feature, where the feature is in the 5'' to 3'' direction. [SO:ke]', 447, 0, 0);
INSERT INTO chado.cvterm VALUES (447, 22, 'RNA_sequence_secondary_structure', 'A folded RNA sequence. [SO:ke]', 448, 0, 0);
INSERT INTO chado.cvterm VALUES (448, 22, 'transcriptionally_regulated', 'An attribute describing a gene that is regulated at transcription. [SO:ma]', 449, 0, 0);
INSERT INTO chado.cvterm VALUES (449, 22, 'transcriptionally_constitutive', 'Expressed in relatively constant amounts without regard to cellular environmental conditions such as the concentration of a particular substrate. [SO:ke]', 450, 0, 0);
INSERT INTO chado.cvterm VALUES (450, 22, 'transcriptionally_induced', 'An inducer molecule is required for transcription to occur. [SO:ke]', 451, 0, 0);
INSERT INTO chado.cvterm VALUES (451, 22, 'transcriptionally_repressed', 'A repressor molecule is required for transcription to stop. [SO:ke]', 452, 0, 0);
INSERT INTO chado.cvterm VALUES (452, 22, 'silenced_gene', 'A gene that is silenced. [SO:xp]', 453, 0, 0);
INSERT INTO chado.cvterm VALUES (453, 22, 'silenced', 'An attribute describing an epigenetic process where a gene is inactivated at transcriptional or translational level. [SO:ke]', 454, 0, 0);
INSERT INTO chado.cvterm VALUES (454, 22, 'gene_silenced_by_DNA_modification', 'A gene that is silenced by DNA modification. [SO:xp]', 455, 0, 0);
INSERT INTO chado.cvterm VALUES (455, 22, 'silenced_by_DNA_modification', 'An attribute describing an epigenetic process where a gene is inactivated by DNA modifications, resulting in repression of transcription. [SO:ke]', 456, 0, 0);
INSERT INTO chado.cvterm VALUES (456, 22, 'gene_silenced_by_DNA_methylation', 'A gene that is silenced by DNA methylation. [SO:xp]', 457, 0, 0);
INSERT INTO chado.cvterm VALUES (457, 22, 'silenced_by_DNA_methylation', 'An attribute describing an epigenetic process where a gene is inactivated by DNA methylation, resulting in repression of transcription. [SO:ke]', 458, 0, 0);
INSERT INTO chado.cvterm VALUES (458, 22, 'post_translationally_regulated', 'An attribute describing a gene that is regulated after it has been translated. [SO:ke]', 459, 0, 0);
INSERT INTO chado.cvterm VALUES (459, 22, 'translationally_regulated', 'An attribute describing a gene that is regulated as it is translated. [SO:ke]', 460, 0, 0);
INSERT INTO chado.cvterm VALUES (460, 22, 'reverse_primer', 'A single stranded oligo used for polymerase chain reaction. [http://mged.sourceforge.net/ontologies/MGEDontology.php]', 461, 0, 0);
INSERT INTO chado.cvterm VALUES (461, 22, 'reverse', 'Reverse is an attribute of the feature, where the feature is in the 3'' to 5'' direction. Again could be applied to primer. [SO:ke]', 462, 0, 0);
INSERT INTO chado.cvterm VALUES (462, 22, 'epigenetically_modified', 'This attribute describes a gene where heritable changes other than those in the DNA sequence occur. These changes include: modification to the DNA (such as DNA methylation, the covalent modification of cytosine), and post-translational modification of histones. [SO:ke]', 463, 0, 0);
INSERT INTO chado.cvterm VALUES (463, 22, 'genomically_imprinted', 'Imprinted genes are epigenetically modified genes that are expressed monoallelically according to their parent of origin. [SO:ke]', 464, 0, 0);
INSERT INTO chado.cvterm VALUES (464, 22, 'maternally_imprinted', 'The maternal copy of the gene is modified, rendering it transcriptionally silent. [SO:ke]', 465, 0, 0);
INSERT INTO chado.cvterm VALUES (465, 22, 'paternally_imprinted', 'The paternal copy of the gene is modified, rendering it transcriptionally silent. [SO:ke]', 466, 0, 0);
INSERT INTO chado.cvterm VALUES (466, 22, 'allelically_excluded', 'Allelic exclusion is a process occurring in diploid organisms, where a gene is inactivated and not expressed in that cell. [SO:ke]', 467, 0, 0);
INSERT INTO chado.cvterm VALUES (467, 22, 'gene_rearranged_at_DNA_level', 'An epigenetically modified gene, rearranged at the DNA level. [SO:xp]', 468, 0, 0);
INSERT INTO chado.cvterm VALUES (468, 22, 'epigenetically_modified_gene', 'A gene that is epigenetically modified. [SO:ke]', 469, 0, 0);
INSERT INTO chado.cvterm VALUES (469, 22, 'rearranged_at_DNA_level', 'An attribute to describe the sequence of a feature, where the DNA is rearranged. [SO:ke]', 470, 0, 0);
INSERT INTO chado.cvterm VALUES (470, 22, 'ribosome_entry_site', 'Region in mRNA where ribosome assembles. [SO:ke]', 471, 0, 0);
INSERT INTO chado.cvterm VALUES (471, 22, 'five_prime_UTR', 'A region at the 5'' end of a mature transcript (preceding the initiation codon) that is not translated into a protein. [http://www.insdc.org/files/feature_table.html]', 472, 0, 0);
INSERT INTO chado.cvterm VALUES (472, 22, 'attenuator', 'A sequence segment located within the five prime end of an mRNA that causes premature termination of translation. [SO:as]', 473, 0, 0);
INSERT INTO chado.cvterm VALUES (473, 22, 'translation_regulatory_region', 'A regulatory region that is involved in the control of the process of translation. [SO:ke]', 474, 0, 0);
INSERT INTO chado.cvterm VALUES (474, 22, 'terminator', 'The sequence of DNA located either at the end of the transcript that causes RNA polymerase to terminate transcription. [http://www.insdc.org/files/feature_table.html]', 475, 0, 0);
INSERT INTO chado.cvterm VALUES (475, 22, 'DNA_sequence_secondary_structure', 'A folded DNA sequence. [SO:ke]', 476, 0, 0);
INSERT INTO chado.cvterm VALUES (476, 22, 'assembly_component', 'A region of known length which may be used to manufacture a longer region. [SO:ke]', 477, 0, 0);
INSERT INTO chado.cvterm VALUES (477, 22, 'primary_transcript_attribute', '', 478, 1, 0);
INSERT INTO chado.cvterm VALUES (478, 22, 'recoded_codon', 'A codon that has been redefined at translation. The redefinition may be as a result of translational bypass, translational frameshifting or stop codon readthrough. [SO:xp]', 479, 0, 0);
INSERT INTO chado.cvterm VALUES (479, 22, 'codon', 'A set of (usually) three nucleotide bases in a DNA or RNA sequence, which together code for a unique amino acid or the termination of translation and are contained within the CDS. [SO:ke]', 480, 0, 0);
INSERT INTO chado.cvterm VALUES (480, 22, 'capped', 'An attribute describing when a sequence, usually an mRNA is capped by the addition of a modified guanine nucleotide at the 5'' end. [SO:ke]', 481, 0, 0);
INSERT INTO chado.cvterm VALUES (481, 22, 'exon', 'A region of the transcript sequence within a gene which is not removed from the primary RNA transcript by RNA splicing. [SO:ke]', 482, 0, 0);
INSERT INTO chado.cvterm VALUES (482, 22, 'transcript_region', 'A region of a transcript. [SO:ke]', 483, 0, 0);
INSERT INTO chado.cvterm VALUES (483, 22, 'supercontig', 'One or more contigs that have been ordered and oriented using end-read information. Contains gaps that are filled with N''s. [SO:ls]', 484, 0, 0);
INSERT INTO chado.cvterm VALUES (484, 22, 'partial_genomic_sequence_assembly', 'A partial DNA sequence assembly of a chromosome or full genome, which contains gaps that are filled with N''s. [GMOD:ea]', 485, 0, 0);
INSERT INTO chado.cvterm VALUES (691, 22, 'plus_1_frameshift', 'A frameshift caused by inserting one base. [SO:ke]', 696, 0, 0);
INSERT INTO chado.cvterm VALUES (485, 22, 'ultracontig', 'An ordered and oriented set of scaffolds based on somewhat weaker sets of inferential evidence such as one set of mate pair reads together with supporting evidence from ESTs or location of markers from SNP or microsatellite maps, or cytogenetic localization of contained markers. [FB:WG]', 486, 0, 0);
INSERT INTO chado.cvterm VALUES (486, 22, 'sequence_assembly', 'A sequence of nucleotides that has been algorithmically derived from an alignment of two or more different sequences. [SO:ma]', 487, 0, 0);
INSERT INTO chado.cvterm VALUES (487, 22, 'YAC', 'Yeast Artificial Chromosome, a vector constructed from the telomeric, centromeric, and replication origin sequences needed for replication in yeast cells. [SO:ma]', 488, 0, 0);
INSERT INTO chado.cvterm VALUES (488, 22, 'vector_replicon', 'A replicon that has been modified to act as a vector for foreign sequence. [SO:ma]', 489, 0, 0);
INSERT INTO chado.cvterm VALUES (489, 22, 'BAC', 'Bacterial Artificial Chromosome, a cloning vector that can be propagated as mini-chromosomes in a bacterial host. [SO:ma]', 490, 0, 0);
INSERT INTO chado.cvterm VALUES (490, 22, 'PAC', 'The P1-derived artificial chromosome are DNA constructs that are derived from the DNA of P1 bacteriophage. They can carry large amounts (about 100-300 kilobases) of other sequences for a variety of bioengineering purposes. It is one type of vector used to clone DNA fragments (100- to 300-kb insert size; average, 150 kb) in Escherichia coli cells. [http://en.wikipedia.org/wiki/P1-derived_artificial_chromosome]', 491, 0, 0);
INSERT INTO chado.cvterm VALUES (491, 22, 'plasmid', 'A self replicating, using the hosts cellular machinery, often circular nucleic acid molecule that is distinct from a chromosome in the organism. [SO:ma]', 492, 0, 0);
INSERT INTO chado.cvterm VALUES (492, 22, 'replicon', 'A region containing at least one unique origin of replication and a unique termination site. [ISBN:0716719207]', 493, 0, 0);
INSERT INTO chado.cvterm VALUES (493, 22, 'cosmid', 'A cloning vector that is a hybrid of lambda phages and a plasmid that can be propagated as a plasmid or packaged as a phage,since they retain the lambda cos sites. [SO:ma]', 494, 0, 0);
INSERT INTO chado.cvterm VALUES (494, 22, 'phagemid', 'A plasmid which carries within its sequence a bacteriophage replication origin. When the host bacterium is infected with \"helper\" phage, a phagemid is replicated along with the phage DNA and packaged into phage capsids. [SO:ma]', 495, 0, 0);
INSERT INTO chado.cvterm VALUES (495, 22, 'fosmid', 'A cloning vector that utilizes the E. coli F factor. [SO:ma]', 496, 0, 0);
INSERT INTO chado.cvterm VALUES (496, 22, 'sequence_alteration', 'A sequence_alteration is a sequence_feature whose extent is the deviation from another sequence. [SO:ke]', 499, 0, 0);
INSERT INTO chado.cvterm VALUES (497, 22, 'lambda_clone', 'A linear clone derived from lambda bacteriophage. The genes involved in the lysogenic pathway are removed from the from the viral DNA. Up to 25 kb of foreign DNA can then be inserted into the lambda genome. [ISBN:0-1767-2380-8]', 500, 1, 0);
INSERT INTO chado.cvterm VALUES (498, 22, 'methylated_adenine', 'A modified base in which adenine has been methylated. [SO:ke]', 501, 0, 0);
INSERT INTO chado.cvterm VALUES (499, 22, 'modified_adenine', 'A modified adenine DNA base feature. [SO:ke]', 502, 0, 0);
INSERT INTO chado.cvterm VALUES (500, 22, 'splice_site', 'Consensus region of primary transcript bordering junction of splicing. A region that overlaps exactly 2 base and adjacent_to splice_junction. [SO:cjm, SO:ke]', 503, 0, 0);
INSERT INTO chado.cvterm VALUES (501, 22, 'primary_transcript_region', 'A part of a primary transcript. [SO:ke]', 504, 0, 0);
INSERT INTO chado.cvterm VALUES (502, 22, 'five_prime_cis_splice_site', 'Intronic 2 bp region bordering the exon, at the 5'' edge of the intron. A splice_site that is downstream_adjacent_to exon and starts intron. [http://www.ucl.ac.uk/~ucbhjow/b241/glossary.html, SO:cjm, SO:ke]', 505, 0, 0);
INSERT INTO chado.cvterm VALUES (503, 22, 'cis_splice_site', 'Intronic 2 bp region bordering exon. A splice_site that adjacent_to exon and overlaps intron. [SO:cjm, SO:ke]', 506, 0, 0);
INSERT INTO chado.cvterm VALUES (504, 22, 'three_prime_cis_splice_site', 'Intronic 2 bp region bordering the exon, at the 3'' edge of the intron. A splice_site that is upstream_adjacent_to exon and finishes intron. [http://www.ucl.ac.uk/~ucbhjow/b241/glossary.html, SO:cjm, SO:ke]', 507, 0, 0);
INSERT INTO chado.cvterm VALUES (505, 22, 'enhancer', 'A cis-acting sequence that increases the utilization of (some) eukaryotic promoters, and can function in either orientation and in any location (upstream or downstream) relative to the promoter. [http://www.insdc.org/files/feature_table.html]', 508, 0, 0);
INSERT INTO chado.cvterm VALUES (506, 22, 'enhancer_bound_by_factor', 'An enhancer bound by a factor. [SO:xp]', 509, 0, 0);
INSERT INTO chado.cvterm VALUES (507, 22, 'bound_by_factor', 'An attribute describing a sequence that is bound by another molecule. [SO:ke]', 510, 0, 0);
INSERT INTO chado.cvterm VALUES (508, 22, 'gene_component_region', 'A region of a gene that has a specific function. []', 511, 0, 0);
INSERT INTO chado.cvterm VALUES (509, 22, 'restriction_enzyme_cut_site', 'A specific nucleotide sequence of DNA at or near which a particular restriction enzyme cuts the DNA. [SO:ma]', 512, 1, 0);
INSERT INTO chado.cvterm VALUES (510, 22, 'RNApol_I_promoter', 'A DNA sequence in eukaryotic DNA to which RNA polymerase I binds, to begin transcription. [SO:ke]', 513, 0, 0);
INSERT INTO chado.cvterm VALUES (511, 22, 'eukaryotic_promoter', 'A regulatory_region including the Transcription Start Site (TSS) of a gene and serving as a platform for Pre-Initiation Complex (PIC) assembly, enabling transcription of a gene under certain conditions. []', 514, 0, 0);
INSERT INTO chado.cvterm VALUES (512, 22, 'RNApol_II_promoter', 'A DNA sequence in eukaryotic DNA to which RNA polymerase II binds, to begin transcription. [SO:ke]', 515, 0, 0);
INSERT INTO chado.cvterm VALUES (513, 22, 'RNApol_III_promoter', 'A DNA sequence in eukaryotic DNA to which RNA polymerase III binds, to begin transcription. [SO:ke]', 516, 0, 0);
INSERT INTO chado.cvterm VALUES (514, 22, 'CAAT_signal', 'Part of a conserved sequence located about 75-bp upstream of the start point of eukaryotic transcription units which may be involved in RNA polymerase binding; consensus=GG(C|T)CAATCT. [http://www.insdc.org/files/feature_table.html]', 517, 0, 0);
INSERT INTO chado.cvterm VALUES (515, 22, 'GC_rich_promoter_region', 'A conserved GC-rich region located upstream of the start point of eukaryotic transcription units which may occur in multiple copies or in either orientation; consensus=GGGCGG. [http://www.insdc.org/files/feature_table.html]', 518, 0, 0);
INSERT INTO chado.cvterm VALUES (516, 22, 'promoter_element', 'An element that can exist within the promoter region of a gene. []', 519, 0, 0);
INSERT INTO chado.cvterm VALUES (517, 22, 'TATA_box', 'A conserved AT-rich septamer found about 25-bp before the start point of many eukaryotic RNA polymerase II transcript units; may be involved in positioning the enzyme for correct initiation; consensus=TATA(A|T)A(A|T). [http://www.insdc.org/files/feature_table.html, PMID:16858867]', 520, 0, 0);
INSERT INTO chado.cvterm VALUES (518, 22, 'minus_10_signal', 'A conserved region about 10-bp upstream of the start point of bacterial transcription units which may be involved in binding RNA polymerase; consensus=TAtAaT. This region is associated with sigma factor 70. [http://www.insdc.org/files/feature_table.html]', 521, 0, 0);
INSERT INTO chado.cvterm VALUES (519, 22, 'bacterial_RNApol_promoter_sigma_70_element', 'A DNA sequence to which bacterial RNA polymerase sigma 70 binds, to begin transcription. []', 522, 0, 0);
INSERT INTO chado.cvterm VALUES (520, 22, 'bacterial_RNApol_promoter_sigma_ecf_element', 'A bacterial promoter with sigma ecf factor binding dependency. This is a type of bacterial promoters that requires a sigma ECF factor to bind to identified -10 and -35 sequence regions in order to mediate binding of the RNA polymerase to the promoter region as part of transcription initiation. [Invitrogen:kc]', 523, 0, 0);
INSERT INTO chado.cvterm VALUES (521, 22, 'minus_35_signal', 'A conserved hexamer about 35-bp upstream of the start point of bacterial transcription units; consensus=TTGACa or TGTTGACA. This region is associated with sigma factor 70. [http://www.insdc.org/files/feature_table.html]', 524, 0, 0);
INSERT INTO chado.cvterm VALUES (522, 22, 'cross_genome_match', 'A nucleotide match against a sequence from another organism. [SO:ma]', 525, 0, 0);
INSERT INTO chado.cvterm VALUES (523, 22, 'operon', 'The DNA region of a group of adjacent genes whose transcription is coordinated onone or several mutually overlapping transcription units transcribed in the same direction and sharing at least one gene. [SO:ma]', 526, 0, 0);
INSERT INTO chado.cvterm VALUES (524, 22, 'gene_group', 'A collection of related genes. [SO:ma]', 527, 0, 0);
INSERT INTO chado.cvterm VALUES (525, 22, 'clone_insert_start', 'The start of the clone insert. [SO:ke]', 528, 0, 0);
INSERT INTO chado.cvterm VALUES (526, 22, 'retrotransposon', 'A transposable element that is incorporated into a chromosome by a mechanism that requires reverse transcriptase. [http://www.dddmag.com/Glossary.aspx#r]', 529, 0, 0);
INSERT INTO chado.cvterm VALUES (527, 22, 'translated_nucleotide_match', 'A match against a translated sequence. [SO:ke]', 530, 0, 0);
INSERT INTO chado.cvterm VALUES (528, 22, 'DNA_transposon', 'A transposon where the mechanism of transposition is via a DNA intermediate. [SO:ke]', 531, 0, 0);
INSERT INTO chado.cvterm VALUES (529, 22, 'non_transcribed_region', 'A region of the gene which is not transcribed. [SO:ke]', 532, 0, 0);
INSERT INTO chado.cvterm VALUES (530, 22, 'U2_intron', 'A major type of spliceosomal intron spliced by the U2 spliceosome, that includes U1, U2, U4/U6 and U5 snRNAs. [PMID:9428511]', 533, 0, 0);
INSERT INTO chado.cvterm VALUES (531, 22, 'spliceosomal_intron', 'An intron which is spliced by the spliceosome. [SO:ke]', 534, 0, 0);
INSERT INTO chado.cvterm VALUES (532, 22, 'LTR_retrotransposon', 'A retrotransposon flanked by long terminal repeat sequences. [SO:ke]', 535, 0, 0);
INSERT INTO chado.cvterm VALUES (533, 22, 'repeat_family', 'A group of characterized repeat sequences. [SO:ke]', 536, 1, 0);
INSERT INTO chado.cvterm VALUES (534, 22, 'intron', 'A region of a primary transcript that is transcribed, but removed from within the transcript by splicing together the sequences (exons) on either side of it. [http://www.insdc.org/files/feature_table.html]', 537, 0, 0);
INSERT INTO chado.cvterm VALUES (535, 22, 'non_LTR_retrotransposon', 'A retrotransposon without long terminal repeat sequences. [SO:ke]', 538, 0, 0);
INSERT INTO chado.cvterm VALUES (536, 22, 'five_prime_intron', 'An intron that is the most 5-prime in a given transcript. []', 539, 0, 0);
INSERT INTO chado.cvterm VALUES (537, 22, 'interior_intron', 'An intron that is not the most 3-prime or the most 5-prime in a given transcript. []', 540, 0, 0);
INSERT INTO chado.cvterm VALUES (538, 22, 'three_prime_intron', 'An intron that is the most 3-prime in a given transcript. []', 541, 0, 0);
INSERT INTO chado.cvterm VALUES (539, 22, 'RFLP_fragment', 'A DNA fragment used as a reagent to detect the polymorphic genomic loci by hybridizing against the genomic DNA digested with a given restriction enzyme. [GOC:pj]', 542, 0, 0);
INSERT INTO chado.cvterm VALUES (540, 22, 'restriction_fragment', 'A region of polynucleotide sequence produced by digestion with a restriction endonuclease. [SO:ke]', 543, 0, 0);
INSERT INTO chado.cvterm VALUES (541, 22, 'LINE_element', 'A dispersed repeat family with many copies, each from 1 to 6 kb long. New elements are generated by retroposition of a transcribed copy. Typically the LINE contains 2 ORF''s one of which is reverse transcriptase, and 3''and 5'' direct repeats. [http://www.ucl.ac.uk/~ucbhjow/b241/glossary.html]', 544, 0, 0);
INSERT INTO chado.cvterm VALUES (542, 22, 'five_prime_coding_exon_coding_region', 'The sequence of the five_prime_coding_exon that codes for protein. [SO:cjm]', 545, 0, 0);
INSERT INTO chado.cvterm VALUES (543, 22, 'coding_region_of_exon', 'The region of an exon that encodes for protein sequence. [SO:ke]', 546, 0, 0);
INSERT INTO chado.cvterm VALUES (544, 22, 'five_prime_coding_exon', 'The 5'' most coding exon. [SO:ke]', 547, 0, 0);
INSERT INTO chado.cvterm VALUES (545, 22, 'three_prime_coding_exon_coding_region', 'The sequence of the three_prime_coding_exon that codes for protein. [SO:cjm]', 548, 0, 0);
INSERT INTO chado.cvterm VALUES (546, 22, 'three_prime_coding_exon', 'The coding exon that is most 3-prime on a given transcript. [SO:ma]', 549, 0, 0);
INSERT INTO chado.cvterm VALUES (547, 22, 'noncoding_exon', 'An exon that does not contain any codons. [SO:ke]', 550, 0, 0);
INSERT INTO chado.cvterm VALUES (548, 22, 'translocation', 'A region of nucleotide sequence that has translocated to a new position. The observed adjacency of two previously separated regions. [NCBI:th, SO:ke]', 551, 0, 0);
INSERT INTO chado.cvterm VALUES (549, 22, 'structural_alteration', 'An alteration of the genome that leads to a change in the structure of one or more chromosomes. []', 552, 0, 0);
INSERT INTO chado.cvterm VALUES (550, 22, 'interior_exon', 'An exon that is bounded by 5'' and 3'' splice sites. [PMID:10373547]', 553, 0, 0);
INSERT INTO chado.cvterm VALUES (551, 22, 'UTR', 'Messenger RNA sequences that are untranslated and lie five prime or three prime to sequences which are translated. [SO:ke]', 554, 0, 0);
INSERT INTO chado.cvterm VALUES (552, 22, 'three_prime_UTR', 'A region at the 3'' end of a mature transcript (following the stop codon) that is not translated into a protein. [http://www.insdc.org/files/feature_table.html]', 555, 0, 0);
INSERT INTO chado.cvterm VALUES (553, 22, 'SINE_element', 'A repetitive element, a few hundred base pairs long, that is dispersed throughout the genome. A common human SINE is the Alu element. [SO:ke]', 556, 0, 0);
INSERT INTO chado.cvterm VALUES (554, 22, 'simple_sequence_length_variation', 'SSLP are a kind of sequence alteration where the number of repeated sequences in intergenic regions may differ. [SO:ke]', 557, 0, 0);
INSERT INTO chado.cvterm VALUES (555, 22, 'sequence_length_alteration', 'A kind of kind of sequence alteration where the copies of a region present varies across a population. [SO:ke]', 558, 0, 0);
INSERT INTO chado.cvterm VALUES (556, 22, 'terminal_inverted_repeat_element', 'A DNA transposable element defined as having termini with perfect, or nearly perfect short inverted repeats, generally 10 - 40 nucleotides long. [http://www.genetics.org/cgi/reprint/156/4/1983.pdf]', 559, 0, 0);
INSERT INTO chado.cvterm VALUES (557, 22, 'rRNA_primary_transcript', 'A primary transcript encoding a ribosomal RNA. [SO:ke]', 560, 0, 0);
INSERT INTO chado.cvterm VALUES (558, 22, 'tRNA_primary_transcript', 'A primary transcript encoding a transfer RNA (SO:0000253). [SO:ke]', 561, 0, 0);
INSERT INTO chado.cvterm VALUES (559, 22, 'alanine_tRNA_primary_transcript', 'A primary transcript encoding alanyl tRNA. [SO:ke]', 562, 0, 0);
INSERT INTO chado.cvterm VALUES (560, 22, 'arginine_tRNA_primary_transcript', 'A primary transcript encoding arginyl tRNA (SO:0000255). [SO:ke]', 563, 0, 0);
INSERT INTO chado.cvterm VALUES (561, 22, 'asparagine_tRNA_primary_transcript', 'A primary transcript encoding asparaginyl tRNA (SO:0000256). [SO:ke]', 564, 0, 0);
INSERT INTO chado.cvterm VALUES (1958, 22, 'enzymatic_RNA_gene', 'A gene that encodes an enzymatic RNA. []', 2215, 0, 0);
INSERT INTO chado.cvterm VALUES (562, 22, 'aspartic_acid_tRNA_primary_transcript', 'A primary transcript encoding aspartyl tRNA (SO:0000257). [SO:ke]', 565, 0, 0);
INSERT INTO chado.cvterm VALUES (563, 22, 'cysteine_tRNA_primary_transcript', 'A primary transcript encoding cysteinyl tRNA (SO:0000258). [SO:ke]', 566, 0, 0);
INSERT INTO chado.cvterm VALUES (564, 22, 'glutamic_acid_tRNA_primary_transcript', 'A primary transcript encoding glutaminyl tRNA (SO:0000260). [SO:ke]', 567, 0, 0);
INSERT INTO chado.cvterm VALUES (565, 22, 'glutamine_tRNA_primary_transcript', 'A primary transcript encoding glutamyl tRNA (SO:0000260). [SO:ke]', 568, 0, 0);
INSERT INTO chado.cvterm VALUES (566, 22, 'glycine_tRNA_primary_transcript', 'A primary transcript encoding glycyl tRNA (SO:0000263). [SO:ke]', 569, 0, 0);
INSERT INTO chado.cvterm VALUES (567, 22, 'histidine_tRNA_primary_transcript', 'A primary transcript encoding histidyl tRNA (SO:0000262). [SO:ke]', 570, 0, 0);
INSERT INTO chado.cvterm VALUES (568, 22, 'isoleucine_tRNA_primary_transcript', 'A primary transcript encoding isoleucyl tRNA (SO:0000263). [SO:ke]', 571, 0, 0);
INSERT INTO chado.cvterm VALUES (569, 22, 'leucine_tRNA_primary_transcript', 'A primary transcript encoding leucyl tRNA (SO:0000264). [SO:ke]', 572, 0, 0);
INSERT INTO chado.cvterm VALUES (570, 22, 'lysine_tRNA_primary_transcript', 'A primary transcript encoding lysyl tRNA (SO:0000265). [SO:ke]', 573, 0, 0);
INSERT INTO chado.cvterm VALUES (571, 22, 'methionine_tRNA_primary_transcript', 'A primary transcript encoding methionyl tRNA (SO:0000266). [SO:ke]', 574, 0, 0);
INSERT INTO chado.cvterm VALUES (572, 22, 'phenylalanine_tRNA_primary_transcript', 'A primary transcript encoding phenylalanyl tRNA (SO:0000267). [SO:ke]', 575, 0, 0);
INSERT INTO chado.cvterm VALUES (573, 22, 'proline_tRNA_primary_transcript', 'A primary transcript encoding prolyl tRNA (SO:0000268). [SO:ke]', 576, 0, 0);
INSERT INTO chado.cvterm VALUES (574, 22, 'serine_tRNA_primary_transcript', 'A primary transcript encoding seryl tRNA (SO:000269). [SO:ke]', 577, 0, 0);
INSERT INTO chado.cvterm VALUES (575, 22, 'threonine_tRNA_primary_transcript', 'A primary transcript encoding threonyl tRNA (SO:000270). [SO:ke]', 578, 0, 0);
INSERT INTO chado.cvterm VALUES (576, 22, 'tryptophan_tRNA_primary_transcript', 'A primary transcript encoding tryptophanyl tRNA (SO:000271). [SO:ke]', 579, 0, 0);
INSERT INTO chado.cvterm VALUES (577, 22, 'tyrosine_tRNA_primary_transcript', 'A primary transcript encoding tyrosyl tRNA (SO:000272). [SO:ke]', 580, 0, 0);
INSERT INTO chado.cvterm VALUES (578, 22, 'valine_tRNA_primary_transcript', 'A primary transcript encoding valyl tRNA (SO:000273). [SO:ke]', 581, 0, 0);
INSERT INTO chado.cvterm VALUES (579, 22, 'snRNA_primary_transcript', 'A primary transcript encoding a small nuclear RNA (SO:0000274). [SO:ke]', 582, 0, 0);
INSERT INTO chado.cvterm VALUES (580, 22, 'snoRNA_primary_transcript', 'A primary transcript encoding one or more small nucleolar RNAs (SO:0000275). [SO:ke]', 583, 0, 0);
INSERT INTO chado.cvterm VALUES (581, 22, 'mature_transcript', 'A transcript which has undergone the necessary modifications, if any, for its function. In eukaryotes this includes, for example, processing of introns, cleavage, base modification, and modifications to the 5'' and/or the 3'' ends, other than addition of bases. In bacteria functional mRNAs are usually not modified. [SO:ke]', 584, 0, 0);
INSERT INTO chado.cvterm VALUES (582, 22, 'TF_binding_site', 'A DNA site where a transcription factor binds. [SO:ke]', 585, 0, 0);
INSERT INTO chado.cvterm VALUES (583, 22, 'ORF', 'The in-frame interval between the stop codons of a reading frame which when read as sequential triplets, has the potential of encoding a sequential string of amino acids. TER(NNN)nTER. [SGD:rb, SO:ma]', 586, 0, 0);
INSERT INTO chado.cvterm VALUES (584, 22, 'reading_frame', 'A nucleic acid sequence that when read as sequential triplets, has the potential of encoding a sequential string of amino acids. It need not contain the start or stop codon. [SGD:rb]', 587, 0, 0);
INSERT INTO chado.cvterm VALUES (585, 22, 'feature_attribute', 'An attribute describing a located_sequence_feature. [SO:ke]', 588, 0, 0);
INSERT INTO chado.cvterm VALUES (586, 22, 'foldback_element', 'A transposable element with extensive secondary structure, characterized by large modular imperfect long inverted repeats. [http://www.genetics.org/cgi/reprint/156/4/1983.pdf]', 589, 0, 0);
INSERT INTO chado.cvterm VALUES (587, 22, 'flanking_region', 'The sequences extending on either side of a specific region. [SO:ke]', 590, 0, 0);
INSERT INTO chado.cvterm VALUES (588, 22, 'topologically_defined_region', 'A DNA region within which self-interaction occurs more often than expected by chance because of DNA-looping. [PMID:32782014, SO:cb]', 591, 0, 0);
INSERT INTO chado.cvterm VALUES (589, 22, 'chromosome_variation', 'A deviation in chromosome structure or number. []', 592, 0, 0);
INSERT INTO chado.cvterm VALUES (590, 22, 'variant_collection', 'A collection of one or more sequences of an individual. [SO:ke]', 593, 0, 0);
INSERT INTO chado.cvterm VALUES (591, 22, 'chromosomally_aberrant_genome', 'When a genome contains an abnormal amount of chromosomes. []', 594, 0, 0);
INSERT INTO chado.cvterm VALUES (592, 22, 'internal_UTR', 'A UTR bordered by the terminal and initial codons of two CDSs in a polycistronic transcript. Every UTR is either 5'', 3'' or internal. [SO:cjm]', 595, 0, 0);
INSERT INTO chado.cvterm VALUES (593, 22, 'untranslated_region_polycistronic_mRNA', 'The untranslated sequence separating the ''cistrons'' of multicistronic mRNA. [SO:ke]', 596, 0, 0);
INSERT INTO chado.cvterm VALUES (594, 22, 'internal_ribosome_entry_site', 'Sequence element that recruits a ribosomal subunit to internal mRNA for translation initiation. [SO:ke]', 597, 0, 0);
INSERT INTO chado.cvterm VALUES (595, 22, 'four_cutter_restriction_site', '', 598, 1, 0);
INSERT INTO chado.cvterm VALUES (596, 22, 'mRNA_by_polyadenylation_status', '', 599, 1, 0);
INSERT INTO chado.cvterm VALUES (597, 22, 'polyadenylated', 'A attribute describing the addition of a poly A tail to the 3'' end of a mRNA molecule. [SO:ke]', 600, 0, 0);
INSERT INTO chado.cvterm VALUES (598, 22, 'mRNA_attribute', 'An attribute describing an mRNA feature. [SO:ke]', 601, 0, 0);
INSERT INTO chado.cvterm VALUES (599, 22, 'mRNA_not_polyadenylated', '', 602, 1, 0);
INSERT INTO chado.cvterm VALUES (600, 22, 'six_cutter_restriction_site', '', 603, 1, 0);
INSERT INTO chado.cvterm VALUES (601, 22, 'modified_RNA_base_feature', 'A post_transcriptionally modified base. [SO:ke]', 604, 0, 0);
INSERT INTO chado.cvterm VALUES (602, 22, 'base', 'A base is a sequence feature that corresponds to a single unit of a nucleotide polymer. [SO:ke]', 605, 0, 0);
INSERT INTO chado.cvterm VALUES (603, 22, 'eight_cutter_restriction_site', '', 606, 1, 0);
INSERT INTO chado.cvterm VALUES (604, 22, 'rRNA', 'rRNA is an RNA component of a ribosome that can provide both structural scaffolding and catalytic activity. [http://www.insdc.org/files/feature_table.html, ISBN:0198506732]', 607, 0, 0);
INSERT INTO chado.cvterm VALUES (645, 22, 'engineered_foreign_transposable_element_gene', 'A transposable_element that is engineered and foreign. [SO:xp]', 649, 0, 0);
INSERT INTO chado.cvterm VALUES (646, 22, 'type_I_enzyme_restriction_site', 'The recognition site is bipartite and interrupted. [http://www.promega.com]', 650, 1, 0);
INSERT INTO chado.cvterm VALUES (647, 22, 'long_terminal_repeat', 'A sequence directly repeated at both ends of a defined sequence, of the sort typically found in retroviruses. [http://www.insdc.org/files/feature_table.html]', 651, 0, 0);
INSERT INTO chado.cvterm VALUES (648, 22, 'repeat_region', 'A region of sequence containing one or more repeat units. [SO:ke]', 652, 0, 0);
INSERT INTO chado.cvterm VALUES (649, 22, 'fusion_gene', 'A gene that is a fusion. [SO:xp]', 653, 0, 0);
INSERT INTO chado.cvterm VALUES (605, 22, 'tRNA', 'Transfer RNA (tRNA) molecules are approximately 80 nucleotides in length. Their secondary structure includes four short double-helical elements and three loops (D, anti-codon, and T loops). Further hydrogen bonds mediate the characteristic L-shaped molecular structure. Transfer RNAs have two regions of fundamental functional importance: the anti-codon, which is responsible for specific mRNA codon recognition, and the 3'' end, to which the tRNA''s corresponding amino acid is attached (by aminoacyl-tRNA synthetases). Transfer RNAs cope with the degeneracy of the genetic code in two manners: having more than one tRNA (with a specific anti-codon) for a particular amino acid; and ''wobble'' base-pairing, i.e. permitting non-standard base-pairing at the 3rd anti-codon position. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00005, ISBN:0198506732]', 608, 0, 0);
INSERT INTO chado.cvterm VALUES (606, 22, 'sncRNA', 'A non-coding RNA less than 200 nucleotides in length. [PMID:30069443]', 609, 0, 0);
INSERT INTO chado.cvterm VALUES (607, 22, 'alanyl_tRNA', 'A tRNA sequence that has an alanine anticodon, and a 3'' alanine binding region. [SO:ke]', 610, 0, 0);
INSERT INTO chado.cvterm VALUES (608, 22, 'rRNA_small_subunit_primary_transcript', 'A primary transcript encoding a small ribosomal subunit RNA. [SO:ke]', 611, 0, 0);
INSERT INTO chado.cvterm VALUES (609, 22, 'asparaginyl_tRNA', 'A tRNA sequence that has an asparagine anticodon, and a 3'' asparagine binding region. [SO:ke]', 612, 0, 0);
INSERT INTO chado.cvterm VALUES (610, 22, 'aspartyl_tRNA', 'A tRNA sequence that has an aspartic acid anticodon, and a 3'' aspartic acid binding region. [SO:ke]', 613, 0, 0);
INSERT INTO chado.cvterm VALUES (611, 22, 'cysteinyl_tRNA', 'A tRNA sequence that has a cysteine anticodon, and a 3'' cysteine binding region. [SO:ke]', 614, 0, 0);
INSERT INTO chado.cvterm VALUES (612, 22, 'glutaminyl_tRNA', 'A tRNA sequence that has a glutamine anticodon, and a 3'' glutamine binding region. [SO:ke]', 615, 0, 0);
INSERT INTO chado.cvterm VALUES (613, 22, 'glutamyl_tRNA', 'A tRNA sequence that has a glutamic acid anticodon, and a 3'' glutamic acid binding region. [SO:ke]', 616, 0, 0);
INSERT INTO chado.cvterm VALUES (614, 22, 'glycyl_tRNA', 'A tRNA sequence that has a glycine anticodon, and a 3'' glycine binding region. [SO:ke]', 617, 0, 0);
INSERT INTO chado.cvterm VALUES (615, 22, 'histidyl_tRNA', 'A tRNA sequence that has a histidine anticodon, and a 3'' histidine binding region. [SO:ke]', 618, 0, 0);
INSERT INTO chado.cvterm VALUES (616, 22, 'isoleucyl_tRNA', 'A tRNA sequence that has an isoleucine anticodon, and a 3'' isoleucine binding region. [SO:ke]', 619, 0, 0);
INSERT INTO chado.cvterm VALUES (617, 22, 'leucyl_tRNA', 'A tRNA sequence that has a leucine anticodon, and a 3'' leucine binding region. [SO:ke]', 620, 0, 0);
INSERT INTO chado.cvterm VALUES (618, 22, 'lysyl_tRNA', 'A tRNA sequence that has a lysine anticodon, and a 3'' lysine binding region. [SO:ke]', 621, 0, 0);
INSERT INTO chado.cvterm VALUES (619, 22, 'methionyl_tRNA', 'A tRNA sequence that has a methionine anticodon, and a 3'' methionine binding region. [SO:ke]', 622, 0, 0);
INSERT INTO chado.cvterm VALUES (620, 22, 'phenylalanyl_tRNA', 'A tRNA sequence that has a phenylalanine anticodon, and a 3'' phenylalanine binding region. [SO:ke]', 623, 0, 0);
INSERT INTO chado.cvterm VALUES (621, 22, 'prolyl_tRNA', 'A tRNA sequence that has a proline anticodon, and a 3'' proline binding region. [SO:ke]', 624, 0, 0);
INSERT INTO chado.cvterm VALUES (622, 22, 'seryl_tRNA', 'A tRNA sequence that has a serine anticodon, and a 3'' serine binding region. [SO:ke]', 625, 0, 0);
INSERT INTO chado.cvterm VALUES (623, 22, 'threonyl_tRNA', 'A tRNA sequence that has a threonine anticodon, and a 3'' threonine binding region. [SO:ke]', 626, 0, 0);
INSERT INTO chado.cvterm VALUES (624, 22, 'tryptophanyl_tRNA', 'A tRNA sequence that has a tryptophan anticodon, and a 3'' tryptophan binding region. [SO:ke]', 627, 0, 0);
INSERT INTO chado.cvterm VALUES (625, 22, 'tyrosyl_tRNA', 'A tRNA sequence that has a tyrosine anticodon, and a 3'' tyrosine binding region. [SO:ke]', 628, 0, 0);
INSERT INTO chado.cvterm VALUES (626, 22, 'valyl_tRNA', 'A tRNA sequence that has a valine anticodon, and a 3'' valine binding region. [SO:ke]', 629, 0, 0);
INSERT INTO chado.cvterm VALUES (627, 22, 'snRNA', 'A small nuclear RNA molecule involved in pre-mRNA splicing and processing. [http://www.insdc.org/files/feature_table.html, PMID:11733745, WB:ems]', 630, 0, 0);
INSERT INTO chado.cvterm VALUES (628, 22, 'snoRNA', 'Small nucleolar RNAs (snoRNAs) are short non-coding RNAs enriched in the nucleolus as components of small nucleolar ribonucleoproteins. They guide ribose methylation and pseudouridylation of rRNAs and snRNAs, and a subgroup regulate excision of rRNAs from rRNA precursor transcripts. snoRNAs may also guide rRNA acetylation and tRNA methylation, and regulate mRNA abundance and alternative splicing. [GOC:kgc, PMID:31828325]', 631, 0, 0);
INSERT INTO chado.cvterm VALUES (629, 22, 'miRNA', 'Small, ~22-nt, RNA molecule that is the endogenous transcript of a miRNA gene (or the product of other non coding RNA genes. Micro RNAs are produced from precursor molecules (SO:0001244) that can form local hairpin structures, which ordinarily are processed (usually via the Dicer pathway) such that a single miRNA molecule accumulates from one arm of a hairpin precursor molecule. Micro RNAs may trigger the cleavage of their target molecules or act as translational repressors. [PMID:11081512, PMID:12592000]', 632, 0, 0);
INSERT INTO chado.cvterm VALUES (630, 22, 'small_regulatory_ncRNA', 'A non-coding RNA less than 200 nucleotides long, usually with a specific secondary structure, that acts to regulate gene expression. These include short ncRNAs such as piRNA, miRNA and siRNAs (among others). [PMID:28541282, PomBase:al, SO:ma]', 634, 0, 0);
INSERT INTO chado.cvterm VALUES (631, 22, 'pre_miRNA', 'The 60-70 nucleotide region remain after Drosha processing of the primary transcript, that folds back upon itself to form a hairpin structure. [SO:ke]', 635, 0, 0);
INSERT INTO chado.cvterm VALUES (632, 22, 'transcript_bound_by_nucleic_acid', 'A transcript that is bound by a nucleic acid. [SO:xp]', 636, 0, 0);
INSERT INTO chado.cvterm VALUES (633, 22, 'bound_by_nucleic_acid', 'An attribute describing a sequence that is bound by a nucleic acid. [SO:ke]', 637, 0, 0);
INSERT INTO chado.cvterm VALUES (634, 22, 'transcript_bound_by_protein', 'A transcript that is bound by a protein. [SO:xp]', 638, 0, 0);
INSERT INTO chado.cvterm VALUES (635, 22, 'bound_by_protein', 'An attribute describing a sequence that is bound by a protein. [SO:ke]', 639, 0, 0);
INSERT INTO chado.cvterm VALUES (636, 22, 'engineered_gene', 'A gene that is engineered. [SO:xp]', 640, 0, 0);
INSERT INTO chado.cvterm VALUES (637, 22, 'engineered_region', 'A region that is engineered. [SO:xp]', 641, 0, 0);
INSERT INTO chado.cvterm VALUES (638, 22, 'engineered', 'An attribute to describe a region that was modified in vitro. [SO:ke]', 642, 0, 0);
INSERT INTO chado.cvterm VALUES (639, 22, 'engineered_foreign_gene', 'A gene that is engineered and foreign. [SO:xp]', 643, 0, 0);
INSERT INTO chado.cvterm VALUES (640, 22, 'foreign_gene', 'A gene that is foreign. [SO:xp]', 644, 0, 0);
INSERT INTO chado.cvterm VALUES (641, 22, 'engineered_foreign_region', 'A region that is engineered and foreign. [SO:xp]', 645, 0, 0);
INSERT INTO chado.cvterm VALUES (642, 22, 'foreign', 'An attribute to describe a region from another species. [SO:ke]', 646, 0, 0);
INSERT INTO chado.cvterm VALUES (643, 22, 'mRNA_with_minus_1_frameshift', 'An mRNA with a minus 1 frameshift. [SO:xp]', 647, 0, 0);
INSERT INTO chado.cvterm VALUES (644, 22, 'minus_1_frameshift', 'A frameshift caused by deleting one base. [SO:ke]', 648, 0, 0);
INSERT INTO chado.cvterm VALUES (650, 22, 'fusion', 'When two regions of DNA are joined together that are not normally together. []', 654, 0, 0);
INSERT INTO chado.cvterm VALUES (651, 22, 'engineered_fusion_gene', 'A fusion gene that is engineered. [SO:xp]', 655, 0, 0);
INSERT INTO chado.cvterm VALUES (652, 22, 'microsatellite', 'A repeat_region containing repeat_units of 2 to 10 bp repeated in tandem. [http://www.informatics.jax.org/silver/glossary.shtml, NCBI:th]', 656, 0, 0);
INSERT INTO chado.cvterm VALUES (653, 22, 'dinucleotide_repeat_microsatellite_feature', 'A region of a repeating dinucleotide sequence (two bases). []', 657, 0, 0);
INSERT INTO chado.cvterm VALUES (654, 22, 'trinucleotide_repeat_microsatellite_feature', 'A region of a repeating trinucleotide sequence (three bases). []', 658, 0, 0);
INSERT INTO chado.cvterm VALUES (655, 22, 'repetitive_element', '', 659, 1, 0);
INSERT INTO chado.cvterm VALUES (656, 22, 'engineered_foreign_repetitive_element', 'A repetitive element that is engineered and foreign. [SO:xp]', 660, 0, 0);
INSERT INTO chado.cvterm VALUES (657, 22, 'inverted_repeat', 'The sequence is complementarily repeated on the opposite strand. It is a palindrome, and it may, or may not be hyphenated. Examples: GCTGATCAGC, or GCTGA', 661, 0, 0);
INSERT INTO chado.cvterm VALUES (658, 22, 'U12_intron', 'A type of spliceosomal intron spliced by the U12 spliceosome, that includes U11, U12, U4atac/U6atac and U5 snRNAs. [PMID:9428511]', 662, 0, 0);
INSERT INTO chado.cvterm VALUES (659, 22, 'origin_of_replication', 'A region of nucleic acid from which replication initiates; includes sequences that are recognized by replication proteins, the site from which the first separation of complementary strands occurs, and specific replication start sites. [http://www.insdc.org/files/feature_table.html, NCBI:cf]', 663, 0, 0);
INSERT INTO chado.cvterm VALUES (660, 22, 'D_loop', 'Displacement loop; a region within mitochondrial DNA in which a short stretch of RNA is paired with one strand of DNA, displacing the original partner DNA strand in this region; also used to describe the displacement of a region of one strand of duplex DNA by a single stranded invader in the reaction catalyzed by RecA protein. [http://www.insdc.org/files/feature_table.html]', 664, 0, 0);
INSERT INTO chado.cvterm VALUES (661, 22, 'recombination_feature', 'A feature where there has been exchange of genetic material in the event of mitosis or meiosis []', 665, 0, 0);
INSERT INTO chado.cvterm VALUES (662, 22, 'specific_recombination_site', 'A location where recombination or occurs during mitosis or meiosis. []', 666, 0, 0);
INSERT INTO chado.cvterm VALUES (663, 22, 'sequence_rearrangement_feature', 'A feature where a segment of DNA has been rearranged from what it was in the parent cell. []', 667, 0, 0);
INSERT INTO chado.cvterm VALUES (664, 22, 'recombination_feature_of_rearranged_gene', 'A location where a gene is rearranged due to recombination during mitosis or meiosis. []', 668, 0, 0);
INSERT INTO chado.cvterm VALUES (665, 22, 'vertebrate_immune_system_gene_recombination_feature', 'A feature where recombination has occurred for the purpose of generating a diversity in the immune system. []', 669, 0, 0);
INSERT INTO chado.cvterm VALUES (666, 22, 'J_gene_recombination_feature', 'Recombination signal including J-heptamer, J-spacer and J-nonamer in 5'' of J-region of a J-gene or J-sequence. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 670, 0, 0);
INSERT INTO chado.cvterm VALUES (667, 22, 'vertebrate_immune_system_gene_recombination_signal_feature', 'Feature used for the recombination of genomic material for the purpose of generating diversity of the immune system. []', 671, 0, 0);
INSERT INTO chado.cvterm VALUES (668, 22, 'clip', 'Part of the primary transcript that is clipped off during processing. [SO:ke]', 672, 0, 0);
INSERT INTO chado.cvterm VALUES (669, 22, 'type_II_enzyme_restriction_site', 'The recognition site is either palindromic, partially palindromic or an interrupted palindrome. Cleavage occurs within the recognition site. [http://www.promega.com]', 673, 1, 0);
INSERT INTO chado.cvterm VALUES (670, 22, 'modified_DNA_base', 'A modified nucleotide, i.e. a nucleotide other than A, T, C. G. [http://www.insdc.org/files/feature_table.html]', 674, 0, 0);
INSERT INTO chado.cvterm VALUES (671, 22, 'epigenetically_modified_region', 'A biological DNA region implicated in epigenomic changes caused by mechanisms other than changes in the underlying DNA sequence. This includes, nucleosomal histone post-translational modifications, nucleosome depletion to render DNA accessible and post-replicational base modifications such as cytosine modification. [http://en.wikipedia.org/wiki/Epigenetics, SO:ke]', 675, 0, 0);
INSERT INTO chado.cvterm VALUES (672, 22, 'CpG_island', 'Regions of a few hundred to a few thousand bases in vertebrate genomes that are relatively GC and CpG rich; they are typically unmethylated and often found near the 5'' ends of genes. [SO:rd]', 676, 0, 0);
INSERT INTO chado.cvterm VALUES (673, 22, 'sequence_feature_locating_method', '', 677, 1, 0);
INSERT INTO chado.cvterm VALUES (674, 22, 'computed_feature', '', 678, 1, 0);
INSERT INTO chado.cvterm VALUES (675, 22, 'predicted_ab_initio_computation', '', 679, 1, 0);
INSERT INTO chado.cvterm VALUES (676, 22, 'computed_feature_by_similarity', '. [SO:ma]', 680, 1, 0);
INSERT INTO chado.cvterm VALUES (677, 22, 'experimentally_determined', 'Attribute to describe a feature that has been experimentally verified. [SO:ke]', 681, 0, 0);
INSERT INTO chado.cvterm VALUES (678, 22, 'validated', 'An attribute to describe a feature that has been proven. [SO:ke]', 682, 0, 0);
INSERT INTO chado.cvterm VALUES (679, 22, 'stem_loop', 'A double-helical region of nucleic acid formed by base-pairing between adjacent (inverted) complementary sequences. [http://www.insdc.org/files/feature_table.html]', 683, 0, 0);
INSERT INTO chado.cvterm VALUES (680, 22, 'direct_repeat', 'A repeat where the same sequence is repeated in the same direction. Example: GCTGA-followed by-GCTGA. [SO:ke]', 685, 0, 0);
INSERT INTO chado.cvterm VALUES (681, 22, 'TSS', 'The first base where RNA polymerase begins to synthesize the RNA transcript. [SO:ke]', 686, 0, 0);
INSERT INTO chado.cvterm VALUES (682, 22, 'core_promoter_element', 'An element that always exists within the promoter region of a gene. When multiple transcripts exist for a gene, the separate transcripts may have separate core_promoter_elements. [GREEKC:rl]', 687, 0, 0);
INSERT INTO chado.cvterm VALUES (683, 22, 'cDNA_clone', 'Complementary DNA; A piece of DNA copied from an mRNA and spliced into a vector for propagation in a suitable host. [http://seqcore.brcf.med.umich.edu/doc/educ/dnapr/mbglossary/mbgloss.html]', 688, 0, 0);
INSERT INTO chado.cvterm VALUES (684, 22, 'cDNA', 'DNA synthesized by reverse transcriptase using RNA as a template. [SO:ma]', 689, 0, 0);
INSERT INTO chado.cvterm VALUES (685, 22, 'start_codon', 'First codon to be translated by a ribosome. [SO:ke]', 690, 0, 0);
INSERT INTO chado.cvterm VALUES (686, 22, 'stop_codon', 'In mRNA, a set of three nucleotides that indicates the end of information for protein synthesis. [SO:ke]', 691, 0, 0);
INSERT INTO chado.cvterm VALUES (687, 22, 'intronic_splice_enhancer', 'Sequences within the intron that modulate splice site selection for some introns. [SO:ke]', 692, 0, 0);
INSERT INTO chado.cvterm VALUES (688, 22, 'splice_enhancer', 'Region of a transcript that regulates splicing. [SO:ke]', 693, 0, 0);
INSERT INTO chado.cvterm VALUES (689, 22, 'spliceosomal_intron_region', 'A region within an intron. [SO:ke]', 694, 0, 0);
INSERT INTO chado.cvterm VALUES (690, 22, 'mRNA_with_plus_1_frameshift', 'An mRNA with a plus 1 frameshift. [SO:ke]', 695, 0, 0);
INSERT INTO chado.cvterm VALUES (692, 22, 'nuclease_hypersensitive_site', 'A region of nucleotide sequence targeted by a nuclease enzyme that is found cleaved more than would be expected by chance. []', 697, 0, 0);
INSERT INTO chado.cvterm VALUES (693, 22, 'nuclease_sensitive_site', 'A region of nucleotide sequence targeted by a nuclease enzyme. [SO:ma]', 698, 0, 0);
INSERT INTO chado.cvterm VALUES (694, 22, 'accessible_DNA_region', 'A region of DNA that is depleted of nucleosomes and accessible to DNA-binding proteins including transcription factors and nucleases. [PMID:25903461, SO:ds]', 699, 0, 0);
INSERT INTO chado.cvterm VALUES (695, 22, 'coding_start', 'The first base to be translated into protein. [SO:ke]', 700, 0, 0);
INSERT INTO chado.cvterm VALUES (696, 22, 'CDS_region', 'A region of a CDS. [SO:cb]', 701, 0, 0);
INSERT INTO chado.cvterm VALUES (697, 22, 'tag', 'A nucleotide sequence that may be used to identify a larger sequence. [SO:ke]', 702, 0, 0);
INSERT INTO chado.cvterm VALUES (698, 22, 'rRNA_large_subunit_primary_transcript', 'A primary transcript encoding a large ribosomal subunit RNA. [SO:ke]', 703, 0, 0);
INSERT INTO chado.cvterm VALUES (699, 22, 'SAGE_tag', 'A short diagnostic sequence tag, serial analysis of gene expression (SAGE), that allows the quantitative and simultaneous analysis of a large number of transcripts. [http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=7570003&dopt=Abstract]', 704, 0, 0);
INSERT INTO chado.cvterm VALUES (700, 22, 'coding_end', 'The last base to be translated into protein. It does not include the stop codon. [SO:ke]', 705, 0, 0);
INSERT INTO chado.cvterm VALUES (701, 22, 'microarray_oligo', 'A DNA sequence used experimentally to detect the presence or absence of a complementary nucleic acid. []', 706, 0, 0);
INSERT INTO chado.cvterm VALUES (702, 22, 'mRNA_with_plus_2_frameshift', 'An mRNA with a plus 2 frameshift. [SO:xp]', 707, 0, 0);
INSERT INTO chado.cvterm VALUES (703, 22, 'plus_2_framshift', 'A frameshift caused by inserting two bases. [SO:ke]', 708, 0, 0);
INSERT INTO chado.cvterm VALUES (704, 22, 'conserved_region', 'Region of sequence similarity by descent from a common ancestor. [SO:ke]', 709, 0, 0);
INSERT INTO chado.cvterm VALUES (705, 22, 'STS', 'Short (typically a few hundred base pairs) DNA sequence that has a single occurrence in a genome and whose location and base sequence are known. [http://www.biospace.com]', 710, 0, 0);
INSERT INTO chado.cvterm VALUES (706, 22, 'coding_conserved_region', 'Coding region of sequence similarity by descent from a common ancestor. [SO:ke]', 711, 0, 0);
INSERT INTO chado.cvterm VALUES (707, 22, 'exon_junction', 'The boundary between two exons in a processed transcript. [SO:ke]', 712, 0, 0);
INSERT INTO chado.cvterm VALUES (708, 22, 'nc_conserved_region', 'Non-coding region of sequence similarity by descent from a common ancestor. [SO:ke]', 713, 0, 0);
INSERT INTO chado.cvterm VALUES (709, 22, 'mRNA_with_minus_2_frameshift', 'A mRNA with a minus 2 frameshift. [SO:ke]', 714, 0, 0);
INSERT INTO chado.cvterm VALUES (710, 22, 'minus_2_frameshift', 'A frameshift caused by deleting two bases. [SO:ke]', 715, 0, 0);
INSERT INTO chado.cvterm VALUES (711, 22, 'RNAi_reagent', 'A double stranded RNA duplex, at least 20bp long, used experimentally to inhibit gene function by RNA interference. [SO:rd]', 716, 0, 0);
INSERT INTO chado.cvterm VALUES (712, 22, 'ds_oligo', 'A double stranded oligonucleotide. [SO:ke]', 717, 0, 0);
INSERT INTO chado.cvterm VALUES (713, 22, 'MITE', 'A highly repetitive and short (100-500 base pair) transposable element with terminal inverted repeats (TIR) and target site duplication (TSD). MITEs do not encode proteins. [http://www.pnas.org/cgi/content/full/97/18/10083]', 718, 0, 0);
INSERT INTO chado.cvterm VALUES (714, 22, 'recombination_hotspot', 'A region in a genome which promotes recombination. [SO:rd]', 719, 0, 0);
INSERT INTO chado.cvterm VALUES (715, 22, 'chromosome', 'Structural unit composed of a nucleic acid molecule which controls its own replication through the interaction of specific proteins at one or more origins of replication. [SO:ma]', 720, 0, 0);
INSERT INTO chado.cvterm VALUES (716, 22, 'chromosome_band', 'A cytologically distinguishable feature of a chromosome, often made visible by staining, and usually alternating light and dark. [SO:ma]', 721, 0, 0);
INSERT INTO chado.cvterm VALUES (717, 22, 'site_specific_recombination_target_region', 'A region specifically recognised by a recombinase where recombination can occur during mitosis or meiosis. []', 722, 0, 0);
INSERT INTO chado.cvterm VALUES (718, 22, 'splicing_regulatory_region', 'A regulatory_region that modulates splicing. [SO:ke]', 723, 0, 0);
INSERT INTO chado.cvterm VALUES (719, 22, 'EST', 'A tag produced from a single sequencing read from a cDNA clone or PCR product; typically a few hundred base pairs long. [SO:ke]', 724, 0, 0);
INSERT INTO chado.cvterm VALUES (720, 22, 'loxP_site', 'Cre-Recombination target sequence. []', 725, 0, 0);
INSERT INTO chado.cvterm VALUES (721, 22, 'resolution_site', 'A region specifically recognized by a recombinase, which separates a physically contiguous circle of DNA into two physically separate circles. [SO:as]', 726, 0, 0);
INSERT INTO chado.cvterm VALUES (722, 22, 'nucleic_acid', 'An attribute describing a sequence consisting of nucleobases bound to repeating units. The forms found in nature are deoxyribonucleic acid (DNA), where the repeating units are 2-deoxy-D-ribose rings connected to a phosphate backbone, and ribonucleic acid (RNA), where the repeating units are D-ribose rings connected to a phosphate backbone. [CHEBI:33696, RSC:cb]', 727, 0, 0);
INSERT INTO chado.cvterm VALUES (723, 22, 'polymer_attribute', 'An attribute to describe the kind of biological sequence. [SO:ke]', 728, 0, 0);
INSERT INTO chado.cvterm VALUES (724, 22, 'protein_match', 'A match against a protein sequence. [SO:ke]', 729, 0, 0);
INSERT INTO chado.cvterm VALUES (725, 22, 'FRT_site', 'An inversion site found on the Saccharomyces cerevisiae 2 micron plasmid. [SO:ma]', 730, 0, 0);
INSERT INTO chado.cvterm VALUES (726, 22, 'inversion_site', 'A region specifically recognised by a recombinase, which inverts the region flanked by a pair of sites. [SO:ma]', 731, 0, 0);
INSERT INTO chado.cvterm VALUES (727, 22, 'synthetic_sequence', 'An attribute to decide a sequence of nucleotides, nucleotide analogs, or amino acids that has been designed by an experimenter and which may, or may not, correspond with any natural sequence. [SO:ma]', 732, 0, 0);
INSERT INTO chado.cvterm VALUES (728, 22, 'DNA', 'An attribute describing a sequence consisting of nucleobases bound to a repeating unit made of a 2-deoxy-D-ribose ring connected to a phosphate backbone. [RSC:cb]', 733, 0, 0);
INSERT INTO chado.cvterm VALUES (729, 22, 'assembly', 'A region of the genome of known length that is composed by ordering and aligning two or more different regions. [SO:ke]', 734, 0, 0);
INSERT INTO chado.cvterm VALUES (730, 22, 'group_1_intron_homing_endonuclease_target_region', 'A region of intronic nucleotide sequence targeted by a nuclease enzyme. [SO:ke]', 735, 0, 0);
INSERT INTO chado.cvterm VALUES (731, 22, 'haplotype_block', 'A region of the genome which is co-inherited as the result of the lack of historic recombination within it. [SO:ma]', 736, 0, 0);
INSERT INTO chado.cvterm VALUES (732, 22, 'RNA', 'An attribute describing a sequence consisting of nucleobases bound to a repeating unit made of a D-ribose ring connected to a phosphate backbone. [RSC:cb]', 737, 0, 0);
INSERT INTO chado.cvterm VALUES (733, 22, 'flanked', 'An attribute describing a region that is bounded either side by a particular kind of region. [SO:ke]', 738, 0, 0);
INSERT INTO chado.cvterm VALUES (734, 22, 'floxed', 'An attribute describing sequence that is flanked by Lox-P sites. [SO:ke]', 739, 0, 0);
INSERT INTO chado.cvterm VALUES (735, 22, 'FRT_flanked', 'An attribute to describe sequence that is flanked by the FLP recombinase recognition site, FRT. [SO:ke]', 740, 0, 0);
INSERT INTO chado.cvterm VALUES (736, 22, 'invalidated_by_chimeric_cDNA', 'A cDNA clone constructed from more than one mRNA. Usually an experimental artifact. [SO:ma]', 741, 0, 0);
INSERT INTO chado.cvterm VALUES (737, 22, 'invalidated', 'An attribute describing a feature that is invalidated. [SO:ke]', 742, 0, 0);
INSERT INTO chado.cvterm VALUES (738, 22, 'floxed_gene', 'A transgene that is floxed. [SO:xp]', 743, 0, 0);
INSERT INTO chado.cvterm VALUES (739, 22, 'transgene', 'A transgene is a gene that has been transferred naturally or by any of a number of genetic engineering techniques from one organism to another. [SO:xp]', 744, 0, 0);
INSERT INTO chado.cvterm VALUES (740, 22, 'transposable_element_flanking_region', 'The region of sequence surrounding a transposable element. [SO:ke]', 745, 0, 0);
INSERT INTO chado.cvterm VALUES (741, 22, 'integron', 'A region encoding an integrase which acts at a site adjacent to it (attI_site) to insert DNA which must include but is not limited to an attC_site. [SO:as]', 746, 0, 0);
INSERT INTO chado.cvterm VALUES (742, 22, 'insertion_site', 'The junction where an insertion occurred. [SO:ke]', 747, 0, 0);
INSERT INTO chado.cvterm VALUES (743, 22, 'attI_site', 'A region within an integron, adjacent to an integrase, at which site specific recombination involving an attC_site takes place. [SO:as]', 748, 0, 0);
INSERT INTO chado.cvterm VALUES (744, 22, 'integration_excision_site', 'A region specifically recognised by a recombinase, which inserts or removes another region marked by a distinct cognate integration/excision site. [SO:as]', 749, 0, 0);
INSERT INTO chado.cvterm VALUES (745, 22, 'transposable_element_insertion_site', 'The junction in a genome where a transposable_element has inserted. [SO:ke]', 750, 0, 0);
INSERT INTO chado.cvterm VALUES (746, 22, 'integrase_coding_region', '', 751, 1, 0);
INSERT INTO chado.cvterm VALUES (747, 22, 'conjugative_transposon', 'A transposon that encodes function required for conjugation. [http://www.sci.sdsu.edu/~smaloy/Glossary/C.html]', 752, 0, 0);
INSERT INTO chado.cvterm VALUES (748, 22, 'enzymatic_RNA', 'An RNA sequence that has catalytic activity with or without an associated ribonucleoprotein. [RSC:cb]', 753, 0, 0);
INSERT INTO chado.cvterm VALUES (749, 22, 'enzymatic', 'An attribute describing the sequence of a transcript that has catalytic activity with or without an associated ribonucleoprotein. [RSC:cb]', 754, 0, 0);
INSERT INTO chado.cvterm VALUES (750, 22, 'recombinationally_inverted_gene', 'A recombinationally rearranged gene by inversion. [SO:xp]', 755, 0, 0);
INSERT INTO chado.cvterm VALUES (751, 22, 'recombinationally_rearranged_gene', 'A gene that is recombinationally rearranged. [SO:ke]', 756, 0, 0);
INSERT INTO chado.cvterm VALUES (752, 22, 'inversion', 'A continuous nucleotide sequence is inverted in the same position. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 757, 0, 0);
INSERT INTO chado.cvterm VALUES (753, 22, 'ribozyme', 'An RNA with catalytic activity. [SO:ma]', 758, 0, 0);
INSERT INTO chado.cvterm VALUES (754, 22, 'ribozymic', 'An attribute describing the sequence of a transcript that has catalytic activity even without an associated ribonucleoprotein. [RSC:cb]', 759, 0, 0);
INSERT INTO chado.cvterm VALUES (755, 22, 'cytosolic_5_8S_rRNA', 'Cytosolic 5.8S rRNA is an RNA component of the large subunit of cytosolic ribosomes in eukaryotes. [https://rfam.xfam.org/family/RF00002]', 760, 0, 0);
INSERT INTO chado.cvterm VALUES (756, 22, 'cytosolic_LSU_rRNA', 'Cytosolic LSU rRNA is an RNA component of the large subunit of cytosolic ribosomes. [SO:ke]', 761, 0, 0);
INSERT INTO chado.cvterm VALUES (757, 22, 'cytosolic_rRNA_5_8S_gene', 'A gene which codes for 5_8S_rRNA (5.8S rRNA), which functions as a component of the large subunit of the ribosome in eukaryotes. []', 762, 0, 0);
INSERT INTO chado.cvterm VALUES (758, 22, 'RNA_6S', 'A small (184-nt in E. coli) RNA that forms a hairpin type structure. 6S RNA associates with RNA polymerase in a highly specific manner. 6S RNA represses expression from a sigma70-dependent promoter during stationary phase. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00013]', 763, 0, 0);
INSERT INTO chado.cvterm VALUES (759, 22, 'CsrB_RsmB_RNA', 'An enterobacterial RNA that binds the CsrA protein. The CsrB RNAs contain a conserved motif CAGGXXG that is found in up to 18 copies and has been suggested to bind CsrA. The Csr regulatory system has a strong negative regulatory effect on glycogen biosynthesis, glyconeogenesis and glycogen catabolism and a positive regulatory effect on glycolysis. In other bacteria such as Erwinia caratovara the RsmA protein has been shown to regulate the production of virulence determinants, such extracellular enzymes. RsmA binds to RsmB regulatory RNA which is also a member of this family. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00018]', 764, 0, 0);
INSERT INTO chado.cvterm VALUES (760, 22, 'DsrA_RNA', 'DsrA RNA regulates both transcription, by overcoming transcriptional silencing by the nucleoid-associated H-NS protein, and translation, by promoting efficient translation of the stress sigma factor, RpoS. These two activities of DsrA can be separated by mutation: the first of three stem-loops of the 85 nucleotide RNA is necessary for RpoS translation but not for anti-H-NS action, while the second stem-loop is essential for antisilencing and less critical for RpoS translation. The third stem-loop, which behaves as a transcription terminator, can be substituted by the trp transcription terminator without loss of either DsrA function. The sequence of the first stem-loop of DsrA is complementary with the upstream leader portion of RpoS messenger RNA, suggesting that pairing of DsrA with the RpoS message might be important for translational regulation. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00014]', 765, 0, 0);
INSERT INTO chado.cvterm VALUES (761, 22, 'GcvB_RNA', 'A small untranslated RNA involved in expression of the dipeptide and oligopeptide transport systems in Escherichia coli. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00022]', 766, 0, 0);
INSERT INTO chado.cvterm VALUES (762, 22, 'hammerhead_ribozyme', 'A small catalytic RNA motif that catalyzes self-cleavage reaction. Its name comes from its secondary structure which resembles a carpenter''s hammer. The hammerhead ribozyme is involved in the replication of some viroid and some satellite RNAs. [PMID:2436805]', 767, 0, 0);
INSERT INTO chado.cvterm VALUES (763, 22, 'group_IIA_intron', 'A group II intron that recognizes IBS1/EBS1 and IBS2/EBS2 for the 5-prime exon and gamma/gamma-prime for the 3-prime exon. [PMID:20463000]', 768, 0, 0);
INSERT INTO chado.cvterm VALUES (779, 22, 'U5_snRNA', 'U5 RNA is a component of both types of known spliceosome. The precise function of this molecule is unknown, though it is known that the 5'' loop is required for splice site selection and p220 binding, and that both the 3'' stem-loop and the Sm site are important for Sm protein binding and cap methylation. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00020]', 784, 0, 0);
INSERT INTO chado.cvterm VALUES (780, 22, 'U6_snRNA', 'U6 snRNA is a component of the spliceosome which is involved in splicing pre-mRNA. The putative secondary structure consensus base pairing is confined to a short 5'' stem loop, but U6 snRNA is thought to form extensive base-pair interactions with U4 snRNA. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00015]', 785, 0, 0);
INSERT INTO chado.cvterm VALUES (812, 22, 'mature_protein_region', 'The polypeptide sequence that remains when the cleaved peptide regions have been cleaved from the immature peptide. [EBIBS:GAR, http://www.insdc.org/files/feature_table.html, SO:cb]', 823, 0, 0);
INSERT INTO chado.cvterm VALUES (764, 22, 'group_II_intron', 'Group II introns are found in rRNA, tRNA and mRNA of organelles in fungi, plants and protists, and also in mRNA in bacteria. They are large self-splicing ribozymes and have 6 structural domains (usually designated dI to dVI). A subset of group II introns also encode essential splicing proteins in intronic ORFs. The length of these introns can therefore be up to 3kb. Splicing occurs in almost identical fashion to nuclear pre-mRNA splicing with two transesterification steps. The 2'' hydroxyl of a bulged adenosine in domain VI attacks the 5'' splice site, followed by nucleophilic attack on the 3'' splice site by the 3'' OH of the upstream exon. Protein machinery is required for splicing in vivo, and long range intron to intron and intron-exon interactions are important for splice site positioning. Group II introns are further sub-classified into groups IIA and IIB which differ in splice site consensus, distance of bulged A from 3'' splice site, some tertiary interactions, and intronic ORF phylogeny. [http://www.sanger.ac.uk/Software/Rfam/browse/index.shtml]', 769, 0, 0);
INSERT INTO chado.cvterm VALUES (765, 22, 'group_IIB_intron', 'A group II intron that recognizes IBS1/EBS1 and IBS2/EBS2 for the 5-prime exon and IBS3/EBS3 for the 3-prime exon. [PMID:20463000]', 770, 0, 0);
INSERT INTO chado.cvterm VALUES (766, 22, 'MicF_RNA', 'A non-translated 93 nt antisense RNA that binds its target ompF mRNA and regulates ompF expression by inhibiting translation and inducing degradation of the message. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00033]', 771, 0, 0);
INSERT INTO chado.cvterm VALUES (767, 22, 'antisense_RNA', 'Antisense RNA is RNA that is transcribed from the coding, rather than the template, strand of DNA. It is therefore complementary to mRNA. [SO:ke]', 772, 0, 0);
INSERT INTO chado.cvterm VALUES (768, 22, 'OxyS_RNA', 'A small untranslated RNA which is induced in response to oxidative stress in Escherichia coli. Acts as a global regulator to activate or repress the expression of as many as 40 genes, including the fhlA-encoded transcriptional activator and the rpoS-encoded sigma(s) subunit of RNA polymerase. OxyS is bound by the Hfq protein, that increases the OxyS RNA interaction with its target messages. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00035]', 773, 0, 0);
INSERT INTO chado.cvterm VALUES (769, 22, 'RNase_MRP_RNA', 'The RNA molecule essential for the catalytic activity of RNase MRP, an enzymatically active ribonucleoprotein with two distinct roles in eukaryotes. In mitochondria it plays a direct role in the initiation of mitochondrial DNA replication. In the nucleus it is involved in precursor rRNA processing, where it cleaves the internal transcribed spacer 1 between 18S and 5.8S rRNAs. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00030]', 774, 0, 0);
INSERT INTO chado.cvterm VALUES (770, 22, 'RNase_P_RNA', 'The RNA component of Ribonuclease P (RNase P), a ubiquitous endoribonuclease, found in archaea, bacteria and eukarya as well as chloroplasts and mitochondria. Its best characterized activity is the generation of mature 5 prime ends of tRNAs by cleaving the 5 prime leader elements of precursor-tRNAs. Cellular RNase Ps are ribonucleoproteins. RNA from bacterial RNase Ps retains its catalytic activity in the absence of the protein subunit, i.e. it is a ribozyme. Isolated eukaryotic and archaeal RNase P RNA has not been shown to retain its catalytic function, but is still essential for the catalytic activity of the holoenzyme. Although the archaeal and eukaryotic holoenzymes have a much greater protein content than the bacterial ones, the RNA cores from all the three lineages are homologous. Helices corresponding to P1, P2, P3, P4, and P10/11 are common to all cellular RNase P RNAs. Yet, there is considerable sequence variation, particularly among the eukaryotic RNAs. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00010]', 775, 0, 0);
INSERT INTO chado.cvterm VALUES (771, 22, 'RprA_RNA', 'Translational regulation of the stationary phase sigma factor RpoS is mediated by the formation of a double-stranded RNA stem-loop structure in the upstream region of the rpoS messenger RNA, occluding the translation initiation site. Clones carrying rprA (RpoS regulator RNA) increased the translation of RpoS. The rprA gene encodes a 106 nucleotide regulatory RNA. As with DsrA Rfam:RF00014, RprA is predicted to form three stem-loops. Thus, at least two small RNAs, DsrA and RprA, participate in the positive regulation of RpoS translation. Unlike DsrA, RprA does not have an extensive region of complementarity to the RpoS leader, leaving its mechanism of action unclear. RprA is non-essential. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00034]', 776, 0, 0);
INSERT INTO chado.cvterm VALUES (772, 22, 'RRE_RNA', 'The Rev response element (RRE) is encoded within the HIV-env gene. Rev is an essential regulatory protein of HIV that binds an internal loop of the RRE leading, encouraging further Rev-RRE binding. This RNP complex is critical for mRNA export and hence for expression of the HIV structural proteins. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00036]', 777, 0, 0);
INSERT INTO chado.cvterm VALUES (773, 22, 'spot_42_RNA', 'A 109-nucleotide RNA of E. coli that seems to have a regulatory role on the galactose operon. Changes in Spot 42 levels are implicated in affecting DNA polymerase I levels. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00021]', 778, 0, 0);
INSERT INTO chado.cvterm VALUES (774, 22, 'telomerase_RNA', 'The RNA component of telomerase, a reverse transcriptase that synthesizes telomeric DNA. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00025]', 779, 0, 0);
INSERT INTO chado.cvterm VALUES (775, 22, 'U1_snRNA', 'U1 is a small nuclear RNA (snRNA) component of the spliceosome (involved in pre-mRNA splicing). Its 5'' end forms complementary base pairs with the 5'' splice junction, thus defining the 5'' donor site of an intron. There are significant differences in sequence and secondary structure between metazoan and yeast U1 snRNAs, the latter being much longer (568 nucleotides as compared to 164 nucleotides in human). Nevertheless, secondary structure predictions suggest that all U1 snRNAs share a ''common core'' consisting of helices I, II, the proximal region of III, and IV. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00003]', 780, 0, 0);
INSERT INTO chado.cvterm VALUES (776, 22, 'U2_snRNA', 'U2 is a small nuclear RNA (snRNA) component of the spliceosome (involved in pre-mRNA splicing). Complementary binding between U2 snRNA (in an area lying towards the 5'' end but 3'' to hairpin I) and the branchpoint sequence (BPS) of the intron results in the bulging out of an unpaired adenine, on the BPS, which initiates a nucleophilic attack at the intronic 5'' splice site, thus starting the first of two transesterification reactions that mediate splicing. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00004]', 781, 0, 0);
INSERT INTO chado.cvterm VALUES (777, 22, 'U4_snRNA', 'U4 small nuclear RNA (U4 snRNA) is a component of the major U2-dependent spliceosome. It forms a duplex with U6, and with each splicing round, it is displaced from U6 (and the spliceosome) in an ATP-dependent manner, allowing U6 to refold and create the active site for splicing catalysis. A recycling process involving protein Prp24 re-anneals U4 and U6. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00015]', 782, 0, 0);
INSERT INTO chado.cvterm VALUES (778, 22, 'U4atac_snRNA', 'An snRNA required for the splicing of the minor U12-dependent class of eukaryotic nuclear introns. It forms a base paired complex with U6atac_snRNA (SO:0000397). [PMID:12409455]', 783, 0, 0);
INSERT INTO chado.cvterm VALUES (811, 22, 'propeptide', 'Part of a peptide chain which is cleaved off during the formation of the mature protein. [EBIBS:GAR]', 822, 0, 0);
INSERT INTO chado.cvterm VALUES (781, 22, 'U6atac_snRNA', 'U6atac_snRNA is an snRNA required for the splicing of the minor U12-dependent class of eukaryotic nuclear introns. It forms a base paired complex with U4atac_snRNA (SO:0000394). [http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=retrieve&db=pubmed&list_uids=12409455&dopt=Abstract]', 786, 0, 0);
INSERT INTO chado.cvterm VALUES (782, 22, 'U11_snRNA', 'U11 snRNA plays a role in splicing of the minor U12-dependent class of eukaryotic nuclear introns, similar to U1 snRNA in the major class spliceosome it base pairs to the conserved 5'' splice site sequence. [PMID:9622129]', 787, 0, 0);
INSERT INTO chado.cvterm VALUES (783, 22, 'U12_snRNA', 'The U12 small nuclear (snRNA), together with U4atac/U6atac, U5, and U11 snRNAs and associated proteins, forms a spliceosome that cleaves a divergent class of low-abundance pre-mRNA introns. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00007]', 788, 0, 0);
INSERT INTO chado.cvterm VALUES (784, 22, 'sequence_attribute', 'An attribute describes a quality of sequence. [SO:ke]', 789, 0, 0);
INSERT INTO chado.cvterm VALUES (785, 22, 'enhancer_attribute', '', 790, 1, 0);
INSERT INTO chado.cvterm VALUES (786, 22, 'U14_snoRNA', 'U14 small nucleolar RNA (U14 snoRNA) is required for early cleavages of eukaryotic precursor rRNAs. In yeasts, this molecule possess a stem-loop region (known as the Y-domain) which is essential for function. A similar structure, but with a different consensus sequence, is found in plants, but is absent in vertebrates. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00016, PMID:2551119]', 791, 0, 0);
INSERT INTO chado.cvterm VALUES (787, 22, 'C_D_box_snoRNA', 'Most box C/D snoRNAs also contain long (>10 nt) sequences complementary to rRNA. Boxes C and D, as well as boxes C'' and D'', are usually located in close proximity, and form a structure known as the box C/D motif. This motif is important for snoRNA stability, processing, nucleolar targeting and function. A small number of box C/D snoRNAs are involved in rRNA processing; most, however, are known or predicted to serve as guide RNAs in ribose methylation of rRNA. Targeting involves direct base pairing of the snoRNA at the rRNA site to be modified and selection of a rRNA nucleotide a fixed distance from box D or D''. [http://www.bio.umass.edu/biochem/rna-sequence/Yeast_snoRNA_Database/snoRNA_DataBase.html]', 793, 0, 0);
INSERT INTO chado.cvterm VALUES (788, 22, 'U14_snoRNA_primary_transcript', 'The primary transcript of an evolutionarily conserved eukaryotic low molecular weight RNA capable of intermolecular hybridization with both homologous and heterologous 18S rRNA. [PMID:2251119]', 794, 0, 0);
INSERT INTO chado.cvterm VALUES (789, 22, 'vault_RNA', 'A family of RNAs are found as part of the enigmatic vault ribonucleoprotein complex. The complex consists of a major vault protein (MVP), two minor vault proteins (VPARP and TEP1), and several small untranslated RNA molecules. It has been suggested that the vault complex is involved in drug resistance. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00006]', 795, 0, 0);
INSERT INTO chado.cvterm VALUES (790, 22, 'Y_RNA', 'Y RNAs are components of the Ro ribonucleoprotein particle (Ro RNP), in association with Ro60 and La proteins. The Y RNAs and Ro60 and La proteins are well conserved, but the function of the Ro RNP is not known. In humans the RNA component can be one of four small RNAs: hY1, hY3, hY4 and hY5. These small RNAs are predicted to fold into a conserved secondary structure containing three stem structures. The largest of the four, hY1, contains an additional hairpin. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00019]', 796, 0, 0);
INSERT INTO chado.cvterm VALUES (791, 22, 'twintron', 'An intron within an intron. Twintrons are group II or III introns, into which another group II or III intron has been transposed. [PMID:1899376, PMID:7823908]', 797, 0, 0);
INSERT INTO chado.cvterm VALUES (792, 22, 'cytosolic_18S_rRNA', 'Cytosolic 18S rRNA is an RNA component of the small subunit of cytosolic ribosomes in eukaryotes. [SO:ke]', 798, 0, 0);
INSERT INTO chado.cvterm VALUES (793, 22, 'cytosolic_SSU_rRNA', 'Cytosolic SSU rRNA is an RNA component of the small subunit of cytosolic ribosomes. [SO:ke]', 799, 0, 0);
INSERT INTO chado.cvterm VALUES (794, 22, 'cytosolic_rRNA_18S_gene', 'A gene which codes for 18S_rRNA, which functions as the small subunit of the ribosome in eukaryotes. []', 800, 0, 0);
INSERT INTO chado.cvterm VALUES (795, 22, 'site', 'The interbase position where something (eg an aberration) occurred. [SO:ke]', 801, 1, 0);
INSERT INTO chado.cvterm VALUES (796, 22, 'binding_site', 'A biological_region of sequence that, in the molecule, interacts selectively and non-covalently with other molecules. A region on the surface of a molecule that may interact with another molecule. When applied to polypeptides: Amino acids involved in binding or interactions. It can also apply to an amino acid bond which is represented by the positions of the two flanking amino acids. [EBIBS:GAR, SO:ke]', 802, 0, 0);
INSERT INTO chado.cvterm VALUES (797, 22, 'protein_binding_site', 'A binding site that, in the molecule, interacts selectively and non-covalently with polypeptide molecules. [SO:ke]', 804, 0, 0);
INSERT INTO chado.cvterm VALUES (798, 22, 'rescue_region', 'A region that rescues. [SO:xp]', 805, 0, 0);
INSERT INTO chado.cvterm VALUES (799, 22, 'rescue', 'An attribute describing a region''s ability, when introduced to a mutant organism, to re-establish (rescue) a phenotype. [SO:ke]', 806, 0, 0);
INSERT INTO chado.cvterm VALUES (800, 22, 'sequence_difference', 'A region where the sequence differs from that of a specified sequence. [SO:ke]', 807, 0, 0);
INSERT INTO chado.cvterm VALUES (801, 22, 'remark', 'A comment about the sequence. [SO:ke]', 808, 0, 0);
INSERT INTO chado.cvterm VALUES (802, 22, 'invalidated_by_genomic_contamination', 'An attribute to describe a feature that is invalidated due to genomic contamination. [SO:ke]', 809, 0, 0);
INSERT INTO chado.cvterm VALUES (803, 22, 'invalidated_by_genomic_polyA_primed_cDNA', 'An attribute to describe a feature that is invalidated due to polyA priming. [SO:ke]', 810, 0, 0);
INSERT INTO chado.cvterm VALUES (804, 22, 'invalidated_by_partial_processing', 'An attribute to describe a feature that is invalidated due to partial processing. [SO:ke]', 811, 0, 0);
INSERT INTO chado.cvterm VALUES (805, 22, 'polypeptide_domain', 'A structurally or functionally defined protein region. In proteins with multiple domains, the combination of the domains determines the function of the protein. A region which has been shown to recur throughout evolution. [EBIBS:GAR]', 812, 0, 0);
INSERT INTO chado.cvterm VALUES (806, 22, 'polypeptide_structural_region', 'Region of polypeptide with a given structural property. [EBIBS:GAR, SO:cb]', 816, 0, 0);
INSERT INTO chado.cvterm VALUES (807, 22, 'polypeptide_conserved_region', 'A subsection of sequence with biological interest that is conserved in different proteins. They may or may not have functional or structural significance within the proteins in which they are found. [EBIBS:GAR]', 817, 0, 0);
INSERT INTO chado.cvterm VALUES (808, 22, 'signal_peptide', 'The signal_peptide is a short region of the peptide located at the N-terminus that directs the protein to be secreted or part of membrane components. [http://www.insdc.org/files/feature_table.html]', 818, 0, 0);
INSERT INTO chado.cvterm VALUES (809, 22, 'peptide_localization_signal', 'A region of peptide sequence used to target the polypeptide molecule to a specific organelle. [SO:ke]', 820, 0, 0);
INSERT INTO chado.cvterm VALUES (810, 22, 'signal_peptide_region_of_CDS', 'A CDS region corresponding to a signal peptide of a polypeptide. []', 821, 0, 0);
INSERT INTO chado.cvterm VALUES (1959, 22, 'RNase_MRP_RNA_gene', 'A gene that encodes a RNase_MRP_RNA. [SO:ke]', 2216, 0, 0);
INSERT INTO chado.cvterm VALUES (813, 22, 'polypeptide_region', 'Biological sequence region that can be assigned to a specific subsequence of a polypeptide. [SO:GAR, SO:ke]', 825, 0, 0);
INSERT INTO chado.cvterm VALUES (814, 22, 'mature_protein_region_of_CDS', 'A CDS region corresponding to a mature protein region of a polypeptide. []', 826, 0, 0);
INSERT INTO chado.cvterm VALUES (815, 22, 'immature_peptide_region', 'An immature_peptide_region is the extent of the peptide after it has been translated and before any processing occurs. [EBIBS:GAR]', 827, 0, 0);
INSERT INTO chado.cvterm VALUES (816, 22, 'five_prime_terminal_inverted_repeat', 'An inverted repeat (SO:0000294) occurring at the 5-prime termini of a DNA transposon. []', 828, 0, 0);
INSERT INTO chado.cvterm VALUES (817, 22, 'terminal_inverted_repeat', 'An inverted repeat (SO:0000294) occurring at the termini of a DNA transposon. [SO:ke]', 829, 0, 0);
INSERT INTO chado.cvterm VALUES (818, 22, 'three_prime_terminal_inverted_repeat', 'An inverted repeat (SO:0000294) occurring at the 3-prime termini of a DNA transposon. []', 830, 0, 0);
INSERT INTO chado.cvterm VALUES (819, 22, 'U5_LTR_region', 'The U5 segment of the long terminal repeats. []', 831, 0, 0);
INSERT INTO chado.cvterm VALUES (820, 22, 'LTR_component', 'The long terminal repeat found at the ends of the sequence to be inserted into the host genome. []', 832, 0, 0);
INSERT INTO chado.cvterm VALUES (821, 22, 'R_LTR_region', 'The R segment of the long terminal repeats. []', 833, 0, 0);
INSERT INTO chado.cvterm VALUES (822, 22, 'U3_LTR_region', 'The U3 segment of the long terminal repeats. []', 834, 0, 0);
INSERT INTO chado.cvterm VALUES (823, 22, 'five_prime_LTR', 'The long terminal repeat found at the five-prime end of the sequence to be inserted into the host genome. []', 835, 0, 0);
INSERT INTO chado.cvterm VALUES (824, 22, 'three_prime_LTR', 'The long terminal repeat found at the three-prime end of the sequence to be inserted into the host genome. []', 836, 0, 0);
INSERT INTO chado.cvterm VALUES (825, 22, 'R_five_prime_LTR_region', 'The R segment of the three-prime long terminal repeat. []', 837, 0, 0);
INSERT INTO chado.cvterm VALUES (826, 22, 'five_prime_LTR_component', 'A component of the five-prime long terminal repeat. [PMID:8649407]', 838, 0, 0);
INSERT INTO chado.cvterm VALUES (827, 22, 'U5_five_prime_LTR_region', 'The U5 segment of the three-prime long terminal repeat. []', 839, 0, 0);
INSERT INTO chado.cvterm VALUES (828, 22, 'U3_five_prime_LTR_region', 'The U3 segment of the three-prime long terminal repeat. []', 840, 0, 0);
INSERT INTO chado.cvterm VALUES (829, 22, 'R_three_prime_LTR_region', 'The R segment of the three-prime long terminal repeat. []', 841, 0, 0);
INSERT INTO chado.cvterm VALUES (830, 22, 'three_prime_LTR_component', 'A component of the three-prime long terminal repeat. [PMID:8649407]', 842, 0, 0);
INSERT INTO chado.cvterm VALUES (831, 22, 'U3_three_prime_LTR_region', 'The U3 segment of the three-prime long terminal repeat. []', 843, 0, 0);
INSERT INTO chado.cvterm VALUES (832, 22, 'U5_three_prime_LTR_region', 'The U5 segment of the three-prime long terminal repeat. []', 844, 0, 0);
INSERT INTO chado.cvterm VALUES (833, 22, 'non_LTR_retrotransposon_polymeric_tract', 'A polymeric tract, such as poly(dA), within a non_LTR_retrotransposon. [SO:ke]', 845, 0, 0);
INSERT INTO chado.cvterm VALUES (834, 22, 'repeat_component', 'A region of a repeated sequence. [SO:ke]', 846, 0, 0);
INSERT INTO chado.cvterm VALUES (835, 22, 'target_site_duplication', 'A sequence of the target DNA that is duplicated when a transposable element or phage inserts; usually found at each end the insertion. [http://www.koko.gov.my/CocoaBioTech/Glossaryt.html]', 847, 0, 0);
INSERT INTO chado.cvterm VALUES (836, 22, 'RR_tract', 'A polypurine tract within an LTR_retrotransposon. [SO:ke]', 848, 0, 0);
INSERT INTO chado.cvterm VALUES (837, 22, 'ARS', 'A sequence that can autonomously replicate, as a plasmid, when transformed into a bacterial host. [SO:ma]', 849, 0, 0);
INSERT INTO chado.cvterm VALUES (838, 22, 'assortment_derived_duplication', '', 850, 1, 0);
INSERT INTO chado.cvterm VALUES (839, 22, 'gene_not_polyadenylated', '', 851, 1, 0);
INSERT INTO chado.cvterm VALUES (840, 22, 'inverted_ring_chromosome', 'A ring chromosome is a chromosome whose arms have fused together to form a ring in an inverted fashion, often with the loss of the ends of the chromosome. []', 852, 0, 0);
INSERT INTO chado.cvterm VALUES (841, 22, 'chromosomal_inversion', 'An interchromosomal mutation where a region of the chromosome is inverted with respect to wild type. [SO:ke]', 853, 0, 0);
INSERT INTO chado.cvterm VALUES (842, 22, 'ring_chromosome', 'A ring chromosome is a chromosome whose arms have fused together to form a ring, often with the loss of the ends of the chromosome. [http://en.wikipedia.org/wiki/Ring_chromosome]', 854, 0, 0);
INSERT INTO chado.cvterm VALUES (843, 22, 'three_prime_noncoding_exon', 'Non-coding exon in the 3'' UTR. [SO:ke]', 855, 0, 0);
INSERT INTO chado.cvterm VALUES (844, 22, 'five_prime_noncoding_exon', 'Non-coding exon in the 5'' UTR. [SO:ke]', 856, 0, 0);
INSERT INTO chado.cvterm VALUES (845, 22, 'UTR_intron', 'Intron located in the untranslated region. [SO:ke]', 857, 0, 0);
INSERT INTO chado.cvterm VALUES (846, 22, 'five_prime_UTR_intron', 'An intron located in the 5'' UTR. [SO:ke]', 858, 0, 0);
INSERT INTO chado.cvterm VALUES (847, 22, 'three_prime_UTR_intron', 'An intron located in the 3'' UTR. [SO:ke]', 859, 0, 0);
INSERT INTO chado.cvterm VALUES (848, 22, 'random_sequence', 'A sequence of nucleotides or amino acids which, by design, has a \"random\" order of components, given a predetermined input frequency of these components. [SO:ma]', 860, 0, 0);
INSERT INTO chado.cvterm VALUES (849, 22, 'interband', 'A light region between two darkly staining bands in a polytene chromosome. [SO:ma]', 861, 0, 0);
INSERT INTO chado.cvterm VALUES (850, 22, 'gene_with_polyadenylated_mRNA', 'A gene that encodes a polyadenylated mRNA. [SO:xp]', 862, 0, 0);
INSERT INTO chado.cvterm VALUES (851, 22, 'protein_coding_gene', 'A gene that codes for an RNA that can be translated into a protein. []', 863, 0, 0);
INSERT INTO chado.cvterm VALUES (852, 22, 'polyadenylated_mRNA', 'An mRNA that is polyadenylated. [SO:xp]', 864, 0, 0);
INSERT INTO chado.cvterm VALUES (853, 22, 'transgene_attribute', '', 865, 1, 0);
INSERT INTO chado.cvterm VALUES (854, 22, 'chromosomal_transposition', 'A chromosome structure variant whereby a region of a chromosome has been transferred to another position. Among interchromosomal rearrangements, the term transposition is reserved for that class in which the telomeres of the chromosomes involved are coupled (that is to say, form the two ends of a single DNA molecule) as in wild-type. [FB:reference_manual, SO:ke]', 866, 0, 0);
INSERT INTO chado.cvterm VALUES (855, 22, 'rasiRNA', 'A 17-28-nt, small interfering RNA derived from transcripts of repetitive elements. [http://www.developmentalcell.com/content/article/abstract?uid=PIIS1534580703002284, PMID:18032451]', 867, 0, 0);
INSERT INTO chado.cvterm VALUES (856, 22, 'piRNA', 'A small non coding RNA, part of a silencing system that prevents the spreading of selfish genetic elements. [SO:ke]', 868, 0, 0);
INSERT INTO chado.cvterm VALUES (857, 22, 'gene_with_mRNA_with_frameshift', 'A gene that encodes an mRNA with a frameshift. [SO:xp]', 869, 0, 0);
INSERT INTO chado.cvterm VALUES (858, 22, 'recombinationally_rearranged', 'A gene that is recombinationally rearranged. []', 870, 0, 0);
INSERT INTO chado.cvterm VALUES (859, 22, 'interchromosomal_duplication', 'A chromosome duplication involving an insertion from another chromosome. [SO:ke]', 871, 0, 0);
INSERT INTO chado.cvterm VALUES (860, 22, 'chromosomal_duplication', 'An extra chromosome. [SO:ke]', 872, 0, 0);
INSERT INTO chado.cvterm VALUES (861, 22, 'D_gene_segment', 'Germline genomic DNA including D-region with 5'' UTR and 3'' UTR, also designated as D-segment. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 873, 0, 0);
INSERT INTO chado.cvterm VALUES (862, 22, 'vertebrate_immunoglobulin_T_cell_receptor_segment', 'Germline genomic DNA with the sequence for a V, D, C, or J portion of an immunoglobulin/T-cell receptor. []', 874, 0, 0);
INSERT INTO chado.cvterm VALUES (863, 22, 'gene_with_trans_spliced_transcript', 'A gene with a transcript that is trans-spliced. [SO:xp]', 875, 0, 0);
INSERT INTO chado.cvterm VALUES (864, 22, 'trans_spliced_transcript', 'A transcript that is trans-spliced. [SO:xp]', 876, 0, 0);
INSERT INTO chado.cvterm VALUES (865, 22, 'inversion_derived_bipartite_deficiency', 'A chromosomal deletion whereby a chromosome generated by recombination between two inversions; has a deficiency at each end of the inversion. [FB:km]', 877, 0, 0);
INSERT INTO chado.cvterm VALUES (866, 22, 'pseudogenic_region', 'A non-functional descendant of a functional entity. [SO:cjm]', 878, 0, 0);
INSERT INTO chado.cvterm VALUES (867, 22, 'encodes_alternately_spliced_transcripts', 'A gene that encodes more than one transcript. [SO:ke]', 879, 0, 0);
INSERT INTO chado.cvterm VALUES (868, 22, 'decayed_exon', 'A non-functional descendant of an exon. [SO:ke]', 880, 0, 0);
INSERT INTO chado.cvterm VALUES (869, 22, 'inversion_derived_deficiency_plus_duplication', 'A chromosome deletion whereby a chromosome is generated by recombination between two inversions; there is a deficiency at one end of the inversion and a duplication at the other end of the inversion. [FB:km]', 881, 0, 0);
INSERT INTO chado.cvterm VALUES (870, 22, 'intrachromosomal_duplication', 'A duplication that occurred within a chromosome. [SO:ke]', 882, 0, 0);
INSERT INTO chado.cvterm VALUES (871, 22, 'V_gene_segment', 'Germline genomic DNA including L-part1, V-intron and V-exon, with the 5'' UTR and 3'' UTR. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 883, 0, 0);
INSERT INTO chado.cvterm VALUES (872, 22, 'post_translationally_regulated_by_protein_stability', 'An attribute describing a gene sequence where the resulting protein is regulated by the stability of the resulting protein. [SO:ke]', 884, 0, 0);
INSERT INTO chado.cvterm VALUES (873, 22, 'golden_path_fragment', 'One of the pieces of sequence that make up a golden path. [SO:rd]', 885, 0, 0);
INSERT INTO chado.cvterm VALUES (874, 22, 'golden_path', 'A set of subregions selected from sequence contigs which when concatenated form a nonredundant linear sequence. [SO:ls]', 886, 0, 0);
INSERT INTO chado.cvterm VALUES (875, 22, 'post_translationally_regulated_by_protein_modification', 'An attribute describing a gene sequence where the resulting protein is modified to regulate it. [SO:ke]', 887, 0, 0);
INSERT INTO chado.cvterm VALUES (876, 22, 'J_gene_segment', 'Germline genomic DNA of an immunoglobulin/T-cell receptor gene including J-region with 5'' UTR (SO:0000204) and 3'' UTR (SO:0000205), also designated as J-segment. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 888, 0, 0);
INSERT INTO chado.cvterm VALUES (877, 22, 'autoregulated', 'The gene product is involved in its own transcriptional regulation. [SO:ke]', 889, 0, 0);
INSERT INTO chado.cvterm VALUES (878, 22, 'tiling_path', 'A set of regions which overlap with minimal polymorphism to form a linear sequence. [SO:cjm]', 890, 0, 0);
INSERT INTO chado.cvterm VALUES (879, 22, 'negatively_autoregulated', 'The gene product is involved in its own transcriptional regulation where it decreases transcription. [SO:ke]', 891, 0, 0);
INSERT INTO chado.cvterm VALUES (880, 22, 'tiling_path_fragment', 'A piece of sequence that makes up a tiling_path (SO:0000472). [SO:ke]', 892, 0, 0);
INSERT INTO chado.cvterm VALUES (881, 22, 'positively_autoregulated', 'The gene product is involved in its own transcriptional regulation, where it increases transcription. [SO:ke]', 893, 0, 0);
INSERT INTO chado.cvterm VALUES (882, 22, 'contig_read', 'A DNA sequencer read which is part of a contig. [SO:ke]', 894, 0, 0);
INSERT INTO chado.cvterm VALUES (883, 22, 'polycistronic_gene', 'A gene that is polycistronic. [SO:ke]', 895, 1, 0);
INSERT INTO chado.cvterm VALUES (884, 22, 'C_gene_segment', 'Genomic DNA of immunoglobulin/T-cell receptor gene including C-region (and introns if present) with 5'' UTR (SO:0000204) and 3'' UTR (SO:0000205). [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 896, 0, 0);
INSERT INTO chado.cvterm VALUES (885, 22, 'trans_spliced', 'An attribute describing transcript sequence that is created by splicing exons from diferent genes. [SO:ke]', 897, 0, 0);
INSERT INTO chado.cvterm VALUES (886, 22, 'tiling_path_clone', 'A clone which is part of a tiling path. A tiling path is a set of sequencing substrates, typically clones, which have been selected in order to efficiently cover a region of the genome in preparation for sequencing and assembly. [SO:ke]', 898, 0, 0);
INSERT INTO chado.cvterm VALUES (887, 22, 'vertebrate_immunoglobulin_T_cell_receptor_gene_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in germline configuration. []', 899, 0, 0);
INSERT INTO chado.cvterm VALUES (888, 22, 'three_prime_coding_exon_noncoding_region', 'The sequence of the 3'' exon that is not coding. [SO:ke]', 900, 0, 0);
INSERT INTO chado.cvterm VALUES (889, 22, 'noncoding_region_of_exon', 'The maximal intersection of exon and UTR. [SO:ke]', 901, 0, 0);
INSERT INTO chado.cvterm VALUES (890, 22, 'DJ_J_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one DJ-gene, and one J-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 902, 0, 0);
INSERT INTO chado.cvterm VALUES (891, 22, 'vertebrate_immunoglobulin_T_cell_receptor_rearranged_gene_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration. []', 903, 0, 0);
INSERT INTO chado.cvterm VALUES (892, 22, 'DJ_gene_segment', 'Genomic DNA of immunoglobulin/T-cell receptor gene in partially rearranged genomic DNA including D-J-region with 5'' UTR and 3'' UTR, also designated as D-J-segment. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 904, 0, 0);
INSERT INTO chado.cvterm VALUES (893, 22, 'five_prime_coding_exon_noncoding_region', 'The sequence of the 5'' exon preceding the start codon. [SO:ke]', 905, 0, 0);
INSERT INTO chado.cvterm VALUES (894, 22, 'VDJ_J_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one VDJ-gene, one J-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 906, 0, 0);
INSERT INTO chado.cvterm VALUES (895, 22, 'VDJ_gene_segment', 'Rearranged genomic DNA of immunoglobulin/T-cell receptor gene including L-part1, V-intron and V-D-J-exon, with the 5''UTR (SO:0000204) and 3''UTR (SO:0000205). [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 907, 0, 0);
INSERT INTO chado.cvterm VALUES (896, 22, 'VDJ_J_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one VDJ-gene and one J-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 908, 0, 0);
INSERT INTO chado.cvterm VALUES (897, 22, 'VJ_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one VJ-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 909, 0, 0);
INSERT INTO chado.cvterm VALUES (898, 22, 'VJ_gene_segment', 'Rearranged genomic DNA of immunoglobulin/T-cell receptor gene including L-part1, V-intron and V-J-exon, with the 5''UTR (SO:0000204) and 3''UTR (SO:0000205). [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 910, 0, 0);
INSERT INTO chado.cvterm VALUES (1067, 22, 'repeat_unit', 'The simplest repeated component of a repeat region. A single repeat. [SO:ke]', 1082, 0, 0);
INSERT INTO chado.cvterm VALUES (899, 22, 'VJ_J_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one VJ-gene, one J-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 911, 0, 0);
INSERT INTO chado.cvterm VALUES (900, 22, 'VJ_J_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one VJ-gene and one J-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 912, 0, 0);
INSERT INTO chado.cvterm VALUES (901, 22, 'D_gene_recombination_feature', 'Recombination signal including D-heptamer, D-spacer and D-nonamer in 5'' of D-region of a D-gene or D-sequence. []', 913, 0, 0);
INSERT INTO chado.cvterm VALUES (902, 22, 'three_prime_D_heptamer', '7 nucleotide recombination site like CACAGTG, part of a 3'' D-recombination signal sequence of an immunoglobulin/T-cell receptor gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 914, 0, 0);
INSERT INTO chado.cvterm VALUES (903, 22, 'heptamer_of_recombination_feature_of_vertebrate_immune_system_gene', 'Seven nucleotide recombination site (e.g. CACAGTG), part of V-gene, D-gene or J-gene recombination feature of an immunoglobulin or T-cell receptor gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 915, 0, 0);
INSERT INTO chado.cvterm VALUES (904, 22, 'three_prime_D_recombination_signal_sequence', 'Recombination signal of an immunoglobulin/T-cell receptor gene, including the 3'' D-heptamer (SO:0000493), 3'' D-spacer, and 3'' D-nonamer (SO:0000494) in 3'' of the D-region of a D-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 916, 0, 0);
INSERT INTO chado.cvterm VALUES (905, 22, 'three_prime_D_nonamer', 'A 9 nucleotide recombination site (e.g. ACAAAAACC), part of a 3'' D-recombination signal sequence of an immunoglobulin/T-cell receptor gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 917, 0, 0);
INSERT INTO chado.cvterm VALUES (906, 22, 'nonamer_of_recombination_feature_of_vertebrate_immune_system_gene', 'Nine nucleotide recombination site, part of V-gene, D-gene or J-gene recombination feature of an immunoglobulin or T-cell receptor gene. []', 918, 0, 0);
INSERT INTO chado.cvterm VALUES (907, 22, 'three_prime_D_spacer', 'A 12 or 23 nucleotide spacer between the 3''D-HEPTAMER and 3''D-NONAMER of a 3''D-RS. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 919, 0, 0);
INSERT INTO chado.cvterm VALUES (908, 22, 'vertebrate_immune_system_gene_recombination_spacer', 'A 12 or 23 nucleotide spacer between two regions of an immunoglobulin/T-cell receptor gene that may be rearranged by recombinase. []', 920, 0, 0);
INSERT INTO chado.cvterm VALUES (909, 22, 'five_prime_D_heptamer', '7 nucleotide recombination site (e.g. CACTGTG), part of a 5'' D-recombination signal sequence (SO:0000556) of an immunoglobulin/T-cell receptor gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 921, 0, 0);
INSERT INTO chado.cvterm VALUES (910, 22, 'five_prime_D_recombination_signal_sequence', 'Recombination signal of an immunoglobulin/T-cell receptor gene, including the 5'' D-nonamer (SO:0000497), 5'' D-spacer (SO:0000498), and 5'' D-heptamer (SO:0000396) in 5'' of the D-region of a D-gene, or in 5'' of the D-region of DJ-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 922, 0, 0);
INSERT INTO chado.cvterm VALUES (911, 22, 'five_prime_D_nonamer', '9 nucleotide recombination site (e.g. GGTTTTTGT), part of a five_prime_D-recombination signal sequence (SO:0000556) of an immunoglobulin/T-cell receptor gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 923, 0, 0);
INSERT INTO chado.cvterm VALUES (912, 22, 'five_prime_D_spacer', '12 or 23 nucleotide spacer between the 5'' D-heptamer (SO:0000496) and 5'' D-nonamer (SO:0000497) of a 5'' D-recombination signal sequence (SO:0000556) of an immunoglobulin/T-cell receptor gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 924, 0, 0);
INSERT INTO chado.cvterm VALUES (913, 22, 'virtual_sequence', 'A continuous piece of sequence similar to the ''virtual contig'' concept of the Ensembl database. [SO:ke]', 925, 0, 0);
INSERT INTO chado.cvterm VALUES (914, 22, 'Hoogsteen_base_pair', 'A type of non-canonical base-pairing. This is less energetically favourable than watson crick base pairing. Hoogsteen GC base pairs only have two hydrogen bonds. [PMID:12177293]', 926, 0, 0);
INSERT INTO chado.cvterm VALUES (915, 22, 'reverse_Hoogsteen_base_pair', 'A type of non-canonical base-pairing. [SO:ke]', 927, 0, 0);
INSERT INTO chado.cvterm VALUES (916, 22, 'transcribed_region', 'A region of sequence that is transcribed. This region may cover the transcript of a gene, it may emcompas the sequence covered by all of the transcripts of a alternately spliced gene, or it may cover the region transcribed by a polycistronic transcript. A gene may have 1 or more transcribed regions and a transcribed_region may belong to one or more genes. [SO:ke]', 928, 1, 0);
INSERT INTO chado.cvterm VALUES (917, 22, 'alternately_spliced_gene_encodeing_one_transcript', '', 929, 1, 0);
INSERT INTO chado.cvterm VALUES (918, 22, 'D_DJ_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one D-gene, one DJ-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 930, 0, 0);
INSERT INTO chado.cvterm VALUES (919, 22, 'D_DJ_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one D-gene and one DJ-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 931, 0, 0);
INSERT INTO chado.cvterm VALUES (920, 22, 'D_DJ_J_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one D-gene, one DJ-gene, one J-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 932, 0, 0);
INSERT INTO chado.cvterm VALUES (921, 22, 'pseudogenic_exon', 'A non functional descendant of an exon, part of a pseudogene. [SO:ke]', 933, 0, 0);
INSERT INTO chado.cvterm VALUES (922, 22, 'pseudogenic_transcript', 'A non functional descendant of a transcript, part of a pseudogene. [SO:ke]', 934, 0, 0);
INSERT INTO chado.cvterm VALUES (923, 22, 'D_DJ_J_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one D-gene, one DJ-gene, and one J-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 935, 0, 0);
INSERT INTO chado.cvterm VALUES (924, 22, 'D_J_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in germline configuration including at least one D-gene, one J-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 936, 0, 0);
INSERT INTO chado.cvterm VALUES (925, 22, 'VD_gene_segment', 'Genomic DNA of immunoglobulin/T-cell receptor gene in partially rearranged genomic DNA including L-part1, V-intron and V-D-exon, with the 5'' UTR (SO:0000204) and 3'' UTR (SO:0000205). [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 937, 0, 0);
INSERT INTO chado.cvterm VALUES (926, 22, 'vertebrate_immunoglobulin_T_cell_receptor_rearranged_segment', 'Genomic DNA of immunoglobulin/T-cell receptor gene in partially rearranged genomic DNA. []', 938, 0, 0);
INSERT INTO chado.cvterm VALUES (927, 22, 'J_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in germline configuration including at least one J-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 939, 0, 0);
INSERT INTO chado.cvterm VALUES (928, 22, 'inversion_derived_deficiency_plus_aneuploid', 'A chromosomal deletion whereby a chromosome generated by recombination between two inversions; has a deficiency at one end and presumed to have a deficiency or duplication at the other end of the inversion. [FB:km]', 940, 0, 0);
INSERT INTO chado.cvterm VALUES (1068, 22, 'dispersed_repeat', 'A repeat that is located at dispersed sites in the genome. [SO:ke]', 1083, 0, 0);
INSERT INTO chado.cvterm VALUES (929, 22, 'J_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in germline configuration including more than one J-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 941, 0, 0);
INSERT INTO chado.cvterm VALUES (930, 22, 'J_nonamer', '9 nucleotide recombination site (e.g. GGTTTTTGT), part of a J-gene recombination feature of an immunoglobulin/T-cell receptor gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 942, 0, 0);
INSERT INTO chado.cvterm VALUES (931, 22, 'J_heptamer', '7 nucleotide recombination site (e.g. CACAGTG), part of a J-gene recombination feature of an immunoglobulin/T-cell receptor gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 943, 0, 0);
INSERT INTO chado.cvterm VALUES (932, 22, 'J_spacer', '12 or 23 nucleotide spacer between the J-nonamer and the J-heptamer of a J-gene recombination feature of an immunoglobulin/T-cell receptor gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 944, 0, 0);
INSERT INTO chado.cvterm VALUES (933, 22, 'V_DJ_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene and one DJ-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 945, 0, 0);
INSERT INTO chado.cvterm VALUES (934, 22, 'V_DJ_J_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene, one DJ-gene and one J-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 946, 0, 0);
INSERT INTO chado.cvterm VALUES (935, 22, 'V_VDJ_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene, one VDJ-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 947, 0, 0);
INSERT INTO chado.cvterm VALUES (936, 22, 'V_VDJ_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene and one VDJ-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 948, 0, 0);
INSERT INTO chado.cvterm VALUES (937, 22, 'V_VDJ_J_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene, one VDJ-gene and one J-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 949, 0, 0);
INSERT INTO chado.cvterm VALUES (938, 22, 'V_VJ_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene, one VJ-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 950, 0, 0);
INSERT INTO chado.cvterm VALUES (939, 22, 'V_VJ_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene and one VJ-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 951, 0, 0);
INSERT INTO chado.cvterm VALUES (940, 22, 'V_VJ_J_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene, one VJ-gene and one J-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 952, 0, 0);
INSERT INTO chado.cvterm VALUES (941, 22, 'V_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in germline configuration including more than one V-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 953, 0, 0);
INSERT INTO chado.cvterm VALUES (942, 22, 'V_D_DJ_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene, one D-gene, one DJ-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 954, 0, 0);
INSERT INTO chado.cvterm VALUES (943, 22, 'V_D_DJ_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene, one D-gene, one DJ-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 955, 0, 0);
INSERT INTO chado.cvterm VALUES (944, 22, 'V_D_DJ_J_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene, one D-gene, one DJ-gene, one J-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 956, 0, 0);
INSERT INTO chado.cvterm VALUES (945, 22, 'V_D_DJ_J_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene, one D-gene, one DJ-gene and one J-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 957, 0, 0);
INSERT INTO chado.cvterm VALUES (946, 22, 'V_D_J_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in germline configuration including at least one V-gene, one D-gene and one J-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 958, 0, 0);
INSERT INTO chado.cvterm VALUES (947, 22, 'V_D_J_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in germline configuration including at least one V-gene, one D-gene and one J-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 959, 0, 0);
INSERT INTO chado.cvterm VALUES (948, 22, 'V_heptamer', '7 nucleotide recombination site (e.g. CACAGTG), part of V-gene recombination feature of an immunoglobulin/T-cell receptor gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 960, 0, 0);
INSERT INTO chado.cvterm VALUES (949, 22, 'V_gene_recombination_feature', 'Recombination signal including V-heptamer, V-spacer and V-nonamer in 3'' of V-region of a V-gene or V-sequence of an immunoglobulin/T-cell receptor gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 961, 0, 0);
INSERT INTO chado.cvterm VALUES (950, 22, 'V_J_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in germline configuration including at least one V-gene and one J-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 962, 0, 0);
INSERT INTO chado.cvterm VALUES (951, 22, 'V_J_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in germline configuration including at least one V-gene, one J-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 963, 0, 0);
INSERT INTO chado.cvterm VALUES (952, 22, 'V_nonamer', '9 nucleotide recombination site (e.g. ACAAAAACC), part of V-gene recombination feature of an immunoglobulin/T-cell receptor gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 964, 0, 0);
INSERT INTO chado.cvterm VALUES (953, 22, 'V_spacer', '12 or 23 nucleotide spacer between the V-heptamer and the V-nonamer of a V-gene recombination feature of an immunoglobulin/T-cell receptor gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 965, 0, 0);
INSERT INTO chado.cvterm VALUES (954, 22, 'DJ_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one DJ-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 966, 0, 0);
INSERT INTO chado.cvterm VALUES (955, 22, 'DJ_J_C_cluster', 'Genomic DNA in rearranged configuration including at least one D-J-GENE, one J-GENE and one C-GENE. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 967, 0, 0);
INSERT INTO chado.cvterm VALUES (956, 22, 'VDJ_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one VDJ-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 968, 0, 0);
INSERT INTO chado.cvterm VALUES (957, 22, 'V_DJ_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene, one DJ-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 969, 0, 0);
INSERT INTO chado.cvterm VALUES (958, 22, 'alternately_spliced_gene_encoding_greater_than_one_transcript', '', 970, 1, 0);
INSERT INTO chado.cvterm VALUES (959, 22, 'helitron', 'A rolling circle transposon. Autonomous helitrons encode a 5''-to-3'' DNA helicase and nuclease/ligase similar to those encoded by known rolling-circle replicons. [http://www.pnas.org/cgi/content/full/100/11/6569]', 971, 0, 0);
INSERT INTO chado.cvterm VALUES (960, 22, 'recoding_pseudoknot', 'The pseudoknots involved in recoding are unique in that, as they play their role as a structure, they are immediately unfolded and their now linear sequence serves as a template for decoding. [http://www.pubmedcentral.nih.gov/articlerender.fcgi?artid=33937]', 972, 0, 0);
INSERT INTO chado.cvterm VALUES (961, 22, 'pseudoknot', 'A tertiary structure in RNA where nucleotides in a loop form base pairs with a region of RNA downstream of the loop. [RSC:cb]', 973, 0, 0);
INSERT INTO chado.cvterm VALUES (962, 22, 'recoding_stimulatory_region', 'A site in an mRNA sequence that stimulates the recoding of a region in the same mRNA. [http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=12519954&dopt=Abstract]', 974, 0, 0);
INSERT INTO chado.cvterm VALUES (963, 22, 'designed_sequence', 'An oligonucleotide sequence that was designed by an experimenter that may or may not correspond with any natural sequence. []', 975, 0, 0);
INSERT INTO chado.cvterm VALUES (964, 22, 'inversion_derived_bipartite_duplication', 'A chromosome generated by recombination between two inversions; there is a duplication at each end of the inversion. [FB:km]', 976, 0, 0);
INSERT INTO chado.cvterm VALUES (965, 22, 'gene_with_edited_transcript', 'A gene that encodes a transcript that is edited. [SO:xp]', 977, 0, 0);
INSERT INTO chado.cvterm VALUES (966, 22, 'edited_transcript', 'A transcript that is edited. [SO:ke]', 978, 0, 0);
INSERT INTO chado.cvterm VALUES (967, 22, 'inversion_derived_duplication_plus_aneuploid', 'A chromosome generated by recombination between two inversions; has a duplication at one end and presumed to have a deficiency or duplication at the other end of the inversion. [FB:km]', 979, 0, 0);
INSERT INTO chado.cvterm VALUES (968, 22, 'aneuploid_chromosome', 'A chromosome structural variation whereby either a chromosome exists in addition to the normal chromosome complement or is lacking. [SO:ke]', 980, 0, 0);
INSERT INTO chado.cvterm VALUES (969, 22, 'polyA_signal_sequence', 'The recognition sequence necessary for endonuclease cleavage of an RNA transcript that is followed by polyadenylation; consensus=AATAAA. [http://www.insdc.org/files/feature_table.html]', 981, 0, 0);
INSERT INTO chado.cvterm VALUES (970, 22, 'Shine_Dalgarno_sequence', 'A region in the 5'' UTR that pairs with the 16S rRNA during formation of the preinitiation complex. [SO:jh]', 982, 0, 0);
INSERT INTO chado.cvterm VALUES (971, 22, 'polyA_site', 'The site on an RNA transcript to which will be added adenine residues by post-transcriptional polyadenylation. The boundary between the UTR and the polyA sequence. [http://www.insdc.org/files/feature_table.html]', 983, 0, 0);
INSERT INTO chado.cvterm VALUES (972, 22, 'assortment_derived_deficiency_plus_duplication', '', 985, 1, 0);
INSERT INTO chado.cvterm VALUES (973, 22, 'five_prime_clip', '5'' most region of a precursor transcript that is clipped off during processing. [http://www.insdc.org/files/feature_table.html]', 986, 0, 0);
INSERT INTO chado.cvterm VALUES (974, 22, 'three_prime_clip', '3''-most region of a precursor transcript that is clipped off during processing. [http://www.insdc.org/files/feature_table.html]', 987, 0, 0);
INSERT INTO chado.cvterm VALUES (975, 22, 'C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene including more than one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 988, 0, 0);
INSERT INTO chado.cvterm VALUES (976, 22, 'D_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in germline configuration including more than one D-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 989, 0, 0);
INSERT INTO chado.cvterm VALUES (977, 22, 'D_J_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in germline configuration including at least one D-gene and one J-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 990, 0, 0);
INSERT INTO chado.cvterm VALUES (978, 22, 'V_DJ_J_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene, one DJ-gene, one J-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 991, 0, 0);
INSERT INTO chado.cvterm VALUES (979, 22, 'V_VDJ_J_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene, one VDJ-gene, one J-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 992, 0, 0);
INSERT INTO chado.cvterm VALUES (980, 22, 'V_VJ_J_C_cluster', 'Genomic DNA of immunoglobulin/T-cell receptor gene in rearranged configuration including at least one V-gene, one VJ-gene, one J-gene and one C-gene. [http://www.imgt.org/cgi-bin/IMGTlect.jv?query=7#]', 993, 0, 0);
INSERT INTO chado.cvterm VALUES (981, 22, 'inversion_derived_aneuploid_chromosome', 'A chromosome may be generated by recombination between two inversions; presumed to have a deficiency or duplication at each end of the inversion. [FB:km]', 994, 0, 0);
INSERT INTO chado.cvterm VALUES (982, 22, 'bidirectional_promoter', 'A promoter that can allow for transcription in both directions. [PMID:21601935, SO:ke]', 995, 0, 0);
INSERT INTO chado.cvterm VALUES (983, 22, 'retrotransposed', 'An attribute of a feature that occurred as the product of a reverse transcriptase mediated event. [SO:ke]', 996, 0, 0);
INSERT INTO chado.cvterm VALUES (984, 22, 'miRNA_encoding', 'A region that can be transcribed into a microRNA (miRNA). []', 998, 0, 0);
INSERT INTO chado.cvterm VALUES (985, 22, 'rRNA_encoding', 'A region that can be transcribed into a ribosomal RNA (rRNA). []', 999, 0, 0);
INSERT INTO chado.cvterm VALUES (986, 22, 'scRNA_encoding', 'A region that can be transcribed into a small cytoplasmic RNA (scRNA). []', 1000, 0, 0);
INSERT INTO chado.cvterm VALUES (987, 22, 'centromere', 'A region of chromosome where the spindle fibers attach during mitosis and meiosis. [SO:ke]', 1001, 0, 0);
INSERT INTO chado.cvterm VALUES (988, 22, 'chromosomal_structural_element', 'Regions of the chromosome that are important for structural elements. []', 1002, 0, 0);
INSERT INTO chado.cvterm VALUES (989, 22, 'snoRNA_encoding', 'A region that can be transcribed into a small nucleolar RNA (snoRNA). []', 1003, 0, 0);
INSERT INTO chado.cvterm VALUES (990, 22, 'edited_transcript_feature', 'A locatable feature on a transcript that is edited. [SO:ma]', 1004, 0, 0);
INSERT INTO chado.cvterm VALUES (991, 22, 'methylation_guide_snoRNA_primary_transcript', 'A primary transcript encoding a methylation guide small nucleolar RNA. [SO:ke]', 1005, 0, 0);
INSERT INTO chado.cvterm VALUES (992, 22, 'cap', 'A structure consisting of a 7-methylguanosine in 5''-5'' triphosphate linkage with the first nucleotide of an mRNA. It is added post-transcriptionally, and is not encoded in the DNA. [http://seqcore.brcf.med.umich.edu/doc/educ/dnapr/mbglossary/mbgloss.html]', 1006, 0, 0);
INSERT INTO chado.cvterm VALUES (993, 22, 'rRNA_cleavage_snoRNA_primary_transcript', 'A primary transcript encoding an rRNA cleavage snoRNA. [SO:ke]', 1007, 0, 0);
INSERT INTO chado.cvterm VALUES (994, 22, 'pre_edited_region', 'The region of a transcript that will be edited. [http://dna.kdna.ucla.edu/rna/index.aspx]', 1008, 0, 0);
INSERT INTO chado.cvterm VALUES (995, 22, 'tmRNA', 'A tmRNA liberates a mRNA from a stalled ribosome. To accomplish this part of the tmRNA is used as a reading frame that ends in a translation stop signal. The broken mRNA is replaced in the ribosome by the tmRNA and translation of the tmRNA leads to addition of a proteolysis tag to the incomplete protein enabling recognition by a protease. Recently a number of permuted tmRNAs genes have been found encoded in two parts. TmRNAs have been identified in eubacteria and some chloroplasts but are absent from archeal and Eukaryote nuclear genomes. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00023]', 1009, 0, 0);
INSERT INTO chado.cvterm VALUES (996, 22, 'C_D_box_snoRNA_encoding', 'snoRNA that is associated with guiding methylation of nucleotides. It contains two short conserved sequence motifs: C (RUGAUGA) near the 5-prime end and D (CUGA) near the 3-prime end. []', 1010, 0, 0);
INSERT INTO chado.cvterm VALUES (997, 22, 'tmRNA_primary_transcript', 'A primary transcript encoding a tmRNA (SO:0000584). [SO:ke]', 1011, 0, 0);
INSERT INTO chado.cvterm VALUES (998, 22, 'group_I_intron', 'Group I catalytic introns are large self-splicing ribozymes. They catalyze their own excision from mRNA, tRNA and rRNA precursors in a wide range of organisms. The core secondary structure consists of 9 paired regions (P1-P9). These fold to essentially two domains, the P4-P6 domain (formed from the stacking of P5, P4, P6 and P6a helices) and the P3-P9 domain (formed from the P8, P3, P7 and P9 helices). Group I catalytic introns often have long ORFs inserted in loop regions. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00028]', 1012, 0, 0);
INSERT INTO chado.cvterm VALUES (999, 22, 'autocatalytically_spliced_intron', 'A self spliced intron. [SO:ke]', 1013, 0, 0);
INSERT INTO chado.cvterm VALUES (1000, 22, 'SRP_RNA_primary_transcript', 'A primary transcript encoding a signal recognition particle RNA. [SO:ke]', 1014, 0, 0);
INSERT INTO chado.cvterm VALUES (1001, 22, 'SRP_RNA', 'The signal recognition particle (SRP) is a universally conserved ribonucleoprotein. It is involved in the co-translational targeting of proteins to membranes. The eukaryotic SRP consists of a 300-nucleotide 7S RNA and six proteins: SRPs 72, 68, 54, 19, 14, and 9. Archaeal SRP consists of a 7S RNA and homologues of the eukaryotic SRP19 and SRP54 proteins. In most eubacteria, the SRP consists of a 4.5S RNA and the Ffh protein (a homologue of the eukaryotic SRP54 protein). Eukaryotic and archaeal 7S RNAs have very similar secondary structures, with eight helical elements. These fold into the Alu and S domains, separated by a long linker region. Eubacterial SRP is generally a simpler structure, with the M domain of Ffh bound to a region of the 4.5S RNA that corresponds to helix 8 of the eukaryotic and archaeal SRP S domain. Some Gram-positive bacteria (e.g. Bacillus subtilis), however, have a larger SRP RNA that also has an Alu domain. The Alu domain is thought to mediate the peptide chain elongation retardation function of the SRP. The universally conserved helix which interacts with the SRP54/Ffh M domain mediates signal sequence recognition. In eukaryotes and archaea, the SRP19-helix 6 complex is thought to be involved in SRP assembly and stabilizes helix 8 for SRP54 binding. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00017]', 1015, 0, 0);
INSERT INTO chado.cvterm VALUES (1002, 22, 'H_pseudoknot', 'A pseudoknot which contains two stems and at least two loops. [http://www.ncbi.nlm.nih.gov\:80/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=10334330&dopt=Abstract]', 1016, 0, 0);
INSERT INTO chado.cvterm VALUES (1003, 22, 'C_D_box_snoRNA_primary_transcript', 'A primary transcript encoding a small nucleolar RNA of the box C/D family. [SO:ke]', 1017, 0, 0);
INSERT INTO chado.cvterm VALUES (1004, 22, 'H_ACA_box_snoRNA', 'Members of the box H/ACA family contain an ACA triplet, exactly 3 nt upstream from the 3'' end and an H-box in a hinge region that links two structurally similar functional domains of the molecule. Both boxes are important for snoRNA biosynthesis and function. A few box H/ACA snoRNAs are involved in rRNA processing; most others are known or predicted to participate in selection of uridine nucleosides in rRNA to be converted to pseudouridines. Site selection is mediated by direct base pairing of the snoRNA with rRNA through one or both targeting domains. [http://www.bio.umass.edu/biochem/rna-sequence/Yeast_snoRNA_Database/snoRNA_DataBase.html]', 1018, 0, 0);
INSERT INTO chado.cvterm VALUES (1005, 22, 'H_ACA_box_snoRNA_primary_transcript', 'A primary transcript encoding a small nucleolar RNA of the box H/ACA family. [SO:ke]', 1019, 0, 0);
INSERT INTO chado.cvterm VALUES (1006, 22, 'transcript_edited_by_U_insertion/deletion', 'The insertion and deletion of uridine (U) residues, usually within coding regions of mRNA transcripts of cryptogenes in the mitochondrial genome of kinetoplastid protozoa. [http://www.rna.ucla.edu/index.html]', 1020, 1, 0);
INSERT INTO chado.cvterm VALUES (1007, 22, 'edited_by_C_insertion_and_dinucleotide_insertion', '', 1021, 1, 0);
INSERT INTO chado.cvterm VALUES (1008, 22, 'edited_by_C_to_U_substitution', '', 1022, 1, 0);
INSERT INTO chado.cvterm VALUES (1009, 22, 'edited_by_A_to_I_substitution', '', 1023, 1, 0);
INSERT INTO chado.cvterm VALUES (1010, 22, 'edited_by_G_addition', '', 1024, 1, 0);
INSERT INTO chado.cvterm VALUES (1011, 22, 'guide_RNA', 'A short 3''-uridylated RNA that can form a duplex (except for its post-transcriptionally added oligo_U tail (SO:0000609)) with a stretch of mature edited mRNA. [http://www.rna.ucla.edu/index.html]', 1025, 0, 0);
INSERT INTO chado.cvterm VALUES (1012, 22, 'editing_block', 'Edited mRNA sequence mediated by a single guide RNA (SO:0000602). [http://dna.kdna.ucla.edu/rna/index.aspx]', 1026, 0, 0);
INSERT INTO chado.cvterm VALUES (1013, 22, 'intergenic_region', 'A region containing or overlapping no genes that is bounded on either side by a gene, or bounded by a gene and the end of the chromosome. [SO:cjm]', 1027, 0, 0);
INSERT INTO chado.cvterm VALUES (1014, 22, 'editing_domain', 'Edited mRNA sequence mediated by two or more overlapping guide RNAs (SO:0000602). [http://dna.kdna.ucla.edu/rna/index.aspx]', 1028, 0, 0);
INSERT INTO chado.cvterm VALUES (1015, 22, 'unedited_region', 'The region of an edited transcript that will not be edited. [http://dna.kdna.ucla.edu/rna/index.aspx]', 1029, 0, 0);
INSERT INTO chado.cvterm VALUES (1016, 22, 'H_ACA_box_snoRNA_encoding', 'snoRNA that is associated with guiding polyuridylation. It contains two short conserved sequence motifs: H box (ANANNA) and ACA (ACA). []', 1030, 0, 0);
INSERT INTO chado.cvterm VALUES (1017, 22, 'oligo_U_tail', 'The string of non-encoded U''s at the 3'' end of a guide RNA (SO:0000602). [http://www.rna.ucla.edu/]', 1031, 0, 0);
INSERT INTO chado.cvterm VALUES (1018, 22, 'polyA_sequence', 'Sequence of about 100 nucleotides of A added to the 3'' end of most eukaryotic mRNAs. [SO:ke]', 1032, 0, 0);
INSERT INTO chado.cvterm VALUES (1019, 22, 'branch_site', 'A pyrimidine rich sequence near the 3'' end of an intron to which the 5''end becomes covalently bound during nuclear splicing. The resulting structure resembles a lariat. [SO:ke]', 1033, 0, 0);
INSERT INTO chado.cvterm VALUES (1020, 22, 'polypyrimidine_tract', 'The polypyrimidine tract is one of the cis-acting sequence elements directing intron removal in pre-mRNA splicing. [http://nar.oupjournals.org/cgi/content/full/25/4/888]', 1034, 0, 0);
INSERT INTO chado.cvterm VALUES (1021, 22, 'bacterial_RNApol_promoter', 'A DNA sequence to which bacterial RNA polymerase binds, to begin transcription. [SO:ke]', 1035, 0, 0);
INSERT INTO chado.cvterm VALUES (1022, 22, 'prokaryotic_promoter', 'A regulatory_region essential for the specific initiation of transcription at a defined location in a DNA molecule, although this location might not be one single base. It is recognized by a specific RNA polymerase(RNAP)-holoenzyme, and this recognition is not necessarily autonomous. [PMID:32665585]', 1036, 0, 0);
INSERT INTO chado.cvterm VALUES (1023, 22, 'bacterial_terminator', 'A terminator signal for bacterial transcription. [SO:ke]', 1037, 0, 0);
INSERT INTO chado.cvterm VALUES (1024, 22, 'terminator_of_type_2_RNApol_III_promoter', 'A terminator signal for RNA polymerase III transcription. [SO:ke]', 1038, 0, 0);
INSERT INTO chado.cvterm VALUES (1025, 22, 'eukaryotic_terminator', 'A signal for RNA polymerase to terminate transcription. []', 1039, 0, 0);
INSERT INTO chado.cvterm VALUES (1026, 22, 'transcription_end_site', 'The base where transcription ends. [SO:ke]', 1040, 0, 0);
INSERT INTO chado.cvterm VALUES (1027, 22, 'RNApol_III_promoter_type_1', 'This type of promoter recruits RNA pol III. This promoter is intragenic and includes an A box, an intermediate element, and a C box. This is well conserved in the 5s rRNA promoters across species. [PMID:12381659]', 1041, 0, 0);
INSERT INTO chado.cvterm VALUES (1028, 22, 'RNApol_III_promoter_type_2', 'This type of promoter recruits RNA pol III to transcribe genes mainly for t-RNA. This promoter is intragenic and includes an A box and a B box. [PMID:12381659]', 1042, 0, 0);
INSERT INTO chado.cvterm VALUES (1029, 22, 'A_box', 'A variably distant linear promoter region recognized by TFIIIC, with consensus sequence TGGCnnAGTGG. [SO:ke]', 1043, 0, 0);
INSERT INTO chado.cvterm VALUES (1030, 22, 'B_box', 'A variably distant linear promoter region recognized by TFIIIC, with consensus sequence AGGTTCCAnnCC. [SO:ke]', 1044, 0, 0);
INSERT INTO chado.cvterm VALUES (1031, 22, 'RNApol_III_promoter_type_3', 'This type of promoter recruits RNA pol III to transcribe predominantly noncoding RNAs. This promoter contains a proximal sequence element (PSE) and a TATA box upstream of the gene that it regulates. Transcription can also be activated by a distal sequence element (DSE), which is located further upstream.  [PMID:12381659]', 1045, 0, 0);
INSERT INTO chado.cvterm VALUES (1032, 22, 'C_box', 'An RNA polymerase III type 1 promoter with consensus sequence CAnnCCn. [SO:ke]', 1046, 0, 0);
INSERT INTO chado.cvterm VALUES (1033, 22, 'snRNA_encoding', 'A region that can be transcribed into a small nuclear RNA (snRNA). []', 1047, 0, 0);
INSERT INTO chado.cvterm VALUES (1034, 22, 'telomere', 'A specific structure at the end of a linear chromosome, required for the integrity and maintenance of the end. [SO:ma]', 1048, 0, 0);
INSERT INTO chado.cvterm VALUES (1035, 22, 'silencer', 'A regulatory region which upon binding of transcription factors, suppress the transcription of the gene or genes they control. [SO:ke]', 1049, 0, 0);
INSERT INTO chado.cvterm VALUES (1036, 22, 'insulator', 'A regulatory region that 1) when located between a CRM and a gene''s promoter prevents the CRM from modulating that genes expression and 2) acts as a chromatin boundary element or barrier that can block the encroachment of condensed chromatin from an adjacent region. [NCBI:cf, PMID:12154228, SO:regcreative]', 1050, 0, 0);
INSERT INTO chado.cvterm VALUES (1037, 22, 'five_prime_open_reading_frame', 'An open reading frame found within the 5'' UTR that can be translated and stall the translation of the downstream open reading frame. [PMID:12890013]', 1051, 0, 0);
INSERT INTO chado.cvterm VALUES (1038, 22, 'upstream_AUG_codon', 'A start codon upstream of the ORF. [SO:ke]', 1052, 0, 0);
INSERT INTO chado.cvterm VALUES (1039, 22, 'UTR_region', 'A region of UTR. [SO:ke]', 1053, 0, 0);
INSERT INTO chado.cvterm VALUES (1040, 22, 'polycistronic_primary_transcript', 'A primary transcript encoding for more than one gene product. [SO:ke]', 1054, 0, 0);
INSERT INTO chado.cvterm VALUES (1041, 22, 'monocistronic_primary_transcript', 'A primary transcript encoding for one gene product. [SO:ke]', 1055, 0, 0);
INSERT INTO chado.cvterm VALUES (1042, 22, 'monocistronic_transcript', 'A transcript that is monocistronic. [SO:xp]', 1056, 0, 0);
INSERT INTO chado.cvterm VALUES (1043, 22, 'monocistronic', 'An attribute describing a sequence that contains the code for one gene product. [SO:ke]', 1057, 0, 0);
INSERT INTO chado.cvterm VALUES (1044, 22, 'monocistronic_mRNA', 'An mRNA with either a single protein product, or for which the regions encoding all its protein products overlap. [SO:rd]', 1058, 0, 0);
INSERT INTO chado.cvterm VALUES (1045, 22, 'polycistronic_mRNA', 'An mRNA that encodes multiple proteins from at least two non-overlapping regions. [SO:rd]', 1059, 0, 0);
INSERT INTO chado.cvterm VALUES (1046, 22, 'mini_exon_donor_RNA', 'A primary transcript that donates the spliced leader to other mRNA. [SO:ke]', 1060, 0, 0);
INSERT INTO chado.cvterm VALUES (1047, 22, 'spliced_leader_RNA', 'Snall nuclear RNAs that are incorporated into the pre-mRNAs to replace the 5'' end in some eukaryotes. [PMID:24130571]', 1061, 0, 0);
INSERT INTO chado.cvterm VALUES (1048, 22, 'engineered_plasmid', 'A plasmid that is engineered. [SO:xp]', 1062, 0, 0);
INSERT INTO chado.cvterm VALUES (1049, 22, 'transcribed_spacer_region', 'Part of an rRNA transcription unit that is transcribed but discarded during maturation, not giving rise to any part of rRNA. [http://oregonstate.edu/instruction/bb492/general/glossary.html]', 1063, 0, 0);
INSERT INTO chado.cvterm VALUES (1050, 22, 'rRNA_primary_transcript_region', 'A region of an rRNA primary transcript. [SO:ke]', 1064, 0, 0);
INSERT INTO chado.cvterm VALUES (1051, 22, 'internal_transcribed_spacer_region', 'Non-coding regions of DNA sequence that separate genes coding for the 28S, 5.8S, and 18S ribosomal RNAs. [SO:ke]', 1065, 0, 0);
INSERT INTO chado.cvterm VALUES (1052, 22, 'external_transcribed_spacer_region', 'Non-coding regions of DNA that precede the sequence that codes for the ribosomal RNA. [SO:ke]', 1066, 0, 0);
INSERT INTO chado.cvterm VALUES (1053, 22, 'tetranucleotide_repeat_microsatellite_feature', 'A region of a repeating tetranucleotide sequence (four bases). []', 1067, 0, 0);
INSERT INTO chado.cvterm VALUES (1054, 22, 'SRP_RNA_encoding', 'A region that can be transcribed into a signal recognition particle RNA (SRP RNA). []', 1068, 0, 0);
INSERT INTO chado.cvterm VALUES (1055, 22, 'minisatellite', 'A repeat region containing tandemly repeated sequences having a unit length of 10 to 40 bp. [http://www.informatics.jax.org/silver/glossary.shtml]', 1069, 0, 0);
INSERT INTO chado.cvterm VALUES (1056, 22, 'antisense_primary_transcript', 'The reverse complement of the primary transcript. [SO:ke]', 1070, 0, 0);
INSERT INTO chado.cvterm VALUES (1057, 22, 'siRNA', 'A small RNA molecule that is the product of a longer exogenous or endogenous dsRNA, which is either a bimolecular duplex or very long hairpin, processed (via the Dicer pathway) such that numerous siRNAs accumulate from both strands of the dsRNA. siRNAs trigger the cleavage of their target molecules. [PMID:12592000]', 1071, 0, 0);
INSERT INTO chado.cvterm VALUES (1058, 22, 'miRNA_primary_transcript', 'A primary transcript encoding a micro RNA. [SO:ke]', 1072, 0, 0);
INSERT INTO chado.cvterm VALUES (1059, 22, 'cytosolic_rRNA', 'Cytosolic rRNA is an RNA component of the small or large subunits of cytosolic ribosomes. [PMID:3044395]', 1074, 0, 0);
INSERT INTO chado.cvterm VALUES (1060, 22, 'cytosolic_5S_rRNA', 'Cytosolic 5S rRNA is an RNA component of the large subunit of cytosolic ribosomes in both prokaryotes and eukaryotes. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00001]', 1075, 0, 0);
INSERT INTO chado.cvterm VALUES (1061, 22, 'cytosolic_rRNA_5S_gene', 'A gene which codes for 5S_rRNA, which is a portion of the large subunit of the ribosome in both eukaryotes and prokaryotes. []', 1076, 0, 0);
INSERT INTO chado.cvterm VALUES (1062, 22, 'cytosolic_28S_rRNA', 'Cytosolic 28S rRNA is an RNA component of the large subunit of cytosolic ribosomes in metazoan eukaryotes. [SO:ke]', 1077, 0, 0);
INSERT INTO chado.cvterm VALUES (1063, 22, 'cytosolic_rRNA_28S_gene', 'A gene which codes for 28S_rRNA, which functions as a component of the large subunit of the ribosome in eukaryotes. []', 1078, 0, 0);
INSERT INTO chado.cvterm VALUES (1064, 22, 'maxicircle_gene', 'A mitochondrial gene located in a maxicircle. [SO:xp]', 1079, 0, 0);
INSERT INTO chado.cvterm VALUES (1065, 22, 'maxicircle', 'A maxicircle is a replicon, part of a kinetoplast, that contains open reading frames and replicates via a rolling circle method. [PMID:8395055]', 1080, 0, 0);
INSERT INTO chado.cvterm VALUES (1066, 22, 'stRNA_encoding', 'A region that can be transcribed into a small temporal RNA (stRNA). Found in roundworm development. []', 1081, 0, 0);
INSERT INTO chado.cvterm VALUES (2678, 22, 'G_to_A_transition', 'A transition of a guanine to an adenine. [SO:ke]', 2950, 0, 0);
INSERT INTO chado.cvterm VALUES (1069, 22, 'tmRNA_encoding', 'A region that can be transcribed into a transfer-messenger RNA (tmRNA). []', 1084, 0, 0);
INSERT INTO chado.cvterm VALUES (1070, 22, 'DNA_invertase_target_sequence', '', 1085, 1, 0);
INSERT INTO chado.cvterm VALUES (1071, 22, 'intron_attribute', '', 1086, 1, 0);
INSERT INTO chado.cvterm VALUES (1072, 22, 'tRNA_encoding', 'A region that can be transcribed into a transfer RNA (tRNA). []', 1087, 0, 0);
INSERT INTO chado.cvterm VALUES (1073, 22, 'introgressed_chromosome_region', 'A region of a chromosome that has been introduced by backcrossing with a separate species. [PMID:11454782]', 1088, 0, 0);
INSERT INTO chado.cvterm VALUES (1074, 22, 'mobile_intron', 'An intron (mitochondrial, chloroplast, nuclear or prokaryotic) that encodes a double strand sequence specific endonuclease allowing for mobility. [SO:ke]', 1089, 0, 0);
INSERT INTO chado.cvterm VALUES (1075, 22, 'mobile_genetic_element', 'A nucleotide region with either intra-genome or intracellular mobility, of varying length, which often carry the information necessary for transfer and recombination with the host genome. [PMID:14681355]', 1090, 0, 0);
INSERT INTO chado.cvterm VALUES (1076, 22, 'mobile', 'An attribute describing a feature that has either intra-genome or intracellular mobility. [RSC:cb]', 1091, 0, 0);
INSERT INTO chado.cvterm VALUES (1077, 22, 'insertion', 'The sequence of one or more nucleotides added between two adjacent nucleotides in the sequence. [SO:ke]', 1092, 0, 0);
INSERT INTO chado.cvterm VALUES (1078, 22, 'EST_match', 'A match against an EST sequence. [SO:ke]', 1095, 0, 0);
INSERT INTO chado.cvterm VALUES (1079, 22, 'chromosome_breakage_sequence', 'A sequence within the micronuclear DNA of ciliates at which chromosome breakage and telomere addition occurs during nuclear differentiation. [SO:ma]', 1096, 0, 0);
INSERT INTO chado.cvterm VALUES (1080, 22, 'internal_eliminated_sequence', 'A sequence eliminated from the genome of ciliates during nuclear differentiation. [SO:ma]', 1097, 0, 0);
INSERT INTO chado.cvterm VALUES (1081, 22, 'macronucleus_destined_segment', 'A sequence that is conserved, although rearranged relative to the micronucleus, in the macronucleus of a ciliate genome. [SO:ma]', 1098, 0, 0);
INSERT INTO chado.cvterm VALUES (1082, 22, 'gene_member_region', 'A region of a gene. [SO:ke]', 1099, 0, 0);
INSERT INTO chado.cvterm VALUES (1083, 22, 'unit_of_gene_expression', 'Transcription units or transcribed coding sequences. [Bacterial_regulation_working_group:CMA, PMID:32665585]', 1100, 0, 0);
INSERT INTO chado.cvterm VALUES (1084, 22, 'non_canonical_splice_site', 'A splice site where the donor and acceptor sites differ from the canonical form. [SO:ke]', 1101, 1, 0);
INSERT INTO chado.cvterm VALUES (1085, 22, 'canonical_splice_site', 'The major class of splice site with dinucleotides GT and AG for donor and acceptor sites, respectively. [SO:ke]', 1102, 1, 0);
INSERT INTO chado.cvterm VALUES (1086, 22, 'canonical_three_prime_splice_site', 'The canonical 3'' splice site has the sequence \"AG\". [SO:ke]', 1103, 0, 0);
INSERT INTO chado.cvterm VALUES (1087, 22, 'canonical_five_prime_splice_site', 'The canonical 5'' splice site has the sequence \"GT\". [SO:ke]', 1104, 0, 0);
INSERT INTO chado.cvterm VALUES (1088, 22, 'non_canonical_three_prime_splice_site', 'A 3'' splice site that does not have the sequence \"AG\". [SO:ke]', 1105, 0, 0);
INSERT INTO chado.cvterm VALUES (1089, 22, 'non_canonical_five_prime_splice_site', 'A 5'' splice site which does not have the sequence \"GT\". [SO:ke]', 1106, 0, 0);
INSERT INTO chado.cvterm VALUES (1090, 22, 'non_canonical_start_codon', 'A start codon that is not the usual AUG sequence. [SO:ke]', 1107, 0, 0);
INSERT INTO chado.cvterm VALUES (1091, 22, 'aberrant_processed_transcript', 'A transcript that has been processed \"incorrectly\", for example by the failure of splicing of one or more exons. [SO:ke]', 1108, 0, 0);
INSERT INTO chado.cvterm VALUES (1092, 22, 'splicing_feature', '', 1109, 1, 0);
INSERT INTO chado.cvterm VALUES (1093, 22, 'exonic_splice_enhancer', 'Exonic splicing enhancers (ESEs) facilitate exon definition by assisting in the recruitment of splicing factors to the adjacent intron. [http://www.ncbi.nlm.nih.gov\:80/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=12403462&dopt=Abstract]', 1110, 0, 0);
INSERT INTO chado.cvterm VALUES (1094, 22, 'DNaseI_hypersensitive_site', 'DNA region representing open chromatin structure that is hypersensitive to digestion by DNase I. []', 1111, 0, 0);
INSERT INTO chado.cvterm VALUES (1095, 22, 'translocation_element', 'A chromosomal translocation whereby the chromosomes carrying non-homologous centromeres may be recovered independently. These chromosomes are described as translocation elements. This occurs for some translocations, particularly but not exclusively, reciprocal translocations. [SO:ma]', 1112, 0, 0);
INSERT INTO chado.cvterm VALUES (1096, 22, 'chromosomal_translocation', 'A chromosomal mutation. Rearrangements that alter the pairing of telomeres are classified as translocations. [FB:reference_manual]', 1113, 0, 0);
INSERT INTO chado.cvterm VALUES (1097, 22, 'deletion_junction', 'The space between two bases in a sequence which marks the position where a deletion has occurred. [SO:ke]', 1114, 0, 0);
INSERT INTO chado.cvterm VALUES (1098, 22, 'cDNA_match', 'A match against cDNA sequence. [SO:ke]', 1115, 0, 0);
INSERT INTO chado.cvterm VALUES (1099, 22, 'gene_with_polycistronic_transcript', 'A gene that encodes a polycistronic transcript. [SO:xp]', 1116, 0, 0);
INSERT INTO chado.cvterm VALUES (1100, 22, 'cleaved_initiator_methionine', 'The initiator methionine that has been cleaved from a mature polypeptide sequence. [EBIBS:GAR]', 1117, 0, 0);
INSERT INTO chado.cvterm VALUES (1101, 22, 'cleaved_peptide_region', 'The cleaved_peptide_region is the region of a peptide sequence that is cleaved during maturation. [EBIBS:GAR]', 1119, 0, 0);
INSERT INTO chado.cvterm VALUES (1102, 22, 'gene_with_dicistronic_transcript', 'A gene that encodes a dicistronic transcript. [SO:xp]', 1120, 0, 0);
INSERT INTO chado.cvterm VALUES (1103, 22, 'gene_with_recoded_mRNA', 'A gene that encodes an mRNA that is recoded. [SO:xp]', 1121, 0, 0);
INSERT INTO chado.cvterm VALUES (1104, 22, 'recoded', 'An attribute describing an mRNA sequence that has been reprogrammed at translation, causing localized alterations. [SO:ke]', 1122, 0, 0);
INSERT INTO chado.cvterm VALUES (1105, 22, 'SNP', 'SNPs are single base pair positions in genomic DNA at which different sequence alternatives exist in normal individuals in some population(s), wherein the least frequent variant has an abundance of 1% or greater. [SO:cb]', 1123, 0, 0);
INSERT INTO chado.cvterm VALUES (1106, 22, 'SNV', 'SNVs are single nucleotide positions in genomic DNA at which different sequence alternatives exist. [SO:bm]', 1124, 0, 0);
INSERT INTO chado.cvterm VALUES (1107, 22, 'biomaterial_region', 'A region which is intended for use in an experiment. [SO:cb]', 1125, 0, 0);
INSERT INTO chado.cvterm VALUES (1108, 22, 'gene_with_stop_codon_read_through', 'A gene that encodes a transcript with stop codon readthrough. [SO:xp]', 1126, 0, 0);
INSERT INTO chado.cvterm VALUES (1109, 22, 'stop_codon_read_through', 'A stop codon redefined to be a new amino acid. [SO:ke]', 1127, 0, 0);
INSERT INTO chado.cvterm VALUES (1110, 22, 'gene_with_stop_codon_redefined_as_pyrrolysine', 'A gene encoding an mRNA that has the stop codon redefined as pyrrolysine. [SO:xp]', 1128, 0, 0);
INSERT INTO chado.cvterm VALUES (1111, 22, 'stop_codon_redefined_as_pyrrolysine', 'A stop codon redefined to be the new amino acid, pyrrolysine. [SO:ke]', 1129, 0, 0);
INSERT INTO chado.cvterm VALUES (1112, 22, 'possible_base_call_error', 'A region of sequence where the validity of the base calling is questionable. [SO:ke]', 1130, 0, 0);
INSERT INTO chado.cvterm VALUES (1113, 22, 'possible_assembly_error', 'A region of sequence where there may have been an error in the assembly. [SO:ke]', 1131, 0, 0);
INSERT INTO chado.cvterm VALUES (1114, 22, 'experimental_result_region', 'A region of sequence implicated in an experimental result. [SO:ke]', 1132, 0, 0);
INSERT INTO chado.cvterm VALUES (1115, 22, 'trans_splice_acceptor_site', 'The 3'' splice site of the acceptor primary transcript. [SO:ke]', 1133, 0, 0);
INSERT INTO chado.cvterm VALUES (1116, 22, 'trans_splice_site', 'Primary transcript region bordering trans-splice junction. [SO:ke]', 1134, 0, 0);
INSERT INTO chado.cvterm VALUES (1117, 22, 'trans_splice_donor_site', 'The 5'' five prime splice site region of the donor RNA. [SO:ke]', 1135, 0, 0);
INSERT INTO chado.cvterm VALUES (1118, 22, 'SL1_acceptor_site', 'A trans_splicing_acceptor_site which appends the 22nt SL1 RNA leader sequence to the 5'' end of most mRNAs. [SO:nlw]', 1136, 0, 0);
INSERT INTO chado.cvterm VALUES (1119, 22, 'SL2_acceptor_site', 'A trans_splicing_acceptor_site which appends the 22nt SL2 RNA leader sequence to the 5'' end of mRNAs. SL2 acceptor sites occur in genes in internal segments of polycistronic transcripts. [SO:nlw]', 1137, 0, 0);
INSERT INTO chado.cvterm VALUES (1120, 22, 'gene_with_stop_codon_redefined_as_selenocysteine', 'A gene encoding an mRNA that has the stop codon redefined as selenocysteine. [SO:xp]', 1138, 0, 0);
INSERT INTO chado.cvterm VALUES (1121, 22, 'stop_codon_redefined_as_selenocysteine', 'A stop codon redefined to be the new amino acid, selenocysteine. [SO:ke]', 1139, 0, 0);
INSERT INTO chado.cvterm VALUES (1122, 22, 'gene_with_mRNA_recoded_by_translational_bypass', 'A gene with mRNA recoded by translational bypass. [SO:xp]', 1140, 0, 0);
INSERT INTO chado.cvterm VALUES (1123, 22, 'recoded_by_translational_bypass', 'Recoded mRNA where a block of nucleotides is not translated. [SO:ke]', 1141, 0, 0);
INSERT INTO chado.cvterm VALUES (1124, 22, 'gene_with_transcript_with_translational_frameshift', 'A gene encoding a transcript that has a translational frameshift. [SO:xp]', 1142, 0, 0);
INSERT INTO chado.cvterm VALUES (1125, 22, 'nucleotide_motif', 'A region of nucleotide sequence corresponding to a known motif. [SO:ke]', 1143, 0, 0);
INSERT INTO chado.cvterm VALUES (1126, 22, 'sequence_motif', 'A sequence motif is a nucleotide or amino-acid sequence pattern that may have biological significance. [http://en.wikipedia.org/wiki/Sequence_motif]', 1144, 0, 0);
INSERT INTO chado.cvterm VALUES (1127, 22, 'dicistronic_mRNA', 'An mRNA that has the quality dicistronic. [SO:ke]', 1145, 0, 0);
INSERT INTO chado.cvterm VALUES (1128, 22, 'blocked_reading_frame', 'A reading_frame that is interrupted by one or more stop codons; usually identified through inter-genomic sequence comparisons. [SGD:rb]', 1146, 0, 0);
INSERT INTO chado.cvterm VALUES (1129, 22, 'foreign_transposable_element', 'A transposable element that is foreign. [SO:ke]', 1147, 0, 0);
INSERT INTO chado.cvterm VALUES (1130, 22, 'gene_with_dicistronic_primary_transcript', 'A gene that encodes a dicistronic primary transcript. [SO:xp]', 1148, 0, 0);
INSERT INTO chado.cvterm VALUES (1131, 22, 'dicistronic_primary_transcript', 'A primary transcript that has the quality dicistronic. [SO:xp]', 1149, 0, 0);
INSERT INTO chado.cvterm VALUES (1132, 22, 'gene_with_dicistronic_mRNA', 'A gene that encodes a polycistronic mRNA. [SO:xp]', 1150, 0, 0);
INSERT INTO chado.cvterm VALUES (1133, 22, 'iDNA', 'Genomic sequence removed from the genome, as a normal event, by a process of recombination. [SO:ma]', 1151, 0, 0);
INSERT INTO chado.cvterm VALUES (1134, 22, 'oriT', 'A region of a DNA molecule where transfer is initiated during the process of conjugation or mobilization. [http://www.insdc.org/files/feature_table.html]', 1152, 0, 0);
INSERT INTO chado.cvterm VALUES (1135, 22, 'transit_peptide', 'The transit_peptide is a short region at the N-terminus of the peptide that directs the protein to an organelle (chloroplast, mitochondrion, microbody or cyanelle). [http://www.insdc.org/files/feature_table.html]', 1153, 0, 0);
INSERT INTO chado.cvterm VALUES (1136, 22, 'transit_peptide_region_of_CDS', 'CDS region corresponding to a transit peptide region of a polypeptide. []', 1155, 0, 0);
INSERT INTO chado.cvterm VALUES (1137, 22, 'intein', 'A region of a peptide that is able to excise itself and rejoin the remaining portions with a peptide bond. [SO:ke]', 1156, 0, 0);
INSERT INTO chado.cvterm VALUES (1138, 22, 'intein_containing', 'An attribute of protein-coding genes where the initial protein product contains an intein. [SO:ke]', 1157, 0, 0);
INSERT INTO chado.cvterm VALUES (1139, 22, 'gap', 'A gap in the sequence of known length. The unknown bases are filled in with N''s. [SO:ke]', 1158, 0, 0);
INSERT INTO chado.cvterm VALUES (1140, 22, 'fragmentary', 'An attribute to describe a feature that is incomplete. [SO:ke]', 1159, 0, 0);
INSERT INTO chado.cvterm VALUES (1141, 22, 'status', 'An attribute describing the status of a feature, based on the available evidence. [SO:ke]', 1160, 0, 0);
INSERT INTO chado.cvterm VALUES (1142, 22, 'predicted', 'An attribute describing an unverified region. [SO:ke]', 1161, 0, 0);
INSERT INTO chado.cvterm VALUES (1143, 22, 'exemplar_mRNA', 'An exemplar is a representative cDNA sequence for each gene. The exemplar approach is a method that usually involves some initial clustering into gene groups and the subsequent selection of a representative from each gene group. [http://mged.sourceforge.net/ontologies/MGEDontology.php]', 1162, 0, 0);
INSERT INTO chado.cvterm VALUES (1144, 22, 'exemplar', 'An attribute describing a sequence is representative of a class of similar sequences. [SO:ke]', 1163, 0, 0);
INSERT INTO chado.cvterm VALUES (1145, 22, 'sequence_location', 'The location of a sequence. []', 1164, 0, 0);
INSERT INTO chado.cvterm VALUES (1146, 22, 'genome', 'A genome is the sum of genetic material within a cell or virion. [SO:immuno_workshop]', 1166, 0, 0);
INSERT INTO chado.cvterm VALUES (1147, 22, 'minicircle', 'A minicircle is a replicon, part of a kinetoplast, that encodes for guide RNAs. [PMID:8395055]', 1167, 0, 0);
INSERT INTO chado.cvterm VALUES (1148, 22, 'amplification_origin', 'An origin_of_replication that is used for the amplification of a chromosomal nucleic acid sequence. [SO:ma]', 1169, 0, 0);
INSERT INTO chado.cvterm VALUES (1149, 22, 'gene_group_regulatory_region', 'A region that is involved in the regulation of transcription of a group of regulated genes. []', 1170, 1, 0);
INSERT INTO chado.cvterm VALUES (1150, 22, 'lambda_vector', 'The lambda bacteriophage is the vector for the linear lambda clone. The genes involved in the lysogenic pathway are removed from the from the viral DNA. Up to 25 kb of foreign DNA can then be inserted into the lambda genome. [ISBN:0-1767-2380-8]', 1171, 0, 0);
INSERT INTO chado.cvterm VALUES (1151, 22, 'plasmid_vector', 'A plasmid that has been generated to act as a vector for foreign sequence. []', 1172, 0, 0);
INSERT INTO chado.cvterm VALUES (1152, 22, 'single_stranded_cDNA', 'DNA synthesized from RNA by reverse transcriptase, single stranded. []', 1173, 0, 0);
INSERT INTO chado.cvterm VALUES (1153, 22, 'double_stranded_cDNA', 'DNA synthesized from RNA by reverse transcriptase that has been copied by PCR to make it double stranded. []', 1174, 0, 0);
INSERT INTO chado.cvterm VALUES (1154, 22, 'plasmid_clone', '', 1175, 1, 0);
INSERT INTO chado.cvterm VALUES (1155, 22, 'YAC_clone', '', 1176, 1, 0);
INSERT INTO chado.cvterm VALUES (1156, 22, 'phagemid_clone', '', 1177, 1, 0);
INSERT INTO chado.cvterm VALUES (1157, 22, 'PAC_clone', '', 1178, 1, 0);
INSERT INTO chado.cvterm VALUES (1158, 22, 'fosmid_clone', '', 1179, 1, 0);
INSERT INTO chado.cvterm VALUES (1159, 22, 'BAC_clone', '', 1180, 1, 0);
INSERT INTO chado.cvterm VALUES (1160, 22, 'cosmid_clone', '', 1181, 1, 0);
INSERT INTO chado.cvterm VALUES (1161, 22, 'pyrrolysyl_tRNA', 'A tRNA sequence that has a pyrrolysine anticodon, and a 3'' pyrrolysine binding region. [SO:ke]', 1182, 0, 0);
INSERT INTO chado.cvterm VALUES (1162, 22, 'pyrrolysine_tRNA_primary_transcript', 'A primary transcript encoding pyrrolysyl tRNA (SO:0000766). [RSC:cb]', 1183, 0, 0);
INSERT INTO chado.cvterm VALUES (1163, 22, 'clone_insert_start(SO:0000767)', '', 1184, 1, 0);
INSERT INTO chado.cvterm VALUES (1164, 22, 'episome', 'A plasmid that may integrate with a chromosome. [SO:ma]', 1185, 0, 0);
INSERT INTO chado.cvterm VALUES (1165, 22, 'tmRNA_coding_piece', 'The region of a two-piece tmRNA that bears the reading frame encoding the proteolysis tag. The tmRNA gene undergoes circular permutation in some groups of bacteria. Processing of the transcripts from such a gene leaves the mature tmRNA in two pieces, base-paired together. [doi:10.1093/nar/gkh795, Indiana:kw, issn:1362-4962]', 1186, 0, 0);
INSERT INTO chado.cvterm VALUES (1166, 22, 'tmRNA_region', 'A region of a tmRNA. [SO:cb]', 1187, 0, 0);
INSERT INTO chado.cvterm VALUES (1167, 22, 'tmRNA_acceptor_piece', 'The acceptor region of a two-piece tmRNA that when mature is charged at its 3'' end with alanine. The tmRNA gene undergoes circular permutation in some groups of bacteria; processing of the transcripts from such a gene leaves the mature tmRNA in two pieces, base-paired together. [doi:10.1093/nar/gkh795, Indiana:kw]', 1188, 0, 0);
INSERT INTO chado.cvterm VALUES (165, 22, 'QTL', 'A quantitative trait locus (QTL) is a polymorphic locus which contains alleles that differentially affect the expression of a continuously distributed phenotypic trait. Usually it is a marker described by statistical association to quantitative variation in the particular phenotypic trait that is thought to be controlled by the cumulative action of alleles at multiple loci. [http://rgd.mcw.edu/tu/qtls/]', 165, 0, 0);
INSERT INTO chado.cvterm VALUES (1168, 22, 'genomic_island', 'A genomic island is an integrated mobile genetic element, characterized by size (over 10 Kb). It that has features that suggest a foreign origin. These can include nucleotide distribution (oligonucleotides signature, CG content etc.) that differs from the bulk of the chromosome and/or genes suggesting DNA mobility. [Phigo:at, SO:ke]', 1189, 0, 0);
INSERT INTO chado.cvterm VALUES (1169, 22, 'pathogenic_island', 'Mobile genetic elements that contribute to rapid changes in virulence potential. They are present on the genomes of pathogenic strains but absent from the genomes of non pathogenic members of the same or related species. [SO:ke]', 1190, 0, 0);
INSERT INTO chado.cvterm VALUES (1170, 22, 'metabolic_island', 'A transmissible element containing genes involved in metabolism, analogous to the pathogenicity islands of gram negative bacteria. [SO:ke]', 1191, 0, 0);
INSERT INTO chado.cvterm VALUES (1171, 22, 'adaptive_island', 'An adaptive island is a genomic island that provides an adaptive advantage to the host. [SO:ke]', 1192, 0, 0);
INSERT INTO chado.cvterm VALUES (1172, 22, 'symbiosis_island', 'A transmissible element containing genes involved in symbiosis, analogous to the pathogenicity islands of gram negative bacteria. [SO:ke]', 1193, 0, 0);
INSERT INTO chado.cvterm VALUES (1173, 22, 'pseudogenic_rRNA', 'A non functional descendant of an rRNA. [SO:ke]', 1194, 0, 0);
INSERT INTO chado.cvterm VALUES (1174, 22, 'pseudogenic_tRNA', 'A non functional descendent of a tRNA. [SO:ke]', 1195, 0, 0);
INSERT INTO chado.cvterm VALUES (1175, 22, 'engineered_episome', 'An episome that is engineered. [SO:xp]', 1196, 0, 0);
INSERT INTO chado.cvterm VALUES (1176, 22, 'transposable_element_attribute', '', 1197, 1, 0);
INSERT INTO chado.cvterm VALUES (1177, 22, 'transgenic', 'Attribute describing sequence that has been integrated with foreign sequence. [SO:ke]', 1198, 0, 0);
INSERT INTO chado.cvterm VALUES (1178, 22, 'natural', 'An attribute describing a feature that occurs in nature. [SO:ke]', 1199, 0, 0);
INSERT INTO chado.cvterm VALUES (1179, 22, 'cloned_region', 'The region of sequence that has been inserted and is being propagated by the clone. []', 1200, 0, 0);
INSERT INTO chado.cvterm VALUES (1180, 22, 'reagent_attribute', '', 1201, 1, 0);
INSERT INTO chado.cvterm VALUES (1181, 22, 'clone_attribute', '', 1202, 1, 0);
INSERT INTO chado.cvterm VALUES (1182, 22, 'cloned', '', 1203, 1, 0);
INSERT INTO chado.cvterm VALUES (1183, 22, 'cloned_genomic', '', 1204, 1, 0);
INSERT INTO chado.cvterm VALUES (1184, 22, 'cloned_cDNA', '', 1205, 1, 0);
INSERT INTO chado.cvterm VALUES (1185, 22, 'engineered_DNA', '', 1206, 1, 0);
INSERT INTO chado.cvterm VALUES (1186, 22, 'engineered_rescue_region', 'A rescue region that is engineered. [SO:xp]', 1207, 0, 0);
INSERT INTO chado.cvterm VALUES (1187, 22, 'rescue_mini_gene', 'A mini_gene that rescues. [SO:xp]', 1208, 0, 0);
INSERT INTO chado.cvterm VALUES (1188, 22, 'mini_gene', 'By definition, minigenes are short open-reading frames (ORF), usually encoding approximately 9 to 20 amino acids, which are expressed in vivo (as distinct from being synthesized as peptide or protein ex vivo and subsequently injected). The in vivo synthesis confers a distinct advantage: the expressed sequences can enter both antigen presentation pathways, MHC I (inducing CD8+ T- cells, which are usually cytotoxic T-lymphocytes (CTL)) and MHC II (inducing CD4+ T-cells, usually ''T-helpers'' (Th)); and can encounter B-cells, inducing antibody responses. Three main vector approaches have been used to deliver minigenes: viral vectors, bacterial vectors and plasmid DNA. [PMID:15992143]', 1209, 0, 0);
INSERT INTO chado.cvterm VALUES (1189, 22, 'transgenic_transposable_element', 'TE that has been modified in vitro, including insertion of DNA derived from a source other than the originating TE. [FB:mc]', 1210, 0, 0);
INSERT INTO chado.cvterm VALUES (1190, 22, 'natural_transposable_element', 'TE that exists (or existed) in nature. [FB:mc]', 1211, 0, 0);
INSERT INTO chado.cvterm VALUES (1191, 22, 'extrachromosomal_mobile_genetic_element', 'An MGE that is not integrated into the host chromosome. [SO:ke]', 1212, 0, 0);
INSERT INTO chado.cvterm VALUES (1192, 22, 'engineered_transposable_element', 'TE that has been modified by manipulations in vitro. [FB:mc]', 1213, 0, 0);
INSERT INTO chado.cvterm VALUES (1193, 22, 'engineered_foreign_transposable_element', 'A transposable_element that is engineered and foreign. [FB:mc]', 1214, 0, 0);
INSERT INTO chado.cvterm VALUES (1194, 22, 'assortment_derived_duplication(SO:0000800)', 'A multi-chromosome duplication aberration generated by reassortment of other aberration components. [FB:gm]', 1215, 0, 0);
INSERT INTO chado.cvterm VALUES (1195, 22, 'assortment_derived_variation', 'A chromosome variation derived from an event during meiosis. [SO:ke]', 1216, 0, 0);
INSERT INTO chado.cvterm VALUES (1196, 22, 'assortment_derived_deficiency_plus_duplication(SO:0000801)', 'A multi-chromosome aberration generated by reassortment of other aberration components; presumed to have a deficiency and a duplication. [FB:gm]', 1217, 0, 0);
INSERT INTO chado.cvterm VALUES (1197, 22, 'assortment_derived_deficiency(SO:0000802)', 'A multi-chromosome deficiency aberration generated by reassortment of other aberration components. [FB:gm]', 1218, 0, 0);
INSERT INTO chado.cvterm VALUES (1198, 22, 'assortment_derived_aneuploid(SO:0000803)', 'A multi-chromosome aberration generated by reassortment of other aberration components; presumed to have a deficiency or a duplication. [FB:gm]', 1219, 0, 0);
INSERT INTO chado.cvterm VALUES (1199, 22, 'engineered_tag', 'A tag that is engineered. [SO:xp]', 1220, 0, 0);
INSERT INTO chado.cvterm VALUES (1200, 22, 'validated_cDNA_clone', 'A cDNA clone that has been validated. [SO:xp]', 1221, 0, 0);
INSERT INTO chado.cvterm VALUES (1201, 22, 'invalidated_cDNA_clone', 'A cDNA clone that is invalid. [SO:xp]', 1222, 0, 0);
INSERT INTO chado.cvterm VALUES (1202, 22, 'chimeric_cDNA_clone', 'A cDNA clone invalidated because it is chimeric. [SO:xp]', 1223, 0, 0);
INSERT INTO chado.cvterm VALUES (2754, 22, 'mutation_causing_out_of_frame_polypeptide_C_terminal_elongation', '', 3033, 1, 0);
INSERT INTO chado.cvterm VALUES (1203, 22, 'genomically_contaminated_cDNA_clone', 'A cDNA clone invalidated by genomic contamination. [SO:xp]', 1224, 0, 0);
INSERT INTO chado.cvterm VALUES (1204, 22, 'polyA_primed_cDNA_clone', 'A cDNA clone invalidated by polyA priming. [SO:xp]', 1225, 0, 0);
INSERT INTO chado.cvterm VALUES (1205, 22, 'partially_processed_cDNA_clone', 'A cDNA invalidated clone by partial processing. [SO:xp]', 1226, 0, 0);
INSERT INTO chado.cvterm VALUES (1206, 22, 'rescue_gene', 'A gene that rescues. [SO:xp]', 1227, 0, 0);
INSERT INTO chado.cvterm VALUES (1207, 22, 'wild_type', 'An attribute describing sequence with the genotype found in nature and/or standard laboratory stock. [SO:ke]', 1228, 0, 0);
INSERT INTO chado.cvterm VALUES (1208, 22, 'wild_type_rescue_gene', 'A gene that rescues. [SO:xp]', 1230, 0, 0);
INSERT INTO chado.cvterm VALUES (1209, 22, 'mitochondrial_chromosome', 'A chromosome originating in a mitochondria. [SO:xp]', 1231, 0, 0);
INSERT INTO chado.cvterm VALUES (1210, 22, 'chloroplast_chromosome', 'A chromosome originating in a chloroplast. [SO:xp]', 1232, 0, 0);
INSERT INTO chado.cvterm VALUES (1211, 22, 'chromoplast_chromosome', 'A chromosome originating in a chromoplast. [SO:xp]', 1233, 0, 0);
INSERT INTO chado.cvterm VALUES (1212, 22, 'cyanelle_chromosome', 'A chromosome originating in a cyanelle. [SO:xp]', 1234, 0, 0);
INSERT INTO chado.cvterm VALUES (1213, 22, 'leucoplast_chromosome', 'A chromosome with origin in a leucoplast. [SO:xp]', 1235, 0, 0);
INSERT INTO chado.cvterm VALUES (1214, 22, 'macronuclear_chromosome', 'A chromosome originating in a macronucleus. [SO:xp]', 1236, 0, 0);
INSERT INTO chado.cvterm VALUES (1215, 22, 'micronuclear_chromosome', 'A chromosome originating in a micronucleus. [SO:xp]', 1237, 0, 0);
INSERT INTO chado.cvterm VALUES (1216, 22, 'nuclear_chromosome', 'A chromosome originating in a nucleus. [SO:xp]', 1238, 0, 0);
INSERT INTO chado.cvterm VALUES (1217, 22, 'nucleomorphic_chromosome', 'A chromosome originating in a nucleomorph. [SO:xp]', 1239, 0, 0);
INSERT INTO chado.cvterm VALUES (1218, 22, 'promoter_region', 'A region of sequence which is part of a promoter. [SO:ke]', 1240, 1, 0);
INSERT INTO chado.cvterm VALUES (1219, 22, 'mature_transcript_region', 'A region of a mature transcript. [SO:ke]', 1241, 0, 0);
INSERT INTO chado.cvterm VALUES (1220, 22, 'bacterial_RNApol_promoter_region', 'A region which is part of a bacterial RNA polymerase promoter. [SO:ke]', 1244, 1, 0);
INSERT INTO chado.cvterm VALUES (1221, 22, 'RNApol_II_promoter_region', 'A region of sequence which is a promoter for RNA polymerase II. [SO:ke]', 1245, 1, 0);
INSERT INTO chado.cvterm VALUES (1222, 22, 'RNApol_III_promoter_type_1_region', 'A region of sequence which is a promoter for RNA polymerase III type 1. [SO:ke]', 1246, 1, 0);
INSERT INTO chado.cvterm VALUES (1223, 22, 'RNApol_III_promoter_type_2_region', 'A region of sequence which is a promoter for RNA polymerase III type 2. [SO:ke]', 1247, 1, 0);
INSERT INTO chado.cvterm VALUES (1224, 22, 'exon_region', 'A region of an exon. [RSC:cb]', 1248, 0, 0);
INSERT INTO chado.cvterm VALUES (1225, 22, 'homologous_region', 'A region that is homologous to another region. [SO:ke]', 1249, 0, 0);
INSERT INTO chado.cvterm VALUES (1226, 22, 'homologous', 'Similarity due to common ancestry. [SO:ke]', 1250, 0, 0);
INSERT INTO chado.cvterm VALUES (1227, 22, 'paralogous_region', 'A homologous_region that is paralogous to another region. [SO:ke]', 1251, 0, 0);
INSERT INTO chado.cvterm VALUES (1228, 22, 'paralogous', 'An attribute describing a kind of homology where divergence occurred after a duplication event. [SO:ke]', 1252, 0, 0);
INSERT INTO chado.cvterm VALUES (1229, 22, 'orthologous_region', 'A homologous_region that is orthologous to another region. [SO:ke]', 1253, 0, 0);
INSERT INTO chado.cvterm VALUES (1230, 22, 'orthologous', 'An attribute describing a kind of homology where divergence occurred after a speciation event. [SO:ke]', 1254, 0, 0);
INSERT INTO chado.cvterm VALUES (1231, 22, 'conserved', 'A region that is similar or identical across more than one species. []', 1255, 0, 0);
INSERT INTO chado.cvterm VALUES (1232, 22, 'syntenic', 'Attribute describing sequence regions occurring in same order on chromosome of different species. [SO:ke]', 1256, 0, 0);
INSERT INTO chado.cvterm VALUES (1233, 22, 'capped_primary_transcript', 'A primary transcript that is capped. [SO:xp]', 1257, 0, 0);
INSERT INTO chado.cvterm VALUES (1234, 22, 'capped_mRNA', 'An mRNA that is capped. [SO:xp]', 1258, 0, 0);
INSERT INTO chado.cvterm VALUES (1235, 22, 'trans_spliced_mRNA', 'An mRNA that is trans-spliced. [SO:xp]', 1259, 0, 0);
INSERT INTO chado.cvterm VALUES (1236, 22, 'anchor_binding_site', '', 1260, 0, 0);
INSERT INTO chado.cvterm VALUES (1237, 22, 'edited_transcript_by_A_to_I_substitution', 'A transcript that has been edited by A to I substitution. [SO:ke]', 1261, 0, 0);
INSERT INTO chado.cvterm VALUES (1238, 22, 'alternatively_spliced', 'An attribute describing a situation where a gene may encode for more than 1 transcript. [SO:ke]', 1262, 0, 0);
INSERT INTO chado.cvterm VALUES (1239, 22, 'codon_redefined', 'An attribute describing the alteration of codon meaning. [SO:ke]', 1263, 0, 0);
INSERT INTO chado.cvterm VALUES (1240, 22, 'maternally_imprinted_gene', 'A gene that is maternally_imprinted. [SO:xp]', 1264, 0, 0);
INSERT INTO chado.cvterm VALUES (1241, 22, 'paternally_imprinted_gene', 'A gene that is paternally imprinted. [SO:xp]', 1265, 0, 0);
INSERT INTO chado.cvterm VALUES (1242, 22, 'post_translationally_regulated_gene', 'A gene that is post translationally regulated. [SO:xp]', 1266, 0, 0);
INSERT INTO chado.cvterm VALUES (1243, 22, 'negatively_autoregulated_gene', 'A gene that is negatively autoreguated. [SO:xp]', 1267, 0, 0);
INSERT INTO chado.cvterm VALUES (1244, 22, 'positively_autoregulated_gene', 'A gene that is positively autoregulated. [SO:xp]', 1268, 0, 0);
INSERT INTO chado.cvterm VALUES (1245, 22, 'translationally_regulated_gene', 'A gene that is translationally regulated. [SO:xp]', 1269, 0, 0);
INSERT INTO chado.cvterm VALUES (1246, 22, 'allelically_excluded_gene', 'A gene that is allelically_excluded. [SO:xp]', 1270, 0, 0);
INSERT INTO chado.cvterm VALUES (1247, 22, 'nuclear_mitochondrial', 'An attribute describing a nuclear pseudogene of a mitochndrial gene. [SO:ke]', 1271, 1, 0);
INSERT INTO chado.cvterm VALUES (1248, 22, 'processed', 'An attribute describing a pseudogene where by an mRNA was retrotransposed. The mRNA sequence is transcribed back into the genome, lacking introns and promotors, but often including a polyA tail. [SO:ke]', 1272, 1, 0);
INSERT INTO chado.cvterm VALUES (1249, 22, 'unequally_crossed_over', 'An attribute describing a pseudogene that was created by tandem duplication and unequal crossing over during recombination. [SO:ke]', 1273, 1, 0);
INSERT INTO chado.cvterm VALUES (1250, 22, 'independently_known', 'Attribute to describe a feature that is independently known - not predicted. [SO:ke]', 1274, 0, 0);
INSERT INTO chado.cvterm VALUES (1251, 22, 'supported_by_sequence_similarity', 'An attribute to describe a feature that has been predicted using sequence similarity techniques. [SO:ke]', 1275, 0, 0);
INSERT INTO chado.cvterm VALUES (1252, 22, 'supported_by_domain_match', 'An attribute to describe a feature that has been predicted using sequence similarity of a known domain. [SO:ke]', 1276, 0, 0);
INSERT INTO chado.cvterm VALUES (1253, 22, 'supported_by_EST_or_cDNA', 'An attribute to describe a feature that has been predicted using sequence similarity to EST or cDNA data. [SO:ke]', 1277, 0, 0);
INSERT INTO chado.cvterm VALUES (1254, 22, 'orphan', 'A gene whose predicted amino acid sequence is unsupported by any experimental evidence or by any match with any other known sequence. []', 1278, 0, 0);
INSERT INTO chado.cvterm VALUES (1391, 22, 'regulatory_region', 'A region of sequence that is involved in the control of a biological process. [SO:ke]', 1419, 0, 0);
INSERT INTO chado.cvterm VALUES (1255, 22, 'predicted_by_ab_initio_computation', 'An attribute describing a feature that is predicted by a computer program that did not rely on sequence similarity. [SO:ke]', 1279, 0, 0);
INSERT INTO chado.cvterm VALUES (1256, 22, 'asx_turn', 'A motif of three consecutive residues and one H-bond in which: residue(i) is Aspartate or Asparagine (Asx), the side-chain O of residue(i) is H-bonded to the main-chain NH of residue(i+2). [http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1280, 0, 0);
INSERT INTO chado.cvterm VALUES (1257, 22, 'polypeptide_turn_motif', 'A reversal in the direction of the backbone of a protein that is stabilized by hydrogen bond between backbone NH and CO groups, involving no more than 4 amino acid residues. [EBIBS:GAR, uniprot:feature_type]', 1282, 0, 0);
INSERT INTO chado.cvterm VALUES (1258, 22, 'cloned_cDNA_insert', 'A clone insert made from cDNA. [SO:xp]', 1283, 0, 0);
INSERT INTO chado.cvterm VALUES (1259, 22, 'cloned_genomic_insert', 'A clone insert made from genomic DNA. [SO:xp]', 1284, 0, 0);
INSERT INTO chado.cvterm VALUES (1260, 22, 'engineered_insert', 'A clone insert that is engineered. [SO:xp]', 1285, 0, 0);
INSERT INTO chado.cvterm VALUES (1261, 22, 'edit_operation', '', 1286, 1, 0);
INSERT INTO chado.cvterm VALUES (1262, 22, 'insert_U', 'An edit to insert a U. [SO:ke]', 1287, 1, 0);
INSERT INTO chado.cvterm VALUES (1263, 22, 'delete_U', 'An edit to delete a uridine. [SO:ke]', 1288, 1, 0);
INSERT INTO chado.cvterm VALUES (1264, 22, 'substitute_A_to_I', 'An edit to substitute an I for an A. [SO:ke]', 1289, 1, 0);
INSERT INTO chado.cvterm VALUES (1265, 22, 'insert_C', 'An edit to insert a cytidine. [SO:ke]', 1290, 1, 0);
INSERT INTO chado.cvterm VALUES (1266, 22, 'insert_dinucleotide', 'An edit to insert a dinucleotide. [SO:ke]', 1291, 1, 0);
INSERT INTO chado.cvterm VALUES (1267, 22, 'substitute_C_to_U', 'An edit to substitute an U for a C. [SO:ke]', 1292, 1, 0);
INSERT INTO chado.cvterm VALUES (1268, 22, 'insert_G', 'An edit to insert a G. [SO:ke]', 1293, 1, 0);
INSERT INTO chado.cvterm VALUES (1269, 22, 'insert_GC', 'An edit to insert a GC dinucleotide. [SO:ke]', 1294, 1, 0);
INSERT INTO chado.cvterm VALUES (1270, 22, 'insert_GU', 'An edit to insert a GU dinucleotide. [SO:ke]', 1295, 1, 0);
INSERT INTO chado.cvterm VALUES (1271, 22, 'insert_CU', 'An edit to insert a CU dinucleotide. [SO:ke]', 1296, 1, 0);
INSERT INTO chado.cvterm VALUES (1272, 22, 'insert_AU', 'An edit to insert a AU dinucleotide. [SO:ke]', 1297, 1, 0);
INSERT INTO chado.cvterm VALUES (1273, 22, 'insert_AA', 'An edit to insert a AA dinucleotide. [SO:ke]', 1298, 1, 0);
INSERT INTO chado.cvterm VALUES (1274, 22, 'edited_mRNA', 'An mRNA that is edited. [SO:xp]', 1299, 0, 0);
INSERT INTO chado.cvterm VALUES (1275, 22, 'guide_RNA_region', 'A region of guide RNA. [SO:ma]', 1300, 0, 0);
INSERT INTO chado.cvterm VALUES (1276, 22, 'anchor_region', 'A region of a guide_RNA that base-pairs to a target mRNA. [SO:jk]', 1301, 0, 0);
INSERT INTO chado.cvterm VALUES (1277, 22, 'pre_edited_mRNA', 'A primary transcript that, at least in part, encodes one or more proteins that has not been edited. []', 1302, 0, 0);
INSERT INTO chado.cvterm VALUES (1278, 22, 'intermediate', 'An attribute to describe a feature between stages of processing. [SO:ke]', 1303, 0, 0);
INSERT INTO chado.cvterm VALUES (1279, 22, 'miRNA_target_site', 'A miRNA target site is a binding site where the molecule is a micro RNA. [FB:cds]', 1304, 0, 0);
INSERT INTO chado.cvterm VALUES (1280, 22, 'nucleotide_binding_site', 'A binding site that, in the molecule, interacts selectively and non-covalently with nucleotide residues. [SO:cb]', 1305, 0, 0);
INSERT INTO chado.cvterm VALUES (1281, 22, 'edited_CDS', 'A CDS that is edited. [SO:xp]', 1306, 0, 0);
INSERT INTO chado.cvterm VALUES (1282, 22, 'vertebrate_immune_system_feature', '', 1307, 1, 0);
INSERT INTO chado.cvterm VALUES (1283, 22, 'recombinationally_rearranged_vertebrate_immune_system_gene', 'A recombinationally rearranged gene of the vertebrate immune system. [SO:xp]', 1308, 0, 0);
INSERT INTO chado.cvterm VALUES (1284, 22, 'attP_site', 'An integration/excision site of a phage chromosome at which a recombinase acts to insert the phage DNA at a cognate integration/excision site on a bacterial chromosome. [SO:as]', 1309, 0, 0);
INSERT INTO chado.cvterm VALUES (1285, 22, 'phage_sequence', 'The nucleotide sequence of a virus that infects bacteria. [SO:ke]', 1310, 0, 0);
INSERT INTO chado.cvterm VALUES (1286, 22, 'attB_site', 'An integration/excision site of a bacterial chromosome at which a recombinase acts to insert foreign DNA containing a cognate integration/excision site. [SO:as]', 1311, 0, 0);
INSERT INTO chado.cvterm VALUES (1287, 22, 'attL_site', 'A region that results from recombination between attP_site and attB_site, composed of the 5'' portion of attB_site and the 3'' portion of attP_site. [SO:as]', 1312, 0, 0);
INSERT INTO chado.cvterm VALUES (1288, 22, 'attR_site', 'A region that results from recombination between attP_site and attB_site, composed of the 5'' portion of attP_site and the 3'' portion of attB_site. [SO:as]', 1313, 0, 0);
INSERT INTO chado.cvterm VALUES (1289, 22, 'dif_site', 'A site at which replicated bacterial circular chromosomes are decatenated by site specific resolvase. [SO:as]', 1314, 0, 0);
INSERT INTO chado.cvterm VALUES (1290, 22, 'attC_site', 'An attC site is a sequence required for the integration of a DNA of an integron. [SO:as]', 1315, 0, 0);
INSERT INTO chado.cvterm VALUES (1291, 22, 'oriV', 'An origin of vegetative replication in plasmids and phages. [SO:as]', 1316, 0, 0);
INSERT INTO chado.cvterm VALUES (1292, 22, 'oriC', 'An origin of bacterial chromosome replication. [SO:as]', 1317, 0, 0);
INSERT INTO chado.cvterm VALUES (1293, 22, 'DNA_chromosome', 'Structural unit composed of a self-replicating, DNA molecule. [SO:ma]', 1318, 0, 0);
INSERT INTO chado.cvterm VALUES (1294, 22, 'double_stranded_DNA_chromosome', 'Structural unit composed of a self-replicating, double-stranded DNA molecule. [SO:ma]', 1319, 0, 0);
INSERT INTO chado.cvterm VALUES (1295, 22, 'double', 'When a nucleotide polymer has two strands that are reverse-complement to one another and pair together. []', 1320, 0, 0);
INSERT INTO chado.cvterm VALUES (1296, 22, 'single_stranded_DNA_chromosome', 'Structural unit composed of a self-replicating, single-stranded DNA molecule. [SO:ma]', 1321, 0, 0);
INSERT INTO chado.cvterm VALUES (1297, 22, 'single', 'When a nucleotide polymer has only one strand. []', 1322, 0, 0);
INSERT INTO chado.cvterm VALUES (1298, 22, 'linear_double_stranded_DNA_chromosome', 'Structural unit composed of a self-replicating, double-stranded, linear DNA molecule. [SO:ma]', 1323, 0, 0);
INSERT INTO chado.cvterm VALUES (1299, 22, 'linear', 'A quality of a nucleotide polymer that has a 3''-terminal residue and a 5''-terminal residue. [SO:cb]', 1324, 0, 0);
INSERT INTO chado.cvterm VALUES (1300, 22, 'circular_double_stranded_DNA_chromosome', 'Structural unit composed of a self-replicating, double-stranded, circular DNA molecule. [SO:ma]', 1325, 0, 0);
INSERT INTO chado.cvterm VALUES (1301, 22, 'circular', 'A quality of a nucleotide polymer that has no terminal nucleotide residues. [SO:cb]', 1326, 0, 0);
INSERT INTO chado.cvterm VALUES (1302, 22, 'linear_single_stranded_DNA_chromosome', 'Structural unit composed of a self-replicating, single-stranded, linear DNA molecule. [SO:ma]', 1327, 0, 0);
INSERT INTO chado.cvterm VALUES (1303, 22, 'circular_single_stranded_DNA_chromosome', 'Structural unit composed of a self-replicating, single-stranded, circular DNA molecule. [SO:ma]', 1328, 0, 0);
INSERT INTO chado.cvterm VALUES (1304, 22, 'RNA_chromosome', 'Structural unit composed of a self-replicating, RNA molecule. [SO:ma]', 1329, 0, 0);
INSERT INTO chado.cvterm VALUES (1305, 22, 'single_stranded_RNA_chromosome', 'Structural unit composed of a self-replicating, single-stranded RNA molecule. [SO:ma]', 1330, 0, 0);
INSERT INTO chado.cvterm VALUES (1306, 22, 'linear_single_stranded_RNA_chromosome', 'Structural unit composed of a self-replicating, single-stranded, linear RNA molecule. [SO:ma]', 1331, 0, 0);
INSERT INTO chado.cvterm VALUES (1307, 22, 'linear_double_stranded_RNA_chromosome', 'Structural unit composed of a self-replicating, double-stranded, linear RNA molecule. [SO:ma]', 1332, 0, 0);
INSERT INTO chado.cvterm VALUES (1308, 22, 'double_stranded_RNA_chromosome', 'Structural unit composed of a self-replicating, double-stranded RNA molecule. [SO:ma]', 1333, 0, 0);
INSERT INTO chado.cvterm VALUES (1309, 22, 'circular_single_stranded_RNA_chromosome', 'Structural unit composed of a self-replicating, single-stranded, circular DNA molecule. [SO:ma]', 1334, 0, 0);
INSERT INTO chado.cvterm VALUES (1310, 22, 'circular_double_stranded_RNA_chromosome', 'Structural unit composed of a self-replicating, double-stranded, circular RNA molecule. [SO:ma]', 1335, 0, 0);
INSERT INTO chado.cvterm VALUES (1311, 22, 'sequence_replication_mode', '', 1336, 1, 0);
INSERT INTO chado.cvterm VALUES (1312, 22, 'rolling_circle', '', 1337, 1, 0);
INSERT INTO chado.cvterm VALUES (1313, 22, 'theta_replication', '', 1338, 1, 0);
INSERT INTO chado.cvterm VALUES (1314, 22, 'DNA_replication_mode', '', 1339, 1, 0);
INSERT INTO chado.cvterm VALUES (1315, 22, 'RNA_replication_mode', '', 1340, 1, 0);
INSERT INTO chado.cvterm VALUES (1316, 22, 'insertion_sequence', 'A terminal_inverted_repeat_element that is bacterial and only encodes the functions required for its transposition between these inverted repeats. [SO:as]', 1341, 0, 0);
INSERT INTO chado.cvterm VALUES (1317, 22, 'minicircle_gene', 'A gene found within a minicircle. []', 1342, 0, 0);
INSERT INTO chado.cvterm VALUES (1318, 22, 'cryptic', 'A feature_attribute describing a feature that is not manifest under normal conditions. [SO:ke]', 1343, 0, 0);
INSERT INTO chado.cvterm VALUES (1319, 22, 'template_region', 'A region of a guide_RNA that specifies the insertions and deletions of bases in the editing of a target mRNA. [SO:jk]', 1344, 0, 0);
INSERT INTO chado.cvterm VALUES (1320, 22, 'gRNA_encoding', 'A non-protein_coding gene that encodes a guide_RNA. [SO:ma]', 1345, 0, 0);
INSERT INTO chado.cvterm VALUES (1321, 22, 'rho_dependent_bacterial_terminator', 'A transcription terminator that is dependent upon Rho. []', 1347, 0, 0);
INSERT INTO chado.cvterm VALUES (1322, 22, 'rho_independent_bacterial_terminator', 'A transcription terminator that is not dependent upon Rho. Rather, the mRNA contains a sequence that allows it to base-pair with itself and make a stem-loop structure. []', 1348, 0, 0);
INSERT INTO chado.cvterm VALUES (1323, 22, 'strand_attribute', 'The attribute of how many strands are present in a nucleotide polymer. []', 1349, 0, 0);
INSERT INTO chado.cvterm VALUES (1324, 22, 'topology_attribute', 'The attribute of whether a nucleotide polymer is linear or circular. []', 1350, 0, 0);
INSERT INTO chado.cvterm VALUES (1325, 22, 'class_II_RNA', 'Small non-coding RNA (59-60 nt long) containing 5'' and 3'' ends that are predicted to come together to form a stem structure. Identified in the social amoeba Dictyostelium discoideum and localized in the cytoplasm. [PMID:15333696]', 1351, 0, 0);
INSERT INTO chado.cvterm VALUES (1326, 22, 'class_I_RNA', 'Small non-coding RNA (55-65 nt long) containing highly conserved 5'' and 3'' ends (16 and 8 nt, respectively) that are predicted to come together to form a stem structure. Identified in the social amoeba Dictyostelium discoideum and localized in the cytoplasm. [PMID:15333696]', 1352, 0, 0);
INSERT INTO chado.cvterm VALUES (1327, 22, 'BAC_cloned_genomic_insert', 'A region of DNA that has been inserted into the bacterial genome using a bacterial artificial chromosome. []', 1353, 0, 0);
INSERT INTO chado.cvterm VALUES (1328, 22, 'consensus', 'A sequence produced from an aligment algorithm that uses multiple sequences as input. []', 1354, 0, 0);
INSERT INTO chado.cvterm VALUES (1329, 22, 'consensus_region', 'A region that has a known consensus sequence. []', 1355, 0, 0);
INSERT INTO chado.cvterm VALUES (1330, 22, 'consensus_mRNA', 'An mRNA sequence produced from an aligment algorithm that uses multiple sequences as input. []', 1356, 0, 0);
INSERT INTO chado.cvterm VALUES (1331, 22, 'predicted_gene', 'A region of the genome that has been predicted to be a gene but has not been confirmed by laboratory experiments. []', 1357, 0, 0);
INSERT INTO chado.cvterm VALUES (1332, 22, 'gene_fragment', 'A portion of a gene that is not the complete gene. []', 1358, 0, 0);
INSERT INTO chado.cvterm VALUES (1333, 22, 'recursive_splice_site', 'A recursive splice site is a splice site which subdivides a large intron. Recursive splicing is a mechanism that splices large introns by sub dividing the intron at non exonic elements and alternate exons. [http://www.genetics.org/cgi/content/full/170/2/661]', 1359, 0, 0);
INSERT INTO chado.cvterm VALUES (1334, 22, 'BAC_end', 'A region of sequence from the end of a BAC clone that may provide a highly specific marker. [SO:ke]', 1360, 0, 0);
INSERT INTO chado.cvterm VALUES (1335, 22, 'cytosolic_16S_rRNA', 'Cytosolic 16S rRNA is an RNA component of the small subunit of cytosolic ribosomes in prokaryotes. [SO:ke]', 1361, 0, 0);
INSERT INTO chado.cvterm VALUES (1336, 22, 'cytosolic_rRNA_16S_gene', 'A gene which codes for 16S_rRNA, which functions as the small subunit of the ribosome in prokaryotes. []', 1362, 0, 0);
INSERT INTO chado.cvterm VALUES (1337, 22, 'cytosolic_23S_rRNA', 'Cytosolic 23S rRNA is an RNA component of the large subunit of cytosolic ribosomes in prokaryotes. [SO:ke]', 1363, 0, 0);
INSERT INTO chado.cvterm VALUES (1338, 22, 'cytosolic_rRNA_23S_gene', 'A gene which codes for 23S_rRNA, which functions as a component of the large subunit of the ribosome in prokaryotes. []', 1364, 0, 0);
INSERT INTO chado.cvterm VALUES (1339, 22, 'cytosolic_25S_rRNA', 'Cytosolic 25S rRNA is an RNA component of the large subunit of cytosolic ribosomes most eukaryotes. [PMID:15493135, PMID:2100998, RSC:cb]', 1365, 0, 0);
INSERT INTO chado.cvterm VALUES (1340, 22, 'cytosolic_rRNA_25S_gene', 'A gene which codes for 25S_rRNA, which functions as a component of the large subunit of the ribosome in some eukaryotes. []', 1366, 0, 0);
INSERT INTO chado.cvterm VALUES (1341, 22, 'solo_LTR', 'A recombination product between the 2 LTR of the same element. [SO:ke]', 1367, 0, 0);
INSERT INTO chado.cvterm VALUES (1342, 22, 'low_complexity', 'When a sequence does not contain an equal distribution of all four possible nucleotide bases or does not contain all nucleotide bases. []', 1368, 0, 0);
INSERT INTO chado.cvterm VALUES (1343, 22, 'low_complexity_region', 'A region where the DNA does not contain an equal distrubution of all four possible nucleotides or does not contain all four nucleotides. []', 1369, 0, 0);
INSERT INTO chado.cvterm VALUES (1344, 22, 'prophage', 'A phage genome after it has established in the host genome in a latent/immune state either as a plasmid or as an integrated \"island\". [GOC:jl]', 1370, 0, 0);
INSERT INTO chado.cvterm VALUES (1345, 22, 'cryptic_prophage', 'A remnant of an integrated prophage in the host genome or an \"island\" in the host genome that includes phage like-genes. [GOC:jl]', 1371, 0, 0);
INSERT INTO chado.cvterm VALUES (1346, 22, 'tetraloop', 'A base-paired stem with loop of 4 non-hydrogen bonded nucleotides. [SO:ke]', 1372, 0, 0);
INSERT INTO chado.cvterm VALUES (1347, 22, 'DNA_constraint_sequence', 'A double-stranded DNA used to control macromolecular structure and function. [http:/www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=search&db=pubmed&term=SILVERMAN+SK[au\]&dispmax=50]', 1373, 0, 0);
INSERT INTO chado.cvterm VALUES (1348, 22, 'i_motif', 'A cytosine rich domain whereby strands associate both inter- and intramolecularly at moderately acidic pH. [PMID:9753739]', 1374, 0, 0);
INSERT INTO chado.cvterm VALUES (1392, 22, 'enhanceosome', '', 1420, 1, 0);
INSERT INTO chado.cvterm VALUES (1349, 22, 'PNA_oligo', 'Peptide nucleic acid, is a chemical not known to occur naturally but is artificially synthesized and used in some biological research and medical treatments. The PNA backbone is composed of repeating N-(2-aminoethyl)-glycine units linked by peptide bonds. The purine and pyrimidine bases are linked to the backbone by methylene carbonyl bonds. [SO:ke]', 1375, 0, 0);
INSERT INTO chado.cvterm VALUES (1350, 22, 'PNA', 'An attribute describing a sequence composed of peptide nucleic acid (CHEBI:48021), a chemical consisting of nucleobases bound to a backbone composed of repeating N-(2-aminoethyl)-glycine units linked by peptide bonds. The purine and pyrimidine bases are linked to the backbone by methylene carbonyl bonds. [RSC:cb]', 1376, 0, 0);
INSERT INTO chado.cvterm VALUES (1351, 22, 'DNAzyme', 'A DNA sequence with catalytic activity. [SO:cb]', 1377, 0, 0);
INSERT INTO chado.cvterm VALUES (1352, 22, 'MNP', 'A multiple nucleotide polymorphism with alleles of common length > 1, for example AAA/TTT. [http://www.ncbi.nlm.nih.gov/SNP/snp_ref.cgi?rs=rs2067431]', 1378, 0, 0);
INSERT INTO chado.cvterm VALUES (1353, 22, 'MNV', 'An MNV is a multiple nucleotide variant (substitution) in which the inserted sequence is the same length as the replaced sequence. [NCBI:th]', 1379, 0, 0);
INSERT INTO chado.cvterm VALUES (1354, 22, 'intron_domain', 'An intronic region that has an attribute. []', 1380, 0, 0);
INSERT INTO chado.cvterm VALUES (1355, 22, 'wobble_base_pair', 'A type of non-canonical base pairing, most commonly between G and U, which is important for the secondary structure of RNAs. It has similar thermodynamic stability to the Watson-Crick pairing. Wobble base pairs only have two hydrogen bonds. Other wobble base pair possibilities are I-A, I-U and I-C. [PMID:11256617]', 1381, 0, 0);
INSERT INTO chado.cvterm VALUES (1356, 22, 'internal_guide_sequence', 'A purine-rich sequence in the group I introns which determines the locations of the splice sites in group I intron splicing and has catalytic activity. [SO:cb]', 1382, 0, 0);
INSERT INTO chado.cvterm VALUES (1357, 22, 'silent_mutation', 'A sequence variant that does not affect protein function. Silent mutations may occur in genic ( CDS, UTR, intron etc) and intergenic regions. Silent mutations may have affects on processes such as splicing and regulation. [SO:ke]', 1383, 0, 0);
INSERT INTO chado.cvterm VALUES (1358, 22, 'feature_variant', 'A sequence variant that falls entirely or partially within a genomic feature. [EBI:fc, SO:ke]', 1385, 0, 0);
INSERT INTO chado.cvterm VALUES (1359, 22, 'epitope', 'A binding site that, in the molecule, interacts selectively and non-covalently with antibodies, B cells or T cells. [http://en.wikipedia.org/wiki/Epitope, SO:cb]', 1386, 0, 0);
INSERT INTO chado.cvterm VALUES (1360, 22, 'copy_number_variation', 'A variation that increases or decreases the copy number of a given region. [SO:ke]', 1387, 0, 0);
INSERT INTO chado.cvterm VALUES (1361, 22, 'sequence_variant_affecting_copy_number', '', 1388, 1, 0);
INSERT INTO chado.cvterm VALUES (1362, 22, 'chromosome_breakpoint', 'A chromosomal region that may sustain a double-strand break, resulting in a recombination event. []', 1389, 0, 0);
INSERT INTO chado.cvterm VALUES (1363, 22, 'inversion_breakpoint', 'The point within a chromosome where an inversion begins or ends. [SO:cb]', 1391, 0, 0);
INSERT INTO chado.cvterm VALUES (1364, 22, 'allele', 'An allele is one of a set of coexisting sequence variants of a gene. [SO:immuno_workshop]', 1392, 0, 0);
INSERT INTO chado.cvterm VALUES (1365, 22, 'haplotype', 'A haplotype is one of a set of coexisting sequence variants of a haplotype block. [SO:immuno_workshop]', 1393, 0, 0);
INSERT INTO chado.cvterm VALUES (1366, 22, 'polymorphic_sequence_variant', 'A sequence variant that is segregating in one or more natural populations of a species. [SO:immuno_workshop]', 1394, 0, 0);
INSERT INTO chado.cvterm VALUES (1367, 22, 'sequence_collection', 'A collection of discontinuous sequences. [SO:ke]', 1395, 0, 0);
INSERT INTO chado.cvterm VALUES (1368, 22, 'genotype', 'A genotype is a variant genome, complete or incomplete. [SO:immuno_workshop]', 1396, 0, 0);
INSERT INTO chado.cvterm VALUES (1369, 22, 'diplotype', 'A diplotype is a pair of haplotypes from a given individual. It is a genotype where the phase is known. [SO:immuno_workshop]', 1397, 0, 0);
INSERT INTO chado.cvterm VALUES (1370, 22, 'direction_attribute', 'The attribute of whether the sequence is the same direction as a feature (forward) or the opposite direction as a feature (reverse). []', 1398, 0, 0);
INSERT INTO chado.cvterm VALUES (1371, 22, 'mitochondrial_DNA', 'DNA belonging to the genome of a mitochondria. []', 1399, 0, 0);
INSERT INTO chado.cvterm VALUES (1372, 22, 'chloroplast_DNA', 'DNA belonging to the genome of a chloroplast, a photosynthetic plastid. []', 1400, 0, 0);
INSERT INTO chado.cvterm VALUES (1373, 22, 'miRtron', 'A de-branched intron which mimics the structure of pre-miRNA and enters the miRNA processing pathway without Drosha mediated cleavage. [PMID:17589500, SO:ma]', 1401, 0, 0);
INSERT INTO chado.cvterm VALUES (1374, 22, 'arginyl_tRNA', 'A tRNA sequence that has an arginine anticodon, and a 3'' arginine binding region. [SO:ke]', 1402, 0, 0);
INSERT INTO chado.cvterm VALUES (1375, 22, 'integrated_plasmid', 'A plasmid sequence that is integrated within the host chromosome. [SO:ke]', 1403, 0, 0);
INSERT INTO chado.cvterm VALUES (1376, 22, 'viral_sequence', 'The region of nucleotide sequence of a virus, a submicroscopic particle that replicates by infecting a host cell. [SO:ke]', 1404, 0, 0);
INSERT INTO chado.cvterm VALUES (1377, 22, 'attCtn_site', 'An attachment site located on a conjugative transposon and used for site-specific integration of a conjugative transposon. [Phigo:at]', 1405, 0, 0);
INSERT INTO chado.cvterm VALUES (1378, 22, 'nuclear_mt_pseudogene', 'A nuclear pseudogene of either coding or non-coding mitochondria derived sequence. [SO:xp]', 1406, 0, 0);
INSERT INTO chado.cvterm VALUES (1379, 22, 'cointegrated_plasmid', 'A MGE region consisting of two fused plasmids resulting from a replicative transposition event. [phigo:at]', 1407, 0, 0);
INSERT INTO chado.cvterm VALUES (1380, 22, 'IRLinv_site', 'Component of the inversion site located at the left of a region susceptible to site-specific inversion. [Phigo:at]', 1408, 0, 0);
INSERT INTO chado.cvterm VALUES (1381, 22, 'inversion_site_part', 'A region located within an inversion site. [SO:ke]', 1409, 0, 0);
INSERT INTO chado.cvterm VALUES (1382, 22, 'IRRinv_site', 'Component of the inversion site located at the right of a region susceptible to site-specific inversion. [Phigo:at]', 1410, 0, 0);
INSERT INTO chado.cvterm VALUES (1383, 22, 'defective_conjugative_transposon', 'An island that contains genes for integration/excision and the gene and site for the initiation of intercellular transfer by conjugation. It can be complemented for transfer by a conjugative transposon. [Phigo:ariane]', 1411, 0, 0);
INSERT INTO chado.cvterm VALUES (1384, 22, 'repeat_fragment', 'A portion of a repeat, interrupted by the insertion of another element. [SO:ke]', 1412, 0, 0);
INSERT INTO chado.cvterm VALUES (1385, 22, 'nested_repeat(SO:0001649)', 'A repeat that is disrupted by the insertion of another element. [SO:ke]', 1413, 0, 0);
INSERT INTO chado.cvterm VALUES (1386, 22, 'nested_region', '', 1414, 1, 0);
INSERT INTO chado.cvterm VALUES (1387, 22, 'nested_repeat', '', 1415, 1, 0);
INSERT INTO chado.cvterm VALUES (1388, 22, 'nested_transposon', '', 1416, 1, 0);
INSERT INTO chado.cvterm VALUES (1389, 22, 'transposon_fragment', 'A portion of a transposon, interrupted by the insertion of another element. [SO:ke]', 1417, 0, 0);
INSERT INTO chado.cvterm VALUES (1390, 22, 'nested_transposon(SO:0001648)', 'A transposon that is disrupted by the insertion of another element. [SO:ke]', 1418, 0, 0);
INSERT INTO chado.cvterm VALUES (1393, 22, 'promoter_targeting_sequence', 'A transcriptional_cis_regulatory_region that restricts the activity of a CRM to a single promoter and which functions only when both itself and an insulator are located between the CRM and the promoter. [SO:regcreative]', 1421, 1, 0);
INSERT INTO chado.cvterm VALUES (1394, 22, 'sequence_comparison', 'A position or feature where two sequences have been compared. []', 1424, 0, 0);
INSERT INTO chado.cvterm VALUES (1395, 22, 'propeptide_cleavage_site', 'The propeptide_cleavage_site is the arginine/lysine boundary on a propeptide where cleavage occurs. [EBIBS:GAR]', 1425, 0, 0);
INSERT INTO chado.cvterm VALUES (1396, 22, 'propeptide_region_of_CDS', 'A CDS region corresponding to a propeptide of a polypeptide. []', 1428, 0, 0);
INSERT INTO chado.cvterm VALUES (1397, 22, 'active_peptide', 'Active peptides are proteins which are biologically active, released from a precursor molecule. [EBIBS:GAR, UniProt:curation_manual]', 1430, 0, 0);
INSERT INTO chado.cvterm VALUES (1398, 22, 'compositionally_biased_region_of_peptide', 'Polypeptide region that is rich in a particular amino acid or homopolymeric and greater than three residues in length. [EBIBS:GAR, UniProt:curation_manual]', 1432, 0, 0);
INSERT INTO chado.cvterm VALUES (1399, 22, 'polypeptide_motif', 'A sequence motif is a short (up to 20 amino acids) region of biological interest. Such motifs, although they are too short to constitute functional domains, share sequence similarities and are conserved in different proteins. They display a common function (protein-binding, subcellular location etc.). [EBIBS:GAR, UniProt:curation_manual]', 1434, 0, 0);
INSERT INTO chado.cvterm VALUES (1400, 22, 'polypeptide_repeat', 'A polypeptide_repeat is a single copy of an internal sequence repetition. [EBIBS:GAR]', 1436, 0, 0);
INSERT INTO chado.cvterm VALUES (1401, 22, 'membrane_structure', 'Arrangement of the polypeptide with respect to the lipid bilayer. [EBIBS:GAR]', 1439, 0, 0);
INSERT INTO chado.cvterm VALUES (1402, 22, 'extramembrane_polypeptide_region', 'Polypeptide region that is localized outside of a lipid bilayer. [EBIBS:GAR, SO:cb]', 1441, 0, 0);
INSERT INTO chado.cvterm VALUES (1403, 22, 'cytoplasmic_polypeptide_region', 'Polypeptide region that is localized inside the cytoplasm. [EBIBS:GAR, SO:cb]', 1443, 0, 0);
INSERT INTO chado.cvterm VALUES (1404, 22, 'non_cytoplasmic_polypeptide_region', 'Polypeptide region that is localized outside of a lipid bilayer and outside of the cytoplasm. [EBIBS:GAR, SO:cb]', 1445, 0, 0);
INSERT INTO chado.cvterm VALUES (1405, 22, 'intramembrane_polypeptide_region', 'Polypeptide region present in the lipid bilayer. [EBIBS:GAR]', 1447, 0, 0);
INSERT INTO chado.cvterm VALUES (1406, 22, 'membrane_peptide_loop', 'Polypeptide region localized within the lipid bilayer where both ends traverse the same membrane. [EBIBS:GAR, SO:cb]', 1449, 0, 0);
INSERT INTO chado.cvterm VALUES (1407, 22, 'transmembrane_polypeptide_region', 'Polypeptide region traversing the lipid bilayer. [EBIBS:GAR, UniProt:curator_manual]', 1451, 0, 0);
INSERT INTO chado.cvterm VALUES (1408, 22, 'polypeptide_secondary_structure', 'A region of peptide with secondary structure has hydrogen bonding along the peptide chain that causes a defined conformation of the chain. [EBIBS:GAR]', 1453, 0, 0);
INSERT INTO chado.cvterm VALUES (1409, 22, 'polypeptide_structural_motif', 'Motif is a three-dimensional structural element within the chain, which appears also in a variety of other molecules. Unlike a domain, a motif does not need to form a stable globular unit. [EBIBS:GAR]', 1455, 0, 0);
INSERT INTO chado.cvterm VALUES (1410, 22, 'coiled_coil', 'A coiled coil is a structural motif in proteins, in which alpha-helices are coiled together like the strands of a rope. [EBIBS:GAR, UniProt:curation_manual]', 1457, 0, 0);
INSERT INTO chado.cvterm VALUES (1411, 22, 'helix_turn_helix', 'A motif comprising two helices separated by a turn. [EBIBS:GAR]', 1459, 0, 0);
INSERT INTO chado.cvterm VALUES (1412, 22, 'peptide_helix', 'A helix is a secondary_structure conformation where the peptide backbone forms a coil. [EBIBS:GAR]', 1461, 0, 0);
INSERT INTO chado.cvterm VALUES (1413, 22, 'polypeptide_sequencing_information', 'Incompatibility in the sequence due to some experimental problem. [EBIBS:GAR]', 1462, 0, 0);
INSERT INTO chado.cvterm VALUES (1414, 22, 'non_adjacent_residues', 'Indicates that two consecutive residues in a fragment sequence are not consecutive in the full-length protein and that there are a number of unsequenced residues between them. [EBIBS:GAR, UniProt:curation_manual]', 1464, 0, 0);
INSERT INTO chado.cvterm VALUES (1415, 22, 'non_terminal_residue', 'The residue at an extremity of the sequence is not the terminal residue. [EBIBS:GAR, UniProt:curation_manual]', 1466, 0, 0);
INSERT INTO chado.cvterm VALUES (1416, 22, 'sequence_conflict', 'Different sources report differing sequences. [EBIBS:GAR, UniProt:curation_manual]', 1468, 0, 0);
INSERT INTO chado.cvterm VALUES (1417, 22, 'sequence_uncertainty', 'Describes the positions in a sequence where the authors are unsure about the sequence assignment. [EBIBS:GAR, UniProt:curation_manual]', 1470, 0, 0);
INSERT INTO chado.cvterm VALUES (1418, 22, 'cross_link', 'Posttranslationally formed amino acid bonds. [EBIBS:GAR, UniProt:curation_manual]', 1472, 1, 0);
INSERT INTO chado.cvterm VALUES (1419, 22, 'disulfide_bond', 'The covalent bond between sulfur atoms that binds two peptide chains or different parts of one peptide chain and is a structural determinant in many protein molecules. [EBIBS:GAR, UniProt:curation_manual]', 1474, 1, 0);
INSERT INTO chado.cvterm VALUES (1420, 22, 'post_translationally_modified_region', 'A region where a transformation occurs in a protein after it has been synthesized. This which may regulate, stabilize, crosslink or introduce new chemical functionalities in the protein. [EBIBS:GAR, UniProt:curation_manual]', 1476, 0, 0);
INSERT INTO chado.cvterm VALUES (1421, 22, 'biochemical_region_of_peptide', 'A region of a peptide that is involved in a biochemical function. [EBIBS:GAR]', 1478, 0, 0);
INSERT INTO chado.cvterm VALUES (1422, 22, 'covalent_binding_site', 'Binding involving a covalent bond. [EBIBS:GAR]', 1479, 1, 0);
INSERT INTO chado.cvterm VALUES (1423, 22, 'non_covalent_binding_site', 'Binding site for any chemical group (co-enzyme, prosthetic group, etc.). [EBIBS:GAR]', 1481, 1, 0);
INSERT INTO chado.cvterm VALUES (1424, 22, 'polypeptide_metal_contact', 'A binding site that, in the polypeptide molecule, interacts selectively and non-covalently with metal ions. [EBIBS:GAR, SO:cb, UniProt:curation_manual]', 1483, 0, 0);
INSERT INTO chado.cvterm VALUES (1425, 22, 'metal_binding_site', 'A binding site that, in the molecule, interacts selectively and non-covalently with metal ions. [SO:cb]', 1485, 0, 0);
INSERT INTO chado.cvterm VALUES (1426, 22, 'molecular_contact_region', 'A region that is involved a contact with another molecule. [EBIBS:GAR]', 1486, 0, 0);
INSERT INTO chado.cvterm VALUES (1427, 22, 'protein_protein_contact', 'A binding site that, in the protein molecule, interacts selectively and non-covalently with polypeptide residues. [EBIBS:GAR, UniProt:Curation_manual]', 1487, 0, 0);
INSERT INTO chado.cvterm VALUES (1428, 22, 'polypeptide_calcium_ion_contact_site', 'A binding site that, in the polypeptide molecule, interacts selectively and non-covalently with calcium ions. [EBIBS:GAR]', 1489, 0, 0);
INSERT INTO chado.cvterm VALUES (1429, 22, 'polypeptide_cobalt_ion_contact_site', 'A binding site that, in the polypeptide molecule, interacts selectively and non-covalently with cobalt ions. [EBIBS:GAR, SO:cb]', 1491, 0, 0);
INSERT INTO chado.cvterm VALUES (1430, 22, 'polypeptide_copper_ion_contact_site', 'A binding site that, in the polypeptide molecule, interacts selectively and non-covalently with copper ions. [EBIBS:GAR, SO:cb]', 1493, 0, 0);
INSERT INTO chado.cvterm VALUES (1431, 22, 'polypeptide_iron_ion_contact_site', 'A binding site that, in the polypeptide molecule, interacts selectively and non-covalently with iron ions. [EBIBS:GAR, SO:cb]', 1495, 0, 0);
INSERT INTO chado.cvterm VALUES (1432, 22, 'polypeptide_magnesium_ion_contact_site', 'A binding site that, in the polypeptide molecule, interacts selectively and non-covalently with magnesium ions. [EBIBS:GAR, SO:cb]', 1497, 0, 0);
INSERT INTO chado.cvterm VALUES (1433, 22, 'polypeptide_manganese_ion_contact_site', 'A binding site that, in the polypeptide molecule, interacts selectively and non-covalently with manganese ions. [EBIBS:GAR, SO:cb]', 1499, 0, 0);
INSERT INTO chado.cvterm VALUES (1434, 22, 'polypeptide_molybdenum_ion_contact_site', 'A binding site that, in the polypeptide molecule, interacts selectively and non-covalently with molybdenum ions. [EBIBS:GAR, SO:cb]', 1501, 0, 0);
INSERT INTO chado.cvterm VALUES (1435, 22, 'polypeptide_nickel_ion_contact_site', 'A binding site that, in the polypeptide molecule, interacts selectively and non-covalently with nickel ions. [EBIBS:GAR]', 1503, 0, 0);
INSERT INTO chado.cvterm VALUES (1436, 22, 'polypeptide_tungsten_ion_contact_site', 'A binding site that, in the polypeptide molecule, interacts selectively and non-covalently with tungsten ions. [EBIBS:GAR, SO:cb]', 1505, 0, 0);
INSERT INTO chado.cvterm VALUES (1437, 22, 'polypeptide_zinc_ion_contact_site', 'A binding site that, in the polypeptide molecule, interacts selectively and non-covalently with zinc ions. [EBIBS:GAR, SO:cb]', 1507, 0, 0);
INSERT INTO chado.cvterm VALUES (1438, 22, 'catalytic_residue', 'Amino acid involved in the activity of an enzyme. [EBIBS:GAR, UniProt:curation_manual]', 1509, 0, 0);
INSERT INTO chado.cvterm VALUES (1439, 22, 'amino_acid', 'A sequence feature that corresponds to a single amino acid residue in a polypeptide. [RSC:cb]', 1511, 0, 0);
INSERT INTO chado.cvterm VALUES (1440, 22, 'polypeptide_catalytic_motif', 'A polypeptide catalytic motif is a short (up to 20 amino acids) polypeptide region that contains one or more active site residues. [EBIBS:GAR]', 1512, 0, 0);
INSERT INTO chado.cvterm VALUES (1441, 22, 'polypeptide_ligand_contact', 'Residues which interact with a ligand. [EBIBS:GAR]', 1513, 0, 0);
INSERT INTO chado.cvterm VALUES (1442, 22, 'ligand_binding_site', 'A binding site that, in the molecule, interacts selectively and non-covalently with a small molecule such as a drug, or hormone. [SO:ke]', 1515, 0, 0);
INSERT INTO chado.cvterm VALUES (1443, 22, 'asx_motif', 'A motif of five consecutive residues and two H-bonds in which: Residue(i) is Aspartate or Asparagine (Asx), side-chain O of residue(i) is H-bonded to the main-chain NH of residue(i+2) or (i+3), main-chain CO of residue(i) is H-bonded to the main-chain NH of residue(i+3) or (i+4). [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1516, 0, 0);
INSERT INTO chado.cvterm VALUES (1444, 22, 'beta_bulge', 'A motif of three residues within a beta-sheet in which the main chains of two consecutive residues are H-bonded to that of the third, and in which the dihedral angles are as follows: Residue(i): -140 degrees < phi(l) -20 degrees , -90 degrees < psi(l) < 40 degrees. Residue (i+1): -180 degrees < phi < -25 degrees or +120 degrees < phi < +180 degrees, +40 degrees < psi < +180 degrees or -180 degrees < psi < -120 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1518, 0, 0);
INSERT INTO chado.cvterm VALUES (1445, 22, 'beta_bulge_loop', 'A motif of three residues within a beta-sheet consisting of two H-bonds. Beta bulge loops often occur at the loop ends of beta-hairpins. [EBIBS:GAR, Http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1520, 0, 0);
INSERT INTO chado.cvterm VALUES (1446, 22, 'beta_bulge_loop_five', 'A motif of three residues within a beta-sheet consisting of two H-bonds in which: the main-chain NH of residue(i) is H-bonded to the main-chain CO of residue(i+4), the main-chain CO of residue i is H-bonded to the main-chain NH of residue(i+3), these loops have an RL nest at residues i+2 and i+3. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1522, 0, 0);
INSERT INTO chado.cvterm VALUES (1447, 22, 'beta_bulge_loop_six', 'A motif of three residues within a beta-sheet consisting of two H-bonds in which: the main-chain NH of residue(i) is H-bonded to the main-chain CO of residue(i+5), the main-chain CO of residue i is H-bonded to the main-chain NH of residue(i+4), these loops have an RL nest at residues i+3 and i+4. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1524, 0, 0);
INSERT INTO chado.cvterm VALUES (1448, 22, 'beta_strand', 'A beta strand describes a single length of polypeptide chain that forms part of a beta sheet. A single continuous stretch of amino acids adopting an extended conformation of hydrogen bonds between the N-O and the C=O of another part of the peptide. This forms a secondary protein structure in which two or more extended polypeptide regions are hydrogen-bonded to one another in a planar array. [EBIBS:GAR, UniProt:curation_manual]', 1526, 0, 0);
INSERT INTO chado.cvterm VALUES (1449, 22, 'antiparallel_beta_strand', 'A peptide region which hydrogen bonded to another region of peptide running in the oposite direction (one running N-terminal to C-terminal and one running C-terminal to N-terminal). Hydrogen bonding occurs between every other C=O from one strand to every other N-H on the adjacent strand. In this case, if two atoms C-alpha (i) and C-alpha (j) are adjacent in two hydrogen-bonded beta strands, then they form two mutual backbone hydrogen bonds to each other''s flanking peptide groups; this is known as a close pair of hydrogen bonds. The peptide backbone dihedral angles (phi, psi) are about (-140 degrees, 135 degrees) in antiparallel sheets. [EBIBS:GAR, UniProt:curation_manual]', 1528, 0, 0);
INSERT INTO chado.cvterm VALUES (1450, 22, 'parallel_beta_strand', 'A peptide region which hydrogen bonded to another region of peptide running in the oposite direction (both running N-terminal to C-terminal). This orientation is slightly less stable because it introduces nonplanarity in the inter-strand hydrogen bonding pattern. Hydrogen bonding occurs between every other C=O from one strand to every other N-H on the adjacent strand. In this case, if two atoms C-alpha (i)and C-alpha (j) are adjacent in two hydrogen-bonded beta strands, then they do not hydrogen bond to each other; rather, one residue forms hydrogen bonds to the residues that flank the other (but not vice versa). For example, residue i may form hydrogen bonds to residues j - 1 and j + 1; this is known as a wide pair of hydrogen bonds. By contrast, residue j may hydrogen-bond to different residues altogether, or to none at all. The dihedral angles (phi, psi) are about (-120 degrees, 115 degrees) in parallel sheets. [EBIBS:GAR, UniProt:curation_manual]', 1530, 0, 0);
INSERT INTO chado.cvterm VALUES (1451, 22, 'left_handed_peptide_helix', 'A left handed helix is a region of peptide where the coiled conformation turns in an anticlockwise, left handed screw. [EBIBS:GAR]', 1533, 0, 0);
INSERT INTO chado.cvterm VALUES (1452, 22, 'right_handed_peptide_helix', 'A right handed helix is a region of peptide where the coiled conformation turns in a clockwise, right handed screw. [EBIBS:GAR]', 1535, 0, 0);
INSERT INTO chado.cvterm VALUES (1453, 22, 'alpha_helix', 'The helix has 3.6 residues per turn which corresponds to a translation of 1.5 angstroms (= 0.15 nm) along the helical axis. Every backbone N-H group donates a hydrogen bond to the backbone C=O group of the amino acid four residues earlier. [EBIBS:GAR]', 1537, 0, 0);
INSERT INTO chado.cvterm VALUES (1454, 22, 'pi_helix', 'The pi helix has 4.1 residues per turn and a translation of 1.15 (=0.115 nm) along the helical axis. The N-H group of an amino acid forms a hydrogen bond with the C=O group of the amino acid five residues earlier. [EBIBS:GAR]', 1539, 0, 0);
INSERT INTO chado.cvterm VALUES (1455, 22, 'three_ten_helix', 'The 3-10 helix has 3 residues per turn with a translation of 2.0 angstroms (=0.2 nm) along the helical axis. The N-H group of an amino acid forms a hydrogen bond with the C=O group of the amino acid three residues earlier. [EBIBS:GAR]', 1541, 0, 0);
INSERT INTO chado.cvterm VALUES (1456, 22, 'polypeptide_nest_motif', 'A motif of two consecutive residues with dihedral angles. Nest should not have Proline as any residue. Nests frequently occur as parts of other motifs such as Schellman loops. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1543, 0, 0);
INSERT INTO chado.cvterm VALUES (1457, 22, 'polypeptide_nest_left_right_motif', 'A motif of two consecutive residues with dihedral angles: Residue(i): +20 degrees < phi < +140 degrees, -40 degrees < psi < +90 degrees. Residue(i+1): -140 degrees < phi < -20 degrees, -90 degrees < psi < +40 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1545, 0, 0);
INSERT INTO chado.cvterm VALUES (1458, 22, 'polypeptide_nest_right_left_motif', 'A motif of two consecutive residues with dihedral angles: Residue(i): -140 degrees < phi < -20 degrees, -90 degrees < psi < +40 degrees. Residue(i+1): +20 degrees < phi < +140 degrees, -40 degrees < psi < +90 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1547, 0, 0);
INSERT INTO chado.cvterm VALUES (1459, 22, 'schellmann_loop', 'A motif of six or seven consecutive residues that contains two H-bonds. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1549, 0, 0);
INSERT INTO chado.cvterm VALUES (1460, 22, 'schellmann_loop_seven', 'Wild type: A motif of seven consecutive residues that contains two H-bonds in which: the main-chain CO of residue(i) is H-bonded to the main-chain NH of residue(i+6), the main-chain CO of residue(i+1) is H-bonded to the main-chain NH of residue(i+5). [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1551, 0, 0);
INSERT INTO chado.cvterm VALUES (1461, 22, 'schellmann_loop_six', 'Common Type: A motif of six consecutive residues that contains two H-bonds in which: the main-chain CO of residue(i) is H-bonded to the main-chain NH of residue(i+5) the main-chain CO of residue(i+1) is H-bonded to the main-chain NH of residue(i+4). [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1553, 0, 0);
INSERT INTO chado.cvterm VALUES (1462, 22, 'serine_threonine_motif', 'A motif of five consecutive residues and two hydrogen bonds in which: residue(i) is Serine (S) or Threonine (T), the side-chain O of residue(i) is H-bonded to the main-chain NH of residue(i+2) or (i+3) , the main-chain CO group of residue(i) is H-bonded to the main-chain NH of residue(i+3) or (i+4). [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1555, 0, 0);
INSERT INTO chado.cvterm VALUES (1463, 22, 'serine_threonine_staple_motif', 'A motif of four or five consecutive residues and one H-bond in which: residue(i) is Serine (S) or Threonine (T), the side-chain OH of residue(i) is H-bonded to the main-chain CO of residue(i3) or (i4), Phi angles of residues(i1), (i2) and (i3) are negative. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1557, 0, 0);
INSERT INTO chado.cvterm VALUES (1464, 22, 'asx_turn_left_handed_type_one', 'Left handed type I (dihedral angles):- Residue(i): -140 degrees < chi (1) -120 degrees < -20 degrees, -90 degrees < psi +120 degrees < +40 degrees. Residue(i+1): -140 degrees < phi < -20 degrees, -90 degrees < psi < +40 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1560, 0, 0);
INSERT INTO chado.cvterm VALUES (1465, 22, 'asx_turn_left_handed_type_two', 'Left handed type II (dihedral angles):- Residue(i): -140 degrees < chi (1) -120 degrees < -20 degrees, +80 degrees < psi +120 degrees < +180 degrees. Residue(i+1): +20 degrees < phi < +140 degrees, -40 degrees < psi < +90 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1562, 0, 0);
INSERT INTO chado.cvterm VALUES (1466, 22, 'asx_turn_right_handed_type_two', 'Right handed type II (dihedral angles):- Residue(i): -140 degrees < chi (1) -120 degrees < -20 degrees, +80 degrees < psi +120 degrees < +180 degrees. Residue(i+1): +20 degrees < phi < +140 degrees, -40 degrees < psi < +90 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1564, 0, 0);
INSERT INTO chado.cvterm VALUES (1467, 22, 'asx_turn_right_handed_type_one', 'Right handed type I (dihedral angles):- Residue(i): -140 degrees < chi (1) -120 degrees < -20 degrees, -90 degrees < psi +120 degrees < +40 degrees. Residue(i+1): -140 degrees < phi < -20 degrees, -90 degrees < psi < +40 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1566, 0, 0);
INSERT INTO chado.cvterm VALUES (1468, 22, 'beta_turn', 'A motif of four consecutive residues that may contain one H-bond, which, if present, is between the main-chain CO of the first residue and the main-chain NH of the fourth. It is characterized by the dihedral angles of the second and third residues, which are the basis for sub-categorization. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1568, 0, 0);
INSERT INTO chado.cvterm VALUES (1469, 22, 'beta_turn_left_handed_type_one', 'Left handed type I:A motif of four consecutive residues that may contain one H-bond, which, if present, is between the main-chain CO of the first residue and the main-chain NH of the fourth. It is characterized by the dihedral angles:- Residue(i+1): -140 degrees > phi > -20 degrees, -90 degrees > psi > +40 degrees. Residue(i+2): -140 degrees > phi > -20 degrees, -90 degrees > psi > +40 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1570, 0, 0);
INSERT INTO chado.cvterm VALUES (1470, 22, 'beta_turn_left_handed_type_two', 'Left handed type II: A motif of four consecutive residues that may contain one H-bond, which, if present, is between the main-chain CO of the first residue and the main-chain NH of the fourth. It is characterized by the dihedral angles: Residue(i+1): -140 degrees > phi > -20 degrees, +80 degrees > psi > +180 degrees. Residue(i+2): +20 degrees > phi > +140 degrees, -40 degrees > psi > +90 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1572, 0, 0);
INSERT INTO chado.cvterm VALUES (1471, 22, 'beta_turn_right_handed_type_one', 'Right handed type I:A motif of four consecutive residues that may contain one H-bond, which, if present, is between the main-chain CO of the first residue and the main-chain NH of the fourth. It is characterized by the dihedral angles: Residue(i+1): -140 degrees < phi < -20 degrees, -90 degrees < psi < +40 degrees. Residue(i+2): -140 degrees < phi < -20 degrees, -90 degrees < psi < +40 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1574, 0, 0);
INSERT INTO chado.cvterm VALUES (1472, 22, 'beta_turn_right_handed_type_two', 'Right handed type II:A motif of four consecutive residues that may contain one H-bond, which, if present, is between the main-chain CO of the first residue and the main-chain NH of the fourth. It is characterized by the dihedral angles: Residue(i+1): -140 degrees < phi < -20 degrees, +80 degrees < psi < +180 degrees. Residue(i+2): +20 degrees < phi < +140 degrees, -40 degrees < psi < +90 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1576, 0, 0);
INSERT INTO chado.cvterm VALUES (1473, 22, 'gamma_turn', 'Gamma turns, defined for 3 residues i,( i+1),( i+2) if a hydrogen bond exists between residues i and i+2 and the phi and psi angles of residue i+1 fall within 40 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1578, 0, 0);
INSERT INTO chado.cvterm VALUES (1474, 22, 'gamma_turn_classic', 'Gamma turns, defined for 3 residues i, i+1, i+2 if a hydrogen bond exists between residues i and i+2 and the phi and psi angles of residue i+1 fall within 40 degrees: phi(i+1)=75.0 - psi(i+1)=-64.0. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1580, 0, 0);
INSERT INTO chado.cvterm VALUES (1498, 22, 'INR1_motif', 'A promoter motif with consensus sequence TCATTCG. [PMID:16827941]', 1616, 0, 0);
INSERT INTO chado.cvterm VALUES (1475, 22, 'gamma_turn_inverse', 'Gamma turns, defined for 3 residues i, i+1, i+2 if a hydrogen bond exists between residues i and i+2 and the phi and psi angles of residue i+1 fall within 40 degrees: phi(i+1)=-79.0 - psi(i+1)=69.0. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1582, 0, 0);
INSERT INTO chado.cvterm VALUES (1476, 22, 'serine_threonine_turn', 'A motif of three consecutive residues and one H-bond in which: residue(i) is Serine (S) or Threonine (T), the side-chain O of residue(i) is H-bonded to the main-chain NH of residue(i+2). [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1584, 0, 0);
INSERT INTO chado.cvterm VALUES (1477, 22, 'st_turn_left_handed_type_one', 'The peptide twists in an anticlockwise, left handed manner. The dihedral angles for this turn are: Residue(i): -140 degrees < chi(1) -120 degrees < -20 degrees, -90 degrees psi +120 degrees < +40 degrees, residue(i+1): -140 degrees < phi < -20 degrees, -90 < psi < +40 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1586, 0, 0);
INSERT INTO chado.cvterm VALUES (1478, 22, 'st_turn_left_handed_type_two', 'The peptide twists in an anticlockwise, left handed manner. The dihedral angles for this turn are: Residue(i): -140 degrees < chi(1) -120 degrees < -20 degrees, +80 degrees psi +120 degrees < +180 degrees, residue(i+1): +20 degrees < phi < +140 degrees, -40 < psi < +90 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1588, 0, 0);
INSERT INTO chado.cvterm VALUES (1479, 22, 'st_turn_right_handed_type_one', 'The peptide twists in an clockwise, right handed manner. The dihedral angles for this turn are: Residue(i): -140 degrees < chi(1) -120 degrees < -20 degrees, -90 degrees psi +120 degrees < +40 degrees, residue(i+1): -140 degrees < phi < -20 degrees, -90 < psi < +40 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1590, 0, 0);
INSERT INTO chado.cvterm VALUES (1480, 22, 'st_turn_right_handed_type_two', 'The peptide twists in an clockwise, right handed manner. The dihedral angles for this turn are: Residue(i): -140 degrees < chi(1) -120 degrees < -20 degrees, +80 degrees psi +120 degrees < +180 degrees, residue(i+1): +20 degrees < phi < +140 degrees, -40 < psi < +90 degrees. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 1592, 0, 0);
INSERT INTO chado.cvterm VALUES (1481, 22, 'polypeptide_variation_site', 'A site of sequence variation (alteration). Alternative sequence due to naturally occurring events such as polymorphisms and alternative splicing or experimental methods such as site directed mutagenesis. [EBIBS:GAR, SO:ke]', 1594, 0, 0);
INSERT INTO chado.cvterm VALUES (1482, 22, 'natural_variant_site', 'Describes the natural sequence variants due to polymorphisms, disease-associated mutations, RNA editing and variations between strains, isolates or cultivars. [EBIBS:GAR, UniProt:curation_manual]', 1596, 0, 0);
INSERT INTO chado.cvterm VALUES (1483, 22, 'mutated_variant_site', 'Site which has been experimentally altered. [EBIBS:GAR, UniProt:curation_manual]', 1598, 0, 0);
INSERT INTO chado.cvterm VALUES (1484, 22, 'alternate_sequence_site', 'Description of sequence variants produced by alternative splicing, alternative promoter usage, alternative initiation and ribosomal frameshifting. [EBIBS:GAR, UniProt:curation_manual]', 1600, 0, 0);
INSERT INTO chado.cvterm VALUES (1485, 22, 'beta_turn_type_six', 'A motif of four consecutive peptide resides of type VIa or type VIb and where the i+2 residue is cis-proline. [SO:cb]', 1603, 0, 0);
INSERT INTO chado.cvterm VALUES (1486, 22, 'beta_turn_type_six_a', 'A motif of four consecutive peptide residues, of which the i+2 residue is proline, and that may contain one H-bond, which, if present, is between the main-chain CO of the first residue and the main-chain NH of the fourth and is characterized by the dihedral angles: Residue(i+1): phi ~ -60 degrees, psi ~ 120 degrees. Residue(i+2): phi ~ -90 degrees, psi ~ 0 degrees. [PMID:2371257, SO:cb]', 1604, 0, 0);
INSERT INTO chado.cvterm VALUES (1487, 22, 'beta_turn_type_six_a_one', 'A type VIa beta turn with the following phi and psi sngles on amino acid residues 2 and 3: phi-2 = -60 degrees, psi-2 = 120 degrees, phi-3 = -90 degrees, psi-3 = 0 degrees. [PMID:27428516]', 1605, 0, 0);
INSERT INTO chado.cvterm VALUES (1488, 22, 'beta_turn_type_six_a_two', 'A type VIa beta turn with the following phi and psi sngles on amino acid residues 2 and 3: phi-2 = -120 degrees, psi-2 = 120 degrees, phi-3 = -60 degrees, psi-3 = 0 degrees. [PMID:27428516]', 1606, 0, 0);
INSERT INTO chado.cvterm VALUES (1489, 22, 'beta_turn_type_six_b', 'A motif of four consecutive peptide residues, of which the i+2 residue is proline, and that may contain one H-bond, which, if present, is between the main-chain CO of the first residue and the main-chain NH of the fourth and is characterized by the dihedral angles: Residue(i+1): phi ~ -120 degrees, psi ~ 120 degrees. Residue(i+2): phi ~ -60 degrees, psi ~ 0 degrees. [PMID:2371257, SO:cb]', 1607, 0, 0);
INSERT INTO chado.cvterm VALUES (1490, 22, 'beta_turn_type_eight', 'A motif of four consecutive peptide residues that may contain one H-bond, which, if present, is between the main-chain CO of the first residue and the main-chain NH of the fourth and is characterized by the dihedral angles: Residue(i+1): phi ~ -60 degrees, psi ~ -30 degrees. Residue(i+2): phi ~ -120 degrees, psi ~ 120 degrees. [PMID:2371257, SO:cb]', 1608, 0, 0);
INSERT INTO chado.cvterm VALUES (1491, 22, 'DRE_motif', 'A sequence element characteristic of some RNA polymerase II promoters, usually located between -10 and -60 relative to the TSS. Consensus sequence is WATCGATW. [PMID:12537576]', 1609, 0, 0);
INSERT INTO chado.cvterm VALUES (1492, 22, 'DMv4_motif', 'A sequence element characteristic of some RNA polymerase II promoters, located immediately upstream of some TATA box elements with respect to the TSS (+1). Consensus sequence is YGGTCACACTR. Marked spatial preference within core promoter; tend to occur near the TSS, although not as tightly as INR (SO:0000014). [PMID:16827941\:12537576]', 1610, 0, 0);
INSERT INTO chado.cvterm VALUES (1493, 22, 'E_box_motif', 'A sequence element characteristic of some RNA polymerase II promoters, usually located between -60 and +1 relative to the TSS. Consensus sequence is AWCAGCTGWT. Tends to co-occur with DMv2 (SO:0001161). Tends to not occur with DPE motif (SO:0000015). [PMID:12537576\:16827941]', 1611, 0, 0);
INSERT INTO chado.cvterm VALUES (1494, 22, 'DMv5_motif', 'A sequence element characteristic of some RNA polymerase II promoters, usually located between -50 and -10 relative to the TSS. Consensus sequence is KTYRGTATWTTT. Tends to co-occur with DMv4 (SO:0001157) . Tends to not occur with DPE motif (SO:0000015) or MTE (SO:0001162). [PMID:12537576\:16827941]', 1612, 0, 0);
INSERT INTO chado.cvterm VALUES (1495, 22, 'DMv3_motif', 'A sequence element characteristic of some RNA polymerase II promoters, usually located between -30 and +15 relative to the TSS. Consensus sequence is KNNCAKCNCTRNY. Tends to co-occur with DMv2 (SO:0001161). Tends to not occur with DPE motif (SO:0000015) or MTE (0001162). [PMID:12537576\:16827941]', 1613, 0, 0);
INSERT INTO chado.cvterm VALUES (1496, 22, 'DMv2_motif', 'A sequence element characteristic of some RNA polymerase II promoters, usually located between -60 and -45 relative to the TSS. Consensus sequence is MKSYGGCARCGSYSS. Tends to co-occur with DMv3 (SO:0001160). Tends to not occur with DPE motif (SO:0000015) or MTE (SO:0001162). [PMID:12537576\:16827941]', 1614, 0, 0);
INSERT INTO chado.cvterm VALUES (1497, 22, 'MTE', 'A sequence element characteristic of some RNA polymerase II promoters, usually located between +20 and +30 relative to the TSS. Consensus sequence is CSARCSSAACGS. Tends to co-occur with INR motif (SO:0000014). Tends to not occur with DPE motif (SO:0000015) or DMv5 (SO:0001159). [PMID:12537576\:15231738, PMID:16858867]', 1615, 0, 0);
INSERT INTO chado.cvterm VALUES (1499, 22, 'DPE1_motif', 'A promoter motif with consensus sequence CGGACGT. [PMID:16827941]', 1617, 0, 0);
INSERT INTO chado.cvterm VALUES (1500, 22, 'DMv1_motif', 'A promoter motif with consensus sequence CARCCCT. [PMID:16827941]', 1618, 0, 0);
INSERT INTO chado.cvterm VALUES (1501, 22, 'GAGA_motif', 'A non directional promoter motif with consensus sequence GAGAGCG. [PMID:16827941]', 1619, 0, 0);
INSERT INTO chado.cvterm VALUES (1502, 22, 'NDM2_motif', 'A non directional promoter motif with consensus CGMYGYCR. [PMID:16827941]', 1620, 0, 0);
INSERT INTO chado.cvterm VALUES (1503, 22, 'NDM3_motif', 'A non directional promoter motif with consensus sequence GAAAGCT. [PMID:16827941]', 1621, 0, 0);
INSERT INTO chado.cvterm VALUES (1504, 22, 'ds_RNA_viral_sequence', 'A ds_RNA_viral_sequence is a viral_sequence that is the sequence of a virus that exists as double stranded RNA. [SO:ke]', 1622, 0, 0);
INSERT INTO chado.cvterm VALUES (1505, 22, 'polinton', 'A kind of DNA transposon that populates the genomes of protists, fungi, and animals, characterized by a unique set of proteins necessary for their transposition, including a protein-primed DNA polymerase B, retroviral integrase, cysteine protease, and ATPase. Polintons are characterized by 6-bp target site duplications, terminal-inverted repeats that are several hundred nucleotides long, and 5''-AG and TC-3'' termini. Polintons exist as autonomous and nonautonomous elements. [PMID:16537396]', 1623, 0, 0);
INSERT INTO chado.cvterm VALUES (1506, 22, 'rRNA_21S', 'A component of the large ribosomal subunit in mitochondrial rRNA. [RSC:cb]', 1624, 1, 0);
INSERT INTO chado.cvterm VALUES (1507, 22, 'tRNA_region', 'A region of a tRNA. [RSC:cb]', 1625, 0, 0);
INSERT INTO chado.cvterm VALUES (1508, 22, 'anticodon_loop', 'A sequence of seven nucleotide bases in tRNA which contains the anticodon. It has the sequence 5''-pyrimidine-purine-anticodon-modified purine-any base-3. [ISBN:0716719207]', 1626, 0, 0);
INSERT INTO chado.cvterm VALUES (1509, 22, 'anticodon', 'A sequence of three nucleotide bases in tRNA which recognizes a codon in mRNA. [RSC:cb]', 1627, 0, 0);
INSERT INTO chado.cvterm VALUES (1510, 22, 'CCA_tail', 'Base sequence at the 3'' end of a tRNA. The 3''-hydroxyl group on the terminal adenosine is the attachment point for the amino acid. [ISBN:0716719207]', 1628, 0, 0);
INSERT INTO chado.cvterm VALUES (1511, 22, 'DHU_loop', 'Non-base-paired sequence of nucleotide bases in tRNA. It contains several dihydrouracil residues. [ISBN:071671920]', 1629, 0, 0);
INSERT INTO chado.cvterm VALUES (1512, 22, 'T_loop', 'Non-base-paired sequence of three nucleotide bases in tRNA. It has sequence T-Psi-C. [ISBN:0716719207]', 1630, 0, 0);
INSERT INTO chado.cvterm VALUES (1513, 22, 'U3_snoRNA', 'U3 snoRNA is a member of the box C/D class of small nucleolar RNAs. The U3 snoRNA secondary structure is characterised by a small 5'' domain (with boxes A and A''), and a larger 3'' domain (with boxes B, C, C'', and D), the two domains being linked by a single-stranded hinge. Boxes B and C form the B/C motif, which appears to be exclusive to U3 snoRNAs, and boxes C'' and D form the C''/D motif. The latter is functionally similar to the C/D motifs found in other snoRNAs. The 5'' domain and the hinge region act as a pre-rRNA-binding domain. The 3'' domain has conserved protein-binding sites. Both the box B/C and box C''/D motifs are sufficient for nuclear retention of U3 snoRNA. The box C''/D motif is also necessary for nucleolar localization, stability and hypermethylation of U3 snoRNA. Both box B/C and C''/D motifs are involved in specific protein interactions and are necessary for the rRNA processing functions of U3 snoRNA. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00012]', 1631, 0, 0);
INSERT INTO chado.cvterm VALUES (1514, 22, 'AU_rich_element', 'A cis-acting element found in the 3'' UTR of some mRNA which is rich in AUUUA pentamers. Messenger RNAs bearing multiple AU-rich elements are often unstable. [PMID:7892223]', 1632, 0, 0);
INSERT INTO chado.cvterm VALUES (1515, 22, 'Bruno_response_element', 'A cis-acting element found in the 3'' UTR of some mRNA which is bound by the Drosophila Bruno protein and its homologs. [PMID:10893231]', 1633, 0, 0);
INSERT INTO chado.cvterm VALUES (1516, 22, 'iron_responsive_element', 'A regulatory sequence found in the 5'' and 3'' UTRs of many mRNAs which encode iron-binding proteins. It has a hairpin structure and is recognized by trans-acting proteins known as iron-regulatory proteins. [PMID:3198610, PMID:8710843]', 1634, 0, 0);
INSERT INTO chado.cvterm VALUES (1517, 22, 'pseudouridylation_guide_snoRNA', 'A snoRNA that specifies the site of pseudouridylation in an RNA molecule by base pairing with a short sequence around the target residue. [GOC:mah, PMID:12457565]', 1635, 0, 0);
INSERT INTO chado.cvterm VALUES (1518, 22, 'LNA', 'An attribute describing a sequence consisting of nucleobases attached to a repeating unit made of ''locked'' deoxyribose rings connected to a phosphate backbone. The deoxyribose unit''s conformation is ''locked'' by a 2''-C,4''-C-oxymethylene link. [CHEBI:48010]', 1636, 0, 0);
INSERT INTO chado.cvterm VALUES (1519, 22, 'LNA_oligo', 'An oligo composed of LNA residues. [RSC:cb]', 1637, 0, 0);
INSERT INTO chado.cvterm VALUES (1520, 22, 'TNA', 'An attribute describing a sequence consisting of nucleobases attached to a repeating unit made of threose rings connected to a phosphate backbone. [CHEBI:48019]', 1638, 0, 0);
INSERT INTO chado.cvterm VALUES (1521, 22, 'TNA_oligo', 'An oligo composed of TNA residues. [RSC:cb]', 1639, 0, 0);
INSERT INTO chado.cvterm VALUES (1522, 22, 'GNA', 'An attribute describing a sequence consisting of nucleobases attached to a repeating unit made of an acyclic three-carbon propylene glycol connected to a phosphate backbone. It has two enantiomeric forms, (R)-GNA and (S)-GNA. [CHEBI:48015]', 1640, 0, 0);
INSERT INTO chado.cvterm VALUES (1523, 22, 'GNA_oligo', 'An oligo composed of GNA residues. [RSC:cb]', 1641, 0, 0);
INSERT INTO chado.cvterm VALUES (1524, 22, 'R_GNA', 'An attribute describing a GNA sequence in the (R)-GNA enantiomer. [CHEBI:48016]', 1642, 0, 0);
INSERT INTO chado.cvterm VALUES (1525, 22, 'R_GNA_oligo', 'An oligo composed of (R)-GNA residues. [RSC:cb]', 1643, 0, 0);
INSERT INTO chado.cvterm VALUES (1526, 22, 'S_GNA', 'An attribute describing a GNA sequence in the (S)-GNA enantiomer. [CHEBI:48017]', 1644, 0, 0);
INSERT INTO chado.cvterm VALUES (1527, 22, 'S_GNA_oligo', 'An oligo composed of (S)-GNA residues. [RSC:cb]', 1645, 0, 0);
INSERT INTO chado.cvterm VALUES (1528, 22, 'ds_DNA_viral_sequence', 'A ds_DNA_viral_sequence is a viral_sequence that is the sequence of a virus that exists as double stranded DNA. [SO:ke]', 1646, 0, 0);
INSERT INTO chado.cvterm VALUES (1529, 22, 'ss_RNA_viral_sequence', 'A ss_RNA_viral_sequence is a viral_sequence that is the sequence of a virus that exists as single stranded RNA. [SO:ke]', 1647, 0, 0);
INSERT INTO chado.cvterm VALUES (1530, 22, 'negative_sense_ssRNA_viral_sequence', 'A negative_sense_RNA_viral_sequence is a ss_RNA_viral_sequence that is the sequence of a single stranded RNA virus that is complementary to mRNA and must be converted to positive sense RNA by RNA polymerase before translation. [SO:ke]', 1648, 0, 0);
INSERT INTO chado.cvterm VALUES (1531, 22, 'positive_sense_ssRNA_viral_sequence', 'A positive_sense_RNA_viral_sequence is a ss_RNA_viral_sequence that is the sequence of a single stranded RNA virus that can be immediately translated by the host. [SO:ke]', 1649, 0, 0);
INSERT INTO chado.cvterm VALUES (1532, 22, 'ambisense_ssRNA_viral_sequence', 'A ambisense_RNA_virus is a ss_RNA_viral_sequence that is the sequence of a single stranded RNA virus with both messenger and anti messenger polarity. [SO:ke]', 1650, 0, 0);
INSERT INTO chado.cvterm VALUES (1533, 22, 'RNA_polymerase_promoter', 'A region (DNA) to which RNA polymerase binds, to begin transcription. [xenbase:jb]', 1651, 1, 0);
INSERT INTO chado.cvterm VALUES (1534, 22, 'Phage_RNA_Polymerase_Promoter', 'A region (DNA) to which Bacteriophage RNA polymerase binds, to begin transcription. [xenbase:jb]', 1652, 0, 0);
INSERT INTO chado.cvterm VALUES (1535, 22, 'viral_promoter', 'A regulatory_region including the Transcription Start Site (TSS) of a gene found in genes of viruses. [GREEKC:cl]', 1653, 0, 0);
INSERT INTO chado.cvterm VALUES (1536, 22, 'SP6_RNA_Polymerase_Promoter', 'A region (DNA) to which the SP6 RNA polymerase binds, to begin transcription. [xenbase:jb]', 1654, 0, 0);
INSERT INTO chado.cvterm VALUES (1537, 22, 'T3_RNA_Polymerase_Promoter', 'A DNA sequence to which the T3 RNA polymerase binds, to begin transcription. [xenbase:jb]', 1655, 0, 0);
INSERT INTO chado.cvterm VALUES (1538, 22, 'T7_RNA_Polymerase_Promoter', 'A region (DNA) to which the T7 RNA polymerase binds, to begin transcription. [xenbase:jb]', 1656, 0, 0);
INSERT INTO chado.cvterm VALUES (1539, 22, 'five_prime_EST', 'An EST read from the 5'' end of a transcript that usually codes for a protein. These regions tend to be conserved across species and do not change much within a gene family. [http://www.ncbi.nlm.nih.gov/About/primer/est.html]', 1657, 0, 0);
INSERT INTO chado.cvterm VALUES (1540, 22, 'three_prime_EST', 'An EST read from the 3'' end of a transcript. They are more likely to fall within non-coding, or untranslated regions(UTRs). [http://www.ncbi.nlm.nih.gov/About/primer/est.html]', 1658, 0, 0);
INSERT INTO chado.cvterm VALUES (1541, 22, 'translational_frameshift', 'The region of mRNA (not divisible by 3 bases) that is skipped or added during the process of translational frameshifting (GO:0006452), causing the reading frame to be different. [http://www.insdc.org/files/feature_table.html, SO:ke]', 1659, 0, 0);
INSERT INTO chado.cvterm VALUES (1542, 22, 'plus_1_translational_frameshift', 'The region of mRNA 1 base long that is skipped during the process of translational frameshifting (GO:0006452), causing the reading frame to be different. [SO:ke]', 1660, 0, 0);
INSERT INTO chado.cvterm VALUES (1543, 22, 'plus_2_translational_frameshift', 'The region of mRNA 2 bases long that is skipped during the process of translational frameshifting (GO:0006452), causing the reading frame to be different. [SO:ke]', 1661, 0, 0);
INSERT INTO chado.cvterm VALUES (1544, 22, 'group_III_intron', 'Group III introns are introns found in the mRNA of the plastids of euglenoid protists. They are spliced by a two step transesterification with bulged adenosine as initiating nucleophile. [PMID:11377794]', 1662, 0, 0);
INSERT INTO chado.cvterm VALUES (1545, 22, 'endonuclease_spliced_intron', 'An intron that spliced via endonucleolytic cleavage and ligation rather than transesterification. [SO:ke]', 1663, 0, 0);
INSERT INTO chado.cvterm VALUES (1546, 22, 'transgenic_insertion', 'An insertion that derives from another organism, via the use of recombinant DNA technology. [SO:bm]', 1664, 0, 0);
INSERT INTO chado.cvterm VALUES (1547, 22, 'retrogene', 'A gene that has been produced as the product of a reverse transcriptase mediated event. []', 1665, 0, 0);
INSERT INTO chado.cvterm VALUES (1548, 22, 'silenced_by_RNA_interference', 'An attribute describing an epigenetic process where a gene is inactivated by RNA interference. [RSC:cb]', 1666, 0, 0);
INSERT INTO chado.cvterm VALUES (1549, 22, 'silenced_by_histone_modification', 'An attribute describing an epigenetic process where a gene is inactivated by histone modification. [RSC:cb]', 1667, 0, 0);
INSERT INTO chado.cvterm VALUES (1550, 22, 'silenced_by_histone_methylation', 'An attribute describing an epigenetic process where a gene is inactivated by histone methylation. [RSC:cb]', 1668, 0, 0);
INSERT INTO chado.cvterm VALUES (1551, 22, 'silenced_by_histone_deacetylation', 'An attribute describing an epigenetic process where a gene is inactivated by histone deacetylation. [RSC:cb]', 1669, 0, 0);
INSERT INTO chado.cvterm VALUES (1552, 22, 'gene_silenced_by_RNA_interference', 'A gene that is silenced by RNA interference. [SO:xp]', 1670, 0, 0);
INSERT INTO chado.cvterm VALUES (1553, 22, 'gene_silenced_by_histone_modification', 'A gene that is silenced by histone modification. [SO:xp]', 1671, 0, 0);
INSERT INTO chado.cvterm VALUES (1554, 22, 'gene_silenced_by_histone_methylation', 'A gene that is silenced by histone methylation. [SO:xp]', 1672, 0, 0);
INSERT INTO chado.cvterm VALUES (1555, 22, 'gene_silenced_by_histone_deacetylation', 'A gene that is silenced by histone deacetylation. [SO:xp]', 1673, 0, 0);
INSERT INTO chado.cvterm VALUES (1556, 22, 'dihydrouridine', 'A modified RNA base in which the 5,6-dihydrouracil is bound to the ribose ring. [RSC:cb]', 1674, 0, 0);
INSERT INTO chado.cvterm VALUES (1557, 22, 'modified_uridine', 'A uridine base that has been modified. []', 1676, 0, 0);
INSERT INTO chado.cvterm VALUES (1558, 22, 'pseudouridine', 'A modified RNA base in which the 5- position of the uracil is bound to the ribose ring instead of the 4- position. [RSC:cb]', 1677, 0, 0);
INSERT INTO chado.cvterm VALUES (1559, 22, 'inosine', 'A modified RNA base in which hypoxanthine is bound to the ribose ring. [http://library.med.utah.edu/RNAmods/, RSC:cb]', 1679, 0, 0);
INSERT INTO chado.cvterm VALUES (1560, 22, 'seven_methylguanine', 'A modified RNA base in which guanine is methylated at the 7- position. [RSC:cb]', 1680, 0, 0);
INSERT INTO chado.cvterm VALUES (1561, 22, 'ribothymidine', 'A modified RNA base in which thymine is bound to the ribose ring. [RSC:cb]', 1681, 0, 0);
INSERT INTO chado.cvterm VALUES (1562, 22, 'methylinosine', 'A modified RNA base in which methylhypoxanthine is bound to the ribose ring. [RSC:cb]', 1682, 0, 0);
INSERT INTO chado.cvterm VALUES (1563, 22, 'modified_inosine', 'A modified inosine is an inosine base feature that has been altered. [SO:ke]', 1683, 0, 0);
INSERT INTO chado.cvterm VALUES (1564, 22, 'major_TSS', 'The tanscription start site that is most frequently used for transcription of a gene. []', 1684, 0, 0);
INSERT INTO chado.cvterm VALUES (1565, 22, 'minor_TSS', 'A tanscription start site that is not the most frequently used for transcription of a gene. []', 1685, 0, 0);
INSERT INTO chado.cvterm VALUES (1566, 22, 'TSS_region', 'The region of a gene from the 5'' most TSS to the 3'' TSS. [BBOP:nw]', 1686, 1, 0);
INSERT INTO chado.cvterm VALUES (1567, 22, 'encodes_alternate_transcription_start_sites', 'A gene that has multiple possible transcription start sites. []', 1687, 0, 0);
INSERT INTO chado.cvterm VALUES (1568, 22, 'miRNA_primary_transcript_region', 'A part of an miRNA primary_transcript. [SO:ke]', 1688, 0, 0);
INSERT INTO chado.cvterm VALUES (1569, 22, 'miRNA_stem', 'The stem of the hairpin loop formed by folding of the pre-miRNA. [SO:ke]', 1689, 0, 0);
INSERT INTO chado.cvterm VALUES (1570, 22, 'miRNA_loop', 'The loop of the hairpin loop formed by folding of the pre-miRNA. [SO:ke]', 1690, 0, 0);
INSERT INTO chado.cvterm VALUES (1571, 22, 'fragment_assembly', 'A fragment assembly is a genome assembly that orders overlapping fragments of the genome based on landmark sequences. The base pair distance between the landmarks is known allowing additivity of lengths. [SO:ke]', 1691, 0, 0);
INSERT INTO chado.cvterm VALUES (1572, 22, 'fingerprint_map', 'A fingerprint_map is a physical map composed of restriction fragments. [SO:ke]', 1692, 0, 0);
INSERT INTO chado.cvterm VALUES (1573, 22, 'STS_map', 'An STS map is a physical map organized by the unique STS landmarks. [SO:ke]', 1693, 0, 0);
INSERT INTO chado.cvterm VALUES (1574, 22, 'RH_map', 'A radiation hybrid map is a physical map. [SO:ke]', 1694, 0, 0);
INSERT INTO chado.cvterm VALUES (1575, 22, 'sonicate_fragment', 'A DNA fragment generated by sonication. Sonication is a technique used to sheer DNA into smaller fragments. [SO:ke]', 1695, 0, 0);
INSERT INTO chado.cvterm VALUES (1621, 22, 'N6_cis_hydroxyisopentenyl_adenosine', 'N6_cis_hydroxyisopentenyl_adenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1766, 0, 0);
INSERT INTO chado.cvterm VALUES (1576, 22, 'polyploid', 'A kind of chromosome variation where the chromosome complement is an exact multiple of the haploid number and is greater than the diploid number. [SO:ke]', 1696, 0, 0);
INSERT INTO chado.cvterm VALUES (1577, 22, 'autopolyploid', 'A polyploid where the multiple chromosome set was derived from the same organism. [SO:ke]', 1697, 0, 0);
INSERT INTO chado.cvterm VALUES (1578, 22, 'allopolyploid', 'A polyploid where the multiple chromosome set was derived from a different organism. [SO:ke]', 1698, 0, 0);
INSERT INTO chado.cvterm VALUES (1579, 22, 'homing_endonuclease_binding_site', 'The binding site (recognition site) of a homing endonuclease. The binding site is typically large. [SO:ke]', 1699, 0, 0);
INSERT INTO chado.cvterm VALUES (1580, 22, 'octamer_motif', 'A sequence element characteristic of some RNA polymerase II promoters with sequence ATTGCAT that binds Pou-domain transcription factors. [GOC:dh, PMID:3095662]', 1700, 0, 0);
INSERT INTO chado.cvterm VALUES (1581, 22, 'apicoplast_chromosome', 'A chromosome originating in an apicoplast. [SO:xp]', 1701, 0, 0);
INSERT INTO chado.cvterm VALUES (1582, 22, 'overlapping_feature_set', 'A continuous region of sequence composed of the overlapping of multiple sequence_features, which ultimately provides evidence for another sequence_feature. [SO:ke]', 1702, 0, 0);
INSERT INTO chado.cvterm VALUES (1583, 22, 'overlapping_EST_set', 'A continous experimental result region extending the length of multiple overlapping EST''s. [SO:ke]', 1703, 0, 0);
INSERT INTO chado.cvterm VALUES (1584, 22, 'ncRNA_gene', 'A gene that encodes a non-coding RNA. []', 1704, 0, 0);
INSERT INTO chado.cvterm VALUES (1585, 22, 'gRNA_gene', 'A noncoding RNA that guides the insertion or deletion of uridine residues in mitochondrial mRNAs. This may also refer to synthetic RNAs used to guide DNA editing using the CRIPSR/Cas9 system. []', 1705, 0, 0);
INSERT INTO chado.cvterm VALUES (1586, 22, 'miRNA_gene', 'A small noncoding RNA of approximately 22 nucleotides in length which may be involved in regulation of gene expression. []', 1706, 0, 0);
INSERT INTO chado.cvterm VALUES (1587, 22, 'sncRNA_gene', 'A ncRNA_gene that encodes an ncRNA less than 200 nucleotides in length. [PMID:28449079, PMID:30069443, PMID:30937442]', 1708, 0, 0);
INSERT INTO chado.cvterm VALUES (1588, 22, 'scRNA_gene', 'A gene encoding a small noncoding RNA that is generally found only in the cytoplasm. []', 1709, 0, 0);
INSERT INTO chado.cvterm VALUES (1589, 22, 'snoRNA_gene', 'A gene encoding a small noncoding RNA that participates in the processing or chemical modifications of many RNAs, including ribosomal RNAs and spliceosomal RNAs. []', 1710, 0, 0);
INSERT INTO chado.cvterm VALUES (1590, 22, 'snRNA_gene', 'A gene that encodes a small nuclear RNA. [http://en.wikipedia.org/wiki/Small_nuclear_RNA]', 1711, 0, 0);
INSERT INTO chado.cvterm VALUES (1591, 22, 'SRP_RNA_gene', 'A gene that encodes a signal recognition particle (SRP) RNA. []', 1712, 0, 0);
INSERT INTO chado.cvterm VALUES (1592, 22, 'tmRNA_gene', 'A bacterial RNA with both tRNA and mRNA like properties. []', 1713, 0, 0);
INSERT INTO chado.cvterm VALUES (1593, 22, 'tRNA_gene', 'A noncoding RNA that binds to a specific amino acid to allow that amino acid to be used by the ribosome during translation of RNA. []', 1714, 0, 0);
INSERT INTO chado.cvterm VALUES (1594, 22, 'modified_adenosine', 'A modified adenine is an adenine base feature that has been altered. [SO:ke]', 1715, 0, 0);
INSERT INTO chado.cvterm VALUES (1595, 22, 'modified_cytidine', 'A modified cytidine is a cytidine base feature which has been altered. [SO:ke]', 1716, 0, 0);
INSERT INTO chado.cvterm VALUES (1596, 22, 'modified_guanosine', 'A guanosine base that has been modified. []', 1717, 0, 0);
INSERT INTO chado.cvterm VALUES (1597, 22, 'one_methylinosine', '1-methylinosine is a modified inosine. [http://library.med.utah.edu/RNAmods/]', 1718, 0, 0);
INSERT INTO chado.cvterm VALUES (1598, 22, 'one_two_prime_O_dimethylinosine', '1,2''-O-dimethylinosine is a modified inosine. [http://library.med.utah.edu/RNAmods/]', 1720, 0, 0);
INSERT INTO chado.cvterm VALUES (1599, 22, 'two_prime_O_methylinosine', '2''-O-methylinosine is a modified inosine. [http://library.med.utah.edu/RNAmods/]', 1722, 0, 0);
INSERT INTO chado.cvterm VALUES (1600, 22, 'three_methylcytidine', '3-methylcytidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1724, 0, 0);
INSERT INTO chado.cvterm VALUES (1601, 22, 'five_methylcytidine', '5-methylcytidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1726, 0, 0);
INSERT INTO chado.cvterm VALUES (1602, 22, 'two_prime_O_methylcytidine', '2''-O-methylcytidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1728, 0, 0);
INSERT INTO chado.cvterm VALUES (1603, 22, 'two_thiocytidine', '2-thiocytidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1730, 0, 0);
INSERT INTO chado.cvterm VALUES (1604, 22, 'N4_acetylcytidine', 'N4-acetylcytidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1732, 0, 0);
INSERT INTO chado.cvterm VALUES (1605, 22, 'five_formylcytidine', '5-formylcytidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1734, 0, 0);
INSERT INTO chado.cvterm VALUES (1606, 22, 'five_two_prime_O_dimethylcytidine', '5,2''-O-dimethylcytidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1736, 0, 0);
INSERT INTO chado.cvterm VALUES (1607, 22, 'N4_acetyl_2_prime_O_methylcytidine', 'N4-acetyl-2''-O-methylcytidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1738, 0, 0);
INSERT INTO chado.cvterm VALUES (1608, 22, 'lysidine', 'Lysidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1740, 0, 0);
INSERT INTO chado.cvterm VALUES (1609, 22, 'N4_methylcytidine', 'N4-methylcytidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1742, 0, 0);
INSERT INTO chado.cvterm VALUES (1610, 22, 'N4_2_prime_O_dimethylcytidine', 'N4,2''-O-dimethylcytidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1744, 0, 0);
INSERT INTO chado.cvterm VALUES (1611, 22, 'five_hydroxymethylcytidine', '5-hydroxymethylcytidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1746, 0, 0);
INSERT INTO chado.cvterm VALUES (1612, 22, 'five_formyl_two_prime_O_methylcytidine', '5-formyl-2''-O-methylcytidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1748, 0, 0);
INSERT INTO chado.cvterm VALUES (1613, 22, 'N4_N4_2_prime_O_trimethylcytidine', 'N4_N4_2_prime_O_trimethylcytidine is a modified cytidine. [http://library.med.utah.edu/RNAmods/]', 1750, 0, 0);
INSERT INTO chado.cvterm VALUES (1614, 22, 'one_methyladenosine', '1_methyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1752, 0, 0);
INSERT INTO chado.cvterm VALUES (1615, 22, 'two_methyladenosine', '2_methyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1754, 0, 0);
INSERT INTO chado.cvterm VALUES (1616, 22, 'N6_methyladenosine', 'N6_methyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1756, 0, 0);
INSERT INTO chado.cvterm VALUES (1617, 22, 'two_prime_O_methyladenosine', '2prime_O_methyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1758, 0, 0);
INSERT INTO chado.cvterm VALUES (1618, 22, 'two_methylthio_N6_methyladenosine', '2_methylthio_N6_methyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1760, 0, 0);
INSERT INTO chado.cvterm VALUES (1619, 22, 'N6_isopentenyladenosine', 'N6_isopentenyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1762, 0, 0);
INSERT INTO chado.cvterm VALUES (1620, 22, 'two_methylthio_N6_isopentenyladenosine', '2_methylthio_N6_isopentenyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1764, 0, 0);
INSERT INTO chado.cvterm VALUES (2907, 23, 'subform', '', 3216, 0, 0);
INSERT INTO chado.cvterm VALUES (1622, 22, 'two_methylthio_N6_cis_hydroxyisopentenyl_adenosine', '2_methylthio_N6_cis_hydroxyisopentenyl_adenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1768, 0, 0);
INSERT INTO chado.cvterm VALUES (1623, 22, 'N6_glycinylcarbamoyladenosine', 'N6_glycinylcarbamoyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1770, 0, 0);
INSERT INTO chado.cvterm VALUES (1624, 22, 'N6_threonylcarbamoyladenosine', 'N6_threonylcarbamoyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1772, 0, 0);
INSERT INTO chado.cvterm VALUES (1625, 22, 'two_methylthio_N6_threonyl_carbamoyladenosine', '2_methylthio_N6_threonyl_carbamoyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1774, 0, 0);
INSERT INTO chado.cvterm VALUES (1626, 22, 'N6_methyl_N6_threonylcarbamoyladenosine', 'N6_methyl_N6_threonylcarbamoyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1776, 0, 0);
INSERT INTO chado.cvterm VALUES (1627, 22, 'N6_hydroxynorvalylcarbamoyladenosine', 'N6_hydroxynorvalylcarbamoyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1778, 0, 0);
INSERT INTO chado.cvterm VALUES (1628, 22, 'two_methylthio_N6_hydroxynorvalyl_carbamoyladenosine', '2_methylthio_N6_hydroxynorvalyl_carbamoyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1780, 0, 0);
INSERT INTO chado.cvterm VALUES (1629, 22, 'two_prime_O_ribosyladenosine_phosphate', '2prime_O_ribosyladenosine_phosphate is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1782, 0, 0);
INSERT INTO chado.cvterm VALUES (1630, 22, 'N6_N6_dimethyladenosine', 'N6_N6_dimethyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1784, 0, 0);
INSERT INTO chado.cvterm VALUES (1631, 22, 'N6_2_prime_O_dimethyladenosine', 'N6_2prime_O_dimethyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1786, 0, 0);
INSERT INTO chado.cvterm VALUES (1632, 22, 'N6_N6_2_prime_O_trimethyladenosine', 'N6_N6_2prime_O_trimethyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1788, 0, 0);
INSERT INTO chado.cvterm VALUES (1633, 22, 'one_two_prime_O_dimethyladenosine', '1,2''-O-dimethyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1790, 0, 0);
INSERT INTO chado.cvterm VALUES (1634, 22, 'N6_acetyladenosine', 'N6_acetyladenosine is a modified adenosine. [http://library.med.utah.edu/RNAmods/]', 1792, 0, 0);
INSERT INTO chado.cvterm VALUES (1635, 22, 'seven_deazaguanosine', '7-deazaguanosine is a modified guanosine. [http://library.med.utah.edu/RNAmods/]', 1794, 0, 0);
INSERT INTO chado.cvterm VALUES (1636, 22, 'queuosine', 'Queuosine is a modified 7-deazoguanosine. [http://library.med.utah.edu/RNAmods/]', 1795, 0, 0);
INSERT INTO chado.cvterm VALUES (1637, 22, 'epoxyqueuosine', 'Epoxyqueuosine is a modified 7-deazoguanosine. [http://library.med.utah.edu/RNAmods/]', 1797, 0, 0);
INSERT INTO chado.cvterm VALUES (1638, 22, 'galactosyl_queuosine', 'Galactosyl_queuosine is a modified 7-deazoguanosine. [http://library.med.utah.edu/RNAmods/]', 1799, 0, 0);
INSERT INTO chado.cvterm VALUES (1639, 22, 'mannosyl_queuosine', 'Mannosyl_queuosine is a modified 7-deazoguanosine. [http://library.med.utah.edu/RNAmods/]', 1801, 0, 0);
INSERT INTO chado.cvterm VALUES (1640, 22, 'seven_cyano_seven_deazaguanosine', '7_cyano_7_deazaguanosine is a modified 7-deazoguanosine. [http://library.med.utah.edu/RNAmods/]', 1803, 0, 0);
INSERT INTO chado.cvterm VALUES (1641, 22, 'seven_aminomethyl_seven_deazaguanosine', '7_aminomethyl_7_deazaguanosine is a modified 7-deazoguanosine. [http://library.med.utah.edu/RNAmods/]', 1805, 0, 0);
INSERT INTO chado.cvterm VALUES (1642, 22, 'archaeosine', 'Archaeosine is a modified 7-deazoguanosine. [http://library.med.utah.edu/RNAmods/]', 1807, 0, 0);
INSERT INTO chado.cvterm VALUES (1643, 22, 'one_methylguanosine', '1_methylguanosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1809, 0, 0);
INSERT INTO chado.cvterm VALUES (1644, 22, 'N2_methylguanosine', 'N2_methylguanosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1811, 0, 0);
INSERT INTO chado.cvterm VALUES (1645, 22, 'seven_methylguanosine', '7_methylguanosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1813, 0, 0);
INSERT INTO chado.cvterm VALUES (1646, 22, 'two_prime_O_methylguanosine', '2prime_O_methylguanosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1815, 0, 0);
INSERT INTO chado.cvterm VALUES (1647, 22, 'N2_N2_dimethylguanosine', 'N2_N2_dimethylguanosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1817, 0, 0);
INSERT INTO chado.cvterm VALUES (1648, 22, 'N2_2_prime_O_dimethylguanosine', 'N2_2prime_O_dimethylguanosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1819, 0, 0);
INSERT INTO chado.cvterm VALUES (1649, 22, 'N2_N2_2_prime_O_trimethylguanosine', 'N2_N2_2prime_O_trimethylguanosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1821, 0, 0);
INSERT INTO chado.cvterm VALUES (1650, 22, 'two_prime_O_ribosylguanosine_phosphate', '2prime_O_ribosylguanosine_phosphate is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1823, 0, 0);
INSERT INTO chado.cvterm VALUES (1651, 22, 'wybutosine', 'Wybutosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1825, 0, 0);
INSERT INTO chado.cvterm VALUES (1652, 22, 'peroxywybutosine', 'Peroxywybutosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1827, 0, 0);
INSERT INTO chado.cvterm VALUES (1653, 22, 'hydroxywybutosine', 'Hydroxywybutosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1829, 0, 0);
INSERT INTO chado.cvterm VALUES (1654, 22, 'undermodified_hydroxywybutosine', 'Undermodified_hydroxywybutosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1831, 0, 0);
INSERT INTO chado.cvterm VALUES (1655, 22, 'wyosine', 'Wyosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1833, 0, 0);
INSERT INTO chado.cvterm VALUES (1656, 22, 'methylwyosine', 'Methylwyosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1835, 0, 0);
INSERT INTO chado.cvterm VALUES (1657, 22, 'N2_7_dimethylguanosine', 'N2_7_dimethylguanosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1837, 0, 0);
INSERT INTO chado.cvterm VALUES (1658, 22, 'N2_N2_7_trimethylguanosine', 'N2_N2_7_trimethylguanosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1839, 0, 0);
INSERT INTO chado.cvterm VALUES (1659, 22, 'one_two_prime_O_dimethylguanosine', '1_2prime_O_dimethylguanosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1841, 0, 0);
INSERT INTO chado.cvterm VALUES (1660, 22, 'four_demethylwyosine', '4_demethylwyosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1843, 0, 0);
INSERT INTO chado.cvterm VALUES (1661, 22, 'isowyosine', 'Isowyosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1845, 0, 0);
INSERT INTO chado.cvterm VALUES (1662, 22, 'N2_7_2prirme_O_trimethylguanosine', 'N2_7_2prirme_O_trimethylguanosine is a modified guanosine base feature. [http://library.med.utah.edu/RNAmods/]', 1847, 0, 0);
INSERT INTO chado.cvterm VALUES (1663, 22, 'five_methyluridine', '5_methyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1849, 0, 0);
INSERT INTO chado.cvterm VALUES (1664, 22, 'two_prime_O_methyluridine', '2prime_O_methyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1851, 0, 0);
INSERT INTO chado.cvterm VALUES (1665, 22, 'five_two_prime_O_dimethyluridine', '5_2_prime_O_dimethyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1853, 0, 0);
INSERT INTO chado.cvterm VALUES (1666, 22, 'one_methylpseudouridine', '1_methylpseudouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1855, 0, 0);
INSERT INTO chado.cvterm VALUES (1667, 22, 'two_prime_O_methylpseudouridine', '2prime_O_methylpseudouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1857, 0, 0);
INSERT INTO chado.cvterm VALUES (1668, 22, 'two_thiouridine', '2_thiouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1859, 0, 0);
INSERT INTO chado.cvterm VALUES (1669, 22, 'four_thiouridine', '4_thiouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1861, 0, 0);
INSERT INTO chado.cvterm VALUES (1670, 22, 'five_methyl_2_thiouridine', '5_methyl_2_thiouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1863, 0, 0);
INSERT INTO chado.cvterm VALUES (1671, 22, 'two_thio_two_prime_O_methyluridine', '2_thio_2prime_O_methyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1865, 0, 0);
INSERT INTO chado.cvterm VALUES (1672, 22, 'three_three_amino_three_carboxypropyl_uridine', '3_3_amino_3_carboxypropyl_uridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1867, 0, 0);
INSERT INTO chado.cvterm VALUES (1673, 22, 'five_hydroxyuridine', '5_hydroxyuridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1869, 0, 0);
INSERT INTO chado.cvterm VALUES (1674, 22, 'five_methoxyuridine', '5_methoxyuridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1870, 0, 0);
INSERT INTO chado.cvterm VALUES (1675, 22, 'uridine_five_oxyacetic_acid', 'Uridine_5_oxyacetic_acid is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1872, 0, 0);
INSERT INTO chado.cvterm VALUES (1676, 22, 'uridine_five_oxyacetic_acid_methyl_ester', 'Uridine_5_oxyacetic_acid_methyl_ester is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1874, 0, 0);
INSERT INTO chado.cvterm VALUES (1677, 22, 'five_carboxyhydroxymethyl_uridine', '5_carboxyhydroxymethyl_uridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1876, 0, 0);
INSERT INTO chado.cvterm VALUES (1678, 22, 'five_carboxyhydroxymethyl_uridine_methyl_ester', '5_carboxyhydroxymethyl_uridine_methyl_ester is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1878, 0, 0);
INSERT INTO chado.cvterm VALUES (1679, 22, 'five_methoxycarbonylmethyluridine', 'Five_methoxycarbonylmethyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1880, 0, 0);
INSERT INTO chado.cvterm VALUES (1680, 22, 'five_methoxycarbonylmethyl_two_prime_O_methyluridine', 'Five_methoxycarbonylmethyl_2_prime_O_methyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1882, 0, 0);
INSERT INTO chado.cvterm VALUES (1681, 22, 'five_methoxycarbonylmethyl_two_thiouridine', '5_methoxycarbonylmethyl_2_thiouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1884, 0, 0);
INSERT INTO chado.cvterm VALUES (1682, 22, 'five_aminomethyl_two_thiouridine', '5_aminomethyl_2_thiouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1886, 0, 0);
INSERT INTO chado.cvterm VALUES (1683, 22, 'five_methylaminomethyluridine', '5_methylaminomethyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1888, 0, 0);
INSERT INTO chado.cvterm VALUES (1684, 22, 'five_methylaminomethyl_two_thiouridine', '5_methylaminomethyl_2_thiouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1890, 0, 0);
INSERT INTO chado.cvterm VALUES (1685, 22, 'five_methylaminomethyl_two_selenouridine', '5_methylaminomethyl_2_selenouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1892, 0, 0);
INSERT INTO chado.cvterm VALUES (1686, 22, 'five_carbamoylmethyluridine', '5_carbamoylmethyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1894, 0, 0);
INSERT INTO chado.cvterm VALUES (1687, 22, 'five_carbamoylmethyl_two_prime_O_methyluridine', '5_carbamoylmethyl_2_prime_O_methyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1896, 0, 0);
INSERT INTO chado.cvterm VALUES (1688, 22, 'five_carboxymethylaminomethyluridine', '5_carboxymethylaminomethyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1898, 0, 0);
INSERT INTO chado.cvterm VALUES (1689, 22, 'five_carboxymethylaminomethyl_two_prime_O_methyluridine', '5_carboxymethylaminomethyl_2_prime_O_methyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1900, 0, 0);
INSERT INTO chado.cvterm VALUES (1690, 22, 'five_carboxymethylaminomethyl_two_thiouridine', '5_carboxymethylaminomethyl_2_thiouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1902, 0, 0);
INSERT INTO chado.cvterm VALUES (1691, 22, 'three_methyluridine', '3_methyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1904, 0, 0);
INSERT INTO chado.cvterm VALUES (1692, 22, 'one_methyl_three_three_amino_three_carboxypropyl_pseudouridine', '1_methyl_3_3_amino_3_carboxypropyl_pseudouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1906, 0, 0);
INSERT INTO chado.cvterm VALUES (1693, 22, 'five_carboxymethyluridine', '5_carboxymethyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1908, 0, 0);
INSERT INTO chado.cvterm VALUES (1694, 22, 'three_two_prime_O_dimethyluridine', '3_2prime_O_dimethyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1910, 0, 0);
INSERT INTO chado.cvterm VALUES (1695, 22, 'five_methyldihydrouridine', '5_methyldihydrouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1912, 0, 0);
INSERT INTO chado.cvterm VALUES (1696, 22, 'three_methylpseudouridine', '3_methylpseudouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1914, 0, 0);
INSERT INTO chado.cvterm VALUES (1697, 22, 'five_taurinomethyluridine', '5_taurinomethyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1916, 0, 0);
INSERT INTO chado.cvterm VALUES (1698, 22, 'five_taurinomethyl_two_thiouridine', '5_taurinomethyl_2_thiouridineis a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1918, 0, 0);
INSERT INTO chado.cvterm VALUES (1699, 22, 'five_isopentenylaminomethyl_uridine', '5_isopentenylaminomethyl_uridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1920, 0, 0);
INSERT INTO chado.cvterm VALUES (1700, 22, 'five_isopentenylaminomethyl_two_thiouridine', '5_isopentenylaminomethyl_2_thiouridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1922, 0, 0);
INSERT INTO chado.cvterm VALUES (1701, 22, 'five_isopentenylaminomethyl_two_prime_O_methyluridine', '5_isopentenylaminomethyl_2prime_O_methyluridine is a modified uridine base feature. [http://library.med.utah.edu/RNAmods/]', 1924, 0, 0);
INSERT INTO chado.cvterm VALUES (1702, 22, 'histone_binding_site', 'A binding site that, in the nucleotide molecule, interacts selectively and non-covalently with polypeptide residues of a histone. [SO:ke]', 1926, 0, 0);
INSERT INTO chado.cvterm VALUES (1703, 22, 'CDS_fragment', 'A portion of a CDS that is not the complete CDS. []', 1927, 0, 0);
INSERT INTO chado.cvterm VALUES (1704, 22, 'modified_amino_acid_feature', 'A post translationally modified amino acid feature. [SO:ke]', 1928, 0, 0);
INSERT INTO chado.cvterm VALUES (1705, 22, 'modified_glycine', 'A post translationally modified glycine amino acid feature. [SO:ke]', 1929, 0, 0);
INSERT INTO chado.cvterm VALUES (1706, 22, 'modified_L_alanine', 'A post translationally modified alanine amino acid feature. [SO:ke]', 1931, 0, 0);
INSERT INTO chado.cvterm VALUES (1707, 22, 'modified_L_asparagine', 'A post translationally modified asparagine amino acid feature. [SO:ke]', 1933, 0, 0);
INSERT INTO chado.cvterm VALUES (1708, 22, 'modified_L_aspartic_acid', 'A post translationally modified aspartic acid amino acid feature. [SO:ke]', 1935, 0, 0);
INSERT INTO chado.cvterm VALUES (1709, 22, 'modified_L_cysteine', 'A post translationally modified cysteine amino acid feature. [SO:ke]', 1937, 0, 0);
INSERT INTO chado.cvterm VALUES (1710, 22, 'modified_L_glutamic_acid', 'A post translationally modified glutamic acid. []', 1939, 0, 0);
INSERT INTO chado.cvterm VALUES (1711, 22, 'modified_L_threonine', 'A post translationally modified threonine amino acid feature. [SO:ke]', 1941, 0, 0);
INSERT INTO chado.cvterm VALUES (1712, 22, 'modified_L_tryptophan', 'A post translationally modified tryptophan amino acid feature. [SO:ke]', 1943, 0, 0);
INSERT INTO chado.cvterm VALUES (1713, 22, 'modified_L_glutamine', 'A post translationally modified glutamine amino acid feature. [SO:ke]', 1945, 0, 0);
INSERT INTO chado.cvterm VALUES (1714, 22, 'modified_L_methionine', 'A post translationally modified methionine amino acid feature. [SO:ke]', 1947, 0, 0);
INSERT INTO chado.cvterm VALUES (1715, 22, 'modified_L_isoleucine', 'A post translationally modified isoleucine amino acid feature. [SO:ke]', 1949, 0, 0);
INSERT INTO chado.cvterm VALUES (1716, 22, 'modified_L_phenylalanine', 'A post translationally modified phenylalanine amino acid feature. [SO:ke]', 1951, 0, 0);
INSERT INTO chado.cvterm VALUES (1717, 22, 'modified_L_histidine', 'A post translationally modified histidine amino acid feature. [SO:ke]', 1953, 0, 0);
INSERT INTO chado.cvterm VALUES (1718, 22, 'modified_L_serine', 'A post translationally modified serine amino acid feature. [SO:ke]', 1955, 0, 0);
INSERT INTO chado.cvterm VALUES (1719, 22, 'modified_L_lysine', 'A post translationally modified lysine amino acid feature. [SO:ke]', 1957, 0, 0);
INSERT INTO chado.cvterm VALUES (1720, 22, 'modified_L_leucine', 'A post translationally modified leucine amino acid feature. [SO:ke]', 1959, 0, 0);
INSERT INTO chado.cvterm VALUES (1721, 22, 'modified_L_selenocysteine', 'A post translationally modified selenocysteine amino acid feature. [SO:ke]', 1961, 0, 0);
INSERT INTO chado.cvterm VALUES (1722, 22, 'modified_L_valine', 'A post translationally modified valine amino acid feature. [SO:ke]', 1963, 0, 0);
INSERT INTO chado.cvterm VALUES (1723, 22, 'modified_L_proline', 'A post translationally modified proline amino acid feature. [SO:ke]', 1965, 0, 0);
INSERT INTO chado.cvterm VALUES (1724, 22, 'modified_L_tyrosine', 'A post translationally modified tyrosine amino acid feature. [SO:ke]', 1967, 0, 0);
INSERT INTO chado.cvterm VALUES (1725, 22, 'modified_L_arginine', 'A post translationally modified arginine amino acid feature. [SO:ke]', 1969, 0, 0);
INSERT INTO chado.cvterm VALUES (1726, 22, 'peptidyl', 'An attribute describing the nature of a proteinaceous polymer, where by the amino acid units are joined by peptide bonds. [SO:ke]', 1971, 0, 0);
INSERT INTO chado.cvterm VALUES (1727, 22, 'cleaved_for_gpi_anchor_region', 'The C-terminal residues of a polypeptide which are exchanged for a GPI-anchor. [EBI:rh]', 1972, 0, 0);
INSERT INTO chado.cvterm VALUES (1728, 22, 'translocation_breakpoint', 'The point within a chromosome where a translocation begins or ends. [SO:cb]', 1973, 0, 0);
INSERT INTO chado.cvterm VALUES (1729, 22, 'insertion_breakpoint', 'The point within a chromosome where a insertion begins or ends. [SO:cb]', 1974, 0, 0);
INSERT INTO chado.cvterm VALUES (1730, 22, 'deletion_breakpoint', 'The point within a chromosome where a deletion begins or ends. [SO:cb]', 1975, 0, 0);
INSERT INTO chado.cvterm VALUES (1731, 22, 'five_prime_flanking_region', 'A flanking region located five prime of a specific region. [SO:chado]', 1976, 0, 0);
INSERT INTO chado.cvterm VALUES (1732, 22, 'three_prime_flanking_region', 'A flanking region located three prime of a specific region. [SO:chado]', 1977, 0, 0);
INSERT INTO chado.cvterm VALUES (1733, 22, 'transcribed_fragment', 'An experimental region, defined by a tiling array experiment to be transcribed at some level. [SO:ke]', 1978, 0, 0);
INSERT INTO chado.cvterm VALUES (1734, 22, 'splice_junction', 'The boundary between an intron and an exon. [SO:ke]', 1979, 0, 0);
INSERT INTO chado.cvterm VALUES (1735, 22, 'conformational_switch', 'A region of a polypeptide, involved in the transition from one conformational state to another. [SO:ke]', 1980, 0, 0);
INSERT INTO chado.cvterm VALUES (1736, 22, 'dye_terminator_read', 'A read produced by the dye terminator method of sequencing. [SO:ke]', 1981, 0, 0);
INSERT INTO chado.cvterm VALUES (1737, 22, 'pyrosequenced_read', 'A read produced by pyrosequencing technology. [SO:ke]', 1982, 0, 0);
INSERT INTO chado.cvterm VALUES (1738, 22, 'ligation_based_read', 'A read produced by ligation based sequencing technologies. [SO:ke]', 1983, 0, 0);
INSERT INTO chado.cvterm VALUES (1739, 22, 'polymerase_synthesis_read', 'A read produced by the polymerase based sequence by synthesis method. [SO:ke]', 1984, 0, 0);
INSERT INTO chado.cvterm VALUES (1740, 22, 'cis_regulatory_frameshift_element', 'A structural region in an RNA molecule which promotes ribosomal frameshifting of cis coding sequence. [RFAM:jd]', 1985, 0, 0);
INSERT INTO chado.cvterm VALUES (1741, 22, 'expressed_sequence_assembly', 'A sequence assembly derived from expressed sequences. [SO:ke]', 1986, 0, 0);
INSERT INTO chado.cvterm VALUES (1742, 22, 'DNA_binding_site', 'A binding site that, in the molecule, interacts selectively and non-covalently with DNA. [SO:ke]', 1987, 0, 0);
INSERT INTO chado.cvterm VALUES (1743, 22, 'cryptic_gene', 'A gene that is not transcribed under normal conditions and is not critical to normal cellular functioning. [SO:ke]', 1988, 0, 0);
INSERT INTO chado.cvterm VALUES (1744, 22, 'sequence_variant_affecting_polyadenylation', '', 1989, 1, 0);
INSERT INTO chado.cvterm VALUES (1745, 22, 'three_prime_RACE_clone', 'A three prime RACE (Rapid Amplification of cDNA Ends) clone is a cDNA clone copied from the 3'' end of an mRNA (using a poly-dT primer to capture the polyA tail and a gene-specific or randomly primed 5'' primer), and spliced into a vector for propagation in a suitable host. [modENCODE:nlw]', 1990, 0, 0);
INSERT INTO chado.cvterm VALUES (1746, 22, 'cassette_pseudogene', 'A cassette pseudogene is a kind of gene in an inactive form which may recombine at a telomeric locus to form a functional copy. [SO:ke]', 1991, 0, 0);
INSERT INTO chado.cvterm VALUES (1747, 22, 'alanine', 'A non-polar, hydorophobic amino acid encoded by the codons GCN (GCT, GCC, GCA and GCG). []', 1992, 0, 0);
INSERT INTO chado.cvterm VALUES (1748, 22, 'valine', 'A non-polar, hydorophobic amino acid encoded by the codons GTN (GTT, GTC, GTA and GTG). []', 1993, 0, 0);
INSERT INTO chado.cvterm VALUES (1749, 22, 'leucine', 'A non-polar, hydorophobic amino acid encoded by the codons CTN (CTT, CTC, CTA and CTG), TTA and TTG. []', 1994, 0, 0);
INSERT INTO chado.cvterm VALUES (1750, 22, 'isoleucine', 'A non-polar, hydorophobic amino acid encoded by the codons ATH (ATT, ATC and ATA). []', 1995, 0, 0);
INSERT INTO chado.cvterm VALUES (1751, 22, 'proline', 'A non-polar, hydorophobic amino acid encoded by the codons CCN (CCT, CCC, CCA and CCG). []', 1996, 0, 0);
INSERT INTO chado.cvterm VALUES (1752, 22, 'tryptophan', 'A non-polar, hydorophobic amino acid encoded by the codon TGG. []', 1997, 0, 0);
INSERT INTO chado.cvterm VALUES (1753, 22, 'phenylalanine', 'A non-polar, hydorophobic amino acid encoded by the codons TTT and TTC. []', 1998, 0, 0);
INSERT INTO chado.cvterm VALUES (1754, 22, 'methionine', 'A non-polar, hydorophobic amino acid encoded by the codon ATG. []', 1999, 0, 0);
INSERT INTO chado.cvterm VALUES (1755, 22, 'glycine', 'A non-polar, hydorophilic amino acid encoded by the codons GGN (GGT, GGC, GGA and GGG). []', 2000, 0, 0);
INSERT INTO chado.cvterm VALUES (1756, 22, 'serine', 'A polar, hydorophilic amino acid encoded by the codons TCN (TCT, TCC, TCA, TCG), AGT and AGC. []', 2001, 0, 0);
INSERT INTO chado.cvterm VALUES (1757, 22, 'threonine', 'A polar, hydorophilic amino acid encoded by the codons ACN (ACT, ACC, ACA and ACG). []', 2002, 0, 0);
INSERT INTO chado.cvterm VALUES (1758, 22, 'tyrosine', 'A polar, hydorophilic amino acid encoded by the codons TAT and TAC. []', 2003, 0, 0);
INSERT INTO chado.cvterm VALUES (1759, 22, 'cysteine', 'A polar amino acid encoded by the codons TGT and TGC. []', 2004, 0, 0);
INSERT INTO chado.cvterm VALUES (1760, 22, 'glutamine', 'A polar, hydorophilic amino acid encoded by the codons CAA and CAG.  []', 2005, 0, 0);
INSERT INTO chado.cvterm VALUES (1761, 22, 'asparagine', 'A polar, hydorophilic amino acid encoded by the codons AAT and AAC. []', 2006, 0, 0);
INSERT INTO chado.cvterm VALUES (1762, 22, 'lysine', 'A positively charged, hydorophilic amino acid encoded by the codons AAA and AAG. []', 2007, 0, 0);
INSERT INTO chado.cvterm VALUES (1763, 22, 'arginine', 'A positively charged, hydorophilic amino acid encoded by the codons CGN (CGT, CGC, CGA and CGG), AGA and AGG. []', 2008, 0, 0);
INSERT INTO chado.cvterm VALUES (1764, 22, 'histidine', 'A positively charged, hydorophilic amino acid encoded by the codons CAT and CAC. []', 2009, 0, 0);
INSERT INTO chado.cvterm VALUES (1765, 22, 'aspartic_acid', 'A negatively charged, hydorophilic amino acid encoded by the codons GAT and GAC. []', 2010, 0, 0);
INSERT INTO chado.cvterm VALUES (1766, 22, 'glutamic_acid', 'A negatively charged, hydorophilic amino acid encoded by the codons GAA and GAG. []', 2011, 0, 0);
INSERT INTO chado.cvterm VALUES (1767, 22, 'selenocysteine', 'A relatively rare amino acid encoded by the codon UGA in some contexts, whereas UGA is a termination codon in other contexts. [PMID:23275319]', 2012, 0, 0);
INSERT INTO chado.cvterm VALUES (1768, 22, 'pyrrolysine', 'A relatively rare amino acid encoded by the codon UAG in some contexts, whereas UAG is a termination codon in other contexts. [PMID:15788401]', 2013, 0, 0);
INSERT INTO chado.cvterm VALUES (1769, 22, 'transcribed_cluster', 'A region defined by a set of transcribed sequences from the same gene or expressed pseudogene. [SO:ke]', 2014, 0, 0);
INSERT INTO chado.cvterm VALUES (1770, 22, 'unigene_cluster', 'A kind of transcribed_cluster defined by a set of transcribed sequences from the a unique gene. [SO:ke]', 2015, 0, 0);
INSERT INTO chado.cvterm VALUES (1771, 22, 'CRISPR', 'Clustered Palindromic Repeats interspersed with bacteriophage derived spacer sequences. [RFAM:jd]', 2016, 0, 0);
INSERT INTO chado.cvterm VALUES (1772, 22, 'insulator_binding_site', 'A binding site that, in an insulator region of a nucleotide molecule, interacts selectively and non-covalently with polypeptide residues. [SO:ke]', 2017, 0, 0);
INSERT INTO chado.cvterm VALUES (1773, 22, 'enhancer_binding_site', 'A binding site that, in the enhancer region of a nucleotide molecule, interacts selectively and non-covalently with polypeptide residues. [SO:ke]', 2018, 0, 0);
INSERT INTO chado.cvterm VALUES (1774, 22, 'contig_collection', 'A collection of contigs. [SO:ke]', 2019, 0, 0);
INSERT INTO chado.cvterm VALUES (1775, 22, 'lincRNA', 'Long, intervening non-coding RNA. A transcript that does not overlap within the start or end genomic coordinates of a coding gene or pseudogene on either strand. [http://www.gencodegenes.org/gencode_biotypes.html, PMID:19182780, PMID:23463798, SO:ke]', 2020, 0, 0);
INSERT INTO chado.cvterm VALUES (1776, 22, 'lncRNA', 'A non-coding RNA generally longer than 200 nucleotides that cannot be classified as any other ncRNA subtype. Similar to mRNAs, lncRNAs are mainly transcribed by RNA polymerase II, are often capped by 7-methyl guanosine at their 5'' ends, polyadenylated at their 3'' ends and may be spliced." [HGNC:mw] {comment="PMID:33353982}', 2021, 0, 0);
INSERT INTO chado.cvterm VALUES (1777, 22, 'UST', 'An EST spanning part or all of the untranslated regions of a protein-coding transcript. [SO:nlw]', 2022, 0, 0);
INSERT INTO chado.cvterm VALUES (1778, 22, 'three_prime_UST', 'A UST located in the 3''UTR of a protein-coding transcript. [SO:nlw]', 2023, 0, 0);
INSERT INTO chado.cvterm VALUES (1779, 22, 'five_prime_UST', 'An UST located in the 5''UTR of a protein-coding transcript. [SO:nlw]', 2024, 0, 0);
INSERT INTO chado.cvterm VALUES (1780, 22, 'RST', 'A tag produced from a single sequencing read from a RACE product; typically a few hundred base pairs long. [SO:nlw]', 2025, 0, 0);
INSERT INTO chado.cvterm VALUES (1781, 22, 'three_prime_RST', 'A tag produced from a single sequencing read from a 3''-RACE product; typically a few hundred base pairs long. [SO:nlw]', 2026, 0, 0);
INSERT INTO chado.cvterm VALUES (1782, 22, 'five_prime_RST', 'A tag produced from a single sequencing read from a 5''-RACE product; typically a few hundred base pairs long. [SO:nlw]', 2027, 0, 0);
INSERT INTO chado.cvterm VALUES (1783, 22, 'UST_match', 'A match against an UST sequence. [SO:nlw]', 2028, 0, 0);
INSERT INTO chado.cvterm VALUES (1784, 22, 'RST_match', 'A match against an RST sequence. [SO:nlw]', 2029, 0, 0);
INSERT INTO chado.cvterm VALUES (1785, 22, 'primer_match', 'A nucleotide match to a primer sequence. [SO:nlw]', 2030, 0, 0);
INSERT INTO chado.cvterm VALUES (1786, 22, 'miRNA_antiguide', 'A region of the pri miRNA that base pairs with the guide to form the hairpin. [SO:ke]', 2031, 0, 0);
INSERT INTO chado.cvterm VALUES (1787, 22, 'trans_splice_junction', 'The boundary between the spliced leader and the first exon of the mRNA. [SO:ke]', 2032, 0, 0);
INSERT INTO chado.cvterm VALUES (1788, 22, 'outron', 'A region of a primary transcript, that is removed via trans splicing. [PMID:16401417, SO:ke]', 2033, 0, 0);
INSERT INTO chado.cvterm VALUES (1789, 22, 'natural_plasmid', 'A plasmid that occurs naturally. [SO:xp]', 2034, 0, 0);
INSERT INTO chado.cvterm VALUES (1790, 22, 'gene_trap_construct', 'A gene trap construct is a type of engineered plasmid which is designed to integrate into a genome and produce a fusion transcript between exons of the gene into which it inserts and a reporter element in the construct. Gene traps contain a splice acceptor, do not contain promoter elements for the reporter, and are mutagenic. Gene traps may be bicistronic with the second cassette containing a promoter driving an a selectable marker. [ZFIN:dh]', 2035, 0, 0);
INSERT INTO chado.cvterm VALUES (1791, 22, 'promoter_trap_construct', 'A promoter trap construct is a type of engineered plasmid which is designed to integrate into a genome and express a reporter when inserted in close proximity to a promoter element. Promoter traps typically do not contain promoter elements and are mutagenic. [ZFIN:dh]', 2036, 0, 0);
INSERT INTO chado.cvterm VALUES (1792, 22, 'enhancer_trap_construct', 'An enhancer trap construct is a type of engineered plasmid which is designed to integrate into a genome and express a reporter when the expression from a basic minimal promoter is enhanced by genomic enhancer elements. Enhancer traps contain promoter elements and are not usually mutagenic. [ZFIN:dh]', 2037, 0, 0);
INSERT INTO chado.cvterm VALUES (1793, 22, 'PAC_end', 'A region of sequence from the end of a PAC clone that may provide a highly specific marker. [ZFIN:mh]', 2038, 0, 0);
INSERT INTO chado.cvterm VALUES (1794, 22, 'RAPD', 'RAPD is a ''PCR product'' where a sequence variant is identified through the use of PCR with random primers. [ZFIN:mh]', 2039, 0, 0);
INSERT INTO chado.cvterm VALUES (1834, 22, 'insertional', 'When a translocation is simply moving genetic material from one chromosome to another. []', 2079, 0, 0);
INSERT INTO chado.cvterm VALUES (1795, 22, 'shadow_enhancer', 'An enhancer that drives the pattern of transcription and binds to the same TF as the primary enhancer, but is located in the intron of or on the far side of a neighboring gene. [PMID:22083793]', 2040, 0, 0);
INSERT INTO chado.cvterm VALUES (1796, 22, 'substitution', 'A sequence alteration where the length of the change in the variant is the same as that of the reference. [SO:ke]', 2041, 0, 0);
INSERT INTO chado.cvterm VALUES (1797, 22, 'X_element_combinatorial_repeat', 'An X element combinatorial repeat is a repeat region located between the X element and the telomere or adjacent Y'' element. [http://www.yeastgenome.org/help/glossary.html]', 2042, 0, 0);
INSERT INTO chado.cvterm VALUES (1798, 22, 'Y_prime_element', 'A Y'' element is a repeat region (SO:0000657) located adjacent to telomeric repeats or X element combinatorial repeats, either as a single copy or tandem repeat of two to four copies. [http:http\://www.yeastgenome.org/help/glossary.html]', 2043, 0, 0);
INSERT INTO chado.cvterm VALUES (1799, 22, 'standard_draft', 'The status of a whole genome sequence, where the data is minimally filtered or un-filtered, from any number of sequencing platforms, and is assembled into contigs. Genome sequence of this quality may harbour regions of poor quality and can be relatively incomplete. [DOI:10.1126]', 2044, 0, 0);
INSERT INTO chado.cvterm VALUES (1800, 22, 'whole_genome_sequence_status', 'The status of whole genome sequence. [DOI:10.1126]', 2045, 0, 0);
INSERT INTO chado.cvterm VALUES (1801, 22, 'high_quality_draft', 'The status of a whole genome sequence, where overall coverage represents at least 90 percent of the genome. [DOI:10.1126]', 2046, 0, 0);
INSERT INTO chado.cvterm VALUES (1802, 22, 'improved_high_quality_draft', 'The status of a whole genome sequence, where additional work has been performed, using either manual or automated methods, such as gap resolution. [DOI:10.1126]', 2047, 0, 0);
INSERT INTO chado.cvterm VALUES (1803, 22, 'annotation_directed_improved_draft', 'The status of a whole genome sequence,where annotation, and verification of coding regions has occurred. [DOI:10.1126]', 2048, 0, 0);
INSERT INTO chado.cvterm VALUES (1804, 22, 'noncontiguous_finished', 'The status of a whole genome sequence, where the assembly is high quality, closure approaches have been successful for most gaps, misassemblies and low quality regions. [DOI:10.1126]', 2049, 0, 0);
INSERT INTO chado.cvterm VALUES (1805, 22, 'finished_genome', 'The status of a whole genome sequence, with less than 1 error per 100,000 base pairs. [DOI:10.1126]', 2050, 0, 0);
INSERT INTO chado.cvterm VALUES (1806, 22, 'intronic_regulatory_region', 'A regulatory region that is part of an intron. [SO:ke]', 2051, 0, 0);
INSERT INTO chado.cvterm VALUES (1807, 22, 'centromere_DNA_Element_I', 'A centromere DNA Element I (CDEI) is a conserved region, part of the centromere, consisting of a consensus region composed of 8-11bp which enables binding by the centromere binding factor 1(Cbf1p). [PMID:11222754]', 2052, 0, 0);
INSERT INTO chado.cvterm VALUES (1808, 22, 'point_centromere', 'A point centromere is a relatively small centromere (about 125 bp DNA) in discrete sequence, found in some yeast including S. cerevisiae. [PMID:7502067, SO:vw]', 2053, 0, 0);
INSERT INTO chado.cvterm VALUES (1809, 22, 'centromere_DNA_Element_II', 'A centromere DNA Element II (CDEII) is part a conserved region of the centromere, consisting of a consensus region that is AT-rich and ~ 75-100 bp in length. [PMID:11222754]', 2054, 0, 0);
INSERT INTO chado.cvterm VALUES (1810, 22, 'centromere_DNA_Element_III', 'A centromere DNA Element I (CDEI) is a conserved region, part of the centromere, consisting of a consensus region that consists of a 25-bp which enables binding by the centromere DNA binding factor 3 (CBF3) complex. [PMID:11222754]', 2055, 0, 0);
INSERT INTO chado.cvterm VALUES (1811, 22, 'telomeric_repeat', 'The telomeric repeat is a repeat region, part of the chromosome, which in yeast, is a G-rich terminal sequence of the form (TG(1-3))n or more precisely ((TG)(1-6)TG(2-3))n. [PMID:8720065]', 2056, 0, 0);
INSERT INTO chado.cvterm VALUES (1812, 22, 'X_element', 'The X element is a conserved region, of the telomere, of ~475 bp that contains an ARS sequence and in most cases an Abf1p binding site. [http://www.yeastgenome.org/help/glossary.html#xelemcoresequence, PMID:7785338, PMID:8005434]', 2057, 0, 0);
INSERT INTO chado.cvterm VALUES (1813, 22, 'YAC_end', 'A region of sequence from the end of a YAC clone that may provide a highly specific marker. [SO:ke]', 2058, 0, 0);
INSERT INTO chado.cvterm VALUES (1814, 22, 'peptide_collection', 'A collection of peptide sequences. [BBOP:nlw]', 2059, 0, 0);
INSERT INTO chado.cvterm VALUES (1815, 22, 'high_identity_region', 'An experimental feature with high sequence identity to another sequence. [SO:ke]', 2060, 0, 0);
INSERT INTO chado.cvterm VALUES (1816, 22, 'processed_transcript', 'A transcript for which no open reading frame has been identified and for which no other function has been determined. [MGI:hdeen]', 2061, 0, 0);
INSERT INTO chado.cvterm VALUES (1817, 22, 'reference_genome', 'A collection of sequences (often chromosomes) taken as the standard for a given organism and genome assembly. [SO:ke]', 2062, 0, 0);
INSERT INTO chado.cvterm VALUES (1818, 22, 'variant_genome', 'A collection of sequences (often chromosomes) of an individual. [SO:ke]', 2063, 0, 0);
INSERT INTO chado.cvterm VALUES (1819, 22, 'alteration_attribute', 'An attribute of alteration of one or more chromosomes. []', 2064, 0, 0);
INSERT INTO chado.cvterm VALUES (1820, 22, 'chromosomal_variation_attribute', 'An attribute of a change in the structure or number of a chromosomes. []', 2065, 0, 0);
INSERT INTO chado.cvterm VALUES (1821, 22, 'intrachromosomal', 'A change in chromosomes that occurs between two separate chromosomes. []', 2066, 0, 0);
INSERT INTO chado.cvterm VALUES (1822, 22, 'interchromosomal', 'A change in chromosomes that occurs between two sections of the same chromosome or between homologous chromosomes. []', 2067, 0, 0);
INSERT INTO chado.cvterm VALUES (1823, 22, 'insertion_attribute', 'A quality of a chromosomal insertion,. [SO:ke]', 2068, 0, 0);
INSERT INTO chado.cvterm VALUES (1824, 22, 'tandem', 'An insertion of extension of a tandem repeat. []', 2069, 0, 0);
INSERT INTO chado.cvterm VALUES (1825, 22, 'direct', 'A quality of an insertion where the insert is not in a cytologically inverted orientation. [SO:ke]', 2070, 0, 0);
INSERT INTO chado.cvterm VALUES (1826, 22, 'inverted', 'A quality of an insertion where the insert is in a cytologically inverted orientation. [SO:ke]', 2071, 0, 0);
INSERT INTO chado.cvterm VALUES (1827, 22, 'free', 'The quality of a duplication where the new region exists independently of the original. [SO:ke]', 2072, 0, 0);
INSERT INTO chado.cvterm VALUES (1828, 22, 'duplication_attribute', 'An attribute of a duplication, which is an insertion which derives from, or is identical in sequence to, nucleotides present at a known location in the genome. []', 2073, 0, 0);
INSERT INTO chado.cvterm VALUES (1829, 22, 'inversion_attribute', 'When a region of a chromosome is changed to the reverse order without duplication or deletion. []', 2074, 0, 0);
INSERT INTO chado.cvterm VALUES (1830, 22, 'pericentric', 'An inversion event that includes the centromere. []', 2075, 0, 0);
INSERT INTO chado.cvterm VALUES (1831, 22, 'paracentric', 'An inversion event that does not include the centromere. []', 2076, 0, 0);
INSERT INTO chado.cvterm VALUES (1832, 22, 'translocaton_attribute', 'An attribute of a translocation, which is then a region of nucleotide sequence that has translocated to a new position. The observed adjacency of two previously separated regions. []', 2077, 0, 0);
INSERT INTO chado.cvterm VALUES (1833, 22, 'reciprocal', 'When translocation occurs between nonhomologous chromosomes and involved an equal exchange of genetic materials. []', 2078, 0, 0);
INSERT INTO chado.cvterm VALUES (1835, 22, 'assembly_error_correction', 'A region of sequence where the final nucleotide assignment differs from the original assembly due to an improvement that replaces a mistake. [SO:ke]', 2080, 0, 0);
INSERT INTO chado.cvterm VALUES (1836, 22, 'base_call_error_correction', 'A region of sequence where the final nucleotide assignment is different from that given by the base caller due to an improvement that replaces a mistake. [SO:ke]', 2081, 0, 0);
INSERT INTO chado.cvterm VALUES (1837, 22, 'nuclear_localization_signal', 'A polypeptide region that targets a polypeptide to the nucleus. [SO:ke]', 2082, 0, 0);
INSERT INTO chado.cvterm VALUES (1838, 22, 'endosomal_localization_signal', 'A polypeptide region that targets a polypeptide to the endosome. [SO:ke]', 2083, 0, 0);
INSERT INTO chado.cvterm VALUES (1839, 22, 'lysosomal_localization_signal', 'A polypeptide region that targets a polypeptide to the lysosome. [SO:ke]', 2084, 0, 0);
INSERT INTO chado.cvterm VALUES (1840, 22, 'nuclear_export_signal', 'A polypeptide region that targets a polypeptide to he cytoplasm. [SO:ke]', 2085, 0, 0);
INSERT INTO chado.cvterm VALUES (1841, 22, 'recombination_signal_sequence', 'A region recognized by a recombinase. [SO:ke]', 2086, 0, 0);
INSERT INTO chado.cvterm VALUES (1842, 22, 'cryptic_splice_site', 'A splice site that is in part of the transcript not normally spliced. They occur via mutation or transcriptional error. [SO:ke]', 2087, 0, 0);
INSERT INTO chado.cvterm VALUES (1843, 22, 'nuclear_rim_localization_signal', 'A polypeptide region that targets a polypeptide to the nuclear rim. [SO:ke]', 2088, 0, 0);
INSERT INTO chado.cvterm VALUES (1844, 22, 'P_TIR_transposon', 'A P-element is a DNA transposon responsible for hybrid dysgenesis. P elements in this terminal inverted repeat (TIR) transposon superfamily have 31 bp perfect TIR and upon insertion duplicate an 8 bp sequence. It contains transposase that may lack the DDE domain. [PMID:6309410, SO:ke]', 2090, 0, 0);
INSERT INTO chado.cvterm VALUES (1845, 22, 'functional_effect_variant', 'A variant whereby the effect is evaluated with respect to a reference. [SO:ke]', 2091, 0, 0);
INSERT INTO chado.cvterm VALUES (1846, 22, 'structural_variant', 'A sequence variant that changes one or more structural features. [SO:ke]', 2092, 0, 0);
INSERT INTO chado.cvterm VALUES (1847, 22, 'transcript_function_variant', 'A sequence variant which alters the functioning of a transcript with respect to a reference sequence. [SO:ke]', 2093, 0, 0);
INSERT INTO chado.cvterm VALUES (1848, 22, 'functionally_abnormal', 'A sequence variant in which the function of a gene product is altered with respect to a reference. []', 2094, 0, 0);
INSERT INTO chado.cvterm VALUES (1849, 22, 'translational_product_function_variant', 'A sequence variant that affects the functioning of a translational product with respect to a reference sequence. [SO:ke]', 2095, 0, 0);
INSERT INTO chado.cvterm VALUES (1850, 22, 'level_of_transcript_variant', 'A sequence variant which alters the level of a transcript. [SO:ke]', 2096, 0, 0);
INSERT INTO chado.cvterm VALUES (1851, 22, 'decreased_transcript_level_variant', 'A sequence variant that decreases the level of mature, spliced and processed RNA with respect to a reference sequence. [SO:ke]', 2097, 0, 0);
INSERT INTO chado.cvterm VALUES (1852, 22, 'increased_transcript_level_variant', 'A sequence variant that increases the level of mature, spliced and processed RNA with respect to a reference sequence. [SO:ke]', 2098, 0, 0);
INSERT INTO chado.cvterm VALUES (1853, 22, 'transcript_processing_variant', 'A sequence variant that affects the post transcriptional processing of a transcript with respect to a reference sequence. [SO:ke]', 2099, 0, 0);
INSERT INTO chado.cvterm VALUES (1854, 22, 'editing_variant', 'A transcript processing variant whereby the process of editing is disrupted with respect to the reference. [SO:ke]', 2100, 0, 0);
INSERT INTO chado.cvterm VALUES (1855, 22, 'polyadenylation_variant', 'A sequence variant that changes polyadenylation with respect to a reference sequence. [SO:ke]', 2101, 0, 0);
INSERT INTO chado.cvterm VALUES (1856, 22, 'transcript_stability_variant', 'A variant that changes the stability of a transcript with respect to a reference sequence. [SO:ke]', 2102, 0, 0);
INSERT INTO chado.cvterm VALUES (1857, 22, 'decreased_transcript_stability_variant', 'A sequence variant that decreases transcript stability with respect to a reference sequence. [SO:ke]', 2103, 0, 0);
INSERT INTO chado.cvterm VALUES (1858, 22, 'increased_transcript_stability_variant', 'A sequence variant that increases transcript stability with respect to a reference sequence. [SO:ke]', 2104, 0, 0);
INSERT INTO chado.cvterm VALUES (1859, 22, 'transcription_variant', 'A variant that changes alters the transcription of a transcript with respect to a reference sequence. [SO:ke]', 2105, 0, 0);
INSERT INTO chado.cvterm VALUES (1860, 22, 'rate_of_transcription_variant', 'A sequence variant that changes the rate of transcription with respect to a reference sequence. [SO:ke]', 2106, 0, 0);
INSERT INTO chado.cvterm VALUES (1861, 22, 'increased_transcription_rate_variant', 'A sequence variant that increases the rate of transcription with respect to a reference sequence. [SO:ke]', 2107, 0, 0);
INSERT INTO chado.cvterm VALUES (1862, 22, 'decreased_transcription_rate_variant', 'A sequence variant that decreases the rate of transcription with respect to a reference sequence. [SO:ke]', 2108, 0, 0);
INSERT INTO chado.cvterm VALUES (1863, 22, 'translational_product_level_variant', 'A functional variant that changes the translational product level with respect to a reference sequence. [SO:ke]', 2109, 0, 0);
INSERT INTO chado.cvterm VALUES (1864, 22, 'polypeptide_function_variant', 'A sequence variant which changes polypeptide functioning with respect to a reference sequence. [SO:ke]', 2110, 0, 0);
INSERT INTO chado.cvterm VALUES (1865, 22, 'decreased_translational_product_level', 'A sequence variant which decreases the translational product level with respect to a reference sequence. [SO:ke]', 2111, 0, 0);
INSERT INTO chado.cvterm VALUES (1866, 22, 'increased_translational_product_level', 'A sequence variant which increases the translational product level with respect to a reference sequence. [SO:ke]', 2112, 0, 0);
INSERT INTO chado.cvterm VALUES (1867, 22, 'polypeptide_gain_of_function_variant', 'A sequence variant which causes gain of polypeptide function with respect to a reference sequence. [SO:ke]', 2113, 0, 0);
INSERT INTO chado.cvterm VALUES (1868, 22, 'polypeptide_localization_variant', 'A sequence variant which changes the localization of a polypeptide with respect to a reference sequence. [SO:ke]', 2114, 0, 0);
INSERT INTO chado.cvterm VALUES (1869, 22, 'polypeptide_loss_of_function_variant', 'A sequence variant that causes the loss of a polypeptide function with respect to a reference sequence. [SO:ke]', 2115, 0, 0);
INSERT INTO chado.cvterm VALUES (1870, 22, 'inactive_ligand_binding_site', 'A sequence variant that causes the inactivation of a ligand binding site with respect to a reference sequence. [SO:ke]', 2116, 0, 0);
INSERT INTO chado.cvterm VALUES (1871, 22, 'polypeptide_partial_loss_of_function', 'A sequence variant that causes some but not all loss of polypeptide function with respect to a reference sequence. [SO:ke]', 2117, 0, 0);
INSERT INTO chado.cvterm VALUES (1872, 22, 'polypeptide_post_translational_processing_variant', 'A sequence variant that causes a change in post translational processing of the peptide with respect to a reference sequence. [SO:ke]', 2118, 0, 0);
INSERT INTO chado.cvterm VALUES (1873, 22, 'copy_number_change', 'A sequence variant where copies of a feature (CNV) are either increased or decreased. [SO:ke]', 2119, 0, 0);
INSERT INTO chado.cvterm VALUES (1874, 22, 'sequence_length_variant', 'A sequence variant that changes the length of one or more sequence features. []', 2120, 0, 0);
INSERT INTO chado.cvterm VALUES (1875, 22, 'gene_variant', 'A sequence variant where the structure of the gene is changed. [SO:ke]', 2121, 0, 0);
INSERT INTO chado.cvterm VALUES (1876, 22, 'gene_fusion', 'A sequence variant whereby a two genes have become joined. [SO:ke]', 2122, 0, 0);
INSERT INTO chado.cvterm VALUES (1877, 22, 'feature_fusion', 'A sequence variant, caused by an alteration of the genomic sequence, where a deletion fuses genomic features. [SO:ke]', 2123, 0, 0);
INSERT INTO chado.cvterm VALUES (1878, 22, 'regulatory_region_variant', 'A sequence variant located within a regulatory region. [SO:ke]', 2124, 0, 0);
INSERT INTO chado.cvterm VALUES (1879, 22, 'stop_retained_variant', 'A sequence variant where at least one base in the terminator codon is changed, but the terminator remains. [SO:ke]', 2125, 0, 0);
INSERT INTO chado.cvterm VALUES (1880, 22, 'terminator_codon_variant', 'A sequence variant whereby at least one of the bases in the terminator codon is changed. [SO:ke]', 2126, 0, 0);
INSERT INTO chado.cvterm VALUES (1881, 22, 'synonymous_variant', 'A sequence variant where there is no resulting change to the encoded amino acid. [SO:ke]', 2127, 0, 0);
INSERT INTO chado.cvterm VALUES (1882, 22, 'splicing_variant', 'A sequence variant that changes the process of splicing. [SO:ke]', 2128, 0, 0);
INSERT INTO chado.cvterm VALUES (1883, 22, 'transcript_variant', 'A sequence variant that changes the structure of the transcript. [SO:ke]', 2130, 0, 0);
INSERT INTO chado.cvterm VALUES (1884, 22, 'cryptic_splice_site_variant', 'A sequence variant causing a new (functional) splice site. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2131, 0, 0);
INSERT INTO chado.cvterm VALUES (1885, 22, 'cryptic_splice_acceptor', 'A sequence variant whereby a new splice site is created due to the activation of a new acceptor. [SO:ke]', 2132, 0, 0);
INSERT INTO chado.cvterm VALUES (1886, 22, 'cryptic_splice_donor', 'A sequence variant whereby a new splice site is created due to the activation of a new donor. [SO:ke]', 2133, 0, 0);
INSERT INTO chado.cvterm VALUES (1887, 22, 'exon_loss_variant', 'A sequence variant whereby an exon is lost from the transcript. [SO:ke]', 2134, 0, 0);
INSERT INTO chado.cvterm VALUES (1888, 22, 'intron_gain_variant', 'A sequence variant whereby an intron is gained by the processed transcript; usually a result of an alteration of the donor or acceptor. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2135, 0, 0);
INSERT INTO chado.cvterm VALUES (1889, 22, 'splice_acceptor_variant', 'A splice variant that changes the 2 base region at the 3'' end of an intron. [SO:ke]', 2136, 0, 0);
INSERT INTO chado.cvterm VALUES (1890, 22, 'splice_site_variant', 'A sequence variant that changes the first two or last two bases of an intron, or the 5th base from the start of the intron in the orientation of the transcript. [http://ensembl.org/info/docs/variation/index.html]', 2137, 0, 0);
INSERT INTO chado.cvterm VALUES (1891, 22, 'splice_donor_variant', 'A splice variant that changes the 2 base pair region at the 5'' end of an intron. [SO:ke]', 2138, 0, 0);
INSERT INTO chado.cvterm VALUES (1892, 22, 'complex_transcript_variant', 'A transcript variant with a complex INDEL- Insertion or deletion that spans an exon/intron border or a coding sequence/UTR border. [http://ensembl.org/info/docs/variation/index.html]', 2139, 0, 0);
INSERT INTO chado.cvterm VALUES (1893, 22, 'stop_lost', 'A sequence variant where at least one base of the terminator codon (stop) is changed, resulting in an elongated transcript. [SO:ke]', 2140, 0, 0);
INSERT INTO chado.cvterm VALUES (1894, 22, 'feature_elongation', 'A sequence variant that causes the extension of a genomic feature, with regard to the reference sequence. [SO:ke]', 2141, 0, 0);
INSERT INTO chado.cvterm VALUES (1895, 22, 'nonsynonymous_variant', 'A non-synonymous variant is an inframe, protein altering variant, resulting in a codon change. [SO:ke]', 2142, 0, 0);
INSERT INTO chado.cvterm VALUES (1896, 22, 'transcript_sequence_variant', '', 2143, 1, 0);
INSERT INTO chado.cvterm VALUES (1897, 22, 'coding_sequence_variant', 'A sequence variant that changes the coding sequence. [SO:ke]', 2144, 0, 0);
INSERT INTO chado.cvterm VALUES (1898, 22, 'exon_variant', 'A sequence variant that changes exon sequence. [SO:ke]', 2146, 0, 0);
INSERT INTO chado.cvterm VALUES (1899, 22, 'coding_transcript_variant', 'A transcript variant of a protein coding gene. [SO:ke]', 2147, 0, 0);
INSERT INTO chado.cvterm VALUES (1900, 22, 'initiator_codon_variant', 'A codon variant that changes at least one base of the first codon of a transcript. [SO:ke]', 2148, 0, 0);
INSERT INTO chado.cvterm VALUES (1901, 22, 'missense_variant', 'A sequence variant, that changes one or more bases, resulting in a different amino acid sequence but where the length is preserved. [EBI:fc, EBI:gr, SO:ke]', 2150, 0, 0);
INSERT INTO chado.cvterm VALUES (1902, 22, 'conservative_missense_variant', 'A sequence variant whereby at least one base of a codon is changed resulting in a codon that encodes for a different but similar amino acid. These variants may or may not be deleterious. [SO:ke]', 2154, 0, 0);
INSERT INTO chado.cvterm VALUES (1903, 22, 'non_conservative_missense_variant', 'A sequence variant whereby at least one base of a codon is changed resulting in a codon that encodes for an amino acid with different biochemical properties. [SO:ke]', 2155, 0, 0);
INSERT INTO chado.cvterm VALUES (1904, 22, 'stop_gained', 'A sequence variant whereby at least one base of a codon is changed, resulting in a premature stop codon, leading to a shortened polypeptide. [SO:ke]', 2156, 0, 0);
INSERT INTO chado.cvterm VALUES (1905, 22, 'feature_truncation', 'A sequence variant that causes the reduction of a genomic feature, with regard to the reference sequence. [SO:ke]', 2158, 0, 0);
INSERT INTO chado.cvterm VALUES (1906, 22, 'frameshift_variant', 'A sequence variant which causes a disruption of the translational reading frame, because the number of nucleotides inserted or deleted is not a multiple of three. [SO:ke]', 2159, 0, 0);
INSERT INTO chado.cvterm VALUES (1907, 22, 'protein_altering_variant', 'A sequence_variant which is predicted to change the protein encoded in the coding sequence. [EBI:gr]', 2161, 0, 0);
INSERT INTO chado.cvterm VALUES (1908, 22, 'frame_restoring_variant', 'A sequence variant that reverts the sequence of a previous frameshift mutation back to the initial frame. [SO:ke]', 2164, 0, 0);
INSERT INTO chado.cvterm VALUES (1909, 22, 'minus_1_frameshift_variant', 'A sequence variant which causes a disruption of the translational reading frame, by shifting one base ahead. [http://arjournals.annualreviews.org/doi/pdf/10.1146/annurev.ge.08.120174.001535]', 2165, 0, 0);
INSERT INTO chado.cvterm VALUES (1910, 22, 'minus_2_frameshift_variant', 'A sequence variant which causes a disruption of the translational reading frame, by shifting two bases forward. []', 2166, 0, 0);
INSERT INTO chado.cvterm VALUES (1911, 22, 'plus_1_frameshift_variant', 'A sequence variant which causes a disruption of the translational reading frame, by shifting one base backward. [http://arjournals.annualreviews.org/doi/pdf/10.1146/annurev.ge.08.120174.001535]', 2167, 0, 0);
INSERT INTO chado.cvterm VALUES (1912, 22, 'plus_2_frameshift_variant', 'A sequence variant which causes a disruption of the translational reading frame, by shifting two bases backward. []', 2168, 0, 0);
INSERT INTO chado.cvterm VALUES (1913, 22, 'transcript_secondary_structure_variant', 'A sequence variant within a transcript that changes the secondary structure of the RNA product. [SO:ke]', 2169, 0, 0);
INSERT INTO chado.cvterm VALUES (1914, 22, 'compensatory_transcript_secondary_structure_variant', 'A secondary structure variant that compensate for the change made by a previous variant. [SO:ke]', 2170, 0, 0);
INSERT INTO chado.cvterm VALUES (1915, 22, 'translational_product_structure_variant', 'A sequence variant within the transcript that changes the structure of the translational product. [SO:ke]', 2171, 0, 0);
INSERT INTO chado.cvterm VALUES (1916, 22, '3D_polypeptide_structure_variant', 'A sequence variant that changes the resulting polypeptide structure. [SO:ke]', 2172, 0, 0);
INSERT INTO chado.cvterm VALUES (1917, 22, 'complex_3D_structural_variant', 'A sequence variant that changes the resulting polypeptide structure. [SO:ke]', 2173, 0, 0);
INSERT INTO chado.cvterm VALUES (1918, 22, 'conformational_change_variant', 'A sequence variant in the CDS region that causes a conformational change in the resulting polypeptide sequence. [SO:ke]', 2174, 0, 0);
INSERT INTO chado.cvterm VALUES (1919, 22, 'complex_change_of_translational_product_variant', 'A variant that changes the translational product with respect to the reference. []', 2175, 0, 0);
INSERT INTO chado.cvterm VALUES (1920, 22, 'polypeptide_sequence_variant', 'A sequence variant with in the CDS that causes a change in the resulting polypeptide sequence. [SO:ke]', 2176, 0, 0);
INSERT INTO chado.cvterm VALUES (1921, 22, 'amino_acid_deletion', 'A sequence variant within a CDS resulting in the loss of an amino acid from the resulting polypeptide. [SO:ke]', 2177, 0, 0);
INSERT INTO chado.cvterm VALUES (1922, 22, 'amino_acid_insertion', 'A sequence variant within a CDS resulting in the gain of an amino acid to the resulting polypeptide. [SO:ke]', 2178, 0, 0);
INSERT INTO chado.cvterm VALUES (1923, 22, 'amino_acid_substitution', 'A sequence variant of a codon resulting in the substitution of one amino acid for another in the resulting polypeptide. [SO:ke]', 2179, 0, 0);
INSERT INTO chado.cvterm VALUES (1924, 22, 'conservative_amino_acid_substitution', 'A sequence variant of a codon causing the substitution of a similar amino acid for another in the resulting polypeptide. [SO:ke]', 2180, 0, 0);
INSERT INTO chado.cvterm VALUES (1925, 22, 'non_conservative_amino_acid_substitution', 'A sequence variant of a codon causing the substitution of a non conservative amino acid for another in the resulting polypeptide. [SO:ke]', 2181, 0, 0);
INSERT INTO chado.cvterm VALUES (1926, 22, 'elongated_polypeptide', 'An elongation of a polypeptide sequence deriving from a sequence variant extending the CDS. [SO:ke]', 2182, 0, 0);
INSERT INTO chado.cvterm VALUES (1927, 22, 'elongated_polypeptide_C_terminal', 'An elongation of a polypeptide sequence at the C terminus deriving from a sequence variant extending the CDS. [SO:ke]', 2183, 0, 0);
INSERT INTO chado.cvterm VALUES (1928, 22, 'CDS_three_prime_extension', 'A sequence variant extending the CDS at the 3'' end, that causes elongation of the resulting polypeptide sequence at the C terminus. [PMID:14732127, PMID:15864293, PMID:27984720, PMID:31216041, PMID:32020195]', 2184, 0, 0);
INSERT INTO chado.cvterm VALUES (1929, 22, 'elongated_polypeptide_N_terminal', 'An elongation of a polypeptide sequence at the N terminus deriving from a sequence variant extending the CDS. [SO:ke]', 2185, 0, 0);
INSERT INTO chado.cvterm VALUES (1930, 22, 'CDS_five_prime_extension', 'A sequence variant extending the CDS at the 5'' end, that causes elongation of the resulting polypeptide sequence at the N terminus. [PMID:14732127, PMID:15864293, PMID:27984720, PMID:31216041, PMID:32020195]', 2186, 0, 0);
INSERT INTO chado.cvterm VALUES (1931, 22, 'elongated_in_frame_polypeptide_C_terminal', 'A sequence variant with in the CDS that causes in frame elongation of the resulting polypeptide sequence at the C terminus. [SO:ke]', 2187, 0, 0);
INSERT INTO chado.cvterm VALUES (1932, 22, 'elongated_out_of_frame_polypeptide_C_terminal', 'A sequence variant with in the CDS that causes out of frame elongation of the resulting polypeptide sequence at the C terminus. [SO:ke]', 2188, 0, 0);
INSERT INTO chado.cvterm VALUES (1933, 22, 'elongated_in_frame_polypeptide_N_terminal_elongation', 'A sequence variant with in the CDS that causes in frame elongation of the resulting polypeptide sequence at the N terminus. [SO:ke]', 2189, 0, 0);
INSERT INTO chado.cvterm VALUES (1934, 22, 'elongated_out_of_frame_polypeptide_N_terminal', 'A sequence variant with in the CDS that causes out of frame elongation of the resulting polypeptide sequence at the N terminus. [SO:ke]', 2190, 0, 0);
INSERT INTO chado.cvterm VALUES (1935, 22, 'polypeptide_fusion', 'A sequence variant that causes a fusion of two polypeptide sequences. [SO:ke]', 2191, 0, 0);
INSERT INTO chado.cvterm VALUES (1936, 22, 'polypeptide_truncation', 'A sequence variant of the CD that causes a truncation of the resulting polypeptide. [SO:ke]', 2192, 0, 0);
INSERT INTO chado.cvterm VALUES (1937, 22, 'inactive_catalytic_site', 'A sequence variant that causes the inactivation of a catalytic site with respect to a reference sequence. [SO:ke]', 2193, 0, 0);
INSERT INTO chado.cvterm VALUES (1938, 22, 'non_coding_transcript_variant', 'A transcript variant of a non coding RNA gene. [SO:ke]', 2194, 0, 0);
INSERT INTO chado.cvterm VALUES (1939, 22, 'mature_miRNA_variant', 'A transcript variant located with the sequence of the mature miRNA. [SO:ke]', 2195, 0, 0);
INSERT INTO chado.cvterm VALUES (1940, 22, 'NMD_transcript_variant', 'A variant in a transcript that is the target of nonsense-mediated mRNA decay. [SO:ke]', 2197, 0, 0);
INSERT INTO chado.cvterm VALUES (1941, 22, 'UTR_variant', 'A transcript variant that is located within the UTR. [SO:ke]', 2198, 0, 0);
INSERT INTO chado.cvterm VALUES (1942, 22, '5_prime_UTR_variant', 'A UTR variant of the 5'' UTR. [SO:ke]', 2199, 0, 0);
INSERT INTO chado.cvterm VALUES (1943, 22, '3_prime_UTR_variant', 'A UTR variant of the 3'' UTR. [SO:ke]', 2200, 0, 0);
INSERT INTO chado.cvterm VALUES (1944, 22, 'incomplete_terminal_codon_variant', 'A sequence variant where at least one base of the final codon of an incompletely annotated transcript is changed. [SO:ke]', 2201, 0, 0);
INSERT INTO chado.cvterm VALUES (1945, 22, 'inframe_variant', 'A sequence variant which does not cause a disruption of the translational reading frame. [SO:ke]', 2202, 0, 0);
INSERT INTO chado.cvterm VALUES (1946, 22, 'intron_variant', 'A transcript variant occurring within an intron. [SO:ke]', 2203, 0, 0);
INSERT INTO chado.cvterm VALUES (1947, 22, 'intergenic_variant', 'A sequence variant located in the intergenic region, between genes. [SO:ke]', 2204, 0, 0);
INSERT INTO chado.cvterm VALUES (1948, 22, 'splice_region_variant', 'A sequence variant in which a change has occurred within the region of the splice site, either within 1-3 bases of the exon or 3-8 bases of the intron. [http://ensembl.org/info/docs/variation/index.html]', 2205, 0, 0);
INSERT INTO chado.cvterm VALUES (1949, 22, 'upstream_gene_variant', 'A sequence variant located 5'' of a gene. [SO:ke]', 2206, 0, 0);
INSERT INTO chado.cvterm VALUES (1950, 22, 'downstream_gene_variant', 'A sequence variant located 3'' of a gene. [SO:ke]', 2207, 0, 0);
INSERT INTO chado.cvterm VALUES (1951, 22, '5KB_downstream_variant', 'A sequence variant located within 5 KB of the end of a gene. [SO:ke]', 2208, 0, 0);
INSERT INTO chado.cvterm VALUES (1952, 22, '500B_downstream_variant', 'A sequence variant located within a half KB of the end of a gene. [SO:ke]', 2209, 0, 0);
INSERT INTO chado.cvterm VALUES (1953, 22, '5KB_upstream_variant', 'A sequence variant located within 5KB 5'' of a gene. [SO:ke]', 2210, 0, 0);
INSERT INTO chado.cvterm VALUES (1954, 22, '2KB_upstream_variant', 'A sequence variant located within 2KB 5'' of a gene. [SO:ke]', 2211, 0, 0);
INSERT INTO chado.cvterm VALUES (1955, 22, 'rRNA_gene', 'A gene that encodes for ribosomal RNA. [SO:ke]', 2212, 0, 0);
INSERT INTO chado.cvterm VALUES (1956, 22, 'piRNA_gene', 'A gene that encodes for an piwi associated RNA. [SO:ke]', 2213, 0, 0);
INSERT INTO chado.cvterm VALUES (1957, 22, 'RNase_P_RNA_gene', 'A gene that encodes an RNase P RNA. [SO:ke]', 2214, 0, 0);
INSERT INTO chado.cvterm VALUES (1960, 22, 'lincRNA_gene', 'A gene that encodes a long, intervening non-coding RNA. [http://www.gencodegenes.org/gencode_biotypes.html, PMID:23463798, SO:ke]', 2217, 0, 0);
INSERT INTO chado.cvterm VALUES (1961, 22, 'lncRNA_gene', 'A gene that encodes a long non-coding RNA. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2218, 0, 0);
INSERT INTO chado.cvterm VALUES (1962, 22, 'mathematically_defined_repeat', 'A mathematically defined repeat (MDR) is a experimental feature that is determined by querying overlapping oligomers of length k against a database of shotgun sequence data and identifying regions in the query sequence that exceed a statistically determined threshold of repetitiveness. [SO:jestill]', 2219, 0, 0);
INSERT INTO chado.cvterm VALUES (1963, 22, 'telomerase_RNA_gene', 'A telomerase RNA gene is a non coding RNA gene the RNA product of which is a component of telomerase. [SO:ke]', 2220, 0, 0);
INSERT INTO chado.cvterm VALUES (1964, 22, 'targeting_vector', 'An engineered vector that is able to take part in homologous recombination in a host with the intent of introducing site specific genomic modifications. [MGD:tm, PMID:10354467]', 2221, 0, 0);
INSERT INTO chado.cvterm VALUES (1965, 22, 'DArT_marker', 'A genetic marker, discovered using Diversity Arrays Technology (DArT) technology. [SO:ke]', 2222, 0, 0);
INSERT INTO chado.cvterm VALUES (1966, 22, 'kozak_sequence', 'A kind of ribosome entry site, specific to Eukaryotic organisms that overlaps part of both 5'' UTR and CDS sequence. [SO:ke]', 2223, 0, 0);
INSERT INTO chado.cvterm VALUES (1967, 22, 'retinoic_acid_responsive_element', 'A transcription factor binding site of variable direct repeats of the sequence PuGGTCA spaced by five nucleotides (DR5) found in the promoters of retinoic acid-responsive genes, to which retinoic acid receptors bind. [PMID:11327309, PMID:19917671]', 2224, 0, 0);
INSERT INTO chado.cvterm VALUES (1968, 22, 'nested_tandem_repeat', 'An NTR is a nested repeat of two distinct tandem motifs interspersed with each other. [SO:AF]', 2225, 0, 0);
INSERT INTO chado.cvterm VALUES (1969, 22, 'RNA_polymerase_II_TATA_box', 'A TATA box core promoter of a gene transcribed by RNA polymerase II. [PMID:16858867]', 2226, 0, 0);
INSERT INTO chado.cvterm VALUES (1970, 22, 'RNA_polymerase_III_TATA_box', 'A TATA box core promoter of a gene transcribed by RNA polymerase III. [SO:ke]', 2227, 0, 0);
INSERT INTO chado.cvterm VALUES (1971, 22, 'BREd_motif', 'A core RNA polymerase II promoter element with consensus (G/A)T(T/G/A)(T/A)(G/T)(T/G)(T/G). [PMID:16858867]', 2228, 0, 0);
INSERT INTO chado.cvterm VALUES (1972, 22, 'DCE', 'A discontinuous core element of RNA polymerase II transcribed genes, situated downstream of the TSS. It is composed of three sub elements: SI, SII and SIII. [PMID:16858867]', 2229, 0, 0);
INSERT INTO chado.cvterm VALUES (1973, 22, 'DCE_SI', 'A sub element of the DCE core promoter element, with consensus sequence CTTC. [PMID:16858867, SO:ke]', 2230, 0, 0);
INSERT INTO chado.cvterm VALUES (1974, 22, 'DCE_SII', 'A sub element of the DCE core promoter element with consensus sequence CTGT. [PMID:16858867, SO:ke]', 2231, 0, 0);
INSERT INTO chado.cvterm VALUES (1975, 22, 'DCE_SIII', 'A sub element of the DCE core promoter element with consensus sequence AGC. [PMID:16858867, SO:ke]', 2232, 0, 0);
INSERT INTO chado.cvterm VALUES (1976, 22, 'proximal_promoter_element', 'DNA segment that ranges from about -250 to -40 relative to +1 of RNA transcription start site, where sequence specific DNA-binding transcription factors binds, such as Sp1, CTF (CCAAT-binding transcription factor), and CBF (CCAAT-box binding factor). [PMID:12515390, PMID:9679020, SO:ml]', 2233, 0, 0);
INSERT INTO chado.cvterm VALUES (1977, 22, 'regulatory_promoter_element', 'A promoter element that is not part of the core promoter, but provides the promoter with a specific regulatory region. [PMID:12381659]', 2234, 0, 0);
INSERT INTO chado.cvterm VALUES (1978, 22, 'distal_promoter_element', 'A regulatory promoter element that is distal from the TSS. []', 2235, 0, 0);
INSERT INTO chado.cvterm VALUES (1979, 22, 'bacterial_RNApol_promoter_sigma54_element', 'A DNA sequence to which bacterial RNA polymerase sigma 54 binds, to begin transcription. []', 2236, 0, 0);
INSERT INTO chado.cvterm VALUES (1980, 22, 'minus_12_signal', 'A conserved region about 12-bp upstream of the start point of bacterial transcription units, involved with sigma factor 54. [PMID:18331472]', 2237, 0, 0);
INSERT INTO chado.cvterm VALUES (1981, 22, 'minus_24_signal', 'A conserved region about 24-bp upstream of the start point of bacterial transcription units, involved with sigma factor 54. [PMID:18331472]', 2238, 0, 0);
INSERT INTO chado.cvterm VALUES (1982, 22, 'A_box_type_1', 'An A box within an RNA polymerase III type 1 promoter. [SO:ke]', 2239, 0, 0);
INSERT INTO chado.cvterm VALUES (1983, 22, 'A_box_type_2', 'An A box within an RNA polymerase III type 2 promoter. [SO:ke]', 2240, 0, 0);
INSERT INTO chado.cvterm VALUES (1984, 22, 'intermediate_element', 'A core promoter region of RNA polymerase III type 1 promoters. [PMID:12381659]', 2241, 0, 0);
INSERT INTO chado.cvterm VALUES (1985, 22, 'transcription_regulatory_region', 'A regulatory region that is involved in the control of the process of transcription. [SO:ke]', 2242, 1, 0);
INSERT INTO chado.cvterm VALUES (1986, 22, 'recombination_regulatory_region', 'A regulatory region that is involved in the control of the process of recombination. [SO:ke]', 2243, 0, 0);
INSERT INTO chado.cvterm VALUES (1987, 22, 'replication_regulatory_region', 'A regulatory region that is involved in the control of the process of nucleotide replication. [SO:ke]', 2244, 0, 0);
INSERT INTO chado.cvterm VALUES (1988, 22, 'experimental_feature_attribute', 'An attribute of an experimentally derived feature. [SO:ke]', 2245, 0, 0);
INSERT INTO chado.cvterm VALUES (1989, 22, 'score', 'The score of an experimentally derived feature such as a p-value. [SO:ke]', 2246, 0, 0);
INSERT INTO chado.cvterm VALUES (1990, 22, 'quality_value', 'An experimental feature attribute that defines the quality of the feature in a quantitative way, such as a phred quality score. [SO:ke]', 2247, 0, 0);
INSERT INTO chado.cvterm VALUES (1991, 22, 'restriction_enzyme_recognition_site', 'The nucleotide region (usually a palindrome) that is recognized by a restriction enzyme. This may or may not be equal to the restriction enzyme binding site. [SO:ke]', 2248, 0, 0);
INSERT INTO chado.cvterm VALUES (1992, 22, 'restriction_enzyme_region', 'A region related to restriction enzyme function. [SO:ke]', 2249, 0, 0);
INSERT INTO chado.cvterm VALUES (1993, 22, 'restriction_enzyme_cleavage_junction', 'The boundary at which a restriction enzyme breaks the nucleotide sequence. [SO:ke]', 2250, 0, 0);
INSERT INTO chado.cvterm VALUES (1994, 22, 'nucleotide_cleavage_site', 'A point in nucleic acid where a cleavage event occurs. []', 2251, 0, 0);
INSERT INTO chado.cvterm VALUES (1995, 22, 'five_prime_restriction_enzyme_junction', 'The restriction enzyme cleavage junction on the 5'' strand of the nucleotide sequence. [SO:ke]', 2252, 0, 0);
INSERT INTO chado.cvterm VALUES (1996, 22, 'single_strand_restriction_enzyme_cleavage_site', 'A restriction enzyme cleavage site whereby only one strand is cut. [SO:ke]', 2253, 0, 0);
INSERT INTO chado.cvterm VALUES (1997, 22, 'sticky_end_restriction_enzyme_cleavage_site', 'A site where restriction enzymes can cleave that will produce an overhang or ''sticky end''. []', 2254, 0, 0);
INSERT INTO chado.cvterm VALUES (1998, 22, 'three_prime_restriction_enzyme_junction', 'The restriction enzyme cleavage junction on the 3'' strand of the nucleotide sequence. []', 2255, 0, 0);
INSERT INTO chado.cvterm VALUES (1999, 22, 'blunt_end_restriction_enzyme_cleavage_site', 'A restriction enzyme recognition site that, when cleaved, results in no overhangs. [SBOL:jgquinn, SO:ke]', 2256, 0, 0);
INSERT INTO chado.cvterm VALUES (2000, 22, 'blunt_end_restriction_enzyme_cleavage_junction', 'A restriction enzyme cleavage site where both strands are cut at the same position. [SO:ke]', 2257, 0, 0);
INSERT INTO chado.cvterm VALUES (2001, 22, 'restriction_enzyme_single_strand_overhang', 'A terminal region of DNA sequence where the end of the region is not blunt ended. [SO:ke]', 2258, 0, 0);
INSERT INTO chado.cvterm VALUES (2002, 22, 'experimentally_defined_binding_region', 'A region that has been implicated in binding although the exact coordinates of binding may be unknown. [SO:ke]', 2259, 0, 0);
INSERT INTO chado.cvterm VALUES (2003, 22, 'ChIP_seq_region', 'A region of sequence identified by CHiP seq technology to contain a protein binding site. [SO:ke]', 2260, 0, 0);
INSERT INTO chado.cvterm VALUES (2004, 22, 'ASPE_primer', '\"A primer containing an SNV at the 3'' end for accurate genotyping. [http://www.ncbi.nlm.nih.gov/pubmed/11252801]', 2261, 0, 0);
INSERT INTO chado.cvterm VALUES (2005, 22, 'dCAPS_primer', 'A primer with one or more mismatches to the DNA template corresponding to a position within a restriction enzyme recognition site. [http://www.ncbi.nlm.nih.gov/pubmed/9628033]', 2262, 0, 0);
INSERT INTO chado.cvterm VALUES (2006, 22, 'histone_modification', 'Histone modification is a post translationally modified region whereby residues of the histone protein are modified by methylation, acetylation, phosphorylation, ubiquitination, sumoylation, citrullination, or ADP-ribosylation. [http:en.wikipedia.org/wiki/Histone]', 2263, 0, 0);
INSERT INTO chado.cvterm VALUES (2007, 22, 'histone_methylation_site', 'A histone modification site where the modification is the methylation of the residue. [SO:ke]', 2264, 0, 0);
INSERT INTO chado.cvterm VALUES (2008, 22, 'histone_acetylation_site', 'A histone modification where the modification is the acylation of the residue. [SO:ke]', 2265, 0, 0);
INSERT INTO chado.cvterm VALUES (2009, 22, 'H3K9_acetylation_site', 'A kind of histone modification site, whereby the 9th residue (a lysine), from the start of the H3 histone protein is acetylated. [http://en.wikipedia.org/wiki/Histone]', 2266, 0, 0);
INSERT INTO chado.cvterm VALUES (2010, 22, 'histone_3_acetylation_site', 'A histone 3 modification where the modification is the acetylation of the residue. [EBI:nj, ISBN:0815341059, SO:ke]', 2267, 0, 0);
INSERT INTO chado.cvterm VALUES (2011, 22, 'H3K14_acetylation_site', 'A kind of histone modification site, whereby the 14th residue (a lysine), from the start of the H3 histone protein is acetylated. [http://en.wikipedia.org/wiki/Histone]', 2268, 0, 0);
INSERT INTO chado.cvterm VALUES (2012, 22, 'H3K4_monomethylation_site', 'A kind of histone modification, whereby the 4th residue (a lysine), from the start of the H3 protein is mono-methylated. [http://en.wikipedia.org/wiki/Histone]', 2269, 0, 0);
INSERT INTO chado.cvterm VALUES (2013, 22, 'H3K4_methylation_site', 'A kind of histone modification, whereby the 4th residue (a lysine), from the start of the H3 protein is methylated. [SO:ke]', 2270, 0, 0);
INSERT INTO chado.cvterm VALUES (2014, 22, 'H3K4_trimethylation', 'A kind of histone modification site, whereby the 4th residue (a lysine), from the start of the H3 protein is tri-methylated. [http://en.wikipedia.org/wiki/Histone]', 2271, 0, 0);
INSERT INTO chado.cvterm VALUES (2015, 22, 'H3K9_trimethylation_site', 'A kind of histone modification site, whereby the 9th residue (a lysine), from the start of the H3 histone protein is tri-methylated. [http://en.wikipedia.org/wiki/Histone]', 2272, 0, 0);
INSERT INTO chado.cvterm VALUES (2016, 22, 'H3K9_methylation_site', 'A kind of histone modification site, whereby the 9th residue (a lysine), from the start of the H3 histone protein is methylated. [SO:ke]', 2273, 0, 0);
INSERT INTO chado.cvterm VALUES (2017, 22, 'H3K27_monomethylation_site', 'A kind of histone modification site, whereby the 27th residue (a lysine), from the start of the H3 histone protein is mono-methylated. [http://en.wikipedia.org/wiki/Histone]', 2274, 0, 0);
INSERT INTO chado.cvterm VALUES (2018, 22, 'H3K27_methylation_site', 'A kind of histone modification site, whereby the 27th residue (a lysine), from the start of the H3 histone protein is methylated. [SO:ke]', 2275, 0, 0);
INSERT INTO chado.cvterm VALUES (2019, 22, 'H3K27_trimethylation_site', 'A kind of histone modification site, whereby the 27th residue (a lysine), from the start of the H3 histone protein is tri-methylated. [http://en.wikipedia.org/wiki/Histone]', 2276, 0, 0);
INSERT INTO chado.cvterm VALUES (2020, 22, 'H3K79_monomethylation_site', 'A kind of histone modification site, whereby the 79th residue (a lysine), from the start of the H3 histone protein is mono- methylated. [http://en.wikipedia.org/wiki/Histone]', 2277, 0, 0);
INSERT INTO chado.cvterm VALUES (2021, 22, 'H3K79_methylation_site', 'A kind of histone modification site, whereby the 79th residue (a lysine), from the start of the H3 histone protein is methylated. [SO:ke]', 2278, 0, 0);
INSERT INTO chado.cvterm VALUES (2022, 22, 'H3K79_dimethylation_site', 'A kind of histone modification site, whereby the 79th residue (a lysine), from the start of the H3 histone protein is di-methylated. [http://en.wikipedia.org/wiki/Histone]', 2279, 0, 0);
INSERT INTO chado.cvterm VALUES (2023, 22, 'H3K79_trimethylation_site', 'A kind of histone modification site, whereby the 79th residue (a lysine), from the start of the H3 histone protein is tri-methylated. [http://en.wikipedia.org/wiki/Histone]', 2280, 0, 0);
INSERT INTO chado.cvterm VALUES (2024, 22, 'H4K20_monomethylation_site', 'A kind of histone modification site, whereby the 20th residue (a lysine), from the start of the H4histone protein is mono-methylated. [http://en.wikipedia.org/wiki/Histone]', 2281, 0, 0);
INSERT INTO chado.cvterm VALUES (2025, 22, 'H2BK5_monomethylation_site', 'A kind of histone modification site, whereby the 5th residue (a lysine), from the start of the H2B protein is methylated. [http://en.wikipedia.org/wiki/Histone]', 2282, 0, 0);
INSERT INTO chado.cvterm VALUES (2026, 22, 'ISRE', 'An ISRE is a transcriptional cis regulatory region, containing the consensus region: YAGTTTC(A/T)YTTTYCC, responsible for increased transcription via interferon binding. [http://genesdev.cshlp.org/content/2/4/383.abstrac]', 2283, 0, 0);
INSERT INTO chado.cvterm VALUES (2027, 22, 'histone_ubiqitination_site', 'A histone modification site where ubiquitin may be added. [SO:ke]', 2284, 0, 0);
INSERT INTO chado.cvterm VALUES (2028, 22, 'H2B_ubiquitination_site', 'A histone modification site on H2B where ubiquitin may be added. [SO:ke]', 2285, 0, 0);
INSERT INTO chado.cvterm VALUES (2029, 22, 'H3K18_acetylation_site', 'A kind of histone modification site, whereby the 18th residue (a lysine), from the start of the H3 histone protein is acetylated. [SO:ke]', 2286, 0, 0);
INSERT INTO chado.cvterm VALUES (2030, 22, 'H3K23_acetylation_site', 'A kind of histone modification, whereby the 23rd residue (a lysine), from the start of the H3 histone protein is acetylated. [SO:ke]', 2287, 0, 0);
INSERT INTO chado.cvterm VALUES (2031, 22, 'H3K27_acylation_site', 'A kind of histone modification site, whereby the 27th residue (a lysine), from the start of the H3 histone protein is acylated. [SO:ke]', 2288, 1, 0);
INSERT INTO chado.cvterm VALUES (2032, 22, 'H3K36_monomethylation_site', 'A kind of histone modification site, whereby the 36th residue (a lysine), from the start of the H3 histone protein is mono-methylated. [SO:ke]', 2289, 0, 0);
INSERT INTO chado.cvterm VALUES (2033, 22, 'H3K36_methylation_site', 'A kind of histone modification site, whereby the 36th residue (a lysine), from the start of the H3 histone protein is methylated. [SO:ke]', 2290, 0, 0);
INSERT INTO chado.cvterm VALUES (2177, 22, 'unassigned_supercontig', 'A supercontig that is not been assigned to any ultracontig during a genome assembly project. [GMOD:ea]', 2439, 0, 0);
INSERT INTO chado.cvterm VALUES (2034, 22, 'H3K36_dimethylation_site', 'A kind of histone modification site, whereby the 36th residue (a lysine), from the start of the H3 histone protein is dimethylated. [SO:ke]', 2291, 0, 0);
INSERT INTO chado.cvterm VALUES (2035, 22, 'H3K36_trimethylation_site', 'A kind of histone modification site, whereby the 36th residue (a lysine), from the start of the H3 histone protein is tri-methylated. [SO:ke]', 2292, 0, 0);
INSERT INTO chado.cvterm VALUES (2036, 22, 'H3K4_dimethylation_site', 'A kind of histone modification site, whereby the 4th residue (a lysine), from the start of the H3 histone protein is di-methylated. [SO:ke]', 2293, 0, 0);
INSERT INTO chado.cvterm VALUES (2037, 22, 'H3K27_dimethylation_site', 'A kind of histone modification site, whereby the 27th residue (a lysine), from the start of the H3 histone protein is di-methylated. [SO:ke]', 2294, 0, 0);
INSERT INTO chado.cvterm VALUES (2038, 22, 'H3K9_monomethylation_site', 'A kind of histone modification site, whereby the 9th residue (a lysine), from the start of the H3 histone protein is mono-methylated. [SO:ke]', 2295, 0, 0);
INSERT INTO chado.cvterm VALUES (2039, 22, 'H3K9_dimethylation_site', 'A kind of histone modification site, whereby the 9th residue (a lysine), from the start of the H3 histone protein may be dimethylated. [SO:ke]', 2296, 0, 0);
INSERT INTO chado.cvterm VALUES (2040, 22, 'H4K16_acetylation_site', 'A kind of histone modification site, whereby the 16th residue (a lysine), from the start of the H4 histone protein is acetylated. [SO:ke]', 2297, 0, 0);
INSERT INTO chado.cvterm VALUES (2041, 22, 'histone_4_acetylation_site', 'A histone 4 modification where the modification is the acetylation of the residue. [EBI:nj, ISBN:0815341059, SO:ke]', 2298, 0, 0);
INSERT INTO chado.cvterm VALUES (2042, 22, 'H4K5_acetylation_site', 'A kind of histone modification site, whereby the 5th residue (a lysine), from the start of the H4 histone protein is acetylated. [SO:ke]', 2299, 0, 0);
INSERT INTO chado.cvterm VALUES (2043, 22, 'H4K8_acetylation_site', 'A kind of histone modification site, whereby the 8th residue (a lysine), from the start of the H4 histone protein is acetylated. [SO:KE]', 2300, 0, 0);
INSERT INTO chado.cvterm VALUES (2044, 22, 'histone_acylation_region', 'A histone modification, whereby the histone protein is acylated at multiple sites in a region. [SO:ke]', 2301, 0, 0);
INSERT INTO chado.cvterm VALUES (2045, 22, 'H4K_acylation_region', 'A region of the H4 histone whereby multiple lysines are acylated. [SO:ke]', 2302, 0, 0);
INSERT INTO chado.cvterm VALUES (2046, 22, 'gene_with_non_canonical_start_codon', 'A gene with a start codon other than AUG. [SO:xp]', 2303, 0, 0);
INSERT INTO chado.cvterm VALUES (2047, 22, 'gene_with_start_codon_CUG', 'A gene with a translational start codon of CUG. [SO:mc]', 2304, 0, 0);
INSERT INTO chado.cvterm VALUES (2048, 22, 'pseudogenic_gene_segment', 'A gene segment which when incorporated by somatic recombination in the final gene transcript results in a nonfunctional product. [SO:hd]', 2305, 0, 0);
INSERT INTO chado.cvterm VALUES (2049, 22, 'gene_segment', 'A gene component region which acts as a recombinational unit of a gene whose functional form is generated through somatic recombination. [GOC:add]', 2306, 0, 0);
INSERT INTO chado.cvterm VALUES (2050, 22, 'copy_number_gain', 'A sequence alteration whereby the copy number of a given regions is greater than the reference sequence. [SO:ke]', 2307, 0, 0);
INSERT INTO chado.cvterm VALUES (2051, 22, 'copy_number_loss', 'A sequence alteration whereby the copy number of a given region is less than the reference sequence. [SO:ke]', 2308, 0, 0);
INSERT INTO chado.cvterm VALUES (2052, 22, 'UPD', 'Uniparental disomy is a sequence_alteration where a diploid individual receives two copies for all or part of a chromosome from one parent and no copies of the same chromosome or region from the other parent. [SO:BM]', 2309, 0, 0);
INSERT INTO chado.cvterm VALUES (2053, 22, 'maternal_uniparental_disomy', 'Uniparental disomy is a sequence_alteration where a diploid individual receives two copies for all or part of a chromosome from the mother and no copies of the same chromosome or region from the father. [SO:bm]', 2310, 0, 0);
INSERT INTO chado.cvterm VALUES (2054, 22, 'paternal_uniparental_disomy', 'Uniparental disomy is a sequence_alteration where a diploid individual receives two copies for all or part of a chromosome from the father and no copies of the same chromosome or region from the mother. [SO:bm]', 2311, 0, 0);
INSERT INTO chado.cvterm VALUES (2055, 22, 'open_chromatin_region', 'A DNA sequence that in the normal state of the chromosome corresponds to an unfolded, un-complexed stretch of double-stranded DNA. [SO:cb]', 2312, 0, 0);
INSERT INTO chado.cvterm VALUES (2056, 22, 'SL3_acceptor_site', 'A SL2_acceptor_site which appends the SL3 RNA leader sequence to the 5'' end of an mRNA. SL3 acceptor sites occur in genes in internal segments of polycistronic transcripts. [SO:nlw]', 2313, 0, 0);
INSERT INTO chado.cvterm VALUES (2057, 22, 'SL4_acceptor_site', 'A SL2_acceptor_site which appends the SL4 RNA leader sequence to the 5'' end of an mRNA. SL4 acceptor sites occur in genes in internal segments of polycistronic transcripts. [SO:nlw]', 2314, 0, 0);
INSERT INTO chado.cvterm VALUES (2058, 22, 'SL5_acceptor_site', 'A SL2_acceptor_site which appends the SL5 RNA leader sequence to the 5'' end of an mRNA. SL5 acceptor sites occur in genes in internal segments of polycistronic transcripts. [SO:nlw]', 2315, 0, 0);
INSERT INTO chado.cvterm VALUES (2059, 22, 'SL6_acceptor_site', 'A SL2_acceptor_site which appends the SL6 RNA leader sequence to the 5'' end of an mRNA. SL6 acceptor sites occur in genes in internal segments of polycistronic transcripts. [SO:nlw]', 2316, 0, 0);
INSERT INTO chado.cvterm VALUES (2060, 22, 'SL7_acceptor_site', 'A SL2_acceptor_site which appends the SL7 RNA leader sequence to the 5'' end of an mRNA. SL7 acceptor sites occur in genes in internal segments of polycistronic transcripts. [SO:nlw]', 2317, 0, 0);
INSERT INTO chado.cvterm VALUES (2061, 22, 'SL8_acceptor_site', 'A SL2_acceptor_site which appends the SL8 RNA leader sequence to the 5'' end of an mRNA. SL8 acceptor sites occur in genes in internal segments of polycistronic transcripts. [SO:nlw]', 2318, 0, 0);
INSERT INTO chado.cvterm VALUES (2062, 22, 'SL9_acceptor_site', 'A SL2_acceptor_site which appends the SL9 RNA leader sequence to the 5'' end of an mRNA. SL9 acceptor sites occur in genes in internal segments of polycistronic transcripts. [SO:nlw]', 2319, 0, 0);
INSERT INTO chado.cvterm VALUES (2063, 22, 'SL10_acceptor_site', 'A SL2_acceptor_site which appends the SL10 RNA leader sequence to the 5'' end of an mRNA. SL10 acceptor sites occur in genes in internal segments of polycistronic transcripts. [SO:nlw]', 2320, 0, 0);
INSERT INTO chado.cvterm VALUES (2064, 22, 'SL11_acceptor_site', 'A SL2_acceptor_site which appends the SL11 RNA leader sequence to the 5'' end of an mRNA. SL11 acceptor sites occur in genes in internal segments of polycistronic transcripts. [SO:nlw]', 2321, 0, 0);
INSERT INTO chado.cvterm VALUES (2065, 22, 'SL12_acceptor_site', 'A SL2_acceptor_site which appends the SL12 RNA leader sequence to the 5'' end of an mRNA. SL12 acceptor sites occur in genes in internal segments of polycistronic transcripts. [SO:nlw]', 2322, 0, 0);
INSERT INTO chado.cvterm VALUES (2066, 22, 'duplicated_pseudogene', 'A pseudogene that arose via gene duplication. Generally duplicated pseudogenes have the same structure as the original gene, including intron-exon structure and some regulatory sequence. [http://en.wikipedia.org/wiki/Pseudogene]', 2323, 0, 0);
INSERT INTO chado.cvterm VALUES (2178, 22, 'feature_ablation', 'A sequence variant, caused by an alteration of the genomic sequence, where the deletion, is greater than the extent of the underlying genomic features. [SO:ke]', 2440, 0, 0);
INSERT INTO chado.cvterm VALUES (2067, 22, 'unitary_pseudogene', 'A pseudogene, deactivated from original state by mutation, fixed in a population,where the ortholog in a reference species such as mouse remains functional. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, http://en.wikipedia.org/wiki/Pseudogene, SO:ke]', 2324, 0, 0);
INSERT INTO chado.cvterm VALUES (2068, 22, 'variant_quality', 'A dependent entity that inheres in a bearer, a sequence variant. [PMID:17597783, SO:ke]', 2325, 0, 0);
INSERT INTO chado.cvterm VALUES (2069, 22, 'variant_origin', 'A quality inhering in a variant by virtue of its origin. [PMID:17597783, SO:ke]', 2326, 0, 0);
INSERT INTO chado.cvterm VALUES (2070, 22, 'variant_frequency', 'A physical quality which inheres to the variant by virtue of the number instances of the variant within a population. [PMID:17597783, SO:ke]', 2327, 0, 0);
INSERT INTO chado.cvterm VALUES (2071, 22, 'unique_variant', 'A physical quality which inheres to the variant by virtue of the number instances of the variant within a population. [SO:ke]', 2328, 0, 0);
INSERT INTO chado.cvterm VALUES (2072, 22, 'rare_variant', 'When a variant from the genomic sequence is rarely found in the general population. The threshold for ''rare'' varies between studies. []', 2329, 0, 0);
INSERT INTO chado.cvterm VALUES (2073, 22, 'polymorphic_variant', 'A variant that affects one of several possible alleles at that location, such as the major histocompatibility complex (MHC) genes. []', 2330, 0, 0);
INSERT INTO chado.cvterm VALUES (2074, 22, 'common_variant', 'When a variant from the genomic sequence is commonly found in the general population. []', 2331, 0, 0);
INSERT INTO chado.cvterm VALUES (2075, 22, 'fixed_variant', 'When a variant has become fixed in the population so that it is now the only variant. []', 2332, 0, 0);
INSERT INTO chado.cvterm VALUES (2076, 22, 'variant_phenotype', 'A quality inhering in a variant by virtue of its phenotype. [PMID:17597783, SO:ke]', 2333, 0, 0);
INSERT INTO chado.cvterm VALUES (2077, 22, 'benign_variant', 'A variant that does not affect the function of the gene or cause disease. []', 2334, 0, 0);
INSERT INTO chado.cvterm VALUES (2078, 22, 'disease_associated_variant', 'A variant that has been found to be associated with disease. []', 2335, 0, 0);
INSERT INTO chado.cvterm VALUES (2079, 22, 'disease_causing_variant', 'A variant that has been found to cause disease. []', 2336, 0, 0);
INSERT INTO chado.cvterm VALUES (2080, 22, 'lethal_variant', 'A sequence variant where the mutated gene product does not allow for one or more basic functions necessary for survival. []', 2337, 0, 0);
INSERT INTO chado.cvterm VALUES (2081, 22, 'quantitative_variant', 'A variant within a gene that contributes to a quantitative trait such as height or weight. []', 2338, 0, 0);
INSERT INTO chado.cvterm VALUES (2082, 22, 'maternal_variant', 'A variant in the genetic material inherited from the mother. []', 2339, 0, 0);
INSERT INTO chado.cvterm VALUES (2083, 22, 'paternal_variant', 'A variant in the genetic material inherited from the father. []', 2340, 0, 0);
INSERT INTO chado.cvterm VALUES (2084, 22, 'somatic_variant', 'A variant that has arisen after splitting of the embryo, resulting in the variant being found in only some of the tissues or cells of the body. []', 2341, 0, 0);
INSERT INTO chado.cvterm VALUES (2085, 22, 'germline_variant', 'A variant present in the embryo that is carried by every cell in the body. []', 2342, 0, 0);
INSERT INTO chado.cvterm VALUES (2086, 22, 'pedigree_specific_variant', 'A variant that is found only by individuals that belong to the same pedigree. []', 2343, 0, 0);
INSERT INTO chado.cvterm VALUES (2087, 22, 'population_specific_variant', 'A variant found within only speficic populations. []', 2344, 0, 0);
INSERT INTO chado.cvterm VALUES (2088, 22, 'de_novo_variant', 'A variant arising in the offspring that is not found in either of the parents. []', 2345, 0, 0);
INSERT INTO chado.cvterm VALUES (2089, 22, 'TF_binding_site_variant', 'A sequence variant located within a transcription factor binding site. [EBI:fc]', 2346, 0, 0);
INSERT INTO chado.cvterm VALUES (2090, 22, 'complex_structural_alteration', 'A structural sequence alteration or rearrangement encompassing one or more genome fragments, with 4 or more breakpoints. [FB:reference_manual, NCBI:th, SO:ke]', 2347, 0, 0);
INSERT INTO chado.cvterm VALUES (2091, 22, 'loss_of_heterozygosity', 'A functional variant whereby the sequence alteration causes a loss of function of one allele of a gene. [SO:ke]', 2349, 0, 0);
INSERT INTO chado.cvterm VALUES (2092, 22, 'splice_donor_5th_base_variant', 'A sequence variant that causes a change at the 5th base pair after the start of the intron in the orientation of the transcript. [EBI:gr]', 2350, 0, 0);
INSERT INTO chado.cvterm VALUES (2093, 22, 'U_box', 'An U-box is a conserved T-rich region upstream of a retroviral polypurine tract that is involved in PPT primer creation during reverse transcription. [PMID:10556309, PMID:11577982, PMID:9649446]', 2351, 0, 0);
INSERT INTO chado.cvterm VALUES (2094, 22, 'mating_type_region', 'A specialized region in the genomes of some yeast and fungi, the genes of which regulate mating type. [SO:ke]', 2352, 0, 0);
INSERT INTO chado.cvterm VALUES (2095, 22, 'non_coding_transcript_exon_variant', 'A sequence variant that changes non-coding exon sequence in a non-coding transcript. [EBI:fc, SO:ke]', 2353, 0, 0);
INSERT INTO chado.cvterm VALUES (2096, 22, 'clone_end', 'A read from an end of the clone sequence. [SO:ke]', 2354, 0, 0);
INSERT INTO chado.cvterm VALUES (2097, 22, 'regional_centromere', 'A regional centromere is a large modular centromere found in fission yeast and higher eukaryotes. It consist of a central core region flanked by inverted inner and outer repeat regions. [PMID:7502067, SO:vw]', 2355, 0, 0);
INSERT INTO chado.cvterm VALUES (2098, 22, 'regional_centromere_central_core', 'A conserved region within the central region of a modular centromere, where the kinetochore is formed. [SO:vw]', 2356, 0, 0);
INSERT INTO chado.cvterm VALUES (2099, 22, 'centromeric_repeat', 'A repeat region found within the modular centromere. [SO:ke]', 2357, 0, 0);
INSERT INTO chado.cvterm VALUES (2100, 22, 'regional_centromere_inner_repeat_region', 'The inner inverted repeat region of a modular centromere and part of the central core surrounding a non-conserved central region. This region is adjacent to the central core, on each chromosome arm. [SO:vw]', 2358, 0, 0);
INSERT INTO chado.cvterm VALUES (2101, 22, 'regional_centromere_outer_repeat_region', 'The heterochromatic outer repeat region of a modular centromere. These repeats exist in tandem arrays on both chromosome arms. [SO:vw]', 2359, 0, 0);
INSERT INTO chado.cvterm VALUES (2102, 22, 'tasiRNA', 'The sequence of a 21 nucleotide double stranded, polyadenylated non coding RNA, transcribed from the TAS gene. [PMID:16145017]', 2360, 0, 0);
INSERT INTO chado.cvterm VALUES (2103, 22, 'tasiRNA_primary_transcript', 'A primary transcript encoding a tasiRNA. [PMID:16145017]', 2361, 0, 0);
INSERT INTO chado.cvterm VALUES (2104, 22, 'increased_polyadenylation_variant', 'A transcript processing variant whereby polyadenylation of the encoded transcript is increased with respect to the reference. [SO:ke]', 2362, 0, 0);
INSERT INTO chado.cvterm VALUES (2105, 22, 'decreased_polyadenylation_variant', 'A transcript processing variant whereby polyadenylation of the encoded transcript is decreased with respect to the reference. [SO:ke]', 2363, 0, 0);
INSERT INTO chado.cvterm VALUES (2106, 22, 'DDB_box', 'A conserved polypeptide motif that mediates protein-protein interaction and defines adaptor proteins for DDB1/cullin 4 ubiquitin ligases. [PMID:18794354, PMID:19818632]', 2364, 0, 0);
INSERT INTO chado.cvterm VALUES (2258, 22, '5_carboxylcytosine', 'A modified DNA cytosine base feature, modified by a carboxy group at the 5 carbon. [SO:ke]', 2520, 0, 0);
INSERT INTO chado.cvterm VALUES (2107, 22, 'destruction_box', 'A conserved polypeptide motif that can be recognized by both Fizzy/Cdc20- and FZR/Cdh1-activated anaphase-promoting complex/cyclosome (APC/C) and targets a protein for ubiquitination and subsequent degradation by the APC/C. The consensus sequence is RXXLXXXXN. [PMID:12208841, PMID:1842691]', 2365, 0, 0);
INSERT INTO chado.cvterm VALUES (2108, 22, 'polypeptide_conserved_motif', 'A conserved motif is a short (up to 20 amino acids) region of biological interest that is conserved in different proteins. They may or may not have functional or structural significance within the proteins in which they are found. [EBIBS:GAR]', 2366, 0, 0);
INSERT INTO chado.cvterm VALUES (2109, 22, 'ER_retention_signal', 'A C-terminal tetrapeptide motif that mediates retention of a protein in (or retrieval to) the endoplasmic reticulum. In mammals the sequence is KDEL, and in fungi HDEL or DDEL. [doi:10.1093/jxb/50.331.157, PMID:2077689]', 2367, 0, 0);
INSERT INTO chado.cvterm VALUES (2110, 22, 'KEN_box', 'A conserved polypeptide motif that can be recognized by FZR/Cdh1-activated anaphase-promoting complex/cyclosome (APC/C) and targets a protein for ubiquitination and subsequent degradation by the APC/C. The consensus sequence is KENXXXN. [PMID:10733526, PMID:1220884, PMID:18426916]', 2368, 0, 0);
INSERT INTO chado.cvterm VALUES (2111, 22, 'mitochondrial_targeting_signal', 'A polypeptide region that targets a polypeptide to the mitochondrion. [PomBase:mah]', 2369, 0, 0);
INSERT INTO chado.cvterm VALUES (2112, 22, 'signal_anchor', 'A signal sequence that is not cleaved from the polypeptide. Anchors a Type II membrane protein to the membrane. [http://www.cbs.dtu.dk/services/SignalP/background/biobackground.php]', 2370, 0, 0);
INSERT INTO chado.cvterm VALUES (2113, 22, 'PIP_box', 'A polypeptide region that mediates binding to PCNA. The consensus sequence is QXX(hh)XX(aa), where (h) denotes residues with moderately hydrophobic side chains and (a) denotes residues with highly hydrophobic aromatic side chains. [PMID:9631646]', 2371, 0, 0);
INSERT INTO chado.cvterm VALUES (2114, 22, 'phosphorylation_site', 'A post-translationally modified region in which residues of the protein are modified by phosphorylation. [PomBase:mah]', 2372, 0, 0);
INSERT INTO chado.cvterm VALUES (2115, 22, 'transmembrane_helix', 'A region that traverses the lipid bilayer and adopts a helical secondary structure. [PomBase:mah]', 2373, 0, 0);
INSERT INTO chado.cvterm VALUES (2116, 22, 'vacuolar_sorting_signal', 'A polypeptide region that targets a polypeptide to the vacuole. [PomBase:mah]', 2374, 0, 0);
INSERT INTO chado.cvterm VALUES (2117, 22, 'coding_variant_quality', 'An attribute of a coding genomic variant. []', 2375, 0, 0);
INSERT INTO chado.cvterm VALUES (2118, 22, 'synonymous', 'A variant that does not lead to any change in the amino acid sequence. []', 2376, 0, 0);
INSERT INTO chado.cvterm VALUES (2119, 22, 'non_synonymous', 'A variant that leads to the change of an amino acid within the protein. []', 2377, 0, 0);
INSERT INTO chado.cvterm VALUES (2120, 22, 'inframe', 'An attribute describing a sequence that contains a mutation involving the deletion or insertion of one or more bases, where this number is divisible by 3. [SO:ke]', 2378, 0, 0);
INSERT INTO chado.cvterm VALUES (2121, 22, 'inframe_indel', 'A coding sequence variant where the change does not alter the frame of the transcript. [SO:ke]', 2380, 0, 0);
INSERT INTO chado.cvterm VALUES (2122, 22, 'inframe_insertion', 'An inframe non synonymous variant that inserts bases into in the coding sequence. [EBI:gr]', 2381, 0, 0);
INSERT INTO chado.cvterm VALUES (2123, 22, 'internal_feature_elongation', 'A sequence variant that causes the extension of a genomic feature from within the feature rather than from the terminus of the feature, with regard to the reference sequence. [SO:ke]', 2383, 0, 0);
INSERT INTO chado.cvterm VALUES (2124, 22, 'inframe_deletion', 'An inframe non synonymous variant that deletes bases from the coding sequence. [EBI:gr]', 2384, 0, 0);
INSERT INTO chado.cvterm VALUES (2125, 22, 'conservative_inframe_insertion', 'An inframe increase in cds length that inserts one or more codons into the coding sequence between existing codons. [EBI:gr]', 2386, 0, 0);
INSERT INTO chado.cvterm VALUES (2126, 22, 'disruptive_inframe_insertion', 'An inframe increase in cds length that inserts one or more codons into the coding sequence within an existing codon. [EBI:gr]', 2387, 0, 0);
INSERT INTO chado.cvterm VALUES (2127, 22, 'conservative_inframe_deletion', 'An inframe decrease in cds length that deletes one or more entire codons from the coding sequence but does not change any remaining codons. [EBI:gr]', 2388, 0, 0);
INSERT INTO chado.cvterm VALUES (2128, 22, 'disruptive_inframe_deletion', 'An inframe decrease in cds length that deletes bases from the coding sequence starting within an existing codon. [EBI:gr]', 2389, 0, 0);
INSERT INTO chado.cvterm VALUES (2129, 22, 'mRNA_read', 'A sequencer read of an mRNA substrate. [SO:ke]', 2390, 0, 0);
INSERT INTO chado.cvterm VALUES (2130, 22, 'genomic_DNA_read', 'A sequencer read of a genomic DNA substrate. [SO:ke]', 2391, 0, 0);
INSERT INTO chado.cvterm VALUES (2131, 22, 'mRNA_contig', 'A contig composed of mRNA_reads. [SO:ke]', 2392, 0, 0);
INSERT INTO chado.cvterm VALUES (2132, 22, 'AFLP_fragment', 'A PCR product obtained by applying the AFLP technique, based on a restriction enzyme digestion of genomic DNA and an amplification of the resulting fragments. [GMOD:ea]', 2393, 0, 0);
INSERT INTO chado.cvterm VALUES (2133, 22, 'protein_hmm_match', 'A match to a protein HMM such as pfam. [SO:ke]', 2394, 0, 0);
INSERT INTO chado.cvterm VALUES (2134, 22, 'immunoglobulin_region', 'A region of immunoglobulin sequence, either constant or variable. [SO:ke]', 2395, 0, 0);
INSERT INTO chado.cvterm VALUES (2135, 22, 'V_region', 'The variable region of an immunoglobulin polypeptide sequence. [SO:ke]', 2396, 0, 0);
INSERT INTO chado.cvterm VALUES (2136, 22, 'C_region', 'The constant region of an immunoglobulin polypeptide sequence. [SO:ke]', 2397, 0, 0);
INSERT INTO chado.cvterm VALUES (2137, 22, 'N_region', 'Extra nucleotides inserted between rearranged immunoglobulin segments. [SO:ke]', 2398, 0, 0);
INSERT INTO chado.cvterm VALUES (2138, 22, 'S_region', 'The switch region of immunoglobulin heavy chains; it is involved in the rearrangement of heavy chain DNA leading to the expression of a different immunoglobulin classes from the same B-cell. [SO:ke]', 2399, 0, 0);
INSERT INTO chado.cvterm VALUES (2139, 22, 'mobile_element_insertion', 'A kind of insertion where the inserted sequence is a mobile element. [EBI:dvga]', 2400, 0, 0);
INSERT INTO chado.cvterm VALUES (2140, 22, 'novel_sequence_insertion', 'An insertion the sequence of which cannot be mapped to the reference genome. [NCBI:th]', 2401, 0, 0);
INSERT INTO chado.cvterm VALUES (2141, 22, 'CSL_response_element', 'A promoter element with consensus sequence GTGRGAA, bound by CSL (CBF1/RBP-JK/Suppressor of Hairless/LAG-1) transcription factors. [PMID:19101542]', 2402, 0, 0);
INSERT INTO chado.cvterm VALUES (2142, 22, 'GATA_box', 'A GATA transcription factor element containing the consensus sequence WGATAR (in which W indicates A/T and R indicates A/G). [PMID:8321208]', 2403, 0, 0);
INSERT INTO chado.cvterm VALUES (2143, 22, 'polymorphic_pseudogene', 'A pseudogene in the reference genome, though known to be intact in the genomes of other individuals of the same species. The annotation process has confirmed that the pseudogenisation event is not a genomic sequencing error. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, JAX:hd]', 2404, 0, 0);
INSERT INTO chado.cvterm VALUES (2144, 22, 'AP_1_binding_site', 'A promoter element with consensus sequence TGACTCA, bound by AP-1 and related transcription factors. [PMID:1899230, PMID:3034432, PMID:3125983]', 2405, 0, 0);
INSERT INTO chado.cvterm VALUES (2145, 22, 'CRE', 'MERGED DEFINITION: TARGET DEFINITION: A promoter element with consensus sequence TGACGTCA; bound by the ATF/CREB family of transcription factors.', 2406, 0, 0);
INSERT INTO chado.cvterm VALUES (2146, 22, 'CuRE', 'A promoter element bound by copper ion-sensing transcription factors such as S. cerevisiae Mac1p or S. pombe Cuf1; the consensus sequence is HTHNNGCTGD (more specifically TTTGCKCR in budding yeast). [PMID:10593913, PMID:9188496, PMID:9211922]', 2408, 0, 0);
INSERT INTO chado.cvterm VALUES (2147, 22, 'DRE', 'A promoter element with consensus sequence CGWGGWNGMM, bound by transcription factors related to RecA and found in promoters of genes expressed following several types of DNA damage or inhibition of DNA synthesis. [PMID:11073995, PMID:8668127]', 2409, 0, 0);
INSERT INTO chado.cvterm VALUES (2148, 22, 'FLEX_element', 'A promoter element that has consensus sequence GTAAACAAACAAAM and contains a heptameric core GTAAACA, bound by transcription factors with a forkhead DNA-binding domain. [PMID:10747048, PMID:14871934]', 2410, 0, 0);
INSERT INTO chado.cvterm VALUES (2149, 22, 'forkhead_motif', 'A promoter element with consensus sequence TTTRTTTACA, bound by transcription factors with a forkhead DNA-binding domain. [PMID:15195092]', 2411, 0, 0);
INSERT INTO chado.cvterm VALUES (2150, 22, 'homol_D_box', 'A core promoter element that has the consensus sequence CAGTCACA (or its inverted form TGTGACTG), and plays the role of a TATA box in promoters that do not contain a canonical TATA sequence. [PMID:21673110, PMID:7501449, PMID:8458332]', 2412, 0, 0);
INSERT INTO chado.cvterm VALUES (2151, 22, 'homol_E_box', 'A core promoter element that has the consensus sequence ACCCTACCCT (or its inverted form AGGGTAGGGT), and is found near the homol D box in some promoters that use a homol D box instead of a canonical TATA sequence. [PMID:7501449]', 2413, 0, 0);
INSERT INTO chado.cvterm VALUES (2152, 22, 'HSE', 'A promoter element that consists of at least three copies of the pentanucleotide NGAAN, bound by the heat shock transcription factor HSF. [PMID:17347150, PMID:8689565]', 2414, 0, 0);
INSERT INTO chado.cvterm VALUES (2153, 22, 'iron_repressed_GATA_element', 'A GATA promoter element with consensus sequence WGATAA, found in promoters of genes repressed in the presence of iron. [PMID:11956219, PMID:17211681]', 2415, 0, 0);
INSERT INTO chado.cvterm VALUES (2154, 22, 'mating_type_M_box', 'A promoter element with consensus sequence ACAAT, found in promoters of mating type M-specific genes in fission yeast and bound by the transcription factor Mat1-Mc. [PMID:9233811]', 2416, 0, 0);
INSERT INTO chado.cvterm VALUES (2155, 22, 'androgen_response_element', 'A non-palindromic sequence found in the promoters of genes whose expression is regulated in response to androgen. [PMID:21796522]', 2417, 0, 0);
INSERT INTO chado.cvterm VALUES (2156, 22, 'smFISH_probe', 'A smFISH is a probe that binds RNA in a single molecule in situ hybridization experiment. [PMID:18806792]', 2418, 0, 0);
INSERT INTO chado.cvterm VALUES (2157, 22, 'MCB', 'A promoter element with consensus sequence ACGCGT, bound by the transcription factor complex MBF (MCB-binding factor) and found in promoters of genes expressed during the G1/S transition of the cell cycle. [PMID:16285853]', 2419, 0, 0);
INSERT INTO chado.cvterm VALUES (2158, 22, 'CCAAT_motif', 'A promoter element with consensus sequence CCAAT, bound by a protein complex that represses transcription in response to low iron levels. [PMID:16963626]', 2420, 0, 0);
INSERT INTO chado.cvterm VALUES (2159, 22, 'Ace2_UAS', 'A promoter element with consensus sequence CCAGCC, bound by the fungal transcription factor Ace2. [PMID:16678171]', 2421, 0, 0);
INSERT INTO chado.cvterm VALUES (2160, 22, 'TR_box', 'A promoter element with consensus sequence TTCTTTGTTY, bound an HMG-box transcription factor such as S. pombe Ste11, and found in promoters of genes up-regulated early in meiosis. [PMID:1657709]', 2422, 0, 0);
INSERT INTO chado.cvterm VALUES (2161, 22, 'STREP_motif', 'A promoter element with consensus sequence CCCCTC, bound by the PKA-responsive zinc finger transcription factor Rst2. [PMID:11739717]', 2423, 0, 0);
INSERT INTO chado.cvterm VALUES (2162, 22, 'rDNA_intergenic_spacer_element', 'A DNA motif that contains a core consensus sequence AGGTAAGGGTAATGCAC, is found in the intergenic regions of rDNA repeats, and is bound by an RNA polymerase I transcription termination factor (e.g. S. pombe Reb1). The S. pombe telomeric repeat consensus is TTAC(0-1)A(0-1)G(1-8). [ISBN:978-0199638901, PMID:9016645]', 2424, 0, 0);
INSERT INTO chado.cvterm VALUES (2163, 22, 'sterol_regulatory_element', 'A 10-bp promoter element bound by sterol regulatory element binding proteins (SREBPs), found in promoters of genes involved in sterol metabolism. Many variants of the sequence ATCACCCCAC function as SREs. [GO:mah, PMID:11111080, PMID:16537923]', 2425, 0, 0);
INSERT INTO chado.cvterm VALUES (2164, 22, 'GT_dinucleotide_repeat', 'A dinucleotide repeat region composed of GT repeating elements. [SO:ke]', 2426, 0, 0);
INSERT INTO chado.cvterm VALUES (2165, 22, 'GTT_trinucleotide_repeat', 'A trinucleotide repeat region composed of GTT repeating elements. [SO:ke]', 2427, 0, 0);
INSERT INTO chado.cvterm VALUES (2166, 22, 'Sap1_recognition_motif', 'A DNA motif to which the S. pombe Sap1 protein binds. The consensus sequence is 5''-TARGCAGNTNYAACGMG-3''; it is found at the mating type locus, where it is important for mating type switching, and at replication fork barriers in rDNA repeats. [PMID:16166653, PMID:7651412]', 2428, 0, 0);
INSERT INTO chado.cvterm VALUES (2167, 22, 'CDRE_motif', 'An RNA polymerase II promoter element found in the promoters of genes regulated by calcineurin. The consensus sequence is GNGGCKCA. [PMID:16928959]', 2429, 0, 0);
INSERT INTO chado.cvterm VALUES (2168, 22, 'BAC_read_contig', 'A contig of BAC reads. [GMOD:ea]', 2430, 0, 0);
INSERT INTO chado.cvterm VALUES (2169, 22, 'candidate_gene', 'A gene suspected of being involved in the expression of a trait. [GMOD:ea]', 2431, 0, 0);
INSERT INTO chado.cvterm VALUES (2170, 22, 'positional_candidate_gene', 'A candidate gene whose association with a trait is based on the gene''s location on a chromosome. [GMOD:ea]', 2432, 0, 0);
INSERT INTO chado.cvterm VALUES (2171, 22, 'functional_candidate_gene', 'A candidate gene whose function has something in common biologically with the trait under investigation. [GMOD:ea]', 2433, 0, 0);
INSERT INTO chado.cvterm VALUES (2172, 22, 'enhancerRNA', 'A short ncRNA that is transcribed from an enhancer. May have a regulatory function. [doi:10.1038/465173a, SO:cjm]', 2434, 0, 0);
INSERT INTO chado.cvterm VALUES (2173, 22, 'PCB', 'A promoter element with consensus sequence GNAACR, bound by the transcription factor complex PBF (PCB-binding factor) and found in promoters of genes expressed during the M/G1 transition of the cell cycle. [GO:mah, PMID:12411492]', 2435, 0, 0);
INSERT INTO chado.cvterm VALUES (2174, 22, 'rearrangement_region', 'A region of a chromosome, where the chromosome has undergone a large structural rearrangement that altered the genome organization. There is no longer synteny to the reference genome. [NCBI:th, PMID:18564416]', 2436, 0, 0);
INSERT INTO chado.cvterm VALUES (2175, 22, 'interchromosomal_breakpoint', 'A rearrangement breakpoint between two different chromosomes. [NCBI:th]', 2437, 0, 0);
INSERT INTO chado.cvterm VALUES (2176, 22, 'intrachromosomal_breakpoint', 'A rearrangement breakpoint within the same chromosome. [NCBI:th]', 2438, 0, 0);
INSERT INTO chado.cvterm VALUES (2179, 22, 'feature_amplification', 'A sequence variant, caused by an alteration of the genomic sequence, where the structural change, an amplification of sequence, is greater than the extent of the underlying genomic features. [SO:ke]', 2441, 0, 0);
INSERT INTO chado.cvterm VALUES (2180, 22, 'feature_translocation', 'A sequence variant, caused by an alteration of the genomic sequence, where the structural change, a translocation, is greater than the extent of the underlying genomic features. [SO:ke]', 2442, 0, 0);
INSERT INTO chado.cvterm VALUES (2181, 22, 'transcript_translocation', 'A feature translocation where the region contains a transcript. [SO:ke]', 2443, 0, 0);
INSERT INTO chado.cvterm VALUES (2182, 22, 'regulatory_region_translocation', 'A feature translocation where the region contains a regulatory region. [SO:ke]', 2444, 0, 0);
INSERT INTO chado.cvterm VALUES (2183, 22, 'TFBS_translocation', 'A feature translocation where the region contains a transcription factor binding site. [SO:ke]', 2445, 0, 0);
INSERT INTO chado.cvterm VALUES (2184, 22, 'transcript_fusion', 'A feature fusion where the deletion brings together transcript regions. [SO:ke]', 2446, 0, 0);
INSERT INTO chado.cvterm VALUES (2185, 22, 'regulatory_region_fusion', 'A feature fusion where the deletion brings together regulatory regions. [SO:ke]', 2447, 0, 0);
INSERT INTO chado.cvterm VALUES (2186, 22, 'TFBS_fusion', 'A fusion where the deletion brings together transcription factor binding sites. [SO:ke]', 2448, 0, 0);
INSERT INTO chado.cvterm VALUES (2187, 22, 'transcript_amplification', 'A feature amplification of a region containing a transcript. [SO:ke]', 2449, 0, 0);
INSERT INTO chado.cvterm VALUES (2188, 22, 'transcript_regulatory_region_fusion', 'A feature fusion where the deletion brings together a regulatory region and a transcript region. [SO:ke]', 2450, 0, 0);
INSERT INTO chado.cvterm VALUES (2189, 22, 'regulatory_region_amplification', 'A feature amplification of a region containing a regulatory region. [SO:ke]', 2451, 0, 0);
INSERT INTO chado.cvterm VALUES (2190, 22, 'TFBS_amplification', 'A feature amplification of a region containing a transcription factor binding site. [SO:ke]', 2452, 0, 0);
INSERT INTO chado.cvterm VALUES (2191, 22, 'transcript_ablation', 'A feature ablation whereby the deleted region includes a transcript feature. [SO:ke]', 2453, 0, 0);
INSERT INTO chado.cvterm VALUES (2192, 22, 'regulatory_region_ablation', 'A feature ablation whereby the deleted region includes a regulatory region. [SO:ke]', 2454, 0, 0);
INSERT INTO chado.cvterm VALUES (2193, 22, 'TFBS_ablation', 'A feature ablation whereby the deleted region includes a transcription factor binding site. [SO:ke]', 2455, 0, 0);
INSERT INTO chado.cvterm VALUES (2194, 22, 'transposable_element_CDS', 'A CDS that is part of a transposable element. [SO:ke]', 2456, 0, 0);
INSERT INTO chado.cvterm VALUES (2195, 22, 'transposable_element_pseudogene', 'A pseudogene contained within a transposable element. [SO:ke]', 2457, 0, 0);
INSERT INTO chado.cvterm VALUES (2196, 22, 'dg_repeat', 'A repeat region which is part of the regional centromere outer repeat region. [PMID:16407326, SO:vw]', 2458, 0, 0);
INSERT INTO chado.cvterm VALUES (2197, 22, 'dh_repeat', 'A repeat region which is part of the regional centromere outer repeat region. [PMID:16407326, SO:vw]', 2459, 0, 0);
INSERT INTO chado.cvterm VALUES (2198, 22, 'AACCCT_box', 'A conserved 17-bp sequence (5''-ATCA(C/A)AACCCTAACCCT-3'') commonly present upstream of the start site of histone transcription units functioning as a transcription factor binding site. [PMID:17452352, PMID:4092687]', 2460, 0, 0);
INSERT INTO chado.cvterm VALUES (2199, 22, 'splice_region', 'A region surrounding a cis_splice site, either within 1-3 bases of the exon or 3-8 bases of the intron. [SO:bm]', 2461, 0, 0);
INSERT INTO chado.cvterm VALUES (2200, 22, 'antisense_lncRNA', 'Non-coding RNA transcribed from the opposite DNA strand compared with other transcripts and overlap in part with sense RNA. [PMID:19638999]', 2462, 0, 0);
INSERT INTO chado.cvterm VALUES (2201, 22, 'regional_centromere_outer_repeat_transcript', 'A transcript that is transcribed from the outer repeat region of a regional centromere. [PomBase:mah]', 2463, 0, 0);
INSERT INTO chado.cvterm VALUES (2202, 22, 'frameshift_elongation', 'A frameshift variant that causes the translational reading frame to be extended relative to the reference feature. [SO:ke]', 2464, 0, 0);
INSERT INTO chado.cvterm VALUES (2203, 22, 'frameshift_truncation', 'A frameshift variant that causes the translational reading frame to be shortened relative to the reference feature. [SO:ke]', 2465, 0, 0);
INSERT INTO chado.cvterm VALUES (2204, 22, 'copy_number_increase', 'A sequence variant where copies of a feature are increased relative to the reference. [SO:ke]', 2466, 0, 0);
INSERT INTO chado.cvterm VALUES (2205, 22, 'copy_number_decrease', 'A sequence variant where copies of a feature are decreased relative to the reference. [SO:ke]', 2467, 0, 0);
INSERT INTO chado.cvterm VALUES (2206, 22, 'rDNA_replication_fork_barrier', 'A DNA motif that is found in eukaryotic rDNA repeats, and is a site of replication fork pausing. [PMID:14645529]', 2468, 0, 0);
INSERT INTO chado.cvterm VALUES (2207, 22, 'transcription_start_cluster', 'A region defined by a cluster of experimentally determined transcription starting sites. [PMID:19624849, PMID:21372179, SO:andrewgibson]', 2469, 0, 0);
INSERT INTO chado.cvterm VALUES (2208, 22, 'CAGE_tag', 'A CAGE tag is a sequence tag hat corresponds to 5'' ends of mRNA at cap sites, produced by cap analysis gene expression and used to identify transcriptional start sites. [SO:andrewgibson]', 2470, 0, 0);
INSERT INTO chado.cvterm VALUES (2209, 22, 'CAGE_cluster', 'A kind of transcription_initiation_cluster defined by the clustering of CAGE tags on a sequence region. [PMID:16645617, SO:andrewgibson]', 2471, 0, 0);
INSERT INTO chado.cvterm VALUES (2210, 22, '5_methylcytosine', 'A cytosine methylated at the 5 carbon. [SO:rtapella]', 2472, 0, 0);
INSERT INTO chado.cvterm VALUES (2211, 22, '4_methylcytosine', 'A cytosine methylated at the 4 nitrogen. [SO:rtapella]', 2473, 0, 0);
INSERT INTO chado.cvterm VALUES (2212, 22, 'N6_methyladenine', 'An adenine methylated at the 6 nitrogen. [SO:rtapella]', 2474, 0, 0);
INSERT INTO chado.cvterm VALUES (2213, 22, 'mitochondrial_contig', 'A contig of mitochondria derived sequences. [GMOD:ea]', 2475, 0, 0);
INSERT INTO chado.cvterm VALUES (2214, 22, 'mitochondrial_supercontig', 'A scaffold composed of mitochondrial contigs. [GMOD:ea]', 2476, 0, 0);
INSERT INTO chado.cvterm VALUES (2215, 22, 'TERRA', 'A non-coding RNA transcript, derived from the transcription of the telomere. These transcripts contain G rich telomeric RNA repeats and RNA tracts corresponding to adjacent subtelomeric sequences. They are 100-9000 bases long. [PMID:22139915]', 2477, 0, 0);
INSERT INTO chado.cvterm VALUES (2216, 22, 'telomeric_transcript', 'A non-coding transcript derived from the transcript of the telomere. [PMID:22139915]', 2478, 0, 0);
INSERT INTO chado.cvterm VALUES (2217, 22, 'ARRET', 'A non coding RNA transcript, complementary to subtelomeric tract of TERRA transcript but devoid of the repeats. [PMID:2139915]', 2479, 0, 0);
INSERT INTO chado.cvterm VALUES (2218, 22, 'ARIA', 'A non-coding RNA transcript, derived from the transcription of the telomere. These transcripts consist of C rich repeats. [PMID:22139915]', 2480, 0, 0);
INSERT INTO chado.cvterm VALUES (2219, 22, 'anti_ARRET', 'A non-coding RNA transcript, derived from the transcription of the telomere. These transcripts are antisense of ARRET transcripts. [PMID:22139915]', 2481, 0, 0);
INSERT INTO chado.cvterm VALUES (2220, 22, 'distal_duplication', 'A duplication of the distal region of a chromosome. [SO:bm]', 2482, 0, 0);
INSERT INTO chado.cvterm VALUES (2221, 22, 'duplication', 'An insertion which derives from, or is identical in sequence to, nucleotides present at a known location in the genome. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html, NCBI:th]', 2483, 0, 0);
INSERT INTO chado.cvterm VALUES (2222, 22, 'mitochondrial_DNA_read', 'A sequencer read of a mitochondrial DNA sample. [GMOD:ea]', 2484, 0, 0);
INSERT INTO chado.cvterm VALUES (2223, 22, 'chloroplast_DNA_read', 'A sequencer read of a chloroplast DNA sample. [GMOD:ea]', 2485, 0, 0);
INSERT INTO chado.cvterm VALUES (2224, 22, 'consensus_gDNA', 'Genomic DNA sequence produced from some base calling or alignment algorithm which uses aligned or assembled multiple gDNA sequences as input. [GMOD:ea]', 2486, 0, 0);
INSERT INTO chado.cvterm VALUES (2225, 22, 'restriction_enzyme_five_prime_single_strand_overhang', 'A terminal region of DNA sequence where the end of the region is not blunt ended and the exposed single strand terminates at the 5'' end. [SO:ke]', 2487, 0, 0);
INSERT INTO chado.cvterm VALUES (2226, 22, 'restriction_enzyme_three_prime_single_strand_overhang', 'A terminal region of DNA sequence where the end of the region is not blunt ended and the exposed single strand terminates at the 3'' end. [SO:ke]', 2488, 0, 0);
INSERT INTO chado.cvterm VALUES (2227, 22, 'monomeric_repeat', 'A repeat_region containing repeat_units of 1 bp that is repeated multiple times in tandem. [SO:ke]', 2489, 0, 0);
INSERT INTO chado.cvterm VALUES (2228, 22, 'H3K20_trimethylation_site', 'A kind of histone modification site, whereby the 20th residue (a lysine), from the start of the H3 protein is tri-methylated. [EBI:nj]', 2490, 0, 0);
INSERT INTO chado.cvterm VALUES (2229, 22, 'H3K36_acetylation_site', 'A kind of histone modification site, whereby the 36th residue (a lysine), from the start of the H3 histone protein is acetylated. [EBI:nj]', 2491, 0, 0);
INSERT INTO chado.cvterm VALUES (2230, 22, 'H2BK12_acetylation_site', 'A kind of histone modification site, whereby the 12th residue (a lysine), from the start of the H2B protein is acetylated. [EBI:nj]', 2492, 0, 0);
INSERT INTO chado.cvterm VALUES (2231, 22, 'histone_2B_acetylation_site', 'A histone 2B modification where the modification is the acetylation of the residue. [ISBN:0815341059]', 2493, 0, 0);
INSERT INTO chado.cvterm VALUES (2232, 22, 'H2AK5_acetylation_site', 'A kind of histone modification site, whereby the 5th residue (a lysine), from the start of the H2A histone protein is acetylated. [EBI:nj]', 2494, 0, 0);
INSERT INTO chado.cvterm VALUES (2233, 22, 'histone_2A_acetylation_site', 'A histone 2A modification where the modification is the acetylation of the residue. [ISBN:0815341059]', 2495, 0, 0);
INSERT INTO chado.cvterm VALUES (2234, 22, 'H4K12_acetylation_site', 'A kind of histone modification site, whereby the 12th residue (a lysine), from the start of the H4 histone protein is acetylated. [EBI:nj]', 2496, 0, 0);
INSERT INTO chado.cvterm VALUES (2235, 22, 'H2BK120_acetylation_site', 'A kind of histone modification site, whereby the 120th residue (a lysine), from the start of the H2B histone protein is acetylated. [EBI:nj, http://dx.doi.org/10.4161/epi.6.5.15623]', 2497, 0, 0);
INSERT INTO chado.cvterm VALUES (2236, 22, 'H4K91_acetylation_site', 'A kind of histone modification site, whereby the 91st residue (a lysine), from the start of the H4 histone protein is acetylated. [EBI:nj]', 2498, 0, 0);
INSERT INTO chado.cvterm VALUES (2237, 22, 'H2BK20_acetylation_site', 'A kind of histone modification site, whereby the 20th residue (a lysine), from the start of the H2B histone protein is acetylated. [EBI:nj]', 2499, 0, 0);
INSERT INTO chado.cvterm VALUES (2238, 22, 'H3K4_acetylation_site', 'A kind of histone modification site, whereby the 4th residue (a lysine), from the start of the H3 histone protein is acetylated. [EBI:nj]', 2500, 0, 0);
INSERT INTO chado.cvterm VALUES (2239, 22, 'H2AK9_acetylation_site', 'A kind of histone modification site, whereby the 9th residue (a lysine), from the start of the H2A histone protein is acetylated. [EBI:nj]', 2501, 0, 0);
INSERT INTO chado.cvterm VALUES (2240, 22, 'H3K56_acetylation_site', 'A kind of histone modification site, whereby the 56th residue (a lysine), from the start of the H3 histone protein is acetylated. [EBI:nj]', 2502, 0, 0);
INSERT INTO chado.cvterm VALUES (2241, 22, 'H2BK15_acetylation_site', 'A kind of histone modification site, whereby the 15th residue (a lysine), from the start of the H2B histone protein is acetylated. [EBI:nj]', 2503, 0, 0);
INSERT INTO chado.cvterm VALUES (2242, 22, 'H3R2_monomethylation_site', 'A kind of histone modification site, whereby the 2nd residue (an arginine), from the start of the H3 protein is mono-methylated. [EBI:nj]', 2504, 0, 0);
INSERT INTO chado.cvterm VALUES (2243, 22, 'H3R2_dimethylation_site', 'A kind of histone modification site, whereby the 2nd residue (an arginine), from the start of the H3 protein is di-methylated. [EBI:nj]', 2505, 0, 0);
INSERT INTO chado.cvterm VALUES (2244, 22, 'H4R3_dimethylation_site', 'A kind of histone modification site, whereby the 3nd residue (an arginine), from the start of the H4 protein is di-methylated. [EBI:nj]', 2506, 0, 0);
INSERT INTO chado.cvterm VALUES (2245, 22, 'H4K4_trimethylation_site', 'A kind of histone modification site, whereby the 4th residue (a lysine), from the start of the H4 protein is tri-methylated. [EBI:nj]', 2507, 0, 0);
INSERT INTO chado.cvterm VALUES (2246, 22, 'H3K23_dimethylation_site', 'A kind of histone modification site, whereby the 23rd residue (a lysine), from the start of the H3 protein is di-methylated. [EBI:nj]', 2508, 0, 0);
INSERT INTO chado.cvterm VALUES (2247, 22, 'promoter_flanking_region', 'A region immediately adjacent to a promoter which may or may not contain transcription factor binding sites. [EBI:nj]', 2509, 0, 0);
INSERT INTO chado.cvterm VALUES (2248, 22, 'restriction_enzyme_assembly_scar', 'A region of DNA sequence formed from the ligation of two sticky ends where the palindrome is broken and no longer comprises the recognition site and thus cannot be re-cut by the restriction enzymes used to create the sticky ends. [SO:ke]', 2510, 0, 0);
INSERT INTO chado.cvterm VALUES (2249, 22, 'protein_stability_element', 'A polypeptide region that proves structure in a protein that affects the stability of the protein. [SO:ke]', 2511, 0, 0);
INSERT INTO chado.cvterm VALUES (2250, 22, 'protease_site', 'A polypeptide_region that codes for a protease cleavage site. [SO:ke]', 2512, 0, 0);
INSERT INTO chado.cvterm VALUES (2251, 22, 'RNA_stability_element', 'RNA secondary structure that affects the stability of an RNA molecule. [SO:ke]', 2513, 1, 0);
INSERT INTO chado.cvterm VALUES (2252, 22, 'lariat_intron', 'A kind of intron whereby the excision is driven by lariat formation. [SO:ke]', 2514, 0, 0);
INSERT INTO chado.cvterm VALUES (2253, 22, 'TCT_motif', 'A cis-regulatory element, conserved sequence YYC+1TTTYY, and spans -2 to +6 relative to +1 TSS. It is present in most ribosomal protein genes in Drosophila and mammals but not in the yeast Saccharomyces cerevisiae. Resembles the initiator (TCAKTY in Drosophila) but functionally distinct from initiator. [PMID:20801935, SO:myl]', 2515, 0, 0);
INSERT INTO chado.cvterm VALUES (2254, 22, '5_hydroxymethylcytosine', 'A modified DNA cytosine base feature, modified by a hydroxymethyl group at the 5 carbon. [SO:ke]', 2516, 0, 0);
INSERT INTO chado.cvterm VALUES (2255, 22, '5_formylcytosine', 'A modified DNA cytosine base feature, modified by a formyl group at the 5 carbon. [SO:ke]', 2517, 0, 0);
INSERT INTO chado.cvterm VALUES (2256, 22, 'modified_guanine', 'A modified guanine DNA base feature. [SO:ke]', 2518, 0, 0);
INSERT INTO chado.cvterm VALUES (2257, 22, '8_oxoguanine', 'A modified DNA guanine base,at the 8 carbon, often the product of DNA damage. [SO:ke]', 2519, 0, 0);
INSERT INTO chado.cvterm VALUES (2259, 22, '8_oxoadenine', 'A modified DNA adenine base,at the 8 carbon, often the product of DNA damage. [SO:ke]', 2521, 0, 0);
INSERT INTO chado.cvterm VALUES (2260, 22, 'coding_transcript_intron_variant', 'A transcript variant occurring within an intron of a coding transcript. [SO:ke]', 2522, 0, 0);
INSERT INTO chado.cvterm VALUES (2261, 22, 'non_coding_transcript_intron_variant', 'A transcript variant occurring within an intron of a non coding transcript. [SO:ke]', 2523, 0, 0);
INSERT INTO chado.cvterm VALUES (2262, 22, 'zinc_finger_binding_site', 'A binding site to which a polypeptide will bind with a zinc finger motif, which is characterized by requiring one or more Zinc 2+ ions for stabilized folding. []', 2524, 0, 0);
INSERT INTO chado.cvterm VALUES (2263, 22, 'CTCF_binding_site', 'A transcription factor binding site with consensus sequence CCGCGNGGNGGCAG, bound by CCCTF-binding factor. [EBI:nj]', 2525, 0, 0);
INSERT INTO chado.cvterm VALUES (2264, 22, 'five_prime_sticky_end_restriction_enzyme_cleavage_site', 'A restriction enzyme recognition site that, when cleaved, results in 5 prime overhangs. [SO:ke]', 2526, 0, 0);
INSERT INTO chado.cvterm VALUES (2265, 22, 'three_prime_sticky_end_restriction_enzyme_cleavage_site', 'A restriction enzyme recognition site that, when cleaved, results in 3 prime overhangs. [SO:ke]', 2527, 0, 0);
INSERT INTO chado.cvterm VALUES (2266, 22, 'ribonuclease_site', 'A region of a transcript encoding the cleavage site for a ribonuclease enzyme. [SO:ke]', 2528, 0, 0);
INSERT INTO chado.cvterm VALUES (2267, 22, 'signature', 'A region of sequence where developer information is encoded. [SO:ke]', 2529, 0, 0);
INSERT INTO chado.cvterm VALUES (2268, 22, 'RNA_stability_element(SO:0001979)', 'A motif that affects the stability of RNA. [PMID:22495308, SO:ke]', 2530, 0, 0);
INSERT INTO chado.cvterm VALUES (2269, 22, 'G_box', 'A regulatory promoter element identified in mutation experiments, with consensus sequence: CACGTG. Present in promoters, intergenic regions, coding regions, and introns. They are involved in gene expression responses to light and interact with G-box binding factor and I-box binding factor 1a. [PMID:19249238, PMID:8571452, SO:ml]', 2531, 0, 0);
INSERT INTO chado.cvterm VALUES (2270, 22, 'L_box', 'An orientation dependent regulatory promoter element, with consensus sequence of TTGCACAN4TTGCACA, found in plants. [PMID:17381552, PMID:2902624, SO:ml]', 2532, 0, 0);
INSERT INTO chado.cvterm VALUES (2271, 22, 'I-box', 'A plant regulatory promoter motif, composed of a highly conserved hexamer GATAAG (I-box core). [PMID:2347304, PMID:2902624, SO:ml]', 2533, 0, 0);
INSERT INTO chado.cvterm VALUES (2272, 22, '5_prime_UTR_premature_start_codon_variant', 'A 5'' UTR variant where a premature start codon is introduced, moved or lost. [SANGER:am]', 2534, 0, 0);
INSERT INTO chado.cvterm VALUES (2273, 22, 'silent_mating_type_cassette_array', 'A gene cassette array that corresponds to a silenced version of a mating type region. [PomBase:mah]', 2535, 0, 0);
INSERT INTO chado.cvterm VALUES (2274, 22, 'gene_cassette_array', 'An array of non-functional genes whose members, when captured by recombination form functional genes. [SO:ma]', 2536, 0, 0);
INSERT INTO chado.cvterm VALUES (2275, 22, 'Okazaki_fragment', 'Any of the DNA segments produced by discontinuous synthesis of the lagging strand during DNA replication. [ISBN:0805350152]', 2537, 0, 0);
INSERT INTO chado.cvterm VALUES (2276, 22, 'upstream_transcript_variant', 'A feature variant, where the alteration occurs upstream of the transcript TSS. [EBI:gr]', 2538, 0, 0);
INSERT INTO chado.cvterm VALUES (2277, 22, 'downstream_transcript_variant', 'A feature variant, where the alteration occurs downstream of the transcript termination site. []', 2539, 0, 0);
INSERT INTO chado.cvterm VALUES (2278, 22, '5_prime_UTR_premature_start_codon_gain_variant', 'A 5'' UTR variant where a premature start codon is gained. [Sanger:am]', 2540, 0, 0);
INSERT INTO chado.cvterm VALUES (2279, 22, '5_prime_UTR_premature_start_codon_loss_variant', 'A 5'' UTR variant where a premature start codon is lost. [SANGER:am]', 2541, 0, 0);
INSERT INTO chado.cvterm VALUES (2280, 22, 'five_prime_UTR_premature_start_codon_location_variant', 'A 5'' UTR variant where a premature start codon is moved. [SANGER:am]', 2542, 0, 0);
INSERT INTO chado.cvterm VALUES (2281, 22, 'consensus_AFLP_fragment', 'A consensus AFLP fragment is an AFLP sequence produced from any alignment algorithm which uses assembled multiple AFLP sequences as input. [GMOD:ea]', 2543, 0, 0);
INSERT INTO chado.cvterm VALUES (2282, 22, 'extended_cis_splice_site', 'Intronic positions associated with cis-splicing. Contains the first and second positions immediately before the exon and the first, second and fifth positions immediately after. [SANGER:am]', 2544, 0, 0);
INSERT INTO chado.cvterm VALUES (2283, 22, 'intron_base_5', 'Fifth intronic position after the intron exon boundary, close to the 5'' edge of the intron. [SANGER:am]', 2545, 0, 0);
INSERT INTO chado.cvterm VALUES (2284, 22, 'extended_intronic_splice_region_variant', 'A sequence variant occurring in the intron, within 10 bases of exon. [sanger:am]', 2546, 0, 0);
INSERT INTO chado.cvterm VALUES (2285, 22, 'extended_intronic_splice_region', 'Region of intronic sequence within 10 bases of an exon. [SANGER:am]', 2547, 0, 0);
INSERT INTO chado.cvterm VALUES (2286, 22, 'subtelomere', 'A heterochromatic region of the chromosome, adjacent to the telomere (on the centromeric side) that contains repetitive DNA and sometimes genes and it is transcribed. [POMBE:al]', 2548, 0, 0);
INSERT INTO chado.cvterm VALUES (2287, 22, 'sgRNA', 'A small RNA oligo, typically about 20 bases, that guides the cas nuclease to a target DNA sequence in the CRISPR/cas mutagenesis method. [PMID:23934893]', 2549, 0, 0);
INSERT INTO chado.cvterm VALUES (2288, 22, 'mating_type_region_motif', 'DNA motif that is a component of a mating type region. [SO:ke]', 2550, 0, 0);
INSERT INTO chado.cvterm VALUES (2289, 22, 'Y_region', 'A segment of non-homology between a and alpha mating alleles, found at all three mating loci (HML, MAT, and HMR), has two forms (Ya and Yalpha). [SGD:jd]', 2551, 0, 0);
INSERT INTO chado.cvterm VALUES (2290, 22, 'Z1_region', 'A mating type region motif, one of two segments of homology found at all three mating loci (HML, MAT, and HMR). [SGD:jd]', 2552, 0, 0);
INSERT INTO chado.cvterm VALUES (2291, 22, 'Z2_region', 'A mating type region motif, the rightmost segment of homology in the HML and MAT mating loci (not present in HMR). [SGD:jd]', 2553, 0, 0);
INSERT INTO chado.cvterm VALUES (2292, 22, 'ARS_consensus_sequence', 'The ACS is an 11-bp sequence of the form 5''-WTTTAYRTTTW-3'' which is at the core of every yeast ARS, and is necessary but not sufficient for recognition and binding by the origin recognition complex (ORC). Functional ARSs require an ACS, as well as other cis elements in the 5'' (C domain) and 3'' (B domain) flanking sequences of the ACS. [SGD:jd]', 2554, 0, 0);
INSERT INTO chado.cvterm VALUES (2293, 22, 'DSR_motif', 'The determinant of selective removal (DSR) motif consists of repeats of U(U/C)AAAC. The motif targets meiotic transcripts for removal during mitosis via the exosome. [PMID:22645662]', 2555, 0, 0);
INSERT INTO chado.cvterm VALUES (2294, 22, 'zinc_repressed_element', 'A promoter element that has the consensus sequence GNMGATC, and is found in promoters of genes repressed in the presence of zinc. [PMID:24003116, POMBE:mh]', 2556, 0, 0);
INSERT INTO chado.cvterm VALUES (2295, 22, 'rare_amino_acid_variant', 'A sequence variant whereby at least one base of a codon encoding a rare amino acid is changed, resulting in a different encoded amino acid. [SO:ke]', 2557, 0, 0);
INSERT INTO chado.cvterm VALUES (2296, 22, 'selenocysteine_loss', 'A sequence variant whereby at least one base of a codon encoding selenocysteine is changed, resulting in a different encoded amino acid. [SO:ke]', 2558, 0, 0);
INSERT INTO chado.cvterm VALUES (2297, 22, 'pyrrolysine_loss', 'A sequence variant whereby at least one base of a codon encoding pyrrolysine is changed, resulting in a different encoded amino acid. [SO:ke]', 2559, 0, 0);
INSERT INTO chado.cvterm VALUES (2298, 22, 'intragenic_variant', 'A variant that occurs within a gene but falls outside of all transcript features. This occurs when alternate transcripts of a gene do not share overlapping sequence. [SO:ke]', 2560, 0, 0);
INSERT INTO chado.cvterm VALUES (2299, 22, 'start_lost', 'A codon variant that changes at least one base of the canonical start codon. [SO:ke]', 2561, 0, 0);
INSERT INTO chado.cvterm VALUES (2300, 22, '5_prime_UTR_truncation', 'A sequence variant that causes the reduction of a the 5''UTR with regard to the reference sequence. [SO:ke]', 2562, 0, 0);
INSERT INTO chado.cvterm VALUES (2301, 22, '5_prime_UTR_elongation', 'A sequence variant that causes the extension of 5'' UTR, with regard to the reference sequence. [SO:ke]', 2563, 0, 0);
INSERT INTO chado.cvterm VALUES (2302, 22, '3_prime_UTR_truncation', 'A sequence variant that causes the reduction of a the 3'' UTR with regard to the reference sequence. [SO:ke]', 2564, 0, 0);
INSERT INTO chado.cvterm VALUES (2303, 22, '3_prime_UTR_elongation', 'A sequence variant that causes the extension of 3'' UTR, with regard to the reference sequence. [SO:ke]', 2565, 0, 0);
INSERT INTO chado.cvterm VALUES (2304, 22, 'conserved_intergenic_variant', 'A sequence variant located in a conserved intergenic region, between genes. [SO:ke]', 2566, 0, 0);
INSERT INTO chado.cvterm VALUES (2305, 22, 'conserved_intron_variant', 'A transcript variant occurring within a conserved region of an intron. [SO:ke]', 2567, 0, 0);
INSERT INTO chado.cvterm VALUES (2306, 22, 'start_retained_variant', 'A sequence variant where at least one base in the start codon is changed, but the start remains. [SO:ke]', 2568, 0, 0);
INSERT INTO chado.cvterm VALUES (2307, 22, 'boundary_element', 'Boundary elements are DNA motifs that prevent heterochromatin from spreading into neighboring euchromatic regions. [PMID:24013502]', 2569, 0, 0);
INSERT INTO chado.cvterm VALUES (2308, 22, 'mating_type_region_replication_fork_barrier', 'A DNA motif that is found in eukaryotic rDNA repeats, and is a site of replication fork pausing. [PMID:17614787]', 2570, 0, 0);
INSERT INTO chado.cvterm VALUES (2309, 22, 'priRNA', 'A small RNA molecule, 22-23 nt in size, that is the product of a longer RNA. The production of priRNAs is independent of dicer and involves binding of RNA by argonaute and trimming by triman. In fission yeast, priRNAs trigger the establishment of heterochromatin. PriRNAs are primarily generated from centromeric transcripts (dg and dh repeats), but may also be produced from degradation products of primary transcripts. [PMID:20178743, PMID:24095277, PomBase:al]', 2571, 0, 0);
INSERT INTO chado.cvterm VALUES (2310, 22, 'multiplexing_sequence_identifier', 'A nucleic tag which is used in a ligation step of library preparation process to allow pooling of samples while maintaining ability to identify individual source material and creation of a multiplexed library. [OBO:prs, PMID:22574170]', 2572, 0, 0);
INSERT INTO chado.cvterm VALUES (2311, 22, 'W_region', 'The leftmost segment of homology in the HML and MAT mating loci, but not present in HMR. [SGD:jd]', 2573, 0, 0);
INSERT INTO chado.cvterm VALUES (2312, 22, 'cis_acting_homologous_chromosome_pairing_region', 'A genome region where chromosome pairing occurs preferentially during homologous chromosome pairing during early meiotic prophase of Meiosis I. [PMID:22582262, PMID:23117617, PMID:24173580, PomBase:vw]', 2575, 0, 0);
INSERT INTO chado.cvterm VALUES (2313, 22, 'intein_encoding_region', 'The nucleotide sequence which encodes the intein portion of the precursor gene. [PMID:8165123]', 2576, 0, 0);
INSERT INTO chado.cvterm VALUES (2314, 22, 'uORF', 'A short open reading frame that is found in the 5'' untranslated region of an mRNA and plays a role in translational regulation. [PMID:12890013, PMID:16153175, POMBASE:mah]', 2577, 0, 0);
INSERT INTO chado.cvterm VALUES (2315, 22, 'sORF', 'An open reading frame that encodes a peptide of less than 100 amino acids. [PMID:23970561, PMID:24705786, POMBASE:mah]', 2579, 0, 0);
INSERT INTO chado.cvterm VALUES (2316, 22, 'tnaORF', 'A translated ORF encoded entirely within the antisense strand of a known protein coding gene. [POMBASE:vw]', 2580, 0, 0);
INSERT INTO chado.cvterm VALUES (2317, 22, 'X_region', 'One of two segments of homology found at all three mating loci (HML, MAT and HMR). [SGD:jd]', 2581, 0, 0);
INSERT INTO chado.cvterm VALUES (2318, 22, 'shRNA', 'A short hairpin RNA (shRNA) is an RNA transcript that makes a tight hairpin turn that can be used to silence target gene expression via RNA interference. [PMID:6699500, SO:ke]', 2582, 0, 0);
INSERT INTO chado.cvterm VALUES (2319, 22, 'moR', 'A non-coding transcript encoded by sequences adjacent to the ends of the 5'' and 3'' miR-encoding sequences that abut the loop in precursor miRNA. [SO:ke]', 2583, 0, 0);
INSERT INTO chado.cvterm VALUES (2320, 22, 'loR', 'A short, non coding transcript of loop-derived sequences encoded in precursor miRNA. [SO:ke]', 2584, 0, 0);
INSERT INTO chado.cvterm VALUES (2321, 22, 'miR_encoding_snoRNA_primary_transcript', 'A snoRNA primary transcript that also encodes pre-miR sequence that is processed to form functionally active miRNA. [SO:ke]', 2585, 0, 0);
INSERT INTO chado.cvterm VALUES (2322, 22, 'lncRNA_primary_transcript', 'A primary transcript encoding a lncRNA. [SO:ke]', 2586, 0, 0);
INSERT INTO chado.cvterm VALUES (2323, 22, 'miR_encoding_lncRNA_primary_transcript', 'A lncRNA primary transcript that also encodes pre-miR sequence that is processed to form functionally active miRNA. [SO:ke]', 2587, 0, 0);
INSERT INTO chado.cvterm VALUES (2324, 22, 'miR_encoding_tRNA_primary_transcript', 'A tRNA primary transcript that also encodes pre-miR sequence that is processed to form functionally active miRNA. [SO:ke]', 2588, 0, 0);
INSERT INTO chado.cvterm VALUES (2325, 22, 'shRNA_primary_transcript', 'A primary transcript encoding an shRNA. [SO:ke]', 2589, 0, 0);
INSERT INTO chado.cvterm VALUES (2326, 22, 'miR_encoding_shRNA_primary_transcript', 'A shRNA primary transcript that also encodes pre-miR sequence that is processed to form functionally active miRNA. [SO:ke]', 2590, 0, 0);
INSERT INTO chado.cvterm VALUES (2327, 22, 'vaultRNA_primary_transcript', 'A primary transcript encoding a vaultRNA. [SO:ke]', 2591, 0, 0);
INSERT INTO chado.cvterm VALUES (2328, 22, 'miR_encoding_vaultRNA_primary_transcript', 'A vaultRNA primary transcript that also encodes pre-miR sequence that is processed to form functionally active miRNA. [SO:ke]', 2592, 0, 0);
INSERT INTO chado.cvterm VALUES (2329, 22, 'Y_RNA_primary_transcript', 'A primary transcript encoding a Y-RNA. [SO:ke]', 2593, 0, 0);
INSERT INTO chado.cvterm VALUES (2330, 22, 'miR_encoding_Y_RNA_primary_transcript', 'A Y-RNA primary transcript that also encodes pre-miR sequence that is processed to form functionally active miRNA. [SO:ke]', 2594, 0, 0);
INSERT INTO chado.cvterm VALUES (2331, 22, 'TCS_element', 'A TCS element is a (yeast) transcription factor binding site, bound by the TEA DNA binding domain (DBD) of transcription factors. The consensus site is CATTCC or CATTCT. [PMID:1489142, PMID:20118212, SO:ke]', 2595, 0, 0);
INSERT INTO chado.cvterm VALUES (2332, 22, 'pheromone_response_element', 'A PRE is a (yeast) TFBS with consensus site [TGAAAC(A/G)]. [PMID:1489142, SO:ke]', 2596, 0, 0);
INSERT INTO chado.cvterm VALUES (2333, 22, 'FRE', 'A FRE is an enhancer element necessary and sufficient to confer filamentation associated expression in S. cerevisiae. [PMID:1489142, SO:ke]', 2597, 0, 0);
INSERT INTO chado.cvterm VALUES (2372, 22, '2KB_downstream_variant', 'A sequence variant located within 2KB 3'' of a gene. [SO:ke]', 2636, 0, 0);
INSERT INTO chado.cvterm VALUES (2334, 22, 'transcription_pause_site', 'Transcription pause sites are regions of a gene where RNA polymerase may pause during transcription. The functional role of pausing may be to facilitate factor recruitment, RNA folding, and synchronization with translation. Consensus transcription pause site have been observed in E. coli. [PMID:24789973, SO:ke]', 2598, 0, 0);
INSERT INTO chado.cvterm VALUES (2335, 22, 'disabled_reading_frame', 'A reading frame that could encode a full-length protein but which contains obvious mid-sequence disablements (frameshifts or premature stop codons). [SGD:se]', 2599, 0, 0);
INSERT INTO chado.cvterm VALUES (2336, 22, 'H3K27_acetylation_site', 'A kind of histone modification site, whereby the 27th residue (a lysine), from the start of the H3 histone protein is acetylated. [SO:rs]', 2600, 0, 0);
INSERT INTO chado.cvterm VALUES (2337, 22, 'constitutive_promoter', 'A promoter that allows for continual transcription of gene. [SO:ke]', 2601, 0, 0);
INSERT INTO chado.cvterm VALUES (2338, 22, 'inducible_promoter', 'A promoter whereby activity is induced by the presence or absence of biotic or abiotic factors. [SO:ke]', 2602, 0, 0);
INSERT INTO chado.cvterm VALUES (2339, 22, 'dominant_negative_variant', 'A variant where the mutated gene product adversely affects the other (wild type) gene product. [SO:ke]', 2603, 0, 0);
INSERT INTO chado.cvterm VALUES (2340, 22, 'gain_of_function_variant', 'A sequence variant whereby new or enhanced function is conferred on the gene product. [SO:ke]', 2604, 0, 0);
INSERT INTO chado.cvterm VALUES (2341, 22, 'loss_of_function_variant', 'A sequence variant whereby the gene product has diminished or abolished function. [SO:ke]', 2605, 0, 0);
INSERT INTO chado.cvterm VALUES (2342, 22, 'null_mutation', 'A variant whereby the gene product is not functional or the gene product is not produced. [SO:ke]', 2606, 0, 0);
INSERT INTO chado.cvterm VALUES (2343, 22, 'intronic_splicing_silencer', 'An intronic splicing regulatory element that functions to recruit trans acting splicing factors suppress the transcription of the gene or genes they control. [PMID:23241926, SO:ke]', 2607, 0, 0);
INSERT INTO chado.cvterm VALUES (2344, 22, 'intronic_splicing_enhancer', '', 2608, 1, 0);
INSERT INTO chado.cvterm VALUES (2345, 22, 'exonic_splicing_silencer', 'An exonic splicing regulatory element that functions to recruit trans acting splicing factors suppress the transcription of the gene or genes they control. [PMID:23241926, SO:ke]', 2609, 0, 0);
INSERT INTO chado.cvterm VALUES (2346, 22, 'recombination_enhancer', 'A regulatory_region that promotes or induces the process of recombination. [PMID:8861911, SGD:se]', 2610, 0, 0);
INSERT INTO chado.cvterm VALUES (2347, 22, 'interchromosomal_translocation', 'A translocation where the regions involved are from different chromosomes. [NCBI:th]', 2611, 0, 0);
INSERT INTO chado.cvterm VALUES (2348, 22, 'intrachromosomal_translocation', 'A translocation where the regions involved are from the same chromosome. [NCBI:th]', 2612, 0, 0);
INSERT INTO chado.cvterm VALUES (2349, 22, 'complex_chromosomal_rearrangement', 'A contiguous cluster of translocations, usually the result of a single catastrophic event such as chromothripsis or chromoanasynthesis. [NCBI:th]', 2613, 0, 0);
INSERT INTO chado.cvterm VALUES (2350, 22, 'Alu_insertion', 'An insertion of sequence from the Alu family of mobile elements. [NCBI:th]', 2614, 0, 0);
INSERT INTO chado.cvterm VALUES (2351, 22, 'LINE1_insertion', 'An insertion from the Line1 family of mobile elements. [NCBI:th]', 2615, 0, 0);
INSERT INTO chado.cvterm VALUES (2352, 22, 'L1_LINE_retrotransposon', 'Long interspersed element-1 (LINE-1) elements are found in the human genome, which contains ORF1 (open reading frame1, including CC, coiled coil; RRM, RNA recognition motif; CTD, carboxyl-terminal domain) and ORF2 (including EN, endonuclease; RT, reverse transcriptase; C, cysteine-rich domain). The L1-encoded proteins (ORF1p and ORF2p) can mobilize nonautonomous retrotransposons, other noncoding RNAs, and messenger RNAs. [PMID:31709017]', 2616, 0, 0);
INSERT INTO chado.cvterm VALUES (2353, 22, 'SVA_insertion', 'An insertion of sequence from the SVA family of mobile elements. [NCBI:th]', 2617, 0, 0);
INSERT INTO chado.cvterm VALUES (2354, 22, 'mobile_element_deletion', 'A deletion of a mobile element when comparing a reference sequence (has mobile element) to a individual sequence (does not have mobile element). [NCBI:th]', 2618, 0, 0);
INSERT INTO chado.cvterm VALUES (2355, 22, 'HERV_deletion', 'A deletion of the HERV mobile element with respect to a reference. [NCBI:th]', 2619, 0, 0);
INSERT INTO chado.cvterm VALUES (2356, 22, 'Endogenous_Retrovirus_LTR_retrotransposon', 'Endogenous retrovirus (ERV) retrotransposons are abundant in the genomes of jawed vertebrates. Human ERVs (HERVs) are classified based on their homologies to animal retroviruses. Class I families are similar in sequence to mammalian Gammaretroviruses (type C) and Epsilonretroviruses (Type E). Class II families show homology to mammalian Betaretroviruses (Type B) and Deltaretroviruses (Type D). F-Class III families are similar to foamy viruses. [PMID:17984973]', 2620, 0, 0);
INSERT INTO chado.cvterm VALUES (2357, 22, 'SVA_deletion', 'A deletion of an SVA mobile element. [NCBI:th]', 2621, 0, 0);
INSERT INTO chado.cvterm VALUES (2358, 22, 'LINE1_deletion', 'A deletion of a LINE1 mobile element with respect to a reference. [NCBI:th]', 2622, 0, 0);
INSERT INTO chado.cvterm VALUES (2359, 22, 'Alu_deletion', 'A deletion of an Alu mobile element with respect to a reference. [NCBI:th]', 2623, 0, 0);
INSERT INTO chado.cvterm VALUES (2360, 22, 'CDS_supported_by_peptide_spectrum_match', 'A CDS that is supported by proteomics data. [SO:ke]', 2624, 0, 0);
INSERT INTO chado.cvterm VALUES (2361, 22, 'CDS_supported_by_sequence_similarity_data', 'A CDS that is supported by sequence similarity data. [SO:xp]', 2625, 0, 0);
INSERT INTO chado.cvterm VALUES (2362, 22, 'no_sequence_alteration', 'A position or feature within a sequence that is identical to the comparable position or feature of a specified reference sequence. [SO:ke]', 2626, 0, 0);
INSERT INTO chado.cvterm VALUES (2363, 22, 'intergenic_1kb_variant', 'A variant that falls in an intergenic region that is 1 kb or less between 2 genes. [SO:ke]', 2627, 0, 0);
INSERT INTO chado.cvterm VALUES (2364, 22, 'incomplete_transcript_variant', 'A sequence variant that intersects an incompletely annotated transcript. [SO:ke]', 2628, 0, 0);
INSERT INTO chado.cvterm VALUES (2365, 22, 'incomplete_transcript_3UTR_variant', 'A sequence variant that intersects the 3'' UTR of an incompletely annotated transcript. [SO:ke]', 2629, 0, 0);
INSERT INTO chado.cvterm VALUES (2366, 22, 'incomplete_transcript_5UTR_variant', 'A sequence variant that intersects the 5'' UTR of an incompletely annotated transcript. [SO:ke]', 2630, 0, 0);
INSERT INTO chado.cvterm VALUES (2367, 22, 'incomplete_transcript_intronic_variant', 'A sequence variant that intersects the intron of an incompletely annotated transcript. [SO:ke]', 2631, 0, 0);
INSERT INTO chado.cvterm VALUES (2368, 22, 'incomplete_transcript_splice_region_variant', 'A sequence variant that intersects the splice region of an incompletely annotated transcript. [SO:ke]', 2632, 0, 0);
INSERT INTO chado.cvterm VALUES (2369, 22, 'incomplete_transcript_exonic_variant', 'A sequence variant that intersects the exon of an incompletely annotated transcript. [SO:ke]', 2633, 0, 0);
INSERT INTO chado.cvterm VALUES (2370, 22, 'incomplete_transcript_CDS', 'A sequence variant that intersects the coding regions of an incompletely annotated transcript. [SO:ke]', 2634, 0, 0);
INSERT INTO chado.cvterm VALUES (2371, 22, 'incomplete_transcript_coding_splice_variant', 'A sequence variant that intersects the coding sequence near a splice region of an incompletely annotated transcript. [SO:ke]', 2635, 0, 0);
INSERT INTO chado.cvterm VALUES (2373, 22, 'exonic_splice_region_variant', 'A sequence variant in which a change has occurred within the exonic region of the splice site, 1-2 bases from boundary. [SO:ke]', 2637, 0, 0);
INSERT INTO chado.cvterm VALUES (2374, 22, 'unidirectional_gene_fusion', 'A sequence variant whereby two genes, on the same strand have become joined. [SO:ke]', 2638, 0, 0);
INSERT INTO chado.cvterm VALUES (2375, 22, 'bidirectional_gene_fusion', 'A sequence variant whereby two genes, on alternate strands have become joined. [SO:ke]', 2639, 0, 0);
INSERT INTO chado.cvterm VALUES (2376, 22, 'pseudogenic_CDS', 'A non functional descendant of the coding portion of a coding transcript, part of a pseudogene. [SO:ke]', 2640, 0, 0);
INSERT INTO chado.cvterm VALUES (2377, 22, 'non_coding_transcript_splice_region_variant', 'A transcript variant occurring within the splice region (1-3 bases of the exon or 3-8 bases of the intron) of a non coding transcript. [SO:ke]', 2641, 0, 0);
INSERT INTO chado.cvterm VALUES (2378, 22, '3_prime_UTR_exon_variant', 'A UTR variant of exonic sequence of the 3'' UTR. [SO:ke]', 2642, 0, 0);
INSERT INTO chado.cvterm VALUES (2379, 22, '3_prime_UTR_intron_variant', 'A UTR variant of intronic sequence of the 3'' UTR. [SO:ke]', 2643, 0, 0);
INSERT INTO chado.cvterm VALUES (2380, 22, '5_prime_UTR_intron_variant', 'A UTR variant of intronic sequence of the 5'' UTR. [SO:ke]', 2644, 0, 0);
INSERT INTO chado.cvterm VALUES (2381, 22, '5_prime_UTR_exon_variant', 'A UTR variant of exonic sequence of the 5'' UTR. [SO:ke]', 2645, 0, 0);
INSERT INTO chado.cvterm VALUES (2382, 22, 'structural_interaction_variant', 'A variant that impacts the internal interactions of the resulting polypeptide structure. [SO:ke]', 2646, 0, 0);
INSERT INTO chado.cvterm VALUES (2383, 22, 'non_allelic_homologous_recombination_region', 'A genomic region at a non-allelic position where exchange of genetic material happens as a result of homologous recombination. []', 2647, 0, 0);
INSERT INTO chado.cvterm VALUES (2384, 22, 'scaRNA', 'A ncRNA, specific to the Cajal body, that has been demonstrated to function as a guide RNA in the site-specific synthesis of 2''-O-ribose-methylated nucleotides and pseudouridines in the RNA polymerase II-transcribed U1, U2, U4 and U5 spliceosomal small nuclear RNAs (snRNAs). [PMC:126017, PMID:27775477, PMID:28869095, SO:nrs]', 2648, 0, 0);
INSERT INTO chado.cvterm VALUES (2385, 22, 'short_tandem_repeat_variation', 'A variation that expands or contracts a tandem repeat with regard to a reference. [SO:ke]', 2649, 0, 0);
INSERT INTO chado.cvterm VALUES (2386, 22, 'vertebrate_immune_system_pseudogene', 'A pseudogene derived from a vertebrate immune system gene. [SO:ke]', 2650, 0, 0);
INSERT INTO chado.cvterm VALUES (2387, 22, 'immunoglobulin_pseudogene', 'A pseudogene derived from an immunoglobulin gene. [SO:ke]', 2651, 0, 0);
INSERT INTO chado.cvterm VALUES (2388, 22, 'T_cell_receptor_pseudogene', 'A pseudogene derived from a T-cell receptor gene. [SO:ke]', 2652, 0, 0);
INSERT INTO chado.cvterm VALUES (2389, 22, 'IG_C_pseudogene', 'A pseudogenic constant region of an immunoglobulin gene which closely resembles a known functional Imunoglobulin constant gene but in which the coding region has stop codons, frameshift mutations or a mutation that effects the initiation codon. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2653, 0, 0);
INSERT INTO chado.cvterm VALUES (2390, 22, 'IG_J_pseudogene', 'A pseudogenic joining region which closely resembles a known functional imunoglobulin joining gene but in which the coding region has stop codons, frameshift mutations or a mutation that effects the initiation codon that rearranges at the DNA level and codes the joining region of the variable domain of an immunoglobulin chain. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2654, 0, 0);
INSERT INTO chado.cvterm VALUES (2391, 22, 'IG_V_pseudogene', 'A pseudogenic variable region which closely resembles a known functional imunoglobulin variable gene but in which the coding region has stop codons, frameshift mutations or a mutation that effects the initiation codon that rearranges at the DNA level and codes the variable region of an immunoglobulin chain. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2655, 0, 0);
INSERT INTO chado.cvterm VALUES (2392, 22, 'TR_V_pseudogene', 'A pseudogenic variable region which closely resembles a known functional T receptor variable gene but in which the coding region has stop codons, frameshift mutations or a mutation that effects the initiation codon that rearranges at the DNA level and codes the variable region of an immunoglobulin chain. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2656, 0, 0);
INSERT INTO chado.cvterm VALUES (2393, 22, 'TR_J_pseudogene', 'A pseudogenic joining region which closely resembles a known functional T receptor (TR) joining gene but in which the coding region has stop codons, frameshift mutations or a mutation that effects the initiation codon that rearranges at the DNA level and codes the joining region of the variable domain of an immunoglobulin chain. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2657, 0, 0);
INSERT INTO chado.cvterm VALUES (2394, 22, 'translated_processed_pseudogene', 'A processed pseudogene where there is evidence, (mass spec data) suggesting that it is also translated. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2658, 0, 0);
INSERT INTO chado.cvterm VALUES (2395, 22, 'translated_unprocessed_pseudogene', 'A non-processed pseudogene where there is evidence, (mass spec data) suggesting that it is also translated. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2659, 0, 0);
INSERT INTO chado.cvterm VALUES (2396, 22, 'transcribed_unprocessed_pseudogene', 'A unprocessed pseudogene supported by locus-specific evidence of transcription. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2660, 0, 0);
INSERT INTO chado.cvterm VALUES (2397, 22, 'transcribed_unitary_pseudogene', 'A species specific unprocessed pseudogene without a parent gene, as it has an active orthologue in another species. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2661, 0, 0);
INSERT INTO chado.cvterm VALUES (2398, 22, 'transcribed_processed_pseudogene', 'A processed_pseudogene overlapped by locus-specific evidence of transcription. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2662, 0, 0);
INSERT INTO chado.cvterm VALUES (2399, 22, 'polymorphic_pseudogene_with_retained_intron', 'A polymorphic pseudogene in the reference genome, containing a retained intron, known to be intact in the genomes of other individuals of the same species. The annotation process has confirmed that the pseudogenisation event is not a genomic sequencing error. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2663, 0, 0);
INSERT INTO chado.cvterm VALUES (2400, 22, 'pseudogene_processed_transcript', 'A processed_transcript supported by EST and/or mRNA evidence that aligns unambiguously to a pseudogene locus (i.e. alignment to the pseudogene locus clearly better than alignment to parent locus). [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2664, 0, 0);
INSERT INTO chado.cvterm VALUES (2401, 22, 'coding_transcript_with_retained_intron', 'A protein coding transcript containing a retained intron. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2665, 0, 0);
INSERT INTO chado.cvterm VALUES (2402, 22, 'lncRNA_with_retained_intron', 'A lncRNA transcript containing a retained intron. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2666, 0, 0);
INSERT INTO chado.cvterm VALUES (2403, 22, 'NMD_transcript', 'A protein coding transcript that contains a CDS but has one or more splice junctions >50bp downstream of stop codon, making it susceptible to nonsense mediated decay. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2667, 0, 0);
INSERT INTO chado.cvterm VALUES (2404, 22, 'pseudogenic_transcript_with_retained_intron', 'A transcript supported by EST and/or mRNA evidence that aligns unambiguously to the pseudogene locus; has retained intronic sequence compared to a reference transcript sequence. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2668, 0, 0);
INSERT INTO chado.cvterm VALUES (2405, 22, 'polymorphic_pseudogene_processed_transcript', 'A processed transcript that does not contain a CDS that fullfills annotation criteria and not necessarily functionally non-coding. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2669, 0, 0);
INSERT INTO chado.cvterm VALUES (2406, 22, '<new term>', '', 2670, 1, 0);
INSERT INTO chado.cvterm VALUES (2407, 22, 'NMD_polymorphic_pseudogene_transcript', 'A polymorphic pseudogene transcript that contains a CDS but has one or more splice junctions >50bp downstream of stop codon. Premature stop codon is not introduced, directly or indirectly, as a result of the variation i.e. must be present in both protein_coding and pseudogenic alleles. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2671, 0, 0);
INSERT INTO chado.cvterm VALUES (2408, 22, 'allelic_frequency', 'A physical quality which inheres to the allele by virtue of the number instances of the allele within a population. This is the relative frequency of the allele at a given locus in a population. [SO:ke]', 2672, 0, 0);
INSERT INTO chado.cvterm VALUES (2409, 22, 'three_prime_overlapping_ncrna', 'Transcript where ditag (digital gene expression profiling)and/or published experimental data strongly supports the existence of short non-coding transcripts transcribed from the 3''UTR. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2674, 0, 0);
INSERT INTO chado.cvterm VALUES (2410, 22, 'vertebrate_immune_system_gene', 'The configuration of the IG and TR variable (V), diversity (D) and joining (J) germline genes before DNA rearrangements (with or without constant (C) genes in undefined configuration. (germline, non rearranged regions of the IG DNA loci). [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2675, 0, 0);
INSERT INTO chado.cvterm VALUES (2411, 22, 'immunoglobulin_gene', 'A germline immunoglobulin gene. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2676, 0, 0);
INSERT INTO chado.cvterm VALUES (2412, 22, 'IG_C_gene', 'A constant (C) gene, a gene that codes the constant region of an immunoglobulin chain. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2677, 0, 0);
INSERT INTO chado.cvterm VALUES (2413, 22, 'IG_D_gene', 'A gene that rearranges at the DNA level and codes the diversity region of the variable domain of an immunoglobuin (IG) gene. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2678, 0, 0);
INSERT INTO chado.cvterm VALUES (2414, 22, 'IG_J_gene', 'A joining gene that rearranges at the DNA level and codes the joining region of the variable domain of an immunoglobulin chain. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2679, 0, 0);
INSERT INTO chado.cvterm VALUES (2415, 22, 'IG_V_gene', 'A variable gene that rearranges at the DNA level and codes the variable region of the variable domain of an Immunoglobulin chain. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2680, 0, 0);
INSERT INTO chado.cvterm VALUES (2416, 22, 'mt_rRNA', 'Mitochondrial rRNA is an RNA component of the small or large subunits of mitochondrial ribosomes. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2681, 0, 0);
INSERT INTO chado.cvterm VALUES (2417, 22, 'mt_tRNA', 'Mitochondrial transfer RNA. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2682, 0, 0);
INSERT INTO chado.cvterm VALUES (2418, 22, 'NSD_transcript', 'A transcript that contains a CDS but has no stop codon before the polyA site is reached. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2683, 0, 0);
INSERT INTO chado.cvterm VALUES (2419, 22, 'sense_intronic_lncRNA', 'A long non-coding transcript found within an intron of a coding or non-coding gene, with no overlap of exonic sequence. [GENECODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2684, 0, 0);
INSERT INTO chado.cvterm VALUES (2420, 22, 'sense_overlap_lncRNA', 'A long non-coding transcript that contains a protein coding gene within its intronic sequence on the same strand, with no overlap of exonic sequence. [GENECODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2686, 0, 0);
INSERT INTO chado.cvterm VALUES (2421, 22, 'T_cell_receptor_gene', 'A T-cell receptor germline gene. []', 2687, 0, 0);
INSERT INTO chado.cvterm VALUES (2422, 22, 'TR_C_Gene', 'A constant (C) gene, a gene that codes the constant region of a T-cell receptor chain. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2688, 0, 0);
INSERT INTO chado.cvterm VALUES (2423, 22, 'TR_D_Gene', 'A gene that rearranges at the DNA level and codes the diversity region of the variable domain of aT-cell receptor gene. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2689, 0, 0);
INSERT INTO chado.cvterm VALUES (2424, 22, 'TR_J_Gene', 'A joining gene that rearranges at the DNA level and codes the joining region of the variable domain of aT-cell receptor chain. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2690, 0, 0);
INSERT INTO chado.cvterm VALUES (2425, 22, 'TR_V_Gene', 'A variable gene that rearranges at the DNA level and codes the variable region of the variable domain of aT-cell receptor chain. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html, IGMT:http\://www.imgt.org/IMGTScientificChart/SequenceDescription/Keywords.php]', 2691, 0, 0);
INSERT INTO chado.cvterm VALUES (2426, 22, 'predicted_transcript', 'A transcript feature that has been predicted but is not yet validated. [SO:ke]', 2692, 0, 0);
INSERT INTO chado.cvterm VALUES (2427, 22, 'unconfirmed_transcript', 'This is used for non-spliced EST clusters that have polyA features. This category has been specifically created for the ENCODE project to highlight regions that could indicate the presence of protein coding genes that require experimental validation, either by 5'' RACE or RT-PCR to extend the transcripts, or by confirming expression of the putatively-encoded peptide with specific antibodies. [GENCODE:http\://www.gencodegenes.org/gencode_biotypes.html]', 2693, 0, 0);
INSERT INTO chado.cvterm VALUES (2428, 22, 'early_origin_of_replication', 'An origin of replication that initiates early in S phase. [PMID:23348837, PMID:9115207]', 2694, 0, 0);
INSERT INTO chado.cvterm VALUES (2429, 22, 'late_origin_of_replication', 'An origin of replication that initiates late in S phase. [PMID:23348837, PMID:9115207]', 2695, 0, 0);
INSERT INTO chado.cvterm VALUES (2430, 22, 'histone_2AZ_acetylation_site', 'A histone 2AZ modification where the modification is the acetylation of the residue. [PMID:19385636, PMID:24316985, PMID:27087541]', 2696, 0, 0);
INSERT INTO chado.cvterm VALUES (2431, 22, 'H2AZK4_acetylation_site', 'A kind of histone modification site, whereby the 4th residue (a lysine), from the start of the H2AZ histone protein is acetylated. [PMID:19385636, PMID:24316985, PMID:27087541]', 2697, 0, 0);
INSERT INTO chado.cvterm VALUES (2432, 22, 'H2AZK7_acetylation_site', 'A kind of histone modification site, whereby the 7th residue (a lysine), from the start of the H2AZ histone protein is acetylated. [PMID:19385636, PMID:24316985, PMID:27087541]', 2698, 0, 0);
INSERT INTO chado.cvterm VALUES (2433, 22, 'H2AZK11_acetylation_site', 'A kind of histone modification site, whereby the 11th residue (a lysine), from the start of the H2AZ histone protein is acetylated. [PMID:19385636, PMID:24316985, PMID:27087541]', 2699, 0, 0);
INSERT INTO chado.cvterm VALUES (2434, 22, 'H2AZK13_acetylation_site', 'A kind of histone modification site, whereby the 13th residue (a lysine), from the start of the H2AZ histone protein is acetylated. [PMID:19385636, PMID:24316985, PMID:27087541]', 2700, 0, 0);
INSERT INTO chado.cvterm VALUES (2435, 22, 'H2AZK15_acetylation_site', 'A kind of histone modification site, whereby the 15th residue (a lysine), from the start of the H2AZ histone protein is acetylated. [PMID:19385636, PMID:24316985, PMID:27087541]', 2701, 0, 0);
INSERT INTO chado.cvterm VALUES (2436, 22, 'AUG_initiated_uORF', 'A uORF beginning with the canonical start codon AUG. [PMID:26684391, PMID:27313038]', 2702, 0, 0);
INSERT INTO chado.cvterm VALUES (2437, 22, 'non_AUG_initiated_uORF', 'A uORF beginning with a codon other than AUG. [PMID:26684391, PMID:27313038]', 2703, 0, 0);
INSERT INTO chado.cvterm VALUES (2438, 22, 'genic_downstream_transcript_variant', 'A variant that falls downstream of a transcript, but within the genic region of the gene due to alternately transcribed isoforms. [NCBI:dm, SO:ke]', 2704, 0, 0);
INSERT INTO chado.cvterm VALUES (2439, 22, 'genic_upstream_transcript_variant', 'A variant that falls upstream of a transcript, but within the genic region of the gene due to alternately transcribed isoforms. [NCBI:dm, SO:ke]', 2705, 0, 0);
INSERT INTO chado.cvterm VALUES (2440, 22, 'mitotic_recombination_region', 'A genomic region where there is an exchange of genetic material with another genomic region, occurring in somatic cells. [NCBI:cf, SO:ke]', 2706, 0, 0);
INSERT INTO chado.cvterm VALUES (2441, 22, 'meiotic_recombination_region', 'A genomic region in which there is an exchange of genetic material as a result of the repair of meiosis-specific double strand breaks that occur during meiotic prophase. [NCBI:cf, SO:ke]', 2707, 0, 0);
INSERT INTO chado.cvterm VALUES (2442, 22, 'CArG_box', 'A promoter element bound by the MADS family of transcription factors with consensus 5''-(C/T)TA(T/A)4TA(G/A)-3''. [PMID:1748287, PMID:7623803]', 2708, 0, 0);
INSERT INTO chado.cvterm VALUES (2443, 22, 'Mat2P', 'A gene cassette array containing H+ mating type specific information. [PMID:18354497]', 2709, 0, 0);
INSERT INTO chado.cvterm VALUES (2444, 22, 'Mat3M', 'A gene cassette array containing H- mating type specific information. [PMID:18354497]', 2710, 0, 0);
INSERT INTO chado.cvterm VALUES (2445, 22, 'SHP_box', 'A conserved Cdc48/p97 interaction motif with strict consensus sequence F[PI]GKG[TK][RK]LG[GT] and relaxed consensus sequence FXGKGX[RK]LG. [PMID:17083136, PMID:27655872]', 2711, 0, 0);
INSERT INTO chado.cvterm VALUES (2446, 22, 'short_tandem_repeat_change', 'A sequence variant where the copies of a short tandem repeat (STR) feature are either contracted or expanded. []', 2712, 0, 0);
INSERT INTO chado.cvterm VALUES (2447, 22, 'short_tandem_repeat_expansion', 'A short tandem repeat variant containing more repeat units than the reference sequence. []', 2713, 0, 0);
INSERT INTO chado.cvterm VALUES (2448, 22, 'short_tandem_repeat_contraction', 'A short tandem repeat variant containing fewer repeat units than the reference sequence. []', 2714, 0, 0);
INSERT INTO chado.cvterm VALUES (2449, 22, 'H2BK5_acetylation_site', 'A kind of histone modification site, whereby the 5th residue (a lysine), from the start of the H2B histone protein is acetylated. [http://www.actrec.gov.in/histome/ptm_sp.php?ptm_sp=H2BK5ac, PMID:18552846]', 2715, 0, 0);
INSERT INTO chado.cvterm VALUES (2450, 22, 'trinucleotide_repeat_expansion', 'A short tandem repeat expansion with an increase in a sequence of three nucleotide units repeated in tandem compared to a reference sequence. []', 2716, 0, 0);
INSERT INTO chado.cvterm VALUES (2451, 22, 'ref_miRNA', 'A ref_miRNA (RefSeq-miRNA) sequence is assigned at the creation of a new mature miRNA entry in a database. The ref_miRNA sequence designation remains unchanged even if a different isomiR is later shown to be expressed at a higher level. A ref_miRNA can be produced by one or multiple pre-miRNA. [PMID:26453491]', 2717, 0, 0);
INSERT INTO chado.cvterm VALUES (2452, 22, 'isomiR', 'IsomiRs are all the bona fide variants of a mature product. IsomiRs should be connected to the ref_miRNA it is most likely to be the variant of. Some isomiRs can be variations of one or multiple ref_miRNA. [PMID:26453491]', 2718, 0, 0);
INSERT INTO chado.cvterm VALUES (2453, 22, 'RNA_thermometer', 'An RNA_thermometer is a cis element in the 5'' end of an mRNA that can change its secondary structure in response to temperature and coordinate temperature-dependent gene expression. [PMID:22421878]', 2719, 0, 0);
INSERT INTO chado.cvterm VALUES (2454, 22, 'splice_polypyrimidine_tract_variant', 'A sequence variant that falls in the polypyrimidine tract at 3'' end of intron between 17 and 3 bases from the end (acceptor -3 to acceptor -17). []', 2721, 0, 0);
INSERT INTO chado.cvterm VALUES (2455, 22, 'splice_donor_region_variant', 'A sequence variant that falls in the region between the 3rd and 6th base after splice junction (5'' end of intron). []', 2722, 0, 0);
INSERT INTO chado.cvterm VALUES (2456, 22, 'telomeric_D_loop', 'A telomeric D-loop is a three-stranded DNA displacement loop that forms at the site where the telomeric 3'' single-stranded DNA overhang (formed of the repeat sequence TTAGGG in mammals) is tucked back inside the double-stranded component of telomeric DNA molecule, thus forming a t-loop or telomeric-loop and protecting the chromosome terminus. [PMID:10338204, PMID:15071557, PMID:24012755]', 2723, 0, 0);
INSERT INTO chado.cvterm VALUES (2457, 22, 'sequence_alteration_artifact', 'A sequence_alteration where the source of the alteration is due to an artifact in the base-calling or assembly process. []', 2724, 0, 0);
INSERT INTO chado.cvterm VALUES (2458, 22, 'indel_artifact', 'An indel that is the result of base-calling or assembly error. []', 2725, 0, 0);
INSERT INTO chado.cvterm VALUES (2459, 22, 'deletion_artifact', 'A deletion that is the result of base-calling or assembly error. []', 2726, 0, 0);
INSERT INTO chado.cvterm VALUES (2460, 22, 'insertion_artifact', 'An insertion that is the result of base-calling or assembly error. []', 2727, 0, 0);
INSERT INTO chado.cvterm VALUES (2461, 22, 'substitution_artifact', 'A substitution that is the result of base-calling or assembly error. []', 2728, 0, 0);
INSERT INTO chado.cvterm VALUES (2462, 22, 'duplication_artifact', 'A duplication that is the result of base-calling or assembly error. []', 2729, 0, 0);
INSERT INTO chado.cvterm VALUES (2463, 22, 'SNV_artifact', 'An SNV that is the result of base-calling or assembly error. []', 2730, 0, 0);
INSERT INTO chado.cvterm VALUES (2464, 22, 'MNV_artifact', 'An MNV that is the result of base-calling or assembly error. []', 2731, 0, 0);
INSERT INTO chado.cvterm VALUES (2465, 22, 'ribozyme_gene', 'A gene that encodes a ribozyme. []', 2732, 0, 0);
INSERT INTO chado.cvterm VALUES (2466, 22, 'antisense_lncRNA_gene', 'A gene that encodes an antisense long, non-coding RNA. []', 2733, 0, 0);
INSERT INTO chado.cvterm VALUES (2467, 22, 'sense_overlap_lncRNA_gene', 'A gene that encodes a sense overlap long non-coding RNA. []', 2734, 0, 0);
INSERT INTO chado.cvterm VALUES (2468, 22, 'sense_intronic_lncRNA_gene', 'A gene that encodes a sense intronic long non-coding RNA. []', 2735, 0, 0);
INSERT INTO chado.cvterm VALUES (2469, 22, 'bidirectional_promoter_lncRNA_gene', 'A non-coding locus that originates from within the promoter region of a protein-coding gene, with transcription proceeding in the opposite direction on the other strand. [https://www.gencodegenes.org/pages/biotypes.html]', 2736, 0, 0);
INSERT INTO chado.cvterm VALUES (2470, 22, 'mutational_hotspot', 'A region of genomic sequence known to undergo mutational events with greater frequency than expected by chance. []', 2737, 0, 0);
INSERT INTO chado.cvterm VALUES (2471, 22, 'HERV_insertion', 'An insertion of sequence from the HERV family of mobile elements with respect to a reference. [NCBI:th]', 2738, 0, 0);
INSERT INTO chado.cvterm VALUES (2472, 22, 'functional_gene_region', 'A gene_member_region that encodes sequence that directly contributes to the molecular function of its gene or gene product. [Clingen:mb]', 2739, 0, 0);
INSERT INTO chado.cvterm VALUES (2473, 22, 'allelic_pseudogene', 'A (unitary) pseudogene that is stable in the population but importantly it has a functional alternative allele also in the population. i.e., one strain may have the gene, another strain may have the pseudogene. MHC haplotypes have allelic pseudogenes. []', 2740, 0, 0);
INSERT INTO chado.cvterm VALUES (2474, 22, 'enhancer_blocking_element', 'A transcriptional cis regulatory region that when located between an enhancer and a gene''s promoter prevents the enhancer from modulating the expression of the gene. Sometimes referred to as an insulator but may not include the barrier function of an insulator. [NCBI:cf]', 2741, 0, 0);
INSERT INTO chado.cvterm VALUES (2475, 22, 'imprinting_control_region', 'A regulatory region that controls epigenetic imprinting and affects the expression of target genes in an allele- or parent-of-origin-specific manner. Associated regulatory elements may include differentially methylated regions and non-coding RNAs. []', 2742, 0, 0);
INSERT INTO chado.cvterm VALUES (2476, 22, 'flanking_repeat', 'A repeat lying outside the sequence for which it has functional significance (eg. transposon insertion target sites). []', 2743, 0, 0);
INSERT INTO chado.cvterm VALUES (2477, 22, 'processed_pseudogenic_rRNA', 'The pseudogene has arisen by reverse transcription of a mRNA into cDNA, followed by reintegration into the genome. Therefore, it has lost any intron/exon structure, and it might have a pseudo-polyA-tail. []', 2744, 0, 0);
INSERT INTO chado.cvterm VALUES (2478, 22, 'unprocessed_pseudogenic_rRNA', 'The pseudogene has arisen from a copy of the parent gene by duplication followed by accumulation of random mutation. The changes, compared to their functional homolog, include insertions, deletions, premature stop codons, frameshifts and a higher proportion of non-synonymous versus synonymous substitutions. []', 2745, 0, 0);
INSERT INTO chado.cvterm VALUES (2479, 22, 'unitary_pseudogenic_rRNA', 'The pseudogene has no parent. It is the original gene, which is functional in some species but disrupted in some way (indels, mutation, recombination) in another species or strain. []', 2746, 0, 0);
INSERT INTO chado.cvterm VALUES (2480, 22, 'allelic_pseudogenic_rRNA', 'A (unitary) pseudogene that is stable in the population but importantly it has a functional alternative allele also in the population. i.e., one strain may have the gene, another strain may have the pseudogene. MHC haplotypes have allelic pseudogenes. []', 2747, 0, 0);
INSERT INTO chado.cvterm VALUES (2481, 22, 'processed_pseudogenic_tRNA', 'The pseudogene has arisen by reverse transcription of a mRNA into cDNA, followed by reintegration into the genome. Therefore, it has lost any intron/exon structure, and it might have a pseudo-polyA-tail. []', 2748, 0, 0);
INSERT INTO chado.cvterm VALUES (2482, 22, 'unprocessed_pseudogenic_tRNA', 'The pseudogene has arisen from a copy of the parent gene by duplication followed by accumulation of random mutation. The changes, compared to their functional homolog, include insertions, deletions, premature stop codons, frameshifts and a higher proportion of non-synonymous versus synonymous substitutions. []', 2749, 0, 0);
INSERT INTO chado.cvterm VALUES (2483, 22, 'unitary_pseudogenic_tRNA', 'The pseudogene has no parent. It is the original gene, which is functional in some species but disrupted in some way (indels, mutation, recombination) in another species or strain. []', 2750, 0, 0);
INSERT INTO chado.cvterm VALUES (2484, 22, 'allelic_pseudogenic_tRNA', 'A (unitary) pseudogene that is stable in the population but importantly it has a functional alternative allele also in the population. i.e., one strain may have the gene, another strain may have the pseudogene. MHC haplotypes have allelic pseudogenes. []', 2751, 0, 0);
INSERT INTO chado.cvterm VALUES (2485, 22, 'terminal_repeat', 'A repeat at the ends of and within the sequence for which it has functional significance other than long terminal repeat. []', 2752, 0, 0);
INSERT INTO chado.cvterm VALUES (2486, 22, 'repeat_instability_region', 'A repeat region that is prone to expansions and/or contractions. []', 2753, 0, 0);
INSERT INTO chado.cvterm VALUES (2487, 22, 'replication_start_site', 'A nucleotide site from which replication initiates. [NCBI:cf]', 2754, 0, 0);
INSERT INTO chado.cvterm VALUES (2488, 22, 'response_element', 'A regulatory element that acts in response to a stimulus, usually via transcription factor binding. []', 2755, 0, 0);
INSERT INTO chado.cvterm VALUES (2489, 22, 'sequence_source', 'Identifies the biological source of the specified span of the sequence [NCBI:tm]', 2756, 0, 0);
INSERT INTO chado.cvterm VALUES (2490, 22, 'UNAAAC_motif', 'A hexameric RNA motif consisting of nucleotides UNAAAC (where N can be any nucleotide) that targets the RNA for degradation. [PMID:22645662, PMID:28765164, PomBase:al]', 2757, 0, 0);
INSERT INTO chado.cvterm VALUES (2491, 22, 'long_terminal_repeat_transcript', 'An RNA that is transcribed from a long terminal repeat. [PMID:24256266, PomBase:mh]', 2758, 0, 0);
INSERT INTO chado.cvterm VALUES (2492, 22, 'genomic_DNA_contig', 'A contig composed of genomic DNA derived sequences. [BCS:etrwz]', 2759, 0, 0);
INSERT INTO chado.cvterm VALUES (2493, 22, 'presence_absence_variation', 'A variation qualifying the presence of a sequence in a genome which is entirely missing in another genome. [BCS:bbean, PMID:19956538, PMID:25881062]', 2760, 0, 0);
INSERT INTO chado.cvterm VALUES (2494, 22, 'circular_plasmid', 'A self replicating circular nucleic acid molecule that is distinct from a chromosome in the organism. [PMID:21719542, SBOL:jb]', 2761, 0, 0);
INSERT INTO chado.cvterm VALUES (2495, 22, 'linear_plasmid', 'A self replicating linear nucleic acid molecule that is distinct from a chromosome in the organism. They are capped by terminal proteins covalently bound to the 5'' ends of the DNA. [PMID:21719542, SBOL:jb]', 2762, 0, 0);
INSERT INTO chado.cvterm VALUES (2496, 22, 'transcription_termination_signal', 'Termination signal preferentially observed downstream of polyadenylation signal [PMID:28367989]', 2763, 0, 0);
INSERT INTO chado.cvterm VALUES (2497, 22, 'redundant_inserted_stop_gained', 'A sequence variant whereby at least one base of a codon is changed, resulting in a stop codon inserted next to an existing stop codon. This leads to a polypeptide of the same length. []', 2764, 0, 0);
INSERT INTO chado.cvterm VALUES (2498, 22, 'Zas1_recognition_motif', 'A DNA motif to which the S. pombe Zas1 protein binds. The consensus sequence is 5''-(Y)CCCCAY-3''. [PMID:29735745, PomBase:vw]', 2765, 0, 0);
INSERT INTO chado.cvterm VALUES (2499, 22, 'Pho7_binding_site', 'A promoter element with consensus sequence [5''-TCG(G/C)(A/T)xxTTxAA], bound by the transcription factor Pho7. [PMID:28811350]', 2766, 0, 0);
INSERT INTO chado.cvterm VALUES (2500, 22, 'unspecified_indel', 'A sequence alteration which includes an insertion or a deletion. This describes a sequence length change when the direction of the change is unspecified or when such changes are pooled into one category. [ZFIN:st]', 2767, 0, 0);
INSERT INTO chado.cvterm VALUES (2501, 22, 'functionally_normal', 'A sequence variant in which the function of a gene product is retained with respect to a reference. []', 2768, 0, 0);
INSERT INTO chado.cvterm VALUES (2502, 22, 'function_uncertain_variant', 'A sequence variant in which the function of a gene product is unknown with respect to a reference. []', 2769, 0, 0);
INSERT INTO chado.cvterm VALUES (2503, 22, 'inert_DNA_spacer', 'Sequences that decrease interactions between biological regions, such as between a promoter, its 5'' context and/or the translational unit(s) it regulates. Spacers can affect regulation of translation, transcription, and other biological processes. [PMID:20843779, PMID:24933158, PMID:27034378, PMID:28422998]', 2770, 0, 0);
INSERT INTO chado.cvterm VALUES (2504, 22, '2A_self_cleaving_peptide_region', 'A region that codes for a 2A self-cleaving polypeptide region, which is a region that can result in a break in the peptide sequence at its terminal G-P junction. [PMID:22301656, PMID:28526819]', 2772, 0, 0);
INSERT INTO chado.cvterm VALUES (2505, 22, 'LOZ1_response_element', 'A conserved sequence (5''-CGNMGATCNTY-3'') transcription repressor binding site required for gene repression in the presence of high zinc. []', 2773, 0, 0);
INSERT INTO chado.cvterm VALUES (2506, 22, 'group_IIC_intron', 'A group II intron that recognizes IBS1/EBS1 for the 5-prime exon and IBS3/EBS3 for the 3-prime exon and may also recognize a stem-loop in the RNA. [PMID:20463000]', 2774, 0, 0);
INSERT INTO chado.cvterm VALUES (2507, 22, 'CDS_extension', 'A sequence variant extending the CDS, that causes elongation of the resulting polypeptide sequence. [PMID:14732127, PMID:15864293, PMID:27984720, PMID:31216041, PMID:32020195]', 2775, 0, 0);
INSERT INTO chado.cvterm VALUES (2508, 22, 'CAAX_box', 'A C-terminus protein motif (CAAX) serving as a post-translational prenylation site modified by the attachment of either a farnesyl or a geranyl-geranyl group to a cysteine residue. Farnesyltransferase recognizes CaaX boxes where X = M, S, Q, A, or C, whereas Geranylgeranyltransferase I recognizes CaaX boxes with X = L or E. []', 2776, 0, 0);
INSERT INTO chado.cvterm VALUES (2509, 22, 'self_cleaving_ribozyme', 'An RNA that catalyzes its own cleavage. []', 2777, 0, 0);
INSERT INTO chado.cvterm VALUES (2510, 22, 'selection_marker', 'A genetic feature that encodes a trait used for artificial selection of a subpopulation. []', 2778, 0, 0);
INSERT INTO chado.cvterm VALUES (2511, 22, 'homologous_chromosome_recognition_and_pairing_locus', 'A chromosomal locus where complementary lncRNA and associated proteins accumulate at the corresponding lncRNA gene loci to tether homologous chromosome during chromosome pairing at meiosis I. [PMID:22582262, PMID:31811152]', 2779, 0, 0);
INSERT INTO chado.cvterm VALUES (2512, 22, 'pumilio_response_element', 'A cis-acting element involved in RNA stability found in the 3'' UTR of some RNA (consensus UGUAAAUA). [PMID:30601114]', 2780, 0, 0);
INSERT INTO chado.cvterm VALUES (2513, 22, 'SUMO_interaction_motif', 'A polypeptide region that mediates binding to SUMO. The motif contains a hydrophobic core sequence consisting of three or four Ile, Leu, or Val residues plus one acidic or polar residue at position 2 or 3. [PMID:15388847\,PMID\:16524884]', 2781, 0, 0);
INSERT INTO chado.cvterm VALUES (2514, 22, 'cytosolic_SSU_rRNA_gene', 'A gene that codes for cytosolic SSU rRNA. []', 2782, 0, 0);
INSERT INTO chado.cvterm VALUES (2515, 22, 'cytosolic_LSU_rRNA_gene', 'A gene that codes for cytosolic LSU rRNA. []', 2783, 0, 0);
INSERT INTO chado.cvterm VALUES (2516, 22, 'rRNA_21S_gene', 'A gene which codes for 21S_rRNA, which functions as a component of the large subunit of the ribosome in mitochondria. []', 2784, 1, 0);
INSERT INTO chado.cvterm VALUES (2517, 22, 'partially_duplicated_transcript', 'A transcript which is partially duplicated due to duplication of DNA, leading to a new transcript that is only partial and likely nonfunctional. []', 2785, 0, 0);
INSERT INTO chado.cvterm VALUES (2518, 22, 'five_prime_duplicated_transcript', 'A partially_duplicated_transcript where the 5'' end of the transcript is duplicated. []', 2786, 0, 0);
INSERT INTO chado.cvterm VALUES (2519, 22, 'three_prime_duplicated_transcript', 'A partially_duplicated_transcript where the 3'' end of the transcript is duplicated. []', 2787, 0, 0);
INSERT INTO chado.cvterm VALUES (2520, 22, 'spurious_protein', 'A region of DNA that is predicted to be translated and transcribed into a protein by a protein detection algorithm that does not get transcribed in nature. [PMID:21771858]', 2788, 0, 0);
INSERT INTO chado.cvterm VALUES (2521, 22, 'stem_loop_region', 'A portion of a stem loop secondary structure in RNA. []', 2789, 0, 0);
INSERT INTO chado.cvterm VALUES (2522, 22, 'loop', 'The loop portion of a stem loop, which is not folded back upon itself.  []', 2790, 0, 0);
INSERT INTO chado.cvterm VALUES (2523, 22, 'stem', 'The portion of a stem loop where the RNA is folded back upon itself.  []', 2791, 0, 0);
INSERT INTO chado.cvterm VALUES (2524, 22, 'non_complimentary_stem', 'A region of a stem in a stem loop structure where the sequences are non-complimentary. []', 2792, 0, 0);
INSERT INTO chado.cvterm VALUES (2525, 22, 'knob', 'Cytologically observable heterochromatic regions of chromosomes away from centromeres that contain predominatly large tandem repeats and retrotransposons. [PMID:6439888]', 2793, 0, 0);
INSERT INTO chado.cvterm VALUES (2526, 22, 'teb1_recognition_motif', 'A binding motif with the consensus sequence TTAGGG to which Teb1 binds. [PMID:23314747, PMID:27901072]', 2794, 0, 0);
INSERT INTO chado.cvterm VALUES (2527, 22, 'polyA_site_cluster', 'A region defined by a cluster of experimentally determined polyadenylation sites, typically less than 25 bp in length and associated with a single polyadenylation signal. [PMID:17202160, PMID:24072873, PMID:25906188]', 2795, 0, 0);
INSERT INTO chado.cvterm VALUES (2528, 22, 'LARD', 'Large Retrotransposon Derivative elements are long-terminal repeats that contain reverse transcriptase priming sites and are conserved in sequence but contain no open reading frames encoding typical retrotransposon proteins . The LARDs identified in barley and other Triticeae have LTRs ~5.5 kb and an interal domain of ~3.5 kb. LARDs lack coding domains and thus do not encode proteins. [PMID:15082561]', 2796, 0, 0);
INSERT INTO chado.cvterm VALUES (2529, 22, 'TRIM', 'TRIM elements have terminal direct repeat sequences of 100-250 bp in length that flank an internal domain of 100300 bp. TRIMs lack coding domains and thus do not encode proteins. [PMID:11717436]', 2797, 0, 0);
INSERT INTO chado.cvterm VALUES (2530, 22, 'Watson_strand', 'An absolute reference to the strand. When a chromosome has p and q arms, the Watson strand is the strand whose 5''-end is on the short arm of the chromosome. Of note, the term ''plus strand'' is typically based on a reference sequence where it''s preferred for the plus strand to be the Watson strand, but might not be and ''plus strand'' is therefore not an exact synonym. [PMID:21303550]', 2798, 0, 0);
INSERT INTO chado.cvterm VALUES (2615, 22, 'sbRNA', 'A small non-coding stem-loop RNA present in nematodes and insects, functionally and structurally related to vertebrate Y RNA. [PMID:25908866, PMID:30666901]', 2886, 0, 0);
INSERT INTO chado.cvterm VALUES (2616, 22, 'hpRNA_gene', 'A gene encoding a hpRNA. [PMID:18463630, PMID:18719707, PMID:25544562]', 2887, 0, 0);
INSERT INTO chado.cvterm VALUES (2531, 22, 'Crick_strand', 'An absolute reference to the strand. When a chromosome has p and q arms, the Crick strand is the strand whose 5''-end is on the long arm of the chromosome. Of note, the term ''minus strand'' is typically based on a reference sequence where it''s preferred for the minus strand to be the Crick strand, but might not be and ''minus strand'' is therefore not an exact synonym. [PMID:21303550]', 2799, 0, 0);
INSERT INTO chado.cvterm VALUES (2532, 22, 'Copia_LTR_retrotransposon', 'LTR retrotransposons in the Copia superfamily contain elements coding for specific proteins in this order: GAG, AP, INT, RT, RH. GAG is a structural protein for virus-like particles. AP is aspartic proteinase. INT is a DDE integrase. RT is a reverse transcriptase. RH is RNAse H. [PMID:17984973]', 2800, 0, 0);
INSERT INTO chado.cvterm VALUES (2533, 22, 'Gypsy_LTR_retrotransposon', 'LTR retrotransposons in the Gypsy superfamily contain elements coding for specific proteins in this order: GAG, AP, RT, RH, INT. GAG is a structural protein for virus-like particles. AP is aspartic proteinase. INT is a DDE integrase. RT is a reverse transcriptase. RH is RNAse H. [PMID:17984973]', 2801, 0, 0);
INSERT INTO chado.cvterm VALUES (2534, 22, 'Bel_Pao_LTR_retrotransposon', 'LTR retrotransposons in the Bel-Pao superfamily are similar to LTRs in the Gypsy and Retrovirus superfamilies. Mainly described in metazoan genomes, this superfamily contain elements coding for specific proteins in this order: GAG, AP, RT, RH and INT. GAG is a structural protein for virus-like particles. AP is aspartic proteinase. INT is a DDE integrase. RT is a reverse transcriptase. RH is RNAse H. [PMID:17984973]', 2802, 0, 0);
INSERT INTO chado.cvterm VALUES (2535, 22, 'Retrovirus_LTR_retrotransposon', 'LTR retrotransposons in the retrovirus superfamily are similar to LTR retrotransposons in the Gypsy and Bel-Pao superfamilies. Mainly described in vertebrate animals, this superfamily contain elements coding for specific proteins in this order: GAG, AP, RT, RH, INT, and ENV. GAG is a structural protein for virus-like particles. AP is aspartic proteinase. INT is a DDE integrase. RT is a reverse transcriptase. RH is RNAse H. ENV is envelop protein. [PMID:17984973]', 2803, 0, 0);
INSERT INTO chado.cvterm VALUES (2536, 22, 'R2_LINE_retrotransposon', 'R2 retrotransposons are LINE elements (SO:0000194) that insert site-specifically into the host organism''s 28S ribosomal RNA (rRNA) genes. [PMID:21734471]', 2804, 0, 0);
INSERT INTO chado.cvterm VALUES (2537, 22, 'RTE_LINE_retrotransposon', 'RTE retrotransposons are LINE elements (SO:0000194) that contain a domain with homology to the apurinic-apyrimidic (AP) endonucleases in addition to the previously identified reverse transcriptase domain. [PMID:9729877]', 2805, 0, 0);
INSERT INTO chado.cvterm VALUES (2538, 22, 'Jockey_LINE_retrotransposon', 'Jockey retrotransposons are LINE elements (SO:0000194) found only in arthropods. The full-length element is ~5kb and contains two open reading frames (SO:0000236), ORF1 (568 aa) and ORF2 (916 aa), the second of which encodes an apurinic endonuclease (APE) and a reverse transcriptase (RT). [PMID:31709017]', 2806, 0, 0);
INSERT INTO chado.cvterm VALUES (2539, 22, 'I_LINE_retrotransposon', 'Elements of the LINE I superfamily are similar to the Jockey and L1 superfamily. They contains two ORFs, the.second of which includes Apurinic endonuclease (APE) and reverse transcriptase (RT). The I superfamily encodes an RH (RNase H) domain downstream of the RT domain. []', 2807, 0, 0);
INSERT INTO chado.cvterm VALUES (2540, 22, 'tRNA_SINE_retrotransposon', 'Short interspersed elements that originated from tRNAs. [PMID:21673742]', 2809, 0, 0);
INSERT INTO chado.cvterm VALUES (2541, 22, '7SL_SINE_retrotransposon', 'Short interspersed elements that originated from 7SL RNAs. [PMID:21673742]', 2810, 0, 0);
INSERT INTO chado.cvterm VALUES (2542, 22, '5S_SINE_retrotransposon', 'Short interspersed elements that originated from 5S rRNAs. [PMID:21673742]', 2811, 0, 0);
INSERT INTO chado.cvterm VALUES (2543, 22, 'Crypton_YR_transposon', 'Crypton is a superfamily of DNA transposons that use tyrosine recombinase (YR) to cut and rejoin the recombining DNA molecules. [PMID:22011512]', 2812, 0, 0);
INSERT INTO chado.cvterm VALUES (2544, 22, 'Tc1_Mariner_TIR_transposon', 'Elements of the Tc1-Mariner terminal inverted repeat transposon superfamily (also called mariner transposons) are named after the Transponon of C. elegans number 1 transposasse. Their activity creates a 2-bp (TA) target-site duplication (TSD). Stowaway is the non-autonomous element in this superfamily usually shorter than 600 bp. [PMID:17984973, PMID:8556864]', 2813, 0, 0);
INSERT INTO chado.cvterm VALUES (2545, 22, 'hAT_TIR_transposon', 'The hAT terminal inverted repeat transposon superfamily elements were first found in maize (the Ac/Ds elements). Members of the hAT superfamily have TSDs of 8 bp, relatively short TIRs of 527 bp and overall lengths of less than 4 kb. [PMID:11454746]', 2814, 0, 0);
INSERT INTO chado.cvterm VALUES (2546, 22, 'Mutator_TIR_transposon', 'Members of the Mutator family of terminal inverted repeat (TIR) transposon are usually long but are also highly divergent, either sharing only terminal GC nucleotides, or with the GC nucleotides absent. The length of the TSD (7-11 bp, usually 9 bp) remains probably the most useful criterion for identification. [PMID:17984973]', 2815, 0, 0);
INSERT INTO chado.cvterm VALUES (2547, 22, 'Merlin_TIR_transposon', 'Terminal inverted repeat transposon superfamily Merlin elements create 8-9 bp target-site duplications (TSD). [PMID:17984973]', 2816, 0, 0);
INSERT INTO chado.cvterm VALUES (2548, 22, 'Transib_TIR_transposon', 'Terminal inverted repeat (TIR) transposons of the superfamily Transib contain the DDE motif, which is related to the RAG1 protein involved in V(D)J recombination. [PMID:17984973]', 2817, 0, 0);
INSERT INTO chado.cvterm VALUES (2549, 22, 'piggyBac_TIR_transposon', 'Primarily found in animals, the terminal inverted repeat (TIR) transposon superfamily piggyBac elements favour insertion adjacent to TTAA. [PMID:17984973]', 2818, 0, 0);
INSERT INTO chado.cvterm VALUES (2550, 22, 'PIF_Harbinger_TIR_transposon', 'Terminal inverted repeat transposons in the PIF/Harbinger/tourist superfamily create 3-bp target site duplication that are mainly ''TAA'' or ''TTA''. The autonomous PIF-Harbinger elements are relatively small in size, usually a few kb in length. Non-autonomous elements in this superfamily usually shorter than 600 bp are referrred to as Tourist elements. The terminal sequences for PIF/Harbinger/Tourist elements are ''GGG/CCCGGC/GCC'' or ''GA/GGCATGCC/TC''. [PMID:26709091]', 2819, 0, 0);
INSERT INTO chado.cvterm VALUES (2551, 22, 'CACTA_TIR_transposon', 'This terminal inverted repeat of the CACTA family generate 3-bp target site duplication (TSD) upon insertion. CACTA elements do not have a significant preference for genic region insertions. This terminal inverted repeat (TIR) transposon superfamily is named CACTA because their terminal sequences are ''CACTA/GC/TAGTG''. [PMID:26709091]', 2820, 0, 0);
INSERT INTO chado.cvterm VALUES (2552, 22, 'YR_retrotransposon', 'Tyrosine Kinase (YR) retrotransposons are a subclass of non-LTR retrotransposons. These YR-encoding elements consist of central gag, pol and tyrosine recombinase (YR) open reading frames (ORFs) flanked with terminal repeat. The pol ORF includes a reverse transcriptase (RT), a RNase H (RH) and, in case of DIRS, a domain similar to bacterial and phage DNA N-6-adenine-methyltransferase (MT). Compared to the retroviral pol (LTR retrotransposons, non-LTR retrotransposons and Penelope elements), both aspartic protease and DDE integrase are absent from YR retrotransposons. YR retrotransposons have inverted terminal repeats (ITRs). [PMID:24086727]', 2821, 0, 0);
INSERT INTO chado.cvterm VALUES (2553, 22, 'DIRS_YR_retrotransposon', 'Dictyostelium intermediate repeat sequence (DIRS) retrotransposons are members of the YR_retrotransposon (SO:0002286) superfamily with the following protein domains: RT, RH, YR, and MT. RT is a reverse transcriptase. RH is RNAse H. YR is tyrosine recombinase. MT is DNA N-6-adenine-methyltransferase. [PMID:24086727]', 2822, 0, 0);
INSERT INTO chado.cvterm VALUES (2554, 22, 'Ngaro_YR_retrotransposon', 'Ngaro retrotransposons are members of the YR_retrotransposon (SO:0002286) superfamily with the following protein domains: RT, RH, YR. RT is a reverse transcriptase. RH is RNAse H. YR is Tyrosine recombinase. Inverted terminal repeats (ITRs) in Ngaro are arranged in A-pol-B-A-B order where A and B represent ITRs. [PMID:24086727]', 2823, 0, 0);
INSERT INTO chado.cvterm VALUES (2555, 22, 'Viper_YR_retrotransposon', 'VIPER retrotransposons are members of the YR_retrotransposon (SO:0002286 superfamily with protein domains: RT, RH, YR. RT is a reverse transcriptase. RH is RNAse H. YR is Tyrosine recombinase. Inverted terminal repeats (ITRs) in VIPER are arranged in A-pol-B-A-B order where A and B represent ITRs. VIPER is only found in kinetoplastida genomes. [PMID:16297462]', 2824, 0, 0);
INSERT INTO chado.cvterm VALUES (2556, 22, 'Penelope_retrotransposon', 'Penelope is a subclass of non_LTR_retrotransposons (SO:0000189). Penelope retrotransposons contains structural features of TR, RT, EN, TR, terminal repeats which can be in tandem or inverse orientation in different Penelope copies. RT is reverse transcriptase. EN is endonuclease. [PMID:23914310]', 2825, 0, 0);
INSERT INTO chado.cvterm VALUES (2557, 22, 'circular_ncRNA', 'A non-coding RNA that is generated by backsplicing of exons or introns, resulting in a covalently closed loop without a 5 cap or 3 polyA tail. [PMID:29086764, PMID:29182528, PMID:29230098, PMID:29576969, PMID:29626935]', 2826, 0, 0);
INSERT INTO chado.cvterm VALUES (2558, 22, 'circular_mRNA', 'An mRNA that is generated by backsplicing of exons or introns, resulting in a covalently closed loop without a 5 cap or 3 polyA tail. [PMID:29086764, PMID:29182528, PMID:29576969]', 2827, 0, 0);
INSERT INTO chado.cvterm VALUES (2559, 22, 'mitochondrial_control_region', 'The non-coding region of the mitochondrial genome that controls RNA and DNA synthesis. [PMID: 19407924, PMID:10968878]', 2828, 0, 0);
INSERT INTO chado.cvterm VALUES (2560, 22, 'mitochondrial_D_loop', 'Mitochondrial displacement loop; a region within mitochondrial DNA in which a short stretch of RNA is paired with one strand of DNA, displacing the original partner DNA strand in this region. [http://www.insdc.org/files/feature_table.html]', 2830, 0, 0);
INSERT INTO chado.cvterm VALUES (2561, 22, 'transcription_factor_regulatory_site', 'A TF_binding_site that is involved in regulation of expression. [Bacterial_regulation_working_group:CMA, PMID:32665585]', 2831, 0, 0);
INSERT INTO chado.cvterm VALUES (2562, 22, 'TFRS_module', 'The possible discontinuous stretch of DNA that is the combination of one or several TFRSs whose bound TFs work jointly in the regulation of a promoter.  [Bacterial_regulation_working_group:CMA, PMID:32665585]', 2832, 0, 0);
INSERT INTO chado.cvterm VALUES (2563, 22, 'TFRS_collection', 'The possible discontinous stretch of DNA that encompass all the TFRSs that regulate a promoter. [Bacterial_regulation_working_group:CMA, PMID:32665585]', 2833, 0, 0);
INSERT INTO chado.cvterm VALUES (2564, 22, 'simple_operon', 'An operon whose transcription is coordinated on a single transcription unit. [Bacterial_regulation_working_group:CMA, PMID:32665585]', 2834, 0, 0);
INSERT INTO chado.cvterm VALUES (2565, 22, 'complex_operon', 'An operon whose transcription is coordinated on several mutually overlapping transcription units transcribed in the same direction and sharing at least one gene. [Bacterial_regulation_working_group:CMA, PMID:32665585]', 2835, 0, 0);
INSERT INTO chado.cvterm VALUES (2566, 22, 'transcription_unit', 'DNA regions delimited by different nonspurious TSS-TTS pairs. [Bacterial_regulation_working_group:CMA, PMID:32665585]', 2836, 0, 0);
INSERT INTO chado.cvterm VALUES (2567, 22, 'simple_regulon', 'A regulon defined by considering one regulatory gene product. [Bacterial_regulation_working_group:CMA, PMID:32665585]', 2837, 0, 0);
INSERT INTO chado.cvterm VALUES (2568, 22, 'regulon', 'A set of units of gene expression directly regulated by a common set of one or more common regulatory gene products. [ISBN:0198506732, PMID:32665585]', 2838, 0, 0);
INSERT INTO chado.cvterm VALUES (2569, 22, 'complex_regulon', 'A regulon defined by considering the units of expression regulated by a specified set of regulatory gene products. [Bacterial_regulation_working_group:CMA, PMID:32665585]', 2839, 0, 0);
INSERT INTO chado.cvterm VALUES (2570, 22, 'topologically_associated_domain', 'An instance of a self-interacting DNA region flanked by left and right TAD boundaries. [GREEKC:cl, PMID:32782014]', 2840, 0, 0);
INSERT INTO chado.cvterm VALUES (2571, 22, 'topologically_associated_domain_boundary', 'A DNA region enriched in DNA loop anchors and across which DNA loops occur less often than expected by chance. [GREEKC:cl, PMID:32782014]', 2841, 0, 0);
INSERT INTO chado.cvterm VALUES (2572, 22, 'chromatin_regulatory_region', 'A region of a chromosome where regulatory events occur, including epigenetic modifications. These epigenetic modifications can include nucleosome modifications and post-replicational DNA modifications. [GREEKC:cl, PMID:32782014]', 2842, 0, 0);
INSERT INTO chado.cvterm VALUES (2573, 22, 'DNA_loop', 'A region of DNA between two loop anchor positions that are held in close physical proximity. [GREEKC:cl, PMID:32782014]', 2843, 0, 0);
INSERT INTO chado.cvterm VALUES (2574, 22, 'DNA_loop_anchor', 'The ends of a DNA loop where the two strands of DNA are held in close physical proximity. During interphase the anchors of DNA loops are convergently oriented CTCF binding sites. [GREEKC:cl, PMID:32782014]', 2844, 0, 0);
INSERT INTO chado.cvterm VALUES (2575, 22, 'cryptic_promoter', 'The promoter of a cryptic gene. [GREEKC:cl]', 2845, 0, 0);
INSERT INTO chado.cvterm VALUES (2576, 22, 'core_prokaryotic_promoter_element', 'An element that always exists within the promoter region of a prokaryotic gene. [GREEKC:rl]', 2846, 0, 0);
INSERT INTO chado.cvterm VALUES (2577, 22, 'core_viral_promoter_element', 'An element that always exists within the promoter region of a viral gene. [GREEKC:rl]', 2847, 0, 0);
INSERT INTO chado.cvterm VALUES (2578, 22, 'altered_gene_product_level', 'A sequence variant that alters the level or amount of gene product produced. This high level term can be applied where the direction of level change (increased vs decreased gene product level) is unknown or not confirmed. [GenCC:AR]', 2848, 0, 0);
INSERT INTO chado.cvterm VALUES (2579, 22, 'increased_gene_product_level', 'A variant that increases the level or amount of gene product produced. [GenCC:AR]', 2849, 0, 0);
INSERT INTO chado.cvterm VALUES (2580, 22, 'decreased_gene_product_level', 'A sequence variant that decreases the level or amount of gene product produced. [GenCC:AR]', 2850, 0, 0);
INSERT INTO chado.cvterm VALUES (2581, 22, 'absent_gene_product', 'A sequence variant that results in no gene product. [GenCC:AR]', 2851, 0, 0);
INSERT INTO chado.cvterm VALUES (2582, 22, 'altered_gene_product_structure', 'A sequence variant that alters the structure of a gene product. [GenCC:AR]', 2852, 0, 0);
INSERT INTO chado.cvterm VALUES (2617, 22, 'hpRNA', 'An RNA comprising an extended inverted repeat, the stem of which is typically much longer than that of miRNA precursors and can be up to 400 base pairs in length. hpRNAs are processed by Dicer-2 to generate endogenous short interfering RNAs (siRNAs). [PMID:18463630, PMID:18719707, PMID:25544562]', 2888, 0, 0);
INSERT INTO chado.cvterm VALUES (2583, 22, 'NMD_triggering_variant', 'A sequence variant that leads to a change in the location of a termination codon in a transcript that leads to nonsense-mediated decay (NMD). The change in location of a termination codon can be caused by several different types of sequence variants, including stop_gained (SO:0001587), frameshift_variant (SO:0001589), splice_donor_variant (SO:0001575), and splice_acceptor_variant (SO:0001574) types of variants. [GenCC:AR]', 2853, 0, 0);
INSERT INTO chado.cvterm VALUES (2584, 22, 'NMD_escaping_variant', 'A sequence variant that leads to a change in the location of a termination codon in a transcript but allows the transcript to escape nonsense-mediated decay (NMD). The change in location of a termination codon can be caused by several different types of sequence variants, including stop_gained (SO:0001587), frameshift_variant (SO:0001589), splice_donor_variant (SO:0001575), and splice_acceptor_variant (SO:0001574) types of variants. [GenCC:AR]', 2854, 0, 0);
INSERT INTO chado.cvterm VALUES (2585, 22, 'stop_gained_NMD_triggering', 'A stop_gained (SO:0001587) variant that is degraded by nonsense-mediated decay (NMD). [GenCC:AR]', 2855, 0, 0);
INSERT INTO chado.cvterm VALUES (2586, 22, 'stop_gained_NMD_escaping', 'A stop_gained (SO:0001587) variant that allows the transcript to escape nonsense-mediated decay (NMD). [GenCC:AR]', 2856, 0, 0);
INSERT INTO chado.cvterm VALUES (2587, 22, 'frameshift_variant_NMD_triggering', 'A frameshift_variant (SO:0001589) that is degraded by nonsense-mediated decay (NMD). [GenCC:AR]', 2857, 0, 0);
INSERT INTO chado.cvterm VALUES (2588, 22, 'frameshift_variant_NMD_escaping', 'A frameshift_variant (SO:0001589) that allows the transcript to escape nonsense-mediated decay (NMD). [GenCC:AR]', 2858, 0, 0);
INSERT INTO chado.cvterm VALUES (2589, 22, 'splice_donor_variant_NMD_triggering', 'A splice_donor_variant (SO:0001575) that is degraded by nonsense-mediated decay (NMD). [GenCC:AR]', 2859, 0, 0);
INSERT INTO chado.cvterm VALUES (2590, 22, 'splice_donor_variant_NMD_escaping', 'A splice_donor_variant (SO:0001575) that allows the transcript to escape nonsense-mediated decay (NMD). [GenCC:AR]', 2860, 0, 0);
INSERT INTO chado.cvterm VALUES (2591, 22, 'splice_acceptor_variant_NMD_triggering', 'A splice_acceptor_variant (SO:0001574) that is degraded by nonsense-mediated decay (NMD). [GenCC:AR]', 2861, 0, 0);
INSERT INTO chado.cvterm VALUES (2592, 22, 'splice_acceptor_variant_NMD_escaping', 'A splice_acceptor_variant (SO:0001574) that allows the transcript to escape nonsense-mediated decay (NMD). [GenCC:AR]', 2862, 0, 0);
INSERT INTO chado.cvterm VALUES (2593, 22, 'minus_1_translational_frameshift', 'The region of mRNA 1 base long that is included as part of two separate codons during the process of translational frameshifting (GO:0006452), causing the reading frame to be different. [SO:ds]', 2863, 0, 0);
INSERT INTO chado.cvterm VALUES (2594, 22, 'minus_2_translational_frameshift', 'The region of mRNA 2 bases long that is included as part of two separate codons during the process of translational frameshifting (GO:0006452), causing the reading frame to be different. [SO:ds]', 2864, 0, 0);
INSERT INTO chado.cvterm VALUES (2595, 22, 'epigenomically_modified_region', 'A biological region implicated in inherited changes caused by mechanisms other than changes in the underlying DNA sequence. [http://en.wikipedia.org/wiki/Epigenetics, SO:ds]', 2865, 0, 0);
INSERT INTO chado.cvterm VALUES (2596, 22, 'amber_stop_codon', 'A stop codon with the DNA sequence TAG. [https://en.wikipedia.org/wiki/Stop_codon]', 2867, 0, 0);
INSERT INTO chado.cvterm VALUES (2597, 22, 'ochre_stop_codon', 'A stop codon with the DNA sequence TAA. [https://en.wikipedia.org/wiki/Stop_codon]', 2868, 0, 0);
INSERT INTO chado.cvterm VALUES (2598, 22, 'opal_stop_codon', 'A stop codon with the DNA sequence TGA. [https://en.wikipedia.org/wiki/Stop_codon]', 2869, 0, 0);
INSERT INTO chado.cvterm VALUES (2599, 22, 'cytosolic_rRNA_2S_gene', 'A gene that encodes for 2S ribosomal RNA, which functions as a component of the large subunit of the ribosome in Drosophila and at least some other Diptera. [PMID: 118436, PMID: 29474379, PMID: 3136294, PMID:10788608, PMID:407103, PMID:4847940, PMID:768488]', 2870, 0, 0);
INSERT INTO chado.cvterm VALUES (2600, 22, 'cytosolic_2S_rRNA', 'Cytosolic 2S rRNA is a 30 nucleotide RNA component of the large subunit of cytosolic ribosomes in Drosophila and at least some other Diptera. It is homologous to the 3'' part of other 5.8S rRNA molecules. The 3'' end of the 5.8S molecule is able to base-pair with the 5'' end of the 2S rRNA to generate a helical region equivalent in position to the ''GC-rich hairpin'' found in all previously sequenced 5.8S molecules. [PMID: 118436, PMID: 29474379, PMID: 3136294, PMID:10788608, PMID:407103, PMID:4847940, PMID:768488]', 2871, 0, 0);
INSERT INTO chado.cvterm VALUES (2601, 22, 'U7_snRNA', 'A 57 to 71 nucleotide RNA that is a component of the U7 small nuclear ribonucleoprotein complex (U7 snRNP). The U7 snRNP is required for histone pre-mRNA processing. [PMID:15526162]', 2872, 0, 0);
INSERT INTO chado.cvterm VALUES (2602, 22, 'scaRNA_gene', 'A gene that encodes for a scaRNA (small Cajal body-specific RNA). [PMID:27775477, PMID:28869095]', 2873, 0, 0);
INSERT INTO chado.cvterm VALUES (2603, 22, 'RNA_7SK', 'An abundant small nuclear RNA that, together with associated cellular proteins, regulates the activity of the positive transcription elongation factor b (P-TEFb). It is often described in literature as similar to a snRNA, except of longer length. [PMID:19246988, PMID:21853533, PMID:27369380]', 2874, 0, 0);
INSERT INTO chado.cvterm VALUES (2604, 22, 'RNA_7SK_gene', 'A gene encoding a 7SK RNA (SO:0002340). [PMID:19246988, PMID:21853533, PMID:27369380]', 2875, 0, 0);
INSERT INTO chado.cvterm VALUES (2605, 22, 'mt_SSU_rRNA', 'Mitochondrial SSU rRNA is an RNA component of the small subunit of mitochondrial ribosomes. [PMID: 24572720, PMID:3044395]', 2876, 0, 0);
INSERT INTO chado.cvterm VALUES (2606, 22, 'mt_LSU_rRNA', 'Mitochondrial LSU rRNA is an RNA component of the large subunit of mitochondrial ribosomes. [PMID: 24572720, PMID:3044395]', 2877, 0, 0);
INSERT INTO chado.cvterm VALUES (2607, 22, 'plastid_rRNA', 'Plastid rRNA is an RNA component of the small or large subunits of plastid (such as chloroplast) ribosomes. [PMID: 24572720, PMID:3044395]', 2878, 0, 0);
INSERT INTO chado.cvterm VALUES (2608, 22, 'plastid_SSU_rRNA', 'Plastid SSU rRNA is an RNA component of the small subunit of plastid (such as chloroplast) ribosomes. [PMID: 24572720, PMID:3044395]', 2879, 0, 0);
INSERT INTO chado.cvterm VALUES (2609, 22, 'plastid_LSU_rRNA', 'Plastid LSU rRNA is an RNA component of the large subunit of plastid (such as chloroplast) ribosomes. [PMID: 24572720, PMID:3044395]', 2880, 0, 0);
INSERT INTO chado.cvterm VALUES (2610, 22, 'fragile_site', 'A heritable locus on a chromosome that is prone to DNA breakage. []', 2881, 0, 0);
INSERT INTO chado.cvterm VALUES (2611, 22, 'common_fragile_site', 'A fragile site considered part of the normal chromosomal structure. [PMID: 16236432, PMID: 17608616]', 2882, 0, 0);
INSERT INTO chado.cvterm VALUES (2612, 22, 'rare_fragile_site', 'A fragile site found in the chromosomes of less than five percent of the human population. [PMID:16236432, PMID:17608616]', 2883, 0, 0);
INSERT INTO chado.cvterm VALUES (2613, 22, 'sisRNA', 'A non-coding RNA typically derived from intronic sequence of the sense strand of a cognate host gene, that is not rapidly degraded. It may contain exonic sequences, 5 caps, and/or polyA tails. [PMID:27147469, PMID:29397203, PMID:30391089]', 2884, 0, 0);
INSERT INTO chado.cvterm VALUES (2614, 22, 'sbRNA_gene', 'A gene encoding a stem-bulge RNA. [PMID:25908866, PMID:30666901]', 2885, 0, 0);
INSERT INTO chado.cvterm VALUES (2677, 22, 'A_to_G_transition', 'A transition of an adenine to a guanine. [SO:ke]', 2949, 0, 0);
INSERT INTO chado.cvterm VALUES (2618, 22, 'biosynthetic_gene_cluster', 'A physically clustered group of two or more genes in a particular genome that together encode a biosynthetic pathway for the production of a specialized metabolite (including its chemical variants). [PMID:26284661]', 2889, 0, 0);
INSERT INTO chado.cvterm VALUES (2619, 22, 'vault_RNA_gene', 'A gene that encodes a vault RNA. [PMID:19298825, PMID:19491402, PMID:22058117, PMID:22926522, PMID:30773316, PMID:9535882]', 2890, 0, 0);
INSERT INTO chado.cvterm VALUES (2620, 22, 'Y_RNA_gene', 'A gene that encodes a Y RNA. [PMID:1698620, PMID:6187471, PMID:6816230, PMID:7520568, PMID:7539809, PMID:8836182]', 2891, 0, 0);
INSERT INTO chado.cvterm VALUES (2621, 22, 'cytosolic_rRNA_gene', 'A gene that codes for cytosolic rRNA. []', 2892, 0, 0);
INSERT INTO chado.cvterm VALUES (2622, 22, 'mt_rRNA_gene', 'A gene that codes for mitochondrial rRNA. []', 2893, 0, 0);
INSERT INTO chado.cvterm VALUES (2623, 22, 'mt_LSU_rRNA_gene', 'A gene that codes for mitochondrial LSU rRNA. []', 2894, 0, 0);
INSERT INTO chado.cvterm VALUES (2624, 22, 'mt_SSU_rRNA_gene', 'A gene that codes for mitochondrial SSU rRNA. []', 2895, 0, 0);
INSERT INTO chado.cvterm VALUES (2625, 22, 'plastid_rRNA_gene', 'A gene that codes for plastid rRNA. []', 2896, 0, 0);
INSERT INTO chado.cvterm VALUES (2626, 22, 'plastid_LSU_rRNA_gene', 'A gene that codes for plastid LSU rRNA. []', 2897, 0, 0);
INSERT INTO chado.cvterm VALUES (2627, 22, 'plastid_SSU_rRNA_gene', 'A gene that codes for plastid SSU rRNA. []', 2898, 0, 0);
INSERT INTO chado.cvterm VALUES (2628, 22, 'C_D_box_scaRNA', 'A scaRNA possessing a box C/D sequence motif, guiding the methylation of snRNAs. [PMID:17099227, PMID:24659245]', 2899, 0, 0);
INSERT INTO chado.cvterm VALUES (2629, 22, 'H_ACA_box_scaRNA', 'A scaRNA possessing a box H/ACA sequence motif, guiding the pseudouridylation of snRNAs. [PMID:17099227, PMID:24659245]', 2900, 0, 0);
INSERT INTO chado.cvterm VALUES (2630, 22, 'C-D_H_ACA_box_scaRNA', 'A scaRNA possessing both box C/D and box H/ACA sequence motifs, guiding both the methylation and pseudouridylation of snRNAs. [PMID:17099227, PMID:24659245]', 2901, 0, 0);
INSERT INTO chado.cvterm VALUES (2631, 22, 'C_D_box_scaRNA_gene', 'A gene that codes for scaRNA possessing a box C/D sequence motif, guiding the methylation of snRNAs. [PMID:17099227, PMID:24659245]', 2902, 0, 0);
INSERT INTO chado.cvterm VALUES (2632, 22, 'H_ACA_box_scaRNA_gene', 'A gene that codes for scaRNA possessing a box H/ACA sequence motif, guiding the pseudouridylation of snRNAs. [PMID:17099227, PMID:24659245]', 2903, 0, 0);
INSERT INTO chado.cvterm VALUES (2633, 22, 'C-D_H_ACA_box_scaRNA_gene', 'A gene that codes for scaRNA possessing both box C/D and box H/ACA sequence motifs, guiding both the methylation and pseudouridylation of snRNAs. [PMID:17099227, PMID:24659245]', 2904, 0, 0);
INSERT INTO chado.cvterm VALUES (2634, 22, 'C_D_box_snoRNA_gene', 'A gene that codes a C_D_box_snoRNA. Most box C/D snoRNAs also contain long (>10 nt) sequences complementary to rRNA. Boxes C and D, as well as boxes C'' and D'', are usually located in close proximity, and form a structure known as the box C/D motif. This motif is important for snoRNA stability, processing, nucleolar targeting and function. A small number of box C/D snoRNAs are involved in rRNA processing; most, however, are known or predicted to serve as guide RNAs in ribose methylation of rRNA. Targeting involves direct base pairing of the snoRNA at the rRNA site to be modified and selection of a rRNA nucleotide a fixed distance from box D or D''. [PMID:12457565, PMID:22065625]', 2905, 0, 0);
INSERT INTO chado.cvterm VALUES (2635, 22, 'H_ACA_box_snoRNA_gene', 'A gene that codes for H_ACA_box_snoRNA. Members of the box H/ACA family contain an ACA triplet, exactly 3 nt upstream from the 3'' end and an H-box in a hinge region that links two structurally similar functional domains of the molecule. Both boxes are important for snoRNA biosynthesis and function. A few box H/ACA snoRNAs are involved in rRNA processing; most others are known or predicted to participate in selection of uridine nucleosides in rRNA to be converted to pseudouridines. Site selection is mediated by direct base pairing of the snoRNA with rRNA through one or both targeting domains. [PMID:12457565, PMID:22065625]', 2906, 0, 0);
INSERT INTO chado.cvterm VALUES (2636, 22, 'U14_snoRNA_gene', 'A gene that codes for U14_snoRNA. U14 small nucleolar RNA (U14 snoRNA) is required for early cleavages of eukaryotic precursor rRNAs. In yeasts, this molecule possess a stem-loop region (known as the Y-domain) which is essential for function. A similar structure, but with a different consensus sequence, is found in plants, but is absent in vertebrates. []', 2907, 0, 0);
INSERT INTO chado.cvterm VALUES (2637, 22, 'U3_snoRNA_gene', 'A gene that codes for U3_snoRNA. U3 snoRNA is a member of the box C/D class of small nucleolar RNAs. The U3 snoRNA secondary structure is characterised by a small 5'' domain (with boxes A and A''), and a larger 3'' domain (with boxes B, C, C'', and D), the two domains being linked by a single-stranded hinge. Boxes B and C form the B/C motif, which appears to be exclusive to U3 snoRNAs, and boxes C'' and D form the C''/D motif. The latter is functionally similar to the C/D motifs found in other snoRNAs. The 5'' domain and the hinge region act as a pre-rRNA-binding domain. The 3'' domain has conserved protein-binding sites. Both the box B/C and box C''/D motifs are sufficient for nuclear retention of U3 snoRNA. The box C''/D motif is also necessary for nucleolar localization, stability and hypermethylation of U3 snoRNA. Both box B/C and C''/D motifs are involved in specific protein interactions and are necessary for the rRNA processing functions of U3 snoRNA. []', 2908, 0, 0);
INSERT INTO chado.cvterm VALUES (2638, 22, 'methylation_guide_snoRNA_gene', 'A gene that codes for methylation_guide_snoRNA. A snoRNA that specifies the site of 2''-O-ribose methylation in an RNA molecule by base pairing with a short sequence around the target residue. [PMID:12457565]', 2909, 0, 0);
INSERT INTO chado.cvterm VALUES (2639, 22, 'pseudouridylation_guide_snoRNA_gene', 'A gene that codes for pseudouridylation_guide_snoRNA. A snoRNA that specifies the site of pseudouridylation in an RNA molecule by base pairing with a short sequence around the target residue. [PMID:12457565]', 2910, 0, 0);
INSERT INTO chado.cvterm VALUES (2640, 22, 'bidirectional_promoter_lncRNA', 'A long non-coding RNA which is produced using the promoter of a protein-coding gene but with transcription occurring in the opposite direction." [PMID:30175284, PMID:34956340] {comment="PMID:26578749}', 2911, 0, 0);
INSERT INTO chado.cvterm VALUES (2641, 22, 'methylation_guide_snoRNA', 'A snoRNA that specifies the site of 2''-O-ribose methylation in an RNA molecule by base pairing with a short sequence around the target residue. [GOC:mah, PMID:12457565]', 2912, 0, 0);
INSERT INTO chado.cvterm VALUES (2642, 22, 'rRNA_cleavage_RNA', 'An ncRNA that is part of a ribonucleoprotein that cleaves the primary pre-rRNA transcript in the process of producing mature rRNA molecules. [GOC:kgc]', 2913, 0, 0);
INSERT INTO chado.cvterm VALUES (2643, 22, 'exon_of_single_exon_gene', 'An exon that is the only exon in a gene. [RSC:cb]', 2914, 0, 0);
INSERT INTO chado.cvterm VALUES (2644, 22, 'cassette_array_member', 'A gene that is a member of a gene cassette, which is a mobile genetic element. []', 2915, 0, 0);
INSERT INTO chado.cvterm VALUES (2645, 22, 'gene_cassette_member', 'A gene that is a member of a gene cassette, which is a mobile genetic element. []', 2916, 0, 0);
INSERT INTO chado.cvterm VALUES (2646, 22, 'gene_subarray_member', 'A gene that is a member of a group of genes that are either regulated or transcribed together within a larger group of genes that are regulated or transcribed together. []', 2917, 0, 0);
INSERT INTO chado.cvterm VALUES (2647, 22, 'primer_binding_site', 'Non-covalent primer binding site for initiation of replication, transcription, or reverse transcription. [http://www.insdc.org/files/feature_table.html]', 2918, 0, 0);
INSERT INTO chado.cvterm VALUES (2648, 22, 'gene_array', 'An array includes two or more genes, or two or more gene subarrays, contiguously arranged where the individual genes, or subarrays, are either identical in sequence, or essentially so. [SO:ma]', 2919, 0, 0);
INSERT INTO chado.cvterm VALUES (2649, 22, 'gene_subarray', 'A subarray is, by defintition, a member of a gene array (SO:0005851); the members of a subarray may differ substantially in sequence, but are closely related in function. [SO:ma]', 2920, 0, 0);
INSERT INTO chado.cvterm VALUES (2650, 22, 'gene_cassette', 'A gene that can be substituted for a related gene at a different site in the genome. [SGD:se]', 2921, 0, 0);
INSERT INTO chado.cvterm VALUES (2651, 22, 'selenocysteine_tRNA_primary_transcript', 'A primary transcript encoding seryl tRNA (SO:000269). [SO:ke]', 2922, 0, 0);
INSERT INTO chado.cvterm VALUES (2652, 22, 'selenocysteinyl_tRNA', 'A tRNA sequence that has a selenocysteine anticodon, and a 3'' selenocysteine binding region. [SO:ke]', 2923, 0, 0);
INSERT INTO chado.cvterm VALUES (2653, 22, 'syntenic_region', 'A region in which two or more pairs of homologous markers occur on the same chromosome in two or more species. [http://www.informatics.jax.org/silverbook/glossary.shtml]', 2924, 0, 0);
INSERT INTO chado.cvterm VALUES (2654, 22, 'intrinsically_unstructured_polypeptide_region', 'A region of polypeptide chain with high conformational flexibility. [EBIBS:GAR]', 2925, 0, 0);
INSERT INTO chado.cvterm VALUES (2655, 22, 'catmat_left_handed_three', 'A motif of 3 consecutive residues with dihedral angles as follows: res i: phi -90 bounds -120 to -60, res i: psi -10 bounds -50 to 30, res i+1: phi -75 bounds -100 to -50, res i+1: psi 140 bounds 110 to 170. An extra restriction of the length of the O to O distance would be useful, that it be less than 5 Angstrom. More precisely these two oxygens are the main chain carbonyl oxygen atoms of residues i-1 and i+1. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 2926, 0, 0);
INSERT INTO chado.cvterm VALUES (2656, 22, 'catmat_left_handed_four', 'A motif of 4 consecutive residues with dihedral angles as follows: res i: phi -90 bounds -120 to -60, res i psi -10 bounds -50 to 30, res i+1: phi -90 bounds -120 to -60, res i+1: psi -10 bounds -50 to 30, res i+2: phi -75 bounds -100 to -50, res i+2: psi 140 bounds 110 to 170. The extra restriction of the length of the O to O distance is similar, that it be less than 5 Angstrom. In this case these two Oxygen atoms are the main chain carbonyl oxygen atoms of residues i-1 and i+2. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 2927, 0, 0);
INSERT INTO chado.cvterm VALUES (2657, 22, 'catmat_right_handed_three', 'A motif of 3 consecutive residues with dihedral angles as follows: res i: phi -90 bounds -120 to -60, res i: psi -10 bounds -50 to 30, res i+1: phi -75 bounds -100 to -50, res i+1: psi 140 bounds 110 to 170. An extra restriction of the length of the O to O distance would be useful, that it be less than 5 Angstrom. More precisely these two oxygens are the main chain carbonyl oxygen atoms of residues i-1 and i+1. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 2928, 0, 0);
INSERT INTO chado.cvterm VALUES (2658, 22, 'catmat_right_handed_four', 'A motif of 4 consecutive residues with dihedral angles as follows: res i: phi -90 bounds -120 to -60, res i: psi -10 bounds -50 to 30, res i+1: phi -90 bounds -120 to -60, res i+1: psi -10 bounds -50 to 30, res i+2: phi -75 bounds -100 to -50, res i+2: psi 140 bounds 110 to 170. The extra restriction of the length of the O to O distance is similar, that it be less than 5 Angstrom. In this case these two Oxygen atoms are the main chain carbonyl oxygen atoms of residues i-1 and i+2. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 2929, 0, 0);
INSERT INTO chado.cvterm VALUES (2659, 22, 'alpha_beta_motif', 'A motif of five consecutive residues and two H-bonds in which: H-bond between CO of residue(i) and NH of residue(i+4), H-bond between CO of residue(i) and NH of residue(i+3),Phi angles of residues(i+1), (i+2) and (i+3) are negative. [EBIBS:GAR, http://www.ebi.ac.uk/msd-srv/msdmotif/]', 2930, 0, 0);
INSERT INTO chado.cvterm VALUES (2660, 22, 'lipoprotein_signal_peptide', 'A peptide that acts as a signal for both membrane translocation and lipid attachment in prokaryotes. [EBIBS:GAR]', 2931, 0, 0);
INSERT INTO chado.cvterm VALUES (2661, 22, 'no_output', 'An experimental region wherean analysis has been run and not produced any annotation. [EBIBS:GAR]', 2932, 0, 0);
INSERT INTO chado.cvterm VALUES (2662, 22, 'peptide_coil', 'Irregular, unstructured regions of a protein''s backbone, as distinct from the regular region (namely alpha helix and beta strand - characterised by specific patterns of main-chain hydrogen bonds). [EBIBS:GAR]', 2933, 0, 0);
INSERT INTO chado.cvterm VALUES (2663, 22, 'hydrophobic_region_of_peptide', 'Hydrophobic regions are regions with a low affinity for water. [EBIBS:GAR]', 2934, 0, 0);
INSERT INTO chado.cvterm VALUES (2664, 22, 'n_terminal_region', 'The amino-terminal positively-charged region of a signal peptide (approx 1-5 aa). [EBIBS:GAR]', 2935, 0, 0);
INSERT INTO chado.cvterm VALUES (2665, 22, 'c_terminal_region', 'The more polar, carboxy-terminal region of the signal peptide (approx 3-7 aa). [EBIBS:GAR]', 2936, 0, 0);
INSERT INTO chado.cvterm VALUES (2666, 22, 'central_hydrophobic_region_of_signal_peptide', 'The central, hydrophobic region of the signal peptide (approx 7-15 aa). [EBIBS:GAR]', 2937, 0, 0);
INSERT INTO chado.cvterm VALUES (2667, 22, 'polypeptide_binding_motif', 'A polypeptide binding motif is a short (up to 20 amino acids) polypeptide region of biological interest that contains one or more amino acids experimentally shown to bind to a ligand. [EBIBS:GAR]', 2938, 0, 0);
INSERT INTO chado.cvterm VALUES (2668, 22, 'polypeptide_DNA_contact', 'A binding site that, in the polypeptide molecule, interacts selectively and non-covalently with DNA. [EBIBS:GAR, SO:ke]', 2939, 0, 0);
INSERT INTO chado.cvterm VALUES (2669, 22, 'complex_substitution', 'When no simple or well defined DNA mutation event describes the observed DNA change, the keyword \"complex\" should be used. Usually there are multiple equally plausible explanations for the change. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2941, 0, 0);
INSERT INTO chado.cvterm VALUES (2670, 22, 'point_mutation', 'A single nucleotide change which has occurred at the same position of a corresponding nucleotide in a reference sequence. [SO:immuno_workshop]', 2942, 0, 0);
INSERT INTO chado.cvterm VALUES (2671, 22, 'transition', 'Change of a pyrimidine nucleotide, C or T, into an other pyrimidine nucleotide, or change of a purine nucleotide, A or G, into an other purine nucleotide. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2943, 0, 0);
INSERT INTO chado.cvterm VALUES (2672, 22, 'pyrimidine_transition', 'A substitution of a pyrimidine, C or T, for another pyrimidine. [SO:ke]', 2944, 0, 0);
INSERT INTO chado.cvterm VALUES (2673, 22, 'C_to_T_transition', 'A transition of a cytidine to a thymine. [SO:ke]', 2945, 0, 0);
INSERT INTO chado.cvterm VALUES (2674, 22, 'C_to_T_transition_at_pCpG_site', 'The transition of cytidine to thymine occurring at a pCpG site as a consequence of the spontaneous deamination of 5''-methylcytidine. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2946, 0, 0);
INSERT INTO chado.cvterm VALUES (2675, 22, 'T_to_C_transition', 'A transition of a thymine to a cytidine. []', 2947, 0, 0);
INSERT INTO chado.cvterm VALUES (2676, 22, 'purine_transition', 'A substitution of a purine, A or G, for another purine. [SO:ke]', 2948, 0, 0);
INSERT INTO chado.cvterm VALUES (2679, 22, 'transversion', 'Change of a pyrimidine nucleotide, C or T, into a purine nucleotide, A or G, or vice versa. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2951, 0, 0);
INSERT INTO chado.cvterm VALUES (2680, 22, 'pyrimidine_to_purine_transversion', 'Change of a pyrimidine nucleotide, C or T, into a purine nucleotide, A or G. [SO:ke]', 2952, 0, 0);
INSERT INTO chado.cvterm VALUES (2681, 22, 'C_to_A_transversion', 'A transversion from cytidine to adenine. [SO:ke]', 2953, 0, 0);
INSERT INTO chado.cvterm VALUES (2682, 22, 'C_to_G_transversion', 'A transversion of a cytidine to a guanine. []', 2954, 0, 0);
INSERT INTO chado.cvterm VALUES (2683, 22, 'T_to_A_transversion', 'A transversion from T to A. [SO:ke]', 2955, 0, 0);
INSERT INTO chado.cvterm VALUES (2684, 22, 'T_to_G_transversion', 'A transversion from T to G. [SO:ke]', 2956, 0, 0);
INSERT INTO chado.cvterm VALUES (2685, 22, 'purine_to_pyrimidine_transversion', 'Change of a purine nucleotide, A or G , into a pyrimidine nucleotide C or T. [SO:ke]', 2957, 0, 0);
INSERT INTO chado.cvterm VALUES (2686, 22, 'A_to_C_transversion', 'A transversion from adenine to cytidine. [SO:ke]', 2958, 0, 0);
INSERT INTO chado.cvterm VALUES (2687, 22, 'A_to_T_transversion', 'A transversion from adenine to thymine. [SO:ke]', 2959, 0, 0);
INSERT INTO chado.cvterm VALUES (2688, 22, 'G_to_C_transversion', 'A transversion from guanine to cytidine. [SO:ke]', 2960, 0, 0);
INSERT INTO chado.cvterm VALUES (2689, 22, 'G_to_T_transversion', 'A transversion from guanine to thymine. [SO:ke]', 2961, 0, 0);
INSERT INTO chado.cvterm VALUES (2690, 22, 'intrachromosomal_mutation', 'A chromosomal structure variation within a single chromosome. [SO:ke]', 2962, 0, 0);
INSERT INTO chado.cvterm VALUES (2691, 22, 'interchromosomal_mutation', 'A chromosomal structure variation whereby more than one chromosome is involved. [SO:ke]', 2963, 0, 0);
INSERT INTO chado.cvterm VALUES (2692, 22, 'delins', 'A sequence alteration which included an insertion and a deletion, affecting 2 or more bases. [http://varnomen.hgvs.org/recommendations/DNA/variant/delins/]', 2964, 0, 0);
INSERT INTO chado.cvterm VALUES (2693, 22, 'direct_tandem_duplication', 'A tandem duplication where the individual regions are in the same orientation. [SO:ke]', 2968, 0, 0);
INSERT INTO chado.cvterm VALUES (2694, 22, 'tandem_duplication', 'A duplication consisting of 2 identical adjacent regions. [SO:ke]', 2969, 0, 0);
INSERT INTO chado.cvterm VALUES (2695, 22, 'inverted_tandem_duplication', 'A tandem duplication where the individual regions are not in the same orientation. [SO:ke]', 2970, 0, 0);
INSERT INTO chado.cvterm VALUES (2696, 22, 'Robertsonian_fusion', 'A non reciprocal translocation whereby the participating chromosomes break at their centromeres and the long arms fuse to form a single chromosome with a single centromere. [http://en.wikipedia.org/wiki/Robertsonian_translocation]', 2971, 0, 0);
INSERT INTO chado.cvterm VALUES (2697, 22, 'pericentric_inversion', 'A chromosomal inversion that includes the centromere. [FB:reference_manual]', 2972, 0, 0);
INSERT INTO chado.cvterm VALUES (2698, 22, 'paracentric_inversion', 'A chromosomal inversion that does not include the centromere. [FB:reference_manual]', 2973, 0, 0);
INSERT INTO chado.cvterm VALUES (2699, 22, 'reciprocal_chromosomal_translocation', 'A chromosomal translocation with two breaks; two chromosome segments have simply been exchanged. [FB:reference_manual]', 2974, 0, 0);
INSERT INTO chado.cvterm VALUES (2700, 22, 'sequence_variation_affecting_transcript', 'Any change in mature, spliced and processed, RNA that results from a change in the corresponding DNA sequence. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2975, 1, 0);
INSERT INTO chado.cvterm VALUES (2701, 22, 'sequence_variant_causing_no_change_in_transcript', 'No effect on the state of the RNA. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2978, 1, 0);
INSERT INTO chado.cvterm VALUES (2702, 22, 'sequence_variation_affecting_coding_sequence', 'Any of the amino acid coding triplets of a gene are affected by the DNA mutation. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2979, 1, 0);
INSERT INTO chado.cvterm VALUES (2703, 22, 'sequence_variant_causing_initiator_codon_change_in_transcript', 'The DNA mutation changes, usually destroys, the first coding triplet of a gene. Usually prevents translation although another initiator codon may be used. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2980, 1, 0);
INSERT INTO chado.cvterm VALUES (2704, 22, 'sequence_variant_causing_amino_acid_coding_codon_change_in_transcript', 'The DNA mutation affects the amino acid coding sequence of a gene; this region includes both the initiator and terminator codons. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2981, 1, 0);
INSERT INTO chado.cvterm VALUES (2705, 22, 'sequence_variant_causing_synonymous_codon_change_in_transcript', 'The changed codon has the same translation product as the original codon. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2982, 1, 0);
INSERT INTO chado.cvterm VALUES (2706, 22, 'sequence_variant_causing_non_synonymous_codon_change_in_transcript', 'A DNA point mutation that causes a substitution of an amino acid by an other. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2983, 1, 0);
INSERT INTO chado.cvterm VALUES (2707, 22, 'sequence_variant_causing_missense_codon_change_in_transcript', 'The nucleotide change in the codon leads to a new codon coding for a new amino acid. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2984, 1, 0);
INSERT INTO chado.cvterm VALUES (2708, 22, 'sequence_variant_causing_conservative_missense_codon_change_in_transcript', 'The amino acid change following from the codon change does not change the gross properties (size, charge, hydrophobicity) of the amino acid at that position. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2985, 1, 0);
INSERT INTO chado.cvterm VALUES (2709, 22, 'sequence_variant_causing_nonconservative_missense_codon_change_in_transcript', 'The amino acid change following from the codon change changes the gross properties (size, charge, hydrophobicity) of the amino acid in that position. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2986, 1, 0);
INSERT INTO chado.cvterm VALUES (2710, 22, 'sequence_variant_causing_nonsense_codon_change_in_transcript', 'The nucleotide change in the codon triplet creates a terminator codon. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2987, 1, 0);
INSERT INTO chado.cvterm VALUES (2711, 22, 'sequence_variant_causing_terminator_codon_change_in_transcript', 'The nucleotide change in the codon triplet changes the stop codon, causing an elongated transcript sequence. [SO:ke]', 2988, 1, 0);
INSERT INTO chado.cvterm VALUES (2712, 22, 'sequence_variation_affecting_reading_frame', 'An umbrella term for terms describing an effect of a sequence variation on the frame of translation. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2989, 1, 0);
INSERT INTO chado.cvterm VALUES (2713, 22, 'frameshift_sequence_variation', 'A mutation causing a disruption of the translational reading frame, because the number of nucleotides inserted or deleted is not a multiple of three. [SO:ke]', 2990, 1, 0);
INSERT INTO chado.cvterm VALUES (2714, 22, 'sequence_variant_causing_plus_1_frameshift_mutation', 'A mutation causing a disruption of the translational reading frame, due to the insertion of a nucleotide. [SO:ke]', 2991, 1, 0);
INSERT INTO chado.cvterm VALUES (2715, 22, 'sequence_variant_causing_minus_1_frameshift', 'A mutation causing a disruption of the translational reading frame, due to the deletion of a nucleotide. [SO:ke]', 2992, 1, 0);
INSERT INTO chado.cvterm VALUES (2908, 23, 'no_rank', 'A token asserting that the taxon was not assigned a rank. [TAXRANK:curator]', 3217, 0, 0);
INSERT INTO chado.cvterm VALUES (2716, 22, 'sequence_variant_causing_plus_2_frameshift', 'A mutation causing a disruption of the translational reading frame, due to the insertion of two nucleotides. [SO:ke]', 2993, 1, 0);
INSERT INTO chado.cvterm VALUES (2717, 22, 'sequence_variant_causing_minus_2_frameshift', 'A mutation causing a disruption of the translational reading frame, due to the deletion of two nucleotides. [SO:ke]', 2994, 1, 0);
INSERT INTO chado.cvterm VALUES (2718, 22, 'sequence_variant_affecting_transcript_processing', 'Sequence variant affects the way in which the primary transcriptional product is processed to form the mature transcript. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2995, 1, 0);
INSERT INTO chado.cvterm VALUES (2719, 22, 'sequence_variant_affecting_splicing', 'A sequence_variant_effect where the way in which the primary transcriptional product is processed to form the mature transcript, specifically by the removal (splicing) of intron sequences is changed. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2996, 1, 0);
INSERT INTO chado.cvterm VALUES (2720, 22, 'sequence_variant_affecting_splice_donor', 'A sequence_variant_effect that changes the splice donor sequence. [SO:ke]', 2997, 1, 0);
INSERT INTO chado.cvterm VALUES (2721, 22, 'sequence_variant_affecting_splice_acceptor', 'A sequence_variant_effect that changes the splice acceptor sequence. [SO:ke]', 2998, 1, 0);
INSERT INTO chado.cvterm VALUES (2722, 22, 'sequence_variant_causing_cryptic_splice_activation', 'A sequence variant causing a new (functional) splice site. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 2999, 1, 0);
INSERT INTO chado.cvterm VALUES (2723, 22, 'sequence_variant_affecting_editing', 'Sequence variant affects the editing of the transcript. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3000, 1, 0);
INSERT INTO chado.cvterm VALUES (2724, 22, 'sequence_variant_affecting_transcription', 'Mutation affects the process of transcription, its initiation, progression or termination. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3001, 1, 0);
INSERT INTO chado.cvterm VALUES (2725, 22, 'sequence_variant_decreasing_rate_of_transcription', 'A sequence variation that decreases the rate a which transcription of the sequence occurs. [SO:ke]', 3002, 1, 0);
INSERT INTO chado.cvterm VALUES (2726, 22, 'sequence_variation_affecting_transcript_sequence', '', 3003, 1, 0);
INSERT INTO chado.cvterm VALUES (2727, 22, 'sequence_variant_increasing_rate_of_transcription', '', 3004, 1, 0);
INSERT INTO chado.cvterm VALUES (2728, 22, 'sequence_variant_affecting_rate_of_transcription', 'A mutation that alters the rate a which transcription of the sequence occurs. [SO:ke]', 3005, 1, 0);
INSERT INTO chado.cvterm VALUES (2729, 22, 'sequence variant_affecting_transcript_stability', 'Sequence variant affects the stability of the transcript. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3006, 1, 0);
INSERT INTO chado.cvterm VALUES (2730, 22, 'sequence_variant_increasing_transcript_stability', 'Sequence variant increases the stability (half-life) of the transcript. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3007, 1, 0);
INSERT INTO chado.cvterm VALUES (2731, 22, 'sequence_variant_decreasing_transcript_stability', 'Sequence variant decreases the stability (half-life) of the transcript. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3008, 1, 0);
INSERT INTO chado.cvterm VALUES (2732, 22, 'sequence_variation_affecting_level_of_transcript', 'A sequence variation that causes a change in the level of mature, spliced and processed RNA, resulting from a change in the corresponding DNA sequence. [SO:ke]', 3009, 1, 0);
INSERT INTO chado.cvterm VALUES (2733, 22, 'sequence_variation_decreasing_level_of_transcript', 'A sequence variation that causes a decrease in the level of mature, spliced and processed RNA, resulting from a change in the corresponding DNA sequence. [SO:ke]', 3010, 1, 0);
INSERT INTO chado.cvterm VALUES (2734, 22, 'sequence_variation_increasing_level_of_transcript', 'A sequence_variation that causes an increase in the level of mature, spliced and processed RNA, resulting from a change in the corresponding DNA sequence. [SO:ke]', 3011, 1, 0);
INSERT INTO chado.cvterm VALUES (2735, 22, 'sequence_variant_affecting_translational_product', 'A sequence variant causing a change in primary translation product of a transcript. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3012, 1, 0);
INSERT INTO chado.cvterm VALUES (2736, 22, 'sequence_variant_causing_no_change_of_translational_product', 'The sequence variant at RNA level does not lead to any change in polypeptide. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3015, 1, 0);
INSERT INTO chado.cvterm VALUES (2737, 22, 'sequence_variant_causing_complex_change_of_translational_product', 'Any sequence variant effect that is known at nucleotide level but cannot be explained by using other key terms. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3016, 1, 0);
INSERT INTO chado.cvterm VALUES (2738, 22, 'sequence_variant_causing_amino_acid_substitution', 'The replacement of a single amino acid by another. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3017, 1, 0);
INSERT INTO chado.cvterm VALUES (2739, 22, 'sequence_variant_causing_conservative_amino_acid_substitution', '', 3018, 1, 0);
INSERT INTO chado.cvterm VALUES (2740, 22, 'sequence_variant_causing_nonconservative_amino_acid_substitution', '', 3019, 1, 0);
INSERT INTO chado.cvterm VALUES (2741, 22, 'sequence_variant_causing_amino_acid_insertion', 'The insertion of one or more amino acids from the polypeptide, without affecting the surrounding sequence. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3020, 1, 0);
INSERT INTO chado.cvterm VALUES (2742, 22, 'sequence_variant_causing_amino_acid_deletion', 'The deletion of one or more amino acids from the polypeptide, without affecting the surrounding sequence. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3021, 1, 0);
INSERT INTO chado.cvterm VALUES (2743, 22, 'sequence_variant_causing_polypeptide_truncation', 'The translational product is truncated at its C-terminus, usually a result of a nonsense codon change in transcript (SO:1000062). [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3022, 1, 0);
INSERT INTO chado.cvterm VALUES (2744, 22, 'sequence_variant_causing_polypeptide_elongation', 'The extension of the translational product at either (or both) the N-terminus and/or the C-terminus. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3023, 1, 0);
INSERT INTO chado.cvterm VALUES (2745, 22, 'mutation_causing_polypeptide_N_terminal_elongation', '. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3024, 1, 0);
INSERT INTO chado.cvterm VALUES (2746, 22, 'mutation_causing_polypeptide_C_terminal_elongation', '. [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3025, 1, 0);
INSERT INTO chado.cvterm VALUES (2747, 22, 'sequence_variant_affecting_level_of_translational_product', '', 3026, 1, 0);
INSERT INTO chado.cvterm VALUES (2748, 22, 'sequence_variant_decreasing_level_of_translation_product', '', 3027, 1, 0);
INSERT INTO chado.cvterm VALUES (2749, 22, 'sequence_variant_increasing_level_of_translation_product', '', 3028, 1, 0);
INSERT INTO chado.cvterm VALUES (2750, 22, 'sequence_variant_affecting_polypeptide_amino_acid_sequence', '', 3029, 1, 0);
INSERT INTO chado.cvterm VALUES (2751, 22, 'mutation_causing_inframe_polypeptide_N_terminal_elongation', '', 3030, 1, 0);
INSERT INTO chado.cvterm VALUES (2752, 22, 'mutation_causing_out_of_frame_polypeptide_N_terminal_elongation', '', 3031, 1, 0);
INSERT INTO chado.cvterm VALUES (2753, 22, 'mutaton_causing_inframe_polypeptide_C_terminal_elongation', '', 3032, 1, 0);
INSERT INTO chado.cvterm VALUES (2909, 24, 'is a', '', 3218, 0, 1);
INSERT INTO chado.cvterm VALUES (2755, 22, 'frame_restoring_sequence_variant', 'A mutation that reverts the sequence of a previous frameshift mutation back to the initial frame. [SO:ke]', 3034, 1, 0);
INSERT INTO chado.cvterm VALUES (2756, 22, 'sequence_variant_affecting_3D_structure_of_polypeptide', 'A mutation that changes the amino acid sequence of the peptide in such a way that it changes the 3D structure of the molecule. [SO:ke]', 3035, 1, 0);
INSERT INTO chado.cvterm VALUES (2757, 22, 'sequence_variant_causing_no_3D_structural_change', '', 3038, 1, 0);
INSERT INTO chado.cvterm VALUES (2758, 22, 'sequence_variant_causing_complex_3D_structural_change', '', 3039, 1, 0);
INSERT INTO chado.cvterm VALUES (2759, 22, 'sequence_variant_causing_conformational_change', '', 3040, 1, 0);
INSERT INTO chado.cvterm VALUES (2760, 22, 'sequence_variant_affecting_polypeptide_function', '', 3041, 1, 0);
INSERT INTO chado.cvterm VALUES (2761, 22, 'sequence_variant_causing_loss_of_function_of_polypeptide', '', 3042, 1, 0);
INSERT INTO chado.cvterm VALUES (2762, 22, 'sequence_variant_causing_inactive_ligand_binding_site', '', 3043, 1, 0);
INSERT INTO chado.cvterm VALUES (2763, 22, 'sequence_variant_causing_inactive_catalytic_site', '', 3044, 1, 0);
INSERT INTO chado.cvterm VALUES (2764, 22, 'sequence_variant_causing_polypeptide_localization_change', '', 3045, 1, 0);
INSERT INTO chado.cvterm VALUES (2765, 22, 'sequence_variant_causing_polypeptide_post_translational_processing_change', '', 3046, 1, 0);
INSERT INTO chado.cvterm VALUES (2766, 22, 'polypeptide_post_translational_processing_affected', '', 3047, 1, 0);
INSERT INTO chado.cvterm VALUES (2767, 22, 'sequence_variant_causing_partial_loss_of_function_of_polypeptide', '', 3048, 1, 0);
INSERT INTO chado.cvterm VALUES (2768, 22, 'sequence_variant_causing_gain_of_function_of_polypeptide', '', 3049, 1, 0);
INSERT INTO chado.cvterm VALUES (2769, 22, 'sequence_variant_affecting_transcript_secondary_structure', 'A sequence variant that affects the secondary structure (folding) of the RNA transcript molecule. [SO:ke]', 3050, 1, 0);
INSERT INTO chado.cvterm VALUES (2770, 22, 'sequence_variant_causing_compensatory_transcript_secondary_structure_mutation', '', 3051, 1, 0);
INSERT INTO chado.cvterm VALUES (2771, 22, 'sequence_variant_effect', 'The effect of a change in nucleotide sequence. [SO:ke]', 3052, 1, 0);
INSERT INTO chado.cvterm VALUES (2772, 22, 'sequence_variant_causing_polypeptide_fusion', '', 3053, 1, 0);
INSERT INTO chado.cvterm VALUES (2773, 22, 'autosynaptic_chromosome', 'An autosynaptic chromosome is the aneuploid product of recombination between a pericentric inversion and a cytologically wild-type chromosome. [PMID:6804304]', 3054, 0, 0);
INSERT INTO chado.cvterm VALUES (2774, 22, 'homo_compound_chromosome', 'A compound chromosome whereby two copies of the same chromosomal arm attached to a common centromere. The chromosome is diploid for the arm involved. [SO:ke]', 3055, 0, 0);
INSERT INTO chado.cvterm VALUES (2775, 22, 'hetero_compound_chromosome', 'A compound chromosome whereby two arms from different chromosomes are connected through the centromere of one of them. [FB:reference_manual, SO:ke]', 3056, 0, 0);
INSERT INTO chado.cvterm VALUES (2776, 22, 'chromosome_fission', 'A chromosome that occurred by the division of a larger chromosome. [SO:ke]', 3057, 0, 0);
INSERT INTO chado.cvterm VALUES (2777, 22, 'dextrosynaptic_chromosome', 'An autosynaptic chromosome carrying the two right (D = dextro) telomeres. [FB:manual]', 3058, 0, 0);
INSERT INTO chado.cvterm VALUES (2778, 22, 'laevosynaptic_chromosome', 'LS is an autosynaptic chromosome carrying the two left (L = levo) telomeres. [FB:manual]', 3059, 0, 0);
INSERT INTO chado.cvterm VALUES (2779, 22, 'free_duplication', 'A chromosome structure variation whereby the duplicated sequences are carried as a free centric element. [FB:reference_manual]', 3060, 0, 0);
INSERT INTO chado.cvterm VALUES (2780, 22, 'free_ring_duplication', 'A ring chromosome which is a copy of another chromosome. [SO:ke]', 3061, 0, 0);
INSERT INTO chado.cvterm VALUES (2781, 22, 'deficient_translocation', 'A chromosomal deletion whereby a translocation occurs in which one of the four broken ends loses a segment before re-joining. [FB:reference_manual]', 3062, 0, 0);
INSERT INTO chado.cvterm VALUES (2782, 22, 'inversion_cum_translocation', 'A chromosomal translocation whereby the first two breaks are in the same chromosome, and the region between them is rejoined in inverted order to the other side of the first break, such that both sides of break one are present on the same chromosome. The remaining free ends are joined as a translocation with those resulting from the third break. [FB:reference_manual]', 3063, 0, 0);
INSERT INTO chado.cvterm VALUES (2783, 22, 'bipartite_duplication', 'An interchromosomal mutation whereby the (large) region between the first two breaks listed is lost, and the two flanking segments (one of them centric) are joined as a translocation to the free ends resulting from the third break. [FB:reference_manual]', 3064, 0, 0);
INSERT INTO chado.cvterm VALUES (2784, 22, 'cyclic_translocation', 'A chromosomal translocation whereby three breaks occurred in three different chromosomes. The centric segment resulting from the first break listed is joined to the acentric segment resulting from the second, rather than the third. [FB:reference_manual]', 3065, 0, 0);
INSERT INTO chado.cvterm VALUES (2785, 22, 'bipartite_inversion', 'A chromosomal inversion caused by three breaks in the same chromosome; both central segments are inverted in place (i.e., they are not transposed). [FB:reference_manual]', 3066, 0, 0);
INSERT INTO chado.cvterm VALUES (2786, 22, 'uninverted_insertional_duplication', 'An insertional duplication where a copy of the segment between the first two breaks listed is inserted at the third break; the insertion is in cytologically the same orientation as its flanking segments. [FB:reference_manual]', 3067, 0, 0);
INSERT INTO chado.cvterm VALUES (2787, 22, 'insertional_duplication', 'A chromosome duplication involving the insertion of a duplicated region (as opposed to a free duplication). [SO:ke]', 3068, 0, 0);
INSERT INTO chado.cvterm VALUES (2788, 22, 'inverted_insertional_duplication', 'An insertional duplication where a copy of the segment between the first two breaks listed is inserted at the third break; the insertion is in cytologically inverted orientation with respect to its flanking segments. [FB:reference_manual]', 3069, 0, 0);
INSERT INTO chado.cvterm VALUES (2789, 22, 'inverted_interchromosomal_transposition', 'An interchromosomal transposition whereby a copy of the segment between the first two breaks listed is inserted at the third break; the insertion is in cytologically inverted orientation with respect to its flanking segment. [FB:reference_manual]', 3070, 0, 0);
INSERT INTO chado.cvterm VALUES (2790, 22, 'uninverted_interchromosomal_transposition', 'An interchromosomal transition where the segment between the first two breaks listed is removed and inserted at the third break; the insertion is in cytologically the same orientation as its flanking segments. [FB:reference_manual]', 3071, 0, 0);
INSERT INTO chado.cvterm VALUES (2791, 22, 'inverted_intrachromosomal_transposition', 'An intrachromosomal transposition whereby the segment between the first two breaks listed is removed and inserted at the third break; the insertion is in cytologically inverted orientation with respect to its flanking segments. [FB:reference_manual]', 3072, 0, 0);
INSERT INTO chado.cvterm VALUES (2792, 22, 'uninverted_intrachromosomal_transposition', 'An intrachromosomal transposition whereby the segment between the first two breaks listed is removed and inserted at the third break; the insertion is in cytologically the same orientation as its flanking segments. [FB:reference_manual]', 3073, 0, 0);
INSERT INTO chado.cvterm VALUES (2793, 22, 'unoriented_insertional_duplication', 'An insertional duplication where a copy of the segment between the first two breaks listed is inserted at the third break; the orientation of the insertion with respect to its flanking segments is not recorded. [FB:reference_manual]', 3074, 0, 0);
INSERT INTO chado.cvterm VALUES (2794, 22, 'unoriented_interchromosomal_transposition', 'An interchromosomal transposition whereby a copy of the segment between the first two breaks listed is inserted at the third break; the orientation of the insertion with respect to its flanking segments is not recorded. [FB:reference_manual]', 3075, 0, 0);
INSERT INTO chado.cvterm VALUES (2795, 22, 'unoriented_intrachromosomal_transposition', 'An intrachromosomal transposition whereby the segment between the first two breaks listed is removed and inserted at the third break; the orientation of the insertion with respect to its flanking segments is not recorded. [FB:reference_manual]', 3076, 0, 0);
INSERT INTO chado.cvterm VALUES (2796, 22, 'uncharacterized_chromosomal_mutation', 'A chromosome structure variant that has not been characterized. []', 3077, 0, 0);
INSERT INTO chado.cvterm VALUES (2797, 22, 'deficient_inversion', 'A chromosomal deletion whereby three breaks occur in the same chromosome; one central region is lost, and the other is inverted. [FB:reference_manual, SO:ke]', 3078, 0, 0);
INSERT INTO chado.cvterm VALUES (2798, 22, 'partially_characterized_chromosomal_mutation', 'A chromosome structure variant that has not been characterized fully. []', 3079, 0, 0);
INSERT INTO chado.cvterm VALUES (2799, 22, 'sequence_variant_affecting_gene_structure', 'A sequence_variant_effect that changes the gene structure. [SO:ke]', 3080, 1, 0);
INSERT INTO chado.cvterm VALUES (2800, 22, 'sequence_variant_causing_gene_fusion', 'A sequence_variant_effect that changes the gene structure by causing a fusion to another gene. [SO:ke]', 3081, 1, 0);
INSERT INTO chado.cvterm VALUES (2801, 22, 'sequence_variant_causes_exon_loss', 'A sequence variant affecting splicing and causes an exon loss. [SO:ke]', 3082, 1, 0);
INSERT INTO chado.cvterm VALUES (2802, 22, 'sequence_variant_causes_intron_gain', 'A sequence variant effect, causing an intron to be gained by the processed transcript; usually a result of a donor acceptor mutation (SO:1000072). [EBI:www.ebi.ac.uk/mutations/recommendations/mutevent.html]', 3083, 1, 0);
INSERT INTO chado.cvterm VALUES (2803, 22, 'sequence_variant_causing_cryptic_splice_donor_activation', '', 3084, 1, 0);
INSERT INTO chado.cvterm VALUES (2804, 22, 'sequence_variant_causing_cryptic_splice_acceptor_activation', '', 3085, 1, 0);
INSERT INTO chado.cvterm VALUES (2805, 22, 'alternatively_spliced_transcript', 'A transcript that is alternatively spliced. [SO:xp]', 3086, 0, 0);
INSERT INTO chado.cvterm VALUES (2806, 22, 'encodes_1_polypeptide', 'A gene that is alternately spliced, but encodes only one polypeptide. [SO:ke]', 3087, 0, 0);
INSERT INTO chado.cvterm VALUES (2807, 22, 'encodes_greater_than_1_polypeptide', 'A gene that is alternately spliced, and encodes more than one polypeptide. [SO:ke]', 3088, 0, 0);
INSERT INTO chado.cvterm VALUES (2808, 22, 'encodes_different_polypeptides_different_stop', 'A gene that is alternately spliced, and encodes more than one polypeptide, that have overlapping peptide sequences, but use different stop codons. [SO:ke]', 3089, 0, 0);
INSERT INTO chado.cvterm VALUES (2809, 22, 'encodes_overlapping_peptides', 'A gene that is alternately spliced, and encodes more than one polypeptide, that have overlapping peptide sequences. [SO:ke]', 3090, 0, 0);
INSERT INTO chado.cvterm VALUES (2810, 22, 'encodes_overlapping_peptides_different_start', 'A gene that is alternately spliced, and encodes more than one polypeptide, that have overlapping peptide sequences, but use different start codons. [SO:ke]', 3091, 0, 0);
INSERT INTO chado.cvterm VALUES (2811, 22, 'encodes_disjoint_polypeptides', 'A gene that is alternately spliced, and encodes more than one polypeptide, that do not have overlapping peptide sequences. [SO:ke]', 3092, 0, 0);
INSERT INTO chado.cvterm VALUES (2812, 22, 'encodes_overlapping_polypeptides_different_start_and_stop', 'A gene that is alternately spliced, and encodes more than one polypeptide, that have overlapping peptide sequences, but use different start and stop codons. [SO:ke]', 3093, 0, 0);
INSERT INTO chado.cvterm VALUES (2813, 22, 'alternatively_spliced_gene_encoding_greater_than_1_polypeptide_coding_regions_overlapping', '', 3094, 1, 0);
INSERT INTO chado.cvterm VALUES (2814, 22, 'cryptogene', 'A maxicircle gene so extensively edited that it cannot be matched to its edited mRNA sequence. [SO:ma]', 3095, 0, 0);
INSERT INTO chado.cvterm VALUES (2815, 22, 'member_of_regulon', 'A gene that is a member of a group of genes that are either regulated or transcribed together. []', 3096, 0, 0);
INSERT INTO chado.cvterm VALUES (2816, 22, 'alternatively_spliced_transcript_encoding_greater_than_1_polypeptide_different_start_codon_different_stop_codon_coding_regions_non_overlapping', '', 3097, 1, 0);
INSERT INTO chado.cvterm VALUES (2817, 22, 'CDS_independently_known', 'A CDS with the evidence status of being independently known. [SO:xp]', 3098, 0, 0);
INSERT INTO chado.cvterm VALUES (2818, 22, 'orphan_CDS', 'A CDS whose predicted amino acid sequence is unsupported by any experimental evidence or by any match with any other known sequence. [SO:ma]', 3099, 0, 0);
INSERT INTO chado.cvterm VALUES (2819, 22, 'CDS_predicted', 'A CDS that is predicted. [SO:ke]', 3100, 0, 0);
INSERT INTO chado.cvterm VALUES (2820, 22, 'CDS_supported_by_domain_match_data', 'A CDS that is supported by domain similarity. [SO:xp]', 3101, 0, 0);
INSERT INTO chado.cvterm VALUES (2821, 22, 'status_of_coding_sequence', '', 3102, 1, 0);
INSERT INTO chado.cvterm VALUES (2822, 22, 'CDS_supported_by_EST_or_cDNA_data', 'A CDS that is supported by similarity to EST or cDNA data. [SO:xp]', 3103, 0, 0);
INSERT INTO chado.cvterm VALUES (2823, 22, 'internal_Shine_Dalgarno_sequence', 'A Shine-Dalgarno sequence that stimulates recoding through interactions with the anti-Shine-Dalgarno in the RNA of small ribosomal subunits of translating ribosomes. The signal is only operative in Bacteria. [PMID:12519954, SO:ke]', 3104, 0, 0);
INSERT INTO chado.cvterm VALUES (2824, 22, 'recoded_mRNA', 'The sequence of a mature mRNA transcript, modified before translation or during translation, usually by special cis-acting signals. [http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=8811194&dopt=Abstract]', 3105, 0, 0);
INSERT INTO chado.cvterm VALUES (2825, 22, 'minus_1_translationally_frameshifted', 'An attribute describing a translational frameshift of -1. [SO:ke]', 3106, 0, 0);
INSERT INTO chado.cvterm VALUES (2826, 22, 'plus_1_translationally_frameshifted', 'An attribute describing a translational frameshift of +1. [SO:ke]', 3107, 0, 0);
INSERT INTO chado.cvterm VALUES (2827, 22, 'mRNA_recoded_by_translational_bypass', 'A recoded_mRNA where translation was suspended at a particular codon and resumed at a particular non-overlapping downstream codon. [http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=8811194&dopt=Abstract]', 3108, 0, 0);
INSERT INTO chado.cvterm VALUES (2828, 22, 'mRNA_recoded_by_codon_redefinition', 'A recoded_mRNA that was modified by an alteration of codon meaning. [SO:ma]', 3109, 0, 0);
INSERT INTO chado.cvterm VALUES (2829, 22, 'stop_codon_redefinition_as_selenocysteine', '', 3110, 1, 0);
INSERT INTO chado.cvterm VALUES (2830, 22, 'stop_codon_readthrough', '', 3111, 1, 0);
INSERT INTO chado.cvterm VALUES (2831, 22, 'four_bp_start_codon', 'A non-canonical start codon with 4 base pairs. [SO:ke]', 3112, 0, 0);
INSERT INTO chado.cvterm VALUES (2832, 22, 'stop_codon_redefinition_as_pyrrolysine', '', 3113, 1, 0);
INSERT INTO chado.cvterm VALUES (2910, 24, 'part of', '', 3219, 0, 1);
INSERT INTO chado.cvterm VALUES (2833, 22, 'archaeal_intron', 'An intron characteristic of Archaeal tRNA and rRNA genes, where intron transcript generates a bulge-helix-bulge motif that is recognised by a splicing endoribonuclease. [PMID:9301331, SO:ma]', 3114, 0, 0);
INSERT INTO chado.cvterm VALUES (2834, 22, 'tRNA_intron', 'An intron found in tRNA that is spliced via endonucleolytic cleavage and ligation rather than transesterification. [SO:ke]', 3115, 0, 0);
INSERT INTO chado.cvterm VALUES (2835, 22, 'CTG_start_codon', 'A non-canonical start codon of sequence CTG. [SO:ke]', 3116, 0, 0);
INSERT INTO chado.cvterm VALUES (2836, 22, 'SECIS_element', 'The incorporation of selenocysteine into a protein sequence is directed by an in-frame UGA codon (usually a stop codon) within the coding region of the mRNA. Selenoprotein mRNAs contain a conserved secondary structure in the 3'' UTR that is required for the distinction of UGA stop from UGA selenocysteine. The selenocysteine insertion sequence (SECIS) is around 60 nt in length and adopts a hairpin structure which is sufficiently well-defined and conserved to act as a computational screen for selenoprotein genes. [http://www.sanger.ac.uk/cgi-bin/Rfam/getacc?RF00031]', 3117, 0, 0);
INSERT INTO chado.cvterm VALUES (2837, 22, 'retron', 'Sequence coding for a short, single-stranded, DNA sequence via a retrotransposed RNA intermediate; characteristic of some microbial genomes. [SO:ma]', 3118, 0, 0);
INSERT INTO chado.cvterm VALUES (2838, 22, 'three_prime_recoding_site', 'The recoding stimulatory signal located downstream of the recoding site. [SO:ke]', 3119, 0, 0);
INSERT INTO chado.cvterm VALUES (2839, 22, 'three_prime_stem_loop_structure', 'A recoding stimulatory region, the stem-loop secondary structural element is downstream of the redefined region. [PMID:12519954, SO:ke]', 3120, 0, 0);
INSERT INTO chado.cvterm VALUES (2840, 22, 'five_prime_recoding_site', 'The recoding stimulatory signal located upstream of the recoding site. [SO:ke]', 3121, 0, 0);
INSERT INTO chado.cvterm VALUES (2841, 22, 'flanking_three_prime_quadruplet_recoding_signal', 'Four base pair sequence immediately downstream of the redefined region. The redefined region is a frameshift site. The quadruplet is 2 overlapping codons. [PMID:12519954, SO:ke]', 3122, 0, 0);
INSERT INTO chado.cvterm VALUES (2842, 22, 'UAG_stop_codon_signal', 'A stop codon signal for a UAG stop codon redefinition. [SO:ke]', 3123, 0, 0);
INSERT INTO chado.cvterm VALUES (2843, 22, 'stop_codon_signal', 'A recoding stimulatory signal that is a stop codon and has effect on efficiency of recoding. [PMID:12519954, SO:ke]', 3124, 0, 0);
INSERT INTO chado.cvterm VALUES (2844, 22, 'UAA_stop_codon_signal', 'A stop codon signal for a UAA stop codon redefinition. [SO:ke]', 3125, 0, 0);
INSERT INTO chado.cvterm VALUES (2845, 22, 'UGA_stop_codon_signal', 'A stop codon signal for a UGA stop codon redefinition. [SO:ke]', 3126, 0, 0);
INSERT INTO chado.cvterm VALUES (2846, 22, 'three_prime_repeat_recoding_signal', 'A recoding stimulatory signal, downstream sequence important for recoding that contains repetitive elements. [PMID:12519954, SO:ke]', 3127, 0, 0);
INSERT INTO chado.cvterm VALUES (2847, 22, 'distant_three_prime_recoding_signal', 'A recoding signal that is found many hundreds of nucleotides 3'' of a redefined stop codon. [http://www.ncbi.nlm.nih.gov\:80/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=8709208&dopt=Abstract]', 3128, 0, 0);
INSERT INTO chado.cvterm VALUES (2848, 22, 'databank_entry', 'The sequence referred to by an entry in a databank such as GenBank or SwissProt. [SO:ke]', 3129, 0, 0);
INSERT INTO chado.cvterm VALUES (2849, 23, 'has_rank', '', 3130, 0, 1);
INSERT INTO chado.cvterm VALUES (2850, 23, 'is_a', '', 3131, 0, 1);
INSERT INTO chado.cvterm VALUES (2851, 23, 'taxonomic_rank', 'A level of depth of a taxon in a taxonomic hierarchy. [TAXRANK:curator]', 3132, 0, 0);
INSERT INTO chado.cvterm VALUES (2852, 23, 'phylum', '', 3133, 0, 0);
INSERT INTO chado.cvterm VALUES (2853, 23, 'class', '', 3135, 0, 0);
INSERT INTO chado.cvterm VALUES (2854, 23, 'order', '', 3137, 0, 0);
INSERT INTO chado.cvterm VALUES (2855, 23, 'family', '', 3139, 0, 0);
INSERT INTO chado.cvterm VALUES (2856, 23, 'subclass', '', 3143, 0, 0);
INSERT INTO chado.cvterm VALUES (2857, 23, 'subphylum', '', 3145, 0, 0);
INSERT INTO chado.cvterm VALUES (2858, 23, 'subgenus', '', 3147, 0, 0);
INSERT INTO chado.cvterm VALUES (2859, 23, 'species_group', '', 3149, 0, 0);
INSERT INTO chado.cvterm VALUES (2860, 23, 'species_subgroup', '', 3151, 0, 0);
INSERT INTO chado.cvterm VALUES (2861, 23, 'species_complex', '', 3153, 0, 0);
INSERT INTO chado.cvterm VALUES (2862, 23, 'infraorder', '', 3154, 0, 0);
INSERT INTO chado.cvterm VALUES (2863, 23, 'suborder', '', 3156, 0, 0);
INSERT INTO chado.cvterm VALUES (2864, 23, 'superclass', '', 3158, 0, 0);
INSERT INTO chado.cvterm VALUES (2865, 23, 'varietas', '', 3160, 0, 0);
INSERT INTO chado.cvterm VALUES (2866, 23, 'kingdom', '', 3162, 0, 0);
INSERT INTO chado.cvterm VALUES (2867, 23, 'superfamily', '', 3164, 0, 0);
INSERT INTO chado.cvterm VALUES (2868, 23, 'infraclass', '', 3166, 0, 0);
INSERT INTO chado.cvterm VALUES (2869, 23, 'superorder', '', 3168, 0, 0);
INSERT INTO chado.cvterm VALUES (2870, 23, 'parvorder', '', 3170, 0, 0);
INSERT INTO chado.cvterm VALUES (2871, 23, 'superkingdom', '', 3172, 0, 0);
INSERT INTO chado.cvterm VALUES (2872, 23, 'subspecies', '', 3174, 0, 0);
INSERT INTO chado.cvterm VALUES (2873, 23, 'subfamily', '', 3176, 0, 0);
INSERT INTO chado.cvterm VALUES (2874, 23, 'tribe', '', 3178, 0, 0);
INSERT INTO chado.cvterm VALUES (2875, 23, 'forma', '', 3180, 0, 0);
INSERT INTO chado.cvterm VALUES (2876, 23, 'superphylum', '', 3182, 0, 0);
INSERT INTO chado.cvterm VALUES (2877, 23, 'subtribe', '', 3184, 0, 0);
INSERT INTO chado.cvterm VALUES (2878, 23, 'subkingdom', '', 3186, 0, 0);
INSERT INTO chado.cvterm VALUES (2879, 23, 'section', '', 3188, 0, 0);
INSERT INTO chado.cvterm VALUES (2880, 23, 'series', '', 3189, 0, 0);
INSERT INTO chado.cvterm VALUES (2881, 23, 'bio-variety', '', 3190, 0, 0);
INSERT INTO chado.cvterm VALUES (2882, 23, 'candidate', '', 3191, 0, 0);
INSERT INTO chado.cvterm VALUES (2883, 23, 'cultivar', '', 3192, 0, 0);
INSERT INTO chado.cvterm VALUES (2884, 23, 'cultivar-group', '', 3193, 0, 0);
INSERT INTO chado.cvterm VALUES (2885, 23, 'denominationclass', '', 3194, 0, 0);
INSERT INTO chado.cvterm VALUES (2886, 23, 'domain', '', 3195, 0, 0);
INSERT INTO chado.cvterm VALUES (2887, 23, 'graft-chimaera', '', 3196, 0, 0);
INSERT INTO chado.cvterm VALUES (2888, 23, 'grex', '', 3197, 0, 0);
INSERT INTO chado.cvterm VALUES (2889, 23, 'infraphylum', '', 3198, 0, 0);
INSERT INTO chado.cvterm VALUES (2890, 23, 'infrafamily', '', 3199, 0, 0);
INSERT INTO chado.cvterm VALUES (2891, 23, 'infragenerictaxon', '', 3200, 0, 0);
INSERT INTO chado.cvterm VALUES (2892, 23, 'infragenus', '', 3201, 0, 0);
INSERT INTO chado.cvterm VALUES (2893, 23, 'infrakingdom', '', 3202, 0, 0);
INSERT INTO chado.cvterm VALUES (2894, 23, 'infraspecificTaxon', '', 3203, 0, 0);
INSERT INTO chado.cvterm VALUES (2895, 23, 'infratribe', '', 3204, 0, 0);
INSERT INTO chado.cvterm VALUES (2896, 23, 'patho-variety', '', 3205, 0, 0);
INSERT INTO chado.cvterm VALUES (2897, 23, 'specialform', '', 3206, 0, 0);
INSERT INTO chado.cvterm VALUES (2898, 23, 'speciesaggregate', '', 3207, 0, 0);
INSERT INTO chado.cvterm VALUES (2899, 23, 'subvariety', '', 3208, 0, 0);
INSERT INTO chado.cvterm VALUES (2900, 23, 'subsubvariety', '', 3209, 0, 0);
INSERT INTO chado.cvterm VALUES (2901, 23, 'subsection', '', 3210, 0, 0);
INSERT INTO chado.cvterm VALUES (2902, 23, 'subseries', '', 3211, 0, 0);
INSERT INTO chado.cvterm VALUES (2903, 23, 'subspecificaggregate', '', 3212, 0, 0);
INSERT INTO chado.cvterm VALUES (2904, 23, 'subsubform', '', 3213, 0, 0);
INSERT INTO chado.cvterm VALUES (2905, 23, 'supertribe', '', 3214, 0, 0);
INSERT INTO chado.cvterm VALUES (2906, 23, 'supragenerictaxon', '', 3215, 0, 0);
INSERT INTO chado.cvterm VALUES (2912, 24, 'Collective', 'Used when a contact is a collective of individuals rather than a person.', 3221, 0, 0);
INSERT INTO chado.cvterm VALUES (2913, 24, 'Person', '', 3222, 0, 0);
INSERT INTO chado.cvterm VALUES (2914, 24, 'Organization', '', 3223, 0, 0);
INSERT INTO chado.cvterm VALUES (2915, 24, 'University', '', 3224, 0, 0);
INSERT INTO chado.cvterm VALUES (2916, 24, 'Lab', '', 3225, 0, 0);
INSERT INTO chado.cvterm VALUES (2917, 24, 'Institute', '', 3226, 0, 0);
INSERT INTO chado.cvterm VALUES (2918, 24, 'Research Group', '', 3227, 0, 0);
INSERT INTO chado.cvterm VALUES (2919, 24, 'Department', '', 3228, 0, 0);
INSERT INTO chado.cvterm VALUES (2920, 24, 'First Initials', 'The first initials for the author including the initial for the first name and any middle names (not the initial for the last name).', 3229, 0, 0);
INSERT INTO chado.cvterm VALUES (2921, 24, 'Surname', '', 3230, 0, 0);
INSERT INTO chado.cvterm VALUES (2922, 24, 'Given Name', '', 3231, 0, 0);
INSERT INTO chado.cvterm VALUES (2923, 24, 'Middle Names', 'One or more middle names for this person.', 3232, 0, 0);
INSERT INTO chado.cvterm VALUES (2924, 24, 'Middle Initials', 'The middle initials for this person excluding the initial for the given name and the surname.', 3233, 0, 0);
INSERT INTO chado.cvterm VALUES (2925, 24, 'Affiliation', '', 3234, 0, 0);
INSERT INTO chado.cvterm VALUES (2926, 24, 'Department(TCONTACT:0000016)', 'The department of an institution or organization.', 3235, 0, 0);
INSERT INTO chado.cvterm VALUES (2927, 24, 'Institution', '', 3236, 0, 0);
INSERT INTO chado.cvterm VALUES (2928, 24, 'Organization(TCONTACT:0000018)', 'A generic term for any organization.', 3237, 0, 0);
INSERT INTO chado.cvterm VALUES (2929, 24, 'Address', '', 3238, 0, 0);
INSERT INTO chado.cvterm VALUES (2930, 24, 'Address Line 1', '', 3239, 0, 0);
INSERT INTO chado.cvterm VALUES (2931, 24, 'Address Line 2', '', 3240, 0, 0);
INSERT INTO chado.cvterm VALUES (2932, 24, 'Address Line 3', '', 3241, 0, 0);
INSERT INTO chado.cvterm VALUES (2933, 24, 'City', '', 3242, 0, 0);
INSERT INTO chado.cvterm VALUES (2934, 24, 'State', '', 3243, 0, 0);
INSERT INTO chado.cvterm VALUES (2935, 24, 'Province', '', 3244, 0, 0);
INSERT INTO chado.cvterm VALUES (2936, 24, 'Country', '', 3245, 0, 0);
INSERT INTO chado.cvterm VALUES (2937, 24, 'Postal Code', '', 3246, 0, 0);
INSERT INTO chado.cvterm VALUES (2938, 24, 'contact_description', 'A description of the contact', 3247, 0, 0);
INSERT INTO chado.cvterm VALUES (2939, 25, 'is a', '', 3248, 0, 1);
INSERT INTO chado.cvterm VALUES (2940, 25, 'part of', '', 3249, 0, 1);
INSERT INTO chado.cvterm VALUES (2941, 25, 'Publication Dbxref', 'A unique identifer for the publication in a remote database.  The format is a database abbreviation and a unique accession separated by a colon.  (e.g. PMID:23493063)', 3250, 0, 0);
INSERT INTO chado.cvterm VALUES (2942, 25, 'Publication Details', '', 3251, 0, 0);
INSERT INTO chado.cvterm VALUES (2943, 25, 'Book', '', 3252, 0, 0);
INSERT INTO chado.cvterm VALUES (2944, 25, 'Publication Accession', 'The accession number for a publication in a remote database.  This term is obsolete in favor of the ''Publication Dbxref'' term.', 3253, 1, 0);
INSERT INTO chado.cvterm VALUES (2945, 25, 'Collective', 'Used when an author is a collective of individuals rather than a person.', 3254, 0, 0);
INSERT INTO chado.cvterm VALUES (2946, 25, 'Author', '', 3255, 0, 0);
INSERT INTO chado.cvterm VALUES (2947, 25, 'Master''s Thesis', '', 3256, 0, 0);
INSERT INTO chado.cvterm VALUES (2948, 25, 'PhD Thesis', 'PhD thesis or dissertation.', 3257, 0, 0);
INSERT INTO chado.cvterm VALUES (2949, 25, 'Publication Database', 'The name of the database that houses the publication record. This term is obsolete in favor of the ''Publication Dbxref'' term.', 3258, 1, 0);
INSERT INTO chado.cvterm VALUES (2950, 25, 'Received Date', 'The date when the manuscript was first received by the editor for consideration for print. This should be in the format: YYYY Mon Day, where YYYY is a 4 digit year, Mon is a 3-letter English abbreviation for the month followed by the day.  The month and day are optional.', 3259, 0, 0);
INSERT INTO chado.cvterm VALUES (2951, 25, 'Publication Date', 'The date the work was published.  This should be in the format: YYYY Mon Day, where YYYY is a 4 digit year, Mon is a 3-letter English abbreviation for the month followed by the day. The month and day are optional.', 3260, 0, 0);
INSERT INTO chado.cvterm VALUES (2952, 25, 'Conference Name', 'The name of a conference from which presented works are published.', 3261, 0, 0);
INSERT INTO chado.cvterm VALUES (2953, 25, 'Book Chapter', '', 3262, 0, 0);
INSERT INTO chado.cvterm VALUES (2954, 25, 'Unknown Type', '', 3263, 0, 0);
INSERT INTO chado.cvterm VALUES (2955, 25, 'Web Page', '', 3264, 0, 0);
INSERT INTO chado.cvterm VALUES (2956, 25, 'Epub Date', 'The date when a manuscript for the publication was first published online.  This may not be the same date it was formally printed. This should be in the format: YYYY Mon Day, where YYYY is a 4 digit year, Mon is a 3-letter English abbreviation for the month followed by the day. The month and day are optional.', 3265, 0, 0);
INSERT INTO chado.cvterm VALUES (2957, 25, 'Accepted Date', 'The date when a manuscript for the publication was first accepted for publication by the editor. This should be in the format: YYYY Mon Day, where YYYY is a 4 digit year, Mon is a 3-letter English abbreviation for the month followed by the day. The month and day are optional.', 3266, 0, 0);
INSERT INTO chado.cvterm VALUES (2958, 25, 'Journal Abbreviation', 'The journal title ISO Abbreviation.', 3267, 0, 0);
INSERT INTO chado.cvterm VALUES (2959, 25, 'Series Abbreviation', 'An abbreviation for the series name.  (e.g. the journal title ISO Abbreviation).', 3268, 0, 0);
INSERT INTO chado.cvterm VALUES (2960, 25, 'Title', 'The title of the published work.', 3269, 0, 0);
INSERT INTO chado.cvterm VALUES (2961, 25, 'Journal', '', 3270, 0, 0);
INSERT INTO chado.cvterm VALUES (2962, 25, 'Patent', 'Works consisting of documents granted by a government giving exclusive rights to an inventor or assignee to manufacture, use, or sell an invention for a certain number of years. The plural version of this term', 3271, 0, 0);
INSERT INTO chado.cvterm VALUES (2963, 25, 'Volume', 'The volume of the journal where the publication was printed.', 3272, 0, 0);
INSERT INTO chado.cvterm VALUES (2964, 25, 'Issue', 'The issue of the journal where the publication was printed.', 3273, 0, 0);
INSERT INTO chado.cvterm VALUES (2965, 25, 'Pages', 'The pages in the published work where the cited information is found.', 3274, 0, 0);
INSERT INTO chado.cvterm VALUES (2966, 25, 'Start Page', 'The first page in the published work where the cited information is found.', 3275, 0, 0);
INSERT INTO chado.cvterm VALUES (2967, 25, 'Authors', 'The list of authors of the publication. For PubMed style citations list each author with the last name first, followed by initials. Each author should be separated by a comma.', 3276, 0, 0);
INSERT INTO chado.cvterm VALUES (2968, 25, 'ISSN', 'International Standard Serial Number (ISSN) is an eight-character value that uniquely identifies a periodicals in print or other media. There are two sub categories of ISSN: print, p-ISSN and electronic e-ISSN.', 3277, 0, 0);
INSERT INTO chado.cvterm VALUES (2969, 25, 'DOI', 'Digital Object Identifier.', 3278, 0, 0);
INSERT INTO chado.cvterm VALUES (2970, 25, 'Elocation', 'Provides an electronic location for the items. This includes Digital Object Identifiers (DOI) or Publisher Item Identifiers (PII).', 3279, 0, 0);
INSERT INTO chado.cvterm VALUES (2971, 25, 'Abstract', 'The fully printed abstract for the publication.', 3280, 0, 0);
INSERT INTO chado.cvterm VALUES (2972, 25, 'Comments', 'Comments regarding the content in the publication.', 3281, 0, 0);
INSERT INTO chado.cvterm VALUES (2973, 25, 'URL', 'A univeral resource locator (URL) reference where the publication can be found.  For publications found online, this would be the web address for the publication.', 3282, 0, 0);
INSERT INTO chado.cvterm VALUES (2974, 25, 'File Attachment', 'The names of a file associated with the publication (e.g. supplemental data).', 3283, 0, 0);
INSERT INTO chado.cvterm VALUES (2975, 25, 'Year', 'The year the work was published. This should be a 4 digit year.', 3284, 0, 0);
INSERT INTO chado.cvterm VALUES (2976, 25, 'Language', 'The full name of the languge of the publication (e.g. English).', 3285, 0, 0);
INSERT INTO chado.cvterm VALUES (2977, 25, 'Keywords', 'Contains controlled terms that describe the content of the article. Multiple keywords should be separated with a comma.  For keyworks with that exist in a formal ontology or vocabulary, the format can be the database abbreviation, followed by the term accession separated by a comma (e.g. GO:591743).', 3286, 0, 0);
INSERT INTO chado.cvterm VALUES (2978, 25, 'Original Title', '', 3287, 0, 0);
INSERT INTO chado.cvterm VALUES (2979, 25, 'Alias', 'A synonym or alternative name for this publication.', 3288, 0, 0);
INSERT INTO chado.cvterm VALUES (2980, 25, 'Journal Code', '', 3289, 0, 0);
INSERT INTO chado.cvterm VALUES (2981, 25, 'pISSN', 'International Standard Serial Number (ISSN) is an eight-character value that uniquely identifies a periodicals in print or other media. There are two sub categories of ISSN: print, p-ISSN and electronic e-ISSN.', 3290, 0, 0);
INSERT INTO chado.cvterm VALUES (2982, 25, 'Conference Proceedings', 'A generic term for any article, talk, workshop or poster that is part of a conference proceedings.', 3291, 0, 0);
INSERT INTO chado.cvterm VALUES (2983, 25, 'eISSN', 'International Standard Serial Number (ISSN) is an eight-character value that uniquely identifies a periodicals in print or other media. There are two sub categories of ISSN: print, p-ISSN and electronic e-ISSN.', 3292, 0, 0);
INSERT INTO chado.cvterm VALUES (2984, 25, 'Proceedings Talk', '', 3293, 0, 0);
INSERT INTO chado.cvterm VALUES (2985, 25, 'Proceedings Article', '', 3294, 0, 0);
INSERT INTO chado.cvterm VALUES (2986, 25, 'Journal Name', '', 3295, 0, 0);
INSERT INTO chado.cvterm VALUES (2987, 25, 'Series Name', 'The name media that produces a series of publications (e.g. journal, conference proceedings, etc.)', 3296, 0, 0);
INSERT INTO chado.cvterm VALUES (2988, 25, 'Proceedings Poster', '', 3297, 0, 0);
INSERT INTO chado.cvterm VALUES (2989, 25, 'Conference Year', '', 3298, 0, 0);
INSERT INTO chado.cvterm VALUES (2990, 25, 'Proceedings Computer Demo', '', 3299, 0, 0);
INSERT INTO chado.cvterm VALUES (2991, 25, 'Vernacular Title', 'The title of a publication in its original foreign language.', 3300, 0, 0);
INSERT INTO chado.cvterm VALUES (2992, 25, 'Publication Model', 'This term is used to identify the medium/media in which the item is published. There are four possible values which are the same as used by: print, print-electronic, electronic,  electronic-print.  Further explanation:  "print", the journal is published in print format only; "print-electronic",  the journal is published in both print and electronic format; "electronic", the journal is published in electronic format only; "electronic-print", the journal is published first in electronic format followed by print.', 3301, 0, 0);
INSERT INTO chado.cvterm VALUES (2993, 25, 'PII', 'Publisher Item Identifier.', 3302, 0, 0);
INSERT INTO chado.cvterm VALUES (2994, 25, 'Structured Abstract Part', 'A subset of an abstract.  For example, abstracts that have section headers such as ''Purpose'', ''Results'', etc., each of these sections would be an individual part of a structured abstract.', 3303, 0, 0);
INSERT INTO chado.cvterm VALUES (2995, 25, 'Copyright', 'Information regarding the copyright of the publication.', 3304, 0, 0);
INSERT INTO chado.cvterm VALUES (2996, 25, 'Suffix', 'Name suffix such as 2nd, 3rd, Jr, Sr., etc.', 3305, 0, 0);
INSERT INTO chado.cvterm VALUES (2997, 25, 'Language Abbr', 'An abbreviation for a language (e.g. 3 letters)', 3306, 0, 0);
INSERT INTO chado.cvterm VALUES (2998, 25, 'Journal Country', 'The country where the journal was published.', 3307, 0, 0);
INSERT INTO chado.cvterm VALUES (2999, 25, 'Abbreviations', 'Works consisting of lists of shortened forms of written words or phrases used for brevity. Acronyms are included here.', 3308, 0, 0);
INSERT INTO chado.cvterm VALUES (3000, 25, 'Abstracts', 'Works consisting of lists of publications on a subject and that provide full annotated bibliographical information together with substantive summaries or condensations of the facts, ideas, or opinions presented in each publication listed. (From LC Subject Cataloging Manual)', 3309, 0, 0);
INSERT INTO chado.cvterm VALUES (3001, 25, 'Academic Dissertations', 'Works consisting of formal presentations made usually to fulfill requirements for an academic degree.', 3310, 0, 0);
INSERT INTO chado.cvterm VALUES (3002, 25, 'Addresses', 'Works consisting of speeches, orations, or written statements, usually formal, directed to a particular group of persons. These are different from LECTURES that are usually delivered to classes for instructional purposes.', 3311, 0, 0);
INSERT INTO chado.cvterm VALUES (3003, 25, 'Almanacs', 'Works consisting of a calendar of days, weeks, and months, together with information such as astronomical data, various statistics, etc. (From Genre Terms: A Thesaurus for Use in Rare Book and Special Collections Cataloguing, 2d ed)', 3312, 0, 0);
INSERT INTO chado.cvterm VALUES (3004, 25, 'Anecdotes', 'Works consisting of brief accounts or narratives of incidents or events.', 3313, 0, 0);
INSERT INTO chado.cvterm VALUES (3005, 25, 'Animation', 'A film or video wholly or partially created by photographing drawings, sculptures, or other inanimate things in sequence to create the illusion of motion. Animations are also generated by computers. (From Moving Image Materials: Genre Terms, 1988)', 3314, 0, 0);
INSERT INTO chado.cvterm VALUES (3006, 25, 'Annual Reports', 'Works consisting of annual statements concerning the administrative and operational functions of an institution or organization.', 3315, 0, 0);
INSERT INTO chado.cvterm VALUES (3007, 25, 'Atlases', 'Works consisting of collections of illustrative plates, charts, etc., usually with explanatory captions.', 3316, 0, 0);
INSERT INTO chado.cvterm VALUES (3008, 25, 'Autobiography', 'Works consisting of self-described accounts.', 3317, 0, 0);
INSERT INTO chado.cvterm VALUES (3009, 25, 'Bibliography', 'A work consisting of a list of books, articles, documents, publications, and other items, usually on a single subject or related subjects.', 3318, 0, 0);
INSERT INTO chado.cvterm VALUES (3010, 25, 'Biobibliography', 'Works consisting of biographical information as well as lists of the writings of those persons.', 3319, 0, 0);
INSERT INTO chado.cvterm VALUES (3011, 25, 'Biography', 'Works consisting of an account of the events, works, and achievements, personal and professional, during a person''s life. It includes articles on the activities and accomplishments of living persons as well as the presentation of an obituary.', 3320, 0, 0);
INSERT INTO chado.cvterm VALUES (3012, 25, 'Book Illustrations', 'Works consisting of photographs, prints, drawings, portraits, plates, diagrams, facsimiles, maps, tables, or other representations or systematic arrangements of data designed to elucidate or decorate the contents of a publication. (From The ALA Glossary of Library and Information Science, 1983, p114)', 3321, 0, 0);
INSERT INTO chado.cvterm VALUES (3013, 25, 'Book Reviews', 'Works consisting of critical analyses of books or other monographic works.', 3322, 0, 0);
INSERT INTO chado.cvterm VALUES (3119, 25, 'Support of Research', 'Organizational source for funding of research activity.', 3428, 0, 0);
INSERT INTO chado.cvterm VALUES (3014, 25, 'Bookplates', 'Works consisting of book owner''s identification labels. They are usually intended for attaching inside a book or similar object. (From Thesaurus for Graphic Materials II: Genre and Physical Characteristic Terms, 1995)', 3323, 0, 0);
INSERT INTO chado.cvterm VALUES (3015, 25, 'Cartoons', 'Images used to comment on such things as contemporary events, social habits, or political trends; usually executed in a broad or abbreviated manner.', 3324, 0, 0);
INSERT INTO chado.cvterm VALUES (3016, 25, 'Case Reports', 'Clinical presentations that may be followed by evaluative studies that eventually lead to a diagnosis.', 3325, 0, 0);
INSERT INTO chado.cvterm VALUES (3017, 25, 'Catalogs', 'Works consisting of bibliographic records, created according to specific and uniform principles of construction and under the control of an authority file, which describe the materials contained in a collection, library, or group of libraries. Catalogs include also lists of materials prepared for a particular purpose, such as exhibition catalogs, sales catalogs, garden catalogs, medical supply catalogs. (From The ALA Glossary of Library and Information Sciences, 1983)', 3326, 0, 0);
INSERT INTO chado.cvterm VALUES (3018, 25, 'Charts', 'Information presented in graphic form, for example, graphs or diagrams.', 3327, 0, 0);
INSERT INTO chado.cvterm VALUES (3019, 25, 'Chronology', 'Works consisting of lists of events arranged in chronological order.', 3328, 0, 0);
INSERT INTO chado.cvterm VALUES (3020, 25, 'Classical Article', 'Works consisting of a current presentation of a previously printed seminal article marking a milestone in the history of medicine or science. It is usually accompanied by introductory remarks heralding its reprinting, often on the anniversary of its original publication or on an anniversary of the author''s birth or death. It is usually reprinted in full, with complete bibliographical reference to the original appearance.', 3329, 0, 0);
INSERT INTO chado.cvterm VALUES (3021, 25, 'Clinical Conference', 'Work that consists of a conference of physicians on their observations of a patient at the bedside, regarding the physical state, laboratory and other diagnostic findings, clinical manifestations, results of current therapy, etc. A clinical conference usually ends with a confirmation or correction of clinical findings by a pathological diagnosis performed by a pathologist. "Clinical conference" is often referred to as a "clinico-pathological conference."', 3330, 0, 0);
INSERT INTO chado.cvterm VALUES (3022, 25, 'Clinical Trial', 'Work that is the report of a pre-planned clinical study of the safety, efficacy, or optimum dosage schedule of one or more diagnostic, therapeutic, or prophylactic drugs, devices, or techniques in humans selected according to predetermined criteria of eligibility and observed for predefined evidence of favorable and unfavorable effects. While most clinical trials concern humans, this publication type may be used for clinical veterinary articles meeting the requisites for humans. Specific headings for specific types and phases of clinical trials are also available.', 3331, 0, 0);
INSERT INTO chado.cvterm VALUES (3023, 25, 'Clinical Trial, Phase I', 'Work that is the report of a pre-planned, usually controlled, clinical study of the safety and efficacy of diagnostic, therapeutic, or prophylactic drugs, devices, or techniques based on a small number of healthy persons and conducted over the period of about a year in either the United States or a foreign country.', 3332, 0, 0);
INSERT INTO chado.cvterm VALUES (3024, 25, 'Clinical Trial, Phase II', 'Work that is a report of a pre-planned, usually controlled, clinical study of the safety and efficacy of diagnostic, therapeutic, or prophylactic drugs, devices, or techniques based on several hundred volunteers, including a limited number of patients, and conducted over a period of about two years in either the United States or a foreign country.', 3333, 0, 0);
INSERT INTO chado.cvterm VALUES (3025, 25, 'Clinical Trial, Phase III', 'Work that is a report of a pre-planned, usually controlled, clinical study of the safety and efficacy of diagnostic, therapeutic, or prophylactic drugs, devices, or techniques after phase II trials. A large enough group of patients is studied and closely monitored by physicians for adverse response to long-term exposure, over a period of about three years in either the United States or a foreign country.', 3334, 0, 0);
INSERT INTO chado.cvterm VALUES (3026, 25, 'Clinical Trial, Phase IV', 'Work that is a report of a planned post-marketing study of diagnostic, therapeutic, or prophylactic drugs, devices, or techniques that have been approved for general sale after clinical trials, phases I, II, and III. These studies, conducted in the United States or a foreign country, often garner additional data about the safety and efficacy of a product.', 3335, 0, 0);
INSERT INTO chado.cvterm VALUES (3027, 25, 'Collected Correspondence', 'Works consisting of collected letters by or about a person or on a subject.', 3336, 0, 0);
INSERT INTO chado.cvterm VALUES (3028, 25, 'Collected Works', 'Works consisting of collections of previously published works.', 3337, 0, 0);
INSERT INTO chado.cvterm VALUES (3029, 25, 'Collections', 'Works that consist of collections of objects.', 3338, 0, 0);
INSERT INTO chado.cvterm VALUES (3030, 25, 'Comment', 'Work consisting of a critical or explanatory note written to discuss, support, or dispute an article or other presentation previously published. It may take the form of an article, letter, editorial, etc. It appears in publications under a variety of names: comment, commentary, editorial comment, viewpoint, etc.', 3339, 0, 0);
INSERT INTO chado.cvterm VALUES (3031, 25, 'Comparative Study', 'Comparison of outcomes, results, responses, etc for different techniques, therapeutic approaches or other inputs.', 3340, 0, 0);
INSERT INTO chado.cvterm VALUES (3032, 25, 'Congresses', 'Published records of the papers delivered at or issued on the occasion of individual congresses, symposia, and meetings; abstracts of papers delivered at such congresses; reports of the officers and delegates of such congresses; combinations of the foregoing; or proceedings of the conference of a society if they are not limited to matters of internal organization.', 3341, 0, 0);
INSERT INTO chado.cvterm VALUES (3033, 25, 'Consensus Development Conference', 'A work that consists of summary statements representing the majority and current agreement of physicians, scientists, and other professionals meeting to reach a consensus on a selected subject.', 3342, 0, 0);
INSERT INTO chado.cvterm VALUES (3034, 25, 'Controlled Clinical Trial', 'Work consisting of a clinical trial involving one or more test treatments, at least one control treatment, specified outcome measures for evaluating the studied intervention, and a bias-free method for assigning patients to the test treatment. The treatment may be drugs, devices, or procedures studied for diagnostic, therapeutic, or prophylactic effectiveness. Control measures include placebos, active medicine, no-treatment, dosage forms and regimens, historical comparisons, etc. When randomization using mathematical techniques, such as the use of a random numbers table, is employed to assign patients to test or control treatments, the trial is characterized as a RANDOMIZED CONTROLLED TRIAL.', 3343, 0, 0);
INSERT INTO chado.cvterm VALUES (3035, 25, 'Cookbooks', 'Collections of recipes or instructions for preparation of food and organization of meals.', 3344, 0, 0);
INSERT INTO chado.cvterm VALUES (3036, 25, 'Corrected and Republished Article', 'Work that is the republication of an article to correct, amplify, or restore text and data of the originally published article.', 3345, 0, 0);
INSERT INTO chado.cvterm VALUES (3120, 25, 'Tables', 'Presentations of nonstatistical data in tabular form.', 3429, 0, 0);
INSERT INTO chado.cvterm VALUES (3037, 25, 'Database', 'Work consisting of a structured file of information or a set of logically related data stored and retrieved using computer-based means.', 3346, 0, 0);
INSERT INTO chado.cvterm VALUES (3038, 25, 'Diaries', 'Works consisting of records, usually private, of writers'' experiences, observations, feelings, attitudes, etc. They may also be works marked in calendar order in which to note appointments and the like. (From Random House Unabridged Dictionary, 2d ed)', 3347, 0, 0);
INSERT INTO chado.cvterm VALUES (3039, 25, 'Dictionary', 'A reference book containing a list of words - usually in alphabetical order - giving information about form, pronunciation, etymology, grammar, and meaning. A foreign-language dictionary is an alphabetical list of words of one language with their meaning and equivalents in another language.', 3348, 0, 0);
INSERT INTO chado.cvterm VALUES (3040, 25, 'Directory', 'Work consisting of an alphabetical or classified list of names, organizations, subjects, etc., giving usually titles, addresses, affiliations, and other professional data.', 3349, 0, 0);
INSERT INTO chado.cvterm VALUES (3041, 25, 'Documentaries and Factual Films', 'Works consisting of films, videos, and programs which depict actual persons or actual events. They do not include frank historical re-creations and do not attempt to judge the truth of the depiction in a film purporting to be factual or documentary in character. (From Moving Image Materials: Genre Terms, 1988)', 3350, 0, 0);
INSERT INTO chado.cvterm VALUES (3042, 25, 'Drawings', 'Works consisting of graphic representations of objects or ideas by lines.', 3351, 0, 0);
INSERT INTO chado.cvterm VALUES (3043, 25, 'Duplicate Publication', 'Work consisting of an article or book of identical or nearly identical material published simultaneously or successively to material previously published elsewhere, without acknowledgment of the prior publication.', 3352, 0, 0);
INSERT INTO chado.cvterm VALUES (3044, 25, 'Editorial', 'Work consisting of a statement of the opinions, beliefs, and policy of the editor or publisher of a journal, usually on current matters of medical or scientific significance to the medical community or society at large. The editorials published by editors of journals representing the official organ of a society or organization are generally substantive.', 3353, 0, 0);
INSERT INTO chado.cvterm VALUES (3045, 25, 'Electronic Supplementary Materials', 'Supporting content or information, such as animation, datasets, multimedia files, video, movies, audio files, text files, or software, which is submitted for publication in an online journal or an online edition of a journal. This information may be referenced in the text of the article with a link to the supplementary data provided. CATALOG: do not use', 3354, 0, 0);
INSERT INTO chado.cvterm VALUES (3046, 25, 'Encyclopedias', 'Works containing informational articles on subjects in every field of knowledge, usually arranged in alphabetical order, or a similar work limited to a special field or subject. (From The ALA Glossary of Library and Information Science, 1983)', 3355, 0, 0);
INSERT INTO chado.cvterm VALUES (3047, 25, 'Ephemera', 'Works consisting of transient everyday items, usually printed on paper, that are produced for a specific limited use and then often thrown away. (From Genre Terms: A Thesaurus for Use in Rare Book and Special Collections Cataloguing, 2d ed & The ALA Glossary of Library and Information Science, 1983)', 3356, 0, 0);
INSERT INTO chado.cvterm VALUES (3048, 25, 'Essays', 'Works consisting of collections of papers or interpretive literary compositions not previously published.', 3357, 0, 0);
INSERT INTO chado.cvterm VALUES (3049, 25, 'Evaluation Studies', 'Works consisting of studies determining the effectiveness or utility of processes, personnel, and equipment.', 3358, 0, 0);
INSERT INTO chado.cvterm VALUES (3050, 25, 'Examination Questions', 'Works consisting of compilations of questions and answers pertaining to a particular subject, used for study and review.', 3359, 0, 0);
INSERT INTO chado.cvterm VALUES (3051, 25, 'Exhibitions', 'Public displays or items representative of a given subject.', 3360, 0, 0);
INSERT INTO chado.cvterm VALUES (3052, 25, 'Festschrift', 'Work consisting of a collection of essays or other writings contributed by students, teachers, colleagues, and associates to honor a person or institution, usually on the occasion of an anniversary celebration or other event of importance.', 3361, 0, 0);
INSERT INTO chado.cvterm VALUES (3053, 25, 'Fictional Works', 'Works consisting of creative writing, not presented as factual.', 3362, 0, 0);
INSERT INTO chado.cvterm VALUES (3054, 25, 'Forms', 'Works consisting of or containing a substantial number of blank forms.', 3363, 0, 0);
INSERT INTO chado.cvterm VALUES (3055, 25, 'Formularies', 'Works that consist of lists of drugs or collections of recipes, formulas, and prescriptions for the compounding of medicinal preparations.', 3364, 0, 0);
INSERT INTO chado.cvterm VALUES (3056, 25, 'Government Publications', 'Works consisting of documents issued by local, regional, or national governments or by their agencies or subdivisions.', 3365, 0, 0);
INSERT INTO chado.cvterm VALUES (3057, 25, 'Guidebooks', 'Works consisting of publications for travelers that give information about a city, region, or country, or similar handbooks about buildings, museums, etc. (The ALA Glossary of Library and Information Science, 1983)', 3366, 0, 0);
INSERT INTO chado.cvterm VALUES (3058, 25, 'Guideline', 'Work consisting of a set of statements, directions, or principles presenting current or future rules or policy. Guidelines may be developed by government agencies at any level, institutions, organizations such as professional societies or governing boards, or by the convening of expert panels. The text may be cursive or in outline form, but it is generally a comprehensive guide to problems and approaches in any discipline or activity. This concept relates to the general conduct and administration of health care activities rather than to specific decisions for a particular clinical condition. For that aspect, PRACTICE GUIDELINE is available.', 3367, 0, 0);
INSERT INTO chado.cvterm VALUES (3059, 25, 'Handbooks', 'Works consisting of concise reference works in which facts and information pertaining to a certain subject or field are arranged for ready reference and consultation rather than for continuous reading and study.', 3368, 0, 0);
INSERT INTO chado.cvterm VALUES (3060, 25, 'Herbals', 'Works such as books on herbs or plants usually describing their medicinal value. (Random House Unabridged Dictionary, 2d ed)', 3369, 0, 0);
INSERT INTO chado.cvterm VALUES (3061, 25, 'Historical Article', 'An article or portion of an article giving an account of past events or circumstances significant in a field of study, a profession, a discovery, an invention, etc. The concept of history is very wide, ranging from the dawn of time to the present. This publication type is often checked in conjunction with BIOGRAPHY.', 3370, 0, 0);
INSERT INTO chado.cvterm VALUES (3062, 25, 'Humor', 'Works consisting of jokes and facetiae relating to a subject.', 3371, 0, 0);
INSERT INTO chado.cvterm VALUES (3063, 25, 'In Vitro', 'Studies using excised tissues.', 3372, 0, 0);
INSERT INTO chado.cvterm VALUES (3064, 25, 'Incunabula', 'Books printed before 1501.', 3373, 0, 0);
INSERT INTO chado.cvterm VALUES (3065, 25, 'Indexes', 'Works providing an analytical subject approach to materials in a field of knowledge.', 3374, 0, 0);
INSERT INTO chado.cvterm VALUES (3066, 25, 'Instructional Films', 'Works consisting of nonfiction films and video designed to teach, instruct, or train. (From Moving Image Materials: Genre Terms, 1988)', 3375, 0, 0);
INSERT INTO chado.cvterm VALUES (3067, 25, 'Interactive Tutorial', 'Video recordings or other files in which the progress of the instruction or content is determined by user response.', 3376, 0, 0);
INSERT INTO chado.cvterm VALUES (3068, 25, 'Interview', 'Work consisting of a conversation with an individual regarding his or her background and other personal and professional details, opinions on specific subjects posed by the interviewer, etc.', 3377, 0, 0);
INSERT INTO chado.cvterm VALUES (3069, 25, 'Introductory Journal Article', 'Prefactory summary to a special issue or section of a journal devoted to a specific topic. This introductory text can be of varying length and substance.', 3378, 0, 0);
INSERT INTO chado.cvterm VALUES (3070, 25, 'Journal Article', 'The predominant publication type for articles and other items indexed for NLM databases.', 3379, 0, 0);
INSERT INTO chado.cvterm VALUES (3071, 25, 'Juvenile Literature', 'Works produced for children through age 15 or through the ninth grade.', 3380, 0, 0);
INSERT INTO chado.cvterm VALUES (3072, 25, 'Laboratory Manuals', 'Works containing concise background information and directions for activities, including conducting experiments or diagnostic tests in the laboratory.', 3381, 0, 0);
INSERT INTO chado.cvterm VALUES (3073, 25, 'Lecture Notes', 'Works consisting of notes taken at the delivery or reading of a speech before an audience or class, usually given to instruct. (From Random House Unabridged Dictionary, 2d ed)', 3382, 0, 0);
INSERT INTO chado.cvterm VALUES (3074, 25, 'Lectures', 'Works consisting of speeches read or delivered before an audience or class, especially for instruction or to set forth some subject. They are differentiated from ADDRESSES [PUBLICATION TYPE] which are less didactic and more informational, entertaining, inspirational, or polemic. (From Random House Unabridged Dictionary, 2d ed)', 3383, 0, 0);
INSERT INTO chado.cvterm VALUES (3075, 25, 'Legal Cases', 'Works consisting of collections of law reports or the published reports of decided cases and documents or filings related to those cases.', 3384, 0, 0);
INSERT INTO chado.cvterm VALUES (3076, 25, 'Legislation', 'Works consisting of the text of proposed or enacted legislation that may be in the form of bills, laws, statutes, ordinances, or government regulations.', 3385, 0, 0);
INSERT INTO chado.cvterm VALUES (3077, 25, 'Letter', 'Work consisting of written or printed communication between individuals or between persons and representatives of corporate bodies. The correspondence may be personal or professional. In medical and other scientific publications the letter is usually from one or more authors to the editor of the journal or book publishing the item being commented upon or discussed. LETTER is often accompanied by COMMENT.', 3386, 0, 0);
INSERT INTO chado.cvterm VALUES (3078, 25, 'Manuscripts', 'Works prepared by hand including handwritten or typescript drafts of pre-publication papers or works not otherwise reproduced in multiple copies.', 3387, 0, 0);
INSERT INTO chado.cvterm VALUES (3079, 25, 'Maps', 'Works consisting of representations, normally to scale and on a flat medium, of a selection of material or abstract features on the surface of the earth. They may be used also in delineating the heavens and celestial bodies. (From Anglo-American Cataloguing Rules, 2d ed, p619)', 3388, 0, 0);
INSERT INTO chado.cvterm VALUES (3080, 25, 'Meeting Abstracts', 'For individual abstracts of presentations at meetings, congresses, conferences, symposia, colloquia, seminars, workshops, round tables, and other professional gatherings.', 3389, 0, 0);
INSERT INTO chado.cvterm VALUES (3081, 25, 'Meta Analysis', 'Works consisting of studies using a quantitative method of combining the results of independent studies (usually drawn from the published literature) and synthesizing summaries and conclusions which may be used to evaluate therapeutic effectiveness, plan new studies, etc. It is often an overview of clinical trials. It is usually called a meta-analysis by the author or sponsoring body and should be differentiated from reviews of literature.', 3390, 0, 0);
INSERT INTO chado.cvterm VALUES (3082, 25, 'Monograph', 'Work that is any publication that is not a serial or integrating resource. In cataloging usage, It is usually on a single subject or related subjects and is complete in itself, whether constructed of chapters, sections, or parts. While any article encountered in indexing journals can be, strictly speaking, a monograph, as a publication type, a monograph will refer to a cataloging item.', 3391, 0, 0);
INSERT INTO chado.cvterm VALUES (3083, 25, 'Multicenter Study', 'Work consisting of a controlled study executed by several cooperating institutions.', 3392, 0, 0);
INSERT INTO chado.cvterm VALUES (3084, 25, 'News', 'Works consisting of an announcement or statement of recent or current events of new data and matters of interest in the field of medicine or science. In some publications, such as "Nature" or "Science," the news reports are substantively written and herald medical and scientific data of vital or controversial importance.', 3393, 0, 0);
INSERT INTO chado.cvterm VALUES (3085, 25, 'Newspaper Article', 'Work consisting of a news item appearing in a general-interest newspaper or other general news periodical, containing information of current and timely interest in the field of medicine or science. This publication type should not be confused with NEWS Publication Type, reserved for news reports published in various medical or other scientific journals, such as "Nature".', 3394, 0, 0);
INSERT INTO chado.cvterm VALUES (3086, 25, 'Nurses'' Instruction', 'Works consisting of materials developed for a nursing audience.', 3395, 0, 0);
INSERT INTO chado.cvterm VALUES (3087, 25, 'Outlines', 'Works consisting of brief statements of the principal elements of a subject, usually arranged by heads and subheads.', 3396, 0, 0);
INSERT INTO chado.cvterm VALUES (3088, 25, 'Overall', 'A single citation covering papers or abstracts presented at a meeting. The publication type may be used for a single citation with or without the additional indexing or cataloging of individual papers. The individual papers, however, are not labeled OVERALL.', 3397, 0, 0);
INSERT INTO chado.cvterm VALUES (3089, 25, 'Patents (obsolete)', 'This term is obsolete in favor of the existing term ''Patent'' (TPUB:0000041).', 3398, 1, 0);
INSERT INTO chado.cvterm VALUES (3090, 25, 'Patient Education Handout', 'Works consisting of a handout or self-contained informative material used to explain a procedure or a condition or the contents of a specific article in a biomedical journal and written in non-technical language for the patient or consumer.', 3399, 0, 0);
INSERT INTO chado.cvterm VALUES (3091, 25, 'Periodical Index', 'Work consisting of a subject approach to the contents of a periodical issuing an annual, biennial, quinquennial, decennial, etc., index. The heading is used for the overall body of articles published by a periodical in the same sense that BIBLIOGRAPHY is useful when published as a single article.', 3400, 0, 0);
INSERT INTO chado.cvterm VALUES (3092, 25, 'Periodicals', 'Publications intended to be issued on an ongoing basis, generally more frequently than annually, containing separate articles, stories, or writings.', 3401, 0, 0);
INSERT INTO chado.cvterm VALUES (3093, 25, 'Personal Narratives', 'Works consisting of accounts of individual experience in relation to a particular field or of participation in related activities.', 3402, 0, 0);
INSERT INTO chado.cvterm VALUES (3094, 25, 'Pharmacopoeias', 'Authoritative works containing lists of drugs and preparations, their description, formulation, analytic composition, main chemical properties, standards for strength, purity, and dosage, chemical tests for determining identity, etc. They have the status of a standard.', 3403, 0, 0);
INSERT INTO chado.cvterm VALUES (3095, 25, 'Photographs', 'Still images produced from radiation-sensitive materials (sensitive to light, electron beams, or nuclear radiation), generally by means of the chemical action of light on a sensitive film, paper, glass, or metal. Photographs may be positive or negative, opaque or transparent.', 3404, 0, 0);
INSERT INTO chado.cvterm VALUES (3096, 25, 'Phrases', 'Works consisting of common terms, phrases, idioms, and typical conversations, e.g., between health professional and patients. These are often intended for use by non-native speakers of a language.', 3405, 0, 0);
INSERT INTO chado.cvterm VALUES (3097, 25, 'Pictorial Works', 'Works consisting exclusively or mainly of pictures but not technical drawings.', 3406, 0, 0);
INSERT INTO chado.cvterm VALUES (3098, 25, 'Poetry', 'Works that consist of literary and oral genre expressing meaning via symbolism and following formal or informal patterns.', 3407, 0, 0);
INSERT INTO chado.cvterm VALUES (3099, 25, 'Popular Works', 'Works written for non-professional or lay audiences.', 3408, 0, 0);
INSERT INTO chado.cvterm VALUES (3100, 25, 'Portraits', 'Works consisting of graphic representations, especially of the face, of real persons, usually posed, living or dead. They are pictures whose purpose is the portrayal of an individual or group of individuals, not pictures which merely include people as part of an event or scene. (From Thesaurus for Graphic Materials II, p540, 1995)', 3409, 0, 0);
INSERT INTO chado.cvterm VALUES (3101, 25, 'Postcards', 'Cards on which a message may be written or printed for mailing without an envelope. Art & Architectural Thesaurus Online www.getty.edu/research/conducting_research/vocabularies/aat/ accessed 12/18/2008', 3410, 0, 0);
INSERT INTO chado.cvterm VALUES (3102, 25, 'Posters', 'Works consisting of single or multi-sheet notices made to attract attention to events, activities, causes, goods, or services. They are for posting, usually in a public place and are chiefly pictorial. They are intended to make an immediate impression from a distance. Posters do not include poster presentations at conferences and meetings. (From Thesaurus for Graphic Materials II: Genre and Physical Characteristic Headings, 1995)', 3411, 0, 0);
INSERT INTO chado.cvterm VALUES (3103, 25, 'Practice Guideline', 'Work consisting of a set of directions or principles to assist the health care practitioner with patient care decisions about appropriate diagnostic, therapeutic, or other clinical procedures for specific clinical circumstances. Practice guidelines may be developed by government agencies at any level, institutions, organizations such as professional societies or governing boards, or by the convening of expert panels. They can provide a foundation for assessing and evaluating the quality and effectiveness of health care in terms of measuring improved health, reduction of variation in services or procedures performed, and reduction of variation in outcomes of health care delivered.', 3412, 0, 0);
INSERT INTO chado.cvterm VALUES (3104, 25, 'Price Lists', 'Works consisting of lists giving the prices of items for sale, including drugs, equipment, books, etc. Price lists are less detailed than catalogs and not as long.', 3413, 0, 0);
INSERT INTO chado.cvterm VALUES (3105, 25, 'Problems and Exercises', 'Works consisting of collections of practice questions and drills, generally for instructional or review use.', 3414, 0, 0);
INSERT INTO chado.cvterm VALUES (3106, 25, 'Programmed Instruction', 'Works consisting of sequenced self-correction texts.', 3415, 0, 0);
INSERT INTO chado.cvterm VALUES (3107, 25, 'Programs', 'Works consisting of lists of the events, pieces, performers, speakers, etc., of an entertainment, ceremony, or the like. (From: Genre Terms: A Thesaurus for Use in Rare Book and Special Collections Cataloging, 2d ed)', 3416, 0, 0);
INSERT INTO chado.cvterm VALUES (3108, 25, 'Prospectuses', 'Works consisting of advertisements separately printed and distributed by a publisher to describe and solicit orders for a recent or forthcoming publication. In the case of books, they may include sample pages. (From: ALA Glossary of Library and Information Science, 1983)', 3417, 0, 0);
INSERT INTO chado.cvterm VALUES (3109, 25, 'Publication Components', 'Specific parts of publications.', 3418, 0, 0);
INSERT INTO chado.cvterm VALUES (3110, 25, 'Publication Formats', 'Specific genre of publication.', 3419, 0, 0);
INSERT INTO chado.cvterm VALUES (3111, 25, 'Published Erratum', 'Work consisting of an acknowledgment of an error, issued by a publisher, editor, or author. It customarily cites the source where the error occurred, giving complete bibliographic data for retrieval. In the case of books and monographs, author, title, imprint, paging, and other helpful references will be given; in the case of journal articles, the author, title, paging, and journal reference will be shown. An erratum notice is variously cited as Errata or Corrigenda.', 3420, 0, 0);
INSERT INTO chado.cvterm VALUES (3112, 25, 'Randomized Controlled Trial', 'Work consisting of a clinical trial that involves at least one test treatment and one control treatment, concurrent enrollment and follow-up of the test- and control-treated groups, and in which the treatments to be administered are selected by a random process, such as the use of a random-numbers table.', 3421, 0, 0);
INSERT INTO chado.cvterm VALUES (3113, 25, 'Resource guides', 'Works listing and describing various sources of information, from multiple media or in different formats, on a given subject.', 3422, 0, 0);
INSERT INTO chado.cvterm VALUES (3114, 25, 'Retracted Publication', 'Work consisting of the designation of an article or book as retracted in whole or in part by an author or authors or an authorized representative. It identifies a citation previously published and now retracted through a formal issuance from the author, publisher, or other authorized agent, and is distinguished from RETRACTION OF PUBLICATION, which identifies the citation retracting the original published item.', 3423, 0, 0);
INSERT INTO chado.cvterm VALUES (3115, 25, 'Retraction of Publication', 'Work consisting of a statement issued by one or more authors of an article or a book, withdrawing or disavowing acknowledgment of their participation in performing research or writing the results of their study. In indexing, the retraction is sent to the editor of the publication in which the article appeared and is published under the rubric "retraction" or in the form of a letter. This publication type designates the author''s statement of retraction: it should be differentiated from RETRACTED PUBLICATION which labels the retracted publication.', 3424, 0, 0);
INSERT INTO chado.cvterm VALUES (3116, 25, 'Review', 'An article or book published after examination of published material on a subject. It may be comprehensive to various degrees and the time range of material scrutinized may be broad or narrow, but the reviews most often desired are reviews of the current literature. The textual material examined may be equally broad and can encompass, in medicine specifically, clinical material as well as experimental research or case reports. State-of-the-art reviews tend to address more current matters. A review of the literature must be differentiated from HISTORICAL ARTICLE on the same subject, but a review of historical literature is also within the scope of this publication type.', 3425, 0, 0);
INSERT INTO chado.cvterm VALUES (3117, 25, 'Scientific Integrity Review', 'Work consisting of reports by the United States Office of Research Integrity, identifying questionable research published in articles or books. Notification of the questionable data is carried in the NIH Guide for Grants and Contracts.', 3426, 0, 0);
INSERT INTO chado.cvterm VALUES (3118, 25, 'Statistics', 'Works consisting of presentations of numerical data on particular subjects.', 3427, 0, 0);
INSERT INTO chado.cvterm VALUES (3121, 25, 'Technical Report', 'Work consisting of a formal report giving details of the investigation and results of a medical or other scientific problem. When issued by a government agency or comparable official body, its contents may be classified, unclassified, or declassified with regard to security clearance. This publication type may also cover a scientific paper or article that records the current state or current position of scientific research and development. If so labeled by the editor or publisher, this publication type may be properly used for journal articles.', 3430, 0, 0);
INSERT INTO chado.cvterm VALUES (3122, 25, 'Terminology', 'Work consisting of lists of the technical terms or expressions used in a specific field. These lists may or may not be formally adopted or sanctioned by usage.', 3431, 0, 0);
INSERT INTO chado.cvterm VALUES (3123, 25, 'Textbooks', 'Books intended for use in the study of specific subjects, containing systematic presentation of the principles and essential knowledge of the subjects.', 3432, 0, 0);
INSERT INTO chado.cvterm VALUES (3124, 25, 'Twin Study', 'Work consisting of reporting using a method of detecting genetic causes in human traits and genetic factors in behavior using sets of twins.', 3433, 0, 0);
INSERT INTO chado.cvterm VALUES (3125, 25, 'Unedited Footage', 'Work consisting of untitled raw motion picture and video footage which has not been edited or assembled into a finished work. (From: Moving Image Materials: Genre Terms, 1988)', 3434, 0, 0);
INSERT INTO chado.cvterm VALUES (3126, 25, 'Union Lists', 'Works consisting of records of the holdings or items owned by two or more libraries.', 3435, 0, 0);
INSERT INTO chado.cvterm VALUES (3127, 25, 'Unpublished Works', 'Works that have not been formally published.', 3436, 0, 0);
INSERT INTO chado.cvterm VALUES (3128, 25, 'Validation Studies', 'Works consisting of research using processes by which the reliability and relevance of a procedure for a specific purpose are established.', 3437, 0, 0);
INSERT INTO chado.cvterm VALUES (3129, 25, 'Video-Audio Media', 'Used with articles which include video files or clips, or for articles which are entirely video.', 3438, 0, 0);
INSERT INTO chado.cvterm VALUES (3130, 25, 'Webcasts', 'Content from transmission of live or pre-recorded audio or video via connection or download from the INTERNET.', 3439, 0, 0);
INSERT INTO chado.cvterm VALUES (3131, 25, 'Research Support, American Recovery and Reinvestment Act', '', 3440, 0, 0);
INSERT INTO chado.cvterm VALUES (3132, 25, 'Research Support, N.I.H., Extramural', 'A designation for publications of research resulting from extramural research funded by the National Institutes of Health.', 3441, 0, 0);
INSERT INTO chado.cvterm VALUES (3133, 25, 'Research Support, N.I.H., Intramural', 'A designation for publications of research resulting from intramural research at the National Institutes of Health.', 3442, 0, 0);
INSERT INTO chado.cvterm VALUES (3134, 25, 'Research Support, Non-U.S. Gov''t', '', 3443, 0, 0);
INSERT INTO chado.cvterm VALUES (3135, 25, 'Research Support, U.S. Gov''t, Non-P.H.S.', '', 3444, 0, 0);
INSERT INTO chado.cvterm VALUES (3136, 25, 'Research Support, U.S. Gov''t, P.H.S.', '', 3445, 0, 0);
INSERT INTO chado.cvterm VALUES (3137, 25, 'Research Support, U.S. Government', 'For publications noted as supported by US Government.', 3446, 0, 0);
INSERT INTO chado.cvterm VALUES (3138, 25, 'English Abstract', '', 3447, 0, 0);
INSERT INTO chado.cvterm VALUES (3139, 25, 'Meta-Analysis', 'Works consisting of studies using a quantitative method of combining the results of independent studies (usually drawn from the published literature) and synthesizing summaries and conclusions which may be used to evaluate therapeutic effectiveness, plan new studies, etc. It is often an overview of clinical trials. It is usually called a meta-analysis by the author or sponsoring body and should be differentiated from reviews of literature.', 3448, 0, 0);
INSERT INTO chado.cvterm VALUES (3140, 25, 'Publisher', '', 3449, 0, 0);
INSERT INTO chado.cvterm VALUES (3141, 25, 'Published Location', '', 3450, 0, 0);
INSERT INTO chado.cvterm VALUES (3142, 25, 'Prefix', 'A prefix for a name such as a title (e.g. Mr., Mrs., Dr., Chief, Esquire, etc.)', 3451, 0, 0);
INSERT INTO chado.cvterm VALUES (3143, 25, 'ISBN', 'Internaltional Standard Book Number', 3452, 0, 0);
INSERT INTO chado.cvterm VALUES (3144, 25, 'Notes', 'Information about the publication that is not classified using another term.', 3453, 0, 0);
INSERT INTO chado.cvterm VALUES (3145, 25, 'Thesis', 'A Master''s or PhD thesis.', 3454, 0, 0);
INSERT INTO chado.cvterm VALUES (3146, 25, 'Journal Alias', 'An alternate name for a journal', 3455, 0, 0);
INSERT INTO chado.cvterm VALUES (3147, 25, 'Book Name', 'The name of a book to which a book chapter belongs.', 3456, 0, 0);
INSERT INTO chado.cvterm VALUES (3148, 25, 'Media Alias', 'An alternate name for a journal, book, conference proceedings, etc.', 3457, 0, 0);
INSERT INTO chado.cvterm VALUES (3149, 25, 'Media Code', 'A unique special code for a journal, book, conference proceeding, etc', 3458, 0, 0);
INSERT INTO chado.cvterm VALUES (3150, 25, 'Publication Code', 'A unique special code for journal article, book, book chapter or any publication type.', 3459, 0, 0);
INSERT INTO chado.cvterm VALUES (3151, 25, 'Patent Number', 'A unique special code for journal article, book, book chapter or any publication type.', 3460, 0, 0);
INSERT INTO chado.contact VALUES (1, NULL, 'null', 'null');
INSERT INTO chado.pub VALUES (1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 'null', 'null', 1, false, NULL, NULL);
INSERT INTO chado.chadoprop VALUES (1, 2, '1.3', 0);
INSERT INTO chado.cv_root_mview VALUES ('Address', 2929, 24, 'tripal_contact');
INSERT INTO chado.cv_root_mview VALUES ('Affiliation', 2925, 24, 'tripal_contact');
INSERT INTO chado.cv_root_mview VALUES ('Contact Type', 2911, 24, 'tripal_contact');
INSERT INTO chado.cv_root_mview VALUES ('Publication', 172, 25, 'tripal_pub');
INSERT INTO chado.cv_root_mview VALUES ('sequence_attribute', 784, 22, 'sequence');
INSERT INTO chado.cv_root_mview VALUES ('sequence_collection', 1367, 22, 'sequence');
INSERT INTO chado.cv_root_mview VALUES ('sequence_feature', 162, 22, 'sequence');
INSERT INTO chado.cv_root_mview VALUES ('sequence_variant', 166, 22, 'sequence');
INSERT INTO chado.cv_root_mview VALUES ('taxonomic_rank', 2851, 23, 'taxonomic_rank');
INSERT INTO chado.cvterm_dbxref VALUES (1, 420, 421, 0);
INSERT INTO chado.cvterm_dbxref VALUES (2, 354, 497, 0);
INSERT INTO chado.cvterm_dbxref VALUES (3, 354, 498, 0);
INSERT INTO chado.cvterm_dbxref VALUES (4, 629, 633, 0);
INSERT INTO chado.cvterm_dbxref VALUES (5, 679, 684, 0);
INSERT INTO chado.cvterm_dbxref VALUES (6, 786, 792, 0);
INSERT INTO chado.cvterm_dbxref VALUES (7, 796, 803, 0);
INSERT INTO chado.cvterm_dbxref VALUES (8, 805, 813, 0);
INSERT INTO chado.cvterm_dbxref VALUES (9, 805, 814, 0);
INSERT INTO chado.cvterm_dbxref VALUES (10, 805, 815, 0);
INSERT INTO chado.cvterm_dbxref VALUES (11, 808, 819, 0);
INSERT INTO chado.cvterm_dbxref VALUES (12, 812, 824, 0);
INSERT INTO chado.cvterm_dbxref VALUES (13, 971, 984, 0);
INSERT INTO chado.cvterm_dbxref VALUES (14, 983, 997, 0);
INSERT INTO chado.cvterm_dbxref VALUES (15, 1058, 1073, 0);
INSERT INTO chado.cvterm_dbxref VALUES (16, 1077, 1093, 0);
INSERT INTO chado.cvterm_dbxref VALUES (17, 1077, 1094, 0);
INSERT INTO chado.cvterm_dbxref VALUES (18, 1100, 1118, 0);
INSERT INTO chado.cvterm_dbxref VALUES (19, 1135, 1154, 0);
INSERT INTO chado.cvterm_dbxref VALUES (20, 390, 1165, 0);
INSERT INTO chado.cvterm_dbxref VALUES (21, 1065, 1168, 0);
INSERT INTO chado.cvterm_dbxref VALUES (22, 1207, 1229, 0);
INSERT INTO chado.cvterm_dbxref VALUES (23, 813, 1242, 0);
INSERT INTO chado.cvterm_dbxref VALUES (24, 813, 1243, 0);
INSERT INTO chado.cvterm_dbxref VALUES (25, 1256, 1281, 0);
INSERT INTO chado.cvterm_dbxref VALUES (26, 1147, 1346, 0);
INSERT INTO chado.cvterm_dbxref VALUES (27, 1357, 1384, 0);
INSERT INTO chado.cvterm_dbxref VALUES (28, 1362, 1390, 0);
INSERT INTO chado.cvterm_dbxref VALUES (29, 496, 1422, 0);
INSERT INTO chado.cvterm_dbxref VALUES (30, 496, 1423, 0);
INSERT INTO chado.cvterm_dbxref VALUES (31, 1395, 1426, 0);
INSERT INTO chado.cvterm_dbxref VALUES (32, 811, 1427, 0);
INSERT INTO chado.cvterm_dbxref VALUES (33, 815, 1429, 0);
INSERT INTO chado.cvterm_dbxref VALUES (34, 1397, 1431, 0);
INSERT INTO chado.cvterm_dbxref VALUES (35, 1398, 1433, 0);
INSERT INTO chado.cvterm_dbxref VALUES (36, 1399, 1435, 0);
INSERT INTO chado.cvterm_dbxref VALUES (37, 1400, 1437, 0);
INSERT INTO chado.cvterm_dbxref VALUES (38, 806, 1438, 0);
INSERT INTO chado.cvterm_dbxref VALUES (39, 1401, 1440, 0);
INSERT INTO chado.cvterm_dbxref VALUES (40, 1402, 1442, 0);
INSERT INTO chado.cvterm_dbxref VALUES (41, 1403, 1444, 0);
INSERT INTO chado.cvterm_dbxref VALUES (42, 1404, 1446, 0);
INSERT INTO chado.cvterm_dbxref VALUES (43, 1405, 1448, 0);
INSERT INTO chado.cvterm_dbxref VALUES (44, 1406, 1450, 0);
INSERT INTO chado.cvterm_dbxref VALUES (45, 1407, 1452, 0);
INSERT INTO chado.cvterm_dbxref VALUES (46, 1408, 1454, 0);
INSERT INTO chado.cvterm_dbxref VALUES (47, 1409, 1456, 0);
INSERT INTO chado.cvterm_dbxref VALUES (48, 1410, 1458, 0);
INSERT INTO chado.cvterm_dbxref VALUES (49, 1411, 1460, 0);
INSERT INTO chado.cvterm_dbxref VALUES (50, 1413, 1463, 0);
INSERT INTO chado.cvterm_dbxref VALUES (51, 1414, 1465, 0);
INSERT INTO chado.cvterm_dbxref VALUES (52, 1415, 1467, 0);
INSERT INTO chado.cvterm_dbxref VALUES (53, 1416, 1469, 0);
INSERT INTO chado.cvterm_dbxref VALUES (54, 1417, 1471, 0);
INSERT INTO chado.cvterm_dbxref VALUES (55, 1418, 1473, 0);
INSERT INTO chado.cvterm_dbxref VALUES (56, 1419, 1475, 0);
INSERT INTO chado.cvterm_dbxref VALUES (57, 1420, 1477, 0);
INSERT INTO chado.cvterm_dbxref VALUES (58, 1422, 1480, 0);
INSERT INTO chado.cvterm_dbxref VALUES (59, 1423, 1482, 0);
INSERT INTO chado.cvterm_dbxref VALUES (60, 1424, 1484, 0);
INSERT INTO chado.cvterm_dbxref VALUES (61, 1427, 1488, 0);
INSERT INTO chado.cvterm_dbxref VALUES (62, 1428, 1490, 0);
INSERT INTO chado.cvterm_dbxref VALUES (63, 1429, 1492, 0);
INSERT INTO chado.cvterm_dbxref VALUES (64, 1430, 1494, 0);
INSERT INTO chado.cvterm_dbxref VALUES (65, 1431, 1496, 0);
INSERT INTO chado.cvterm_dbxref VALUES (66, 1432, 1498, 0);
INSERT INTO chado.cvterm_dbxref VALUES (67, 1433, 1500, 0);
INSERT INTO chado.cvterm_dbxref VALUES (68, 1434, 1502, 0);
INSERT INTO chado.cvterm_dbxref VALUES (69, 1435, 1504, 0);
INSERT INTO chado.cvterm_dbxref VALUES (70, 1436, 1506, 0);
INSERT INTO chado.cvterm_dbxref VALUES (71, 1437, 1508, 0);
INSERT INTO chado.cvterm_dbxref VALUES (72, 1438, 1510, 0);
INSERT INTO chado.cvterm_dbxref VALUES (73, 1441, 1514, 0);
INSERT INTO chado.cvterm_dbxref VALUES (74, 1443, 1517, 0);
INSERT INTO chado.cvterm_dbxref VALUES (75, 1444, 1519, 0);
INSERT INTO chado.cvterm_dbxref VALUES (76, 1445, 1521, 0);
INSERT INTO chado.cvterm_dbxref VALUES (77, 1446, 1523, 0);
INSERT INTO chado.cvterm_dbxref VALUES (78, 1447, 1525, 0);
INSERT INTO chado.cvterm_dbxref VALUES (79, 1448, 1527, 0);
INSERT INTO chado.cvterm_dbxref VALUES (80, 1449, 1529, 0);
INSERT INTO chado.cvterm_dbxref VALUES (81, 1450, 1531, 0);
INSERT INTO chado.cvterm_dbxref VALUES (82, 1412, 1532, 0);
INSERT INTO chado.cvterm_dbxref VALUES (83, 1451, 1534, 0);
INSERT INTO chado.cvterm_dbxref VALUES (84, 1452, 1536, 0);
INSERT INTO chado.cvterm_dbxref VALUES (85, 1453, 1538, 0);
INSERT INTO chado.cvterm_dbxref VALUES (86, 1454, 1540, 0);
INSERT INTO chado.cvterm_dbxref VALUES (87, 1455, 1542, 0);
INSERT INTO chado.cvterm_dbxref VALUES (88, 1456, 1544, 0);
INSERT INTO chado.cvterm_dbxref VALUES (89, 1457, 1546, 0);
INSERT INTO chado.cvterm_dbxref VALUES (90, 1458, 1548, 0);
INSERT INTO chado.cvterm_dbxref VALUES (91, 1459, 1550, 0);
INSERT INTO chado.cvterm_dbxref VALUES (92, 1460, 1552, 0);
INSERT INTO chado.cvterm_dbxref VALUES (93, 1461, 1554, 0);
INSERT INTO chado.cvterm_dbxref VALUES (94, 1462, 1556, 0);
INSERT INTO chado.cvterm_dbxref VALUES (95, 1463, 1558, 0);
INSERT INTO chado.cvterm_dbxref VALUES (96, 1257, 1559, 0);
INSERT INTO chado.cvterm_dbxref VALUES (97, 1464, 1561, 0);
INSERT INTO chado.cvterm_dbxref VALUES (98, 1465, 1563, 0);
INSERT INTO chado.cvterm_dbxref VALUES (99, 1466, 1565, 0);
INSERT INTO chado.cvterm_dbxref VALUES (100, 1467, 1567, 0);
INSERT INTO chado.cvterm_dbxref VALUES (101, 1468, 1569, 0);
INSERT INTO chado.cvterm_dbxref VALUES (102, 1469, 1571, 0);
INSERT INTO chado.cvterm_dbxref VALUES (103, 1470, 1573, 0);
INSERT INTO chado.cvterm_dbxref VALUES (104, 1471, 1575, 0);
INSERT INTO chado.cvterm_dbxref VALUES (105, 1472, 1577, 0);
INSERT INTO chado.cvterm_dbxref VALUES (106, 1473, 1579, 0);
INSERT INTO chado.cvterm_dbxref VALUES (107, 1474, 1581, 0);
INSERT INTO chado.cvterm_dbxref VALUES (108, 1475, 1583, 0);
INSERT INTO chado.cvterm_dbxref VALUES (109, 1476, 1585, 0);
INSERT INTO chado.cvterm_dbxref VALUES (110, 1477, 1587, 0);
INSERT INTO chado.cvterm_dbxref VALUES (111, 1478, 1589, 0);
INSERT INTO chado.cvterm_dbxref VALUES (112, 1479, 1591, 0);
INSERT INTO chado.cvterm_dbxref VALUES (113, 1480, 1593, 0);
INSERT INTO chado.cvterm_dbxref VALUES (114, 1481, 1595, 0);
INSERT INTO chado.cvterm_dbxref VALUES (115, 1482, 1597, 0);
INSERT INTO chado.cvterm_dbxref VALUES (116, 1483, 1599, 0);
INSERT INTO chado.cvterm_dbxref VALUES (117, 1484, 1601, 0);
INSERT INTO chado.cvterm_dbxref VALUES (118, 1484, 1602, 0);
INSERT INTO chado.cvterm_dbxref VALUES (119, 1556, 1675, 0);
INSERT INTO chado.cvterm_dbxref VALUES (120, 1558, 1678, 0);
INSERT INTO chado.cvterm_dbxref VALUES (121, 1586, 1707, 0);
INSERT INTO chado.cvterm_dbxref VALUES (122, 1597, 1719, 0);
INSERT INTO chado.cvterm_dbxref VALUES (123, 1598, 1721, 0);
INSERT INTO chado.cvterm_dbxref VALUES (124, 1599, 1723, 0);
INSERT INTO chado.cvterm_dbxref VALUES (125, 1600, 1725, 0);
INSERT INTO chado.cvterm_dbxref VALUES (126, 1601, 1727, 0);
INSERT INTO chado.cvterm_dbxref VALUES (127, 1602, 1729, 0);
INSERT INTO chado.cvterm_dbxref VALUES (128, 1603, 1731, 0);
INSERT INTO chado.cvterm_dbxref VALUES (129, 1604, 1733, 0);
INSERT INTO chado.cvterm_dbxref VALUES (130, 1605, 1735, 0);
INSERT INTO chado.cvterm_dbxref VALUES (131, 1606, 1737, 0);
INSERT INTO chado.cvterm_dbxref VALUES (132, 1607, 1739, 0);
INSERT INTO chado.cvterm_dbxref VALUES (133, 1608, 1741, 0);
INSERT INTO chado.cvterm_dbxref VALUES (134, 1609, 1743, 0);
INSERT INTO chado.cvterm_dbxref VALUES (135, 1610, 1745, 0);
INSERT INTO chado.cvterm_dbxref VALUES (136, 1611, 1747, 0);
INSERT INTO chado.cvterm_dbxref VALUES (137, 1612, 1749, 0);
INSERT INTO chado.cvterm_dbxref VALUES (138, 1613, 1751, 0);
INSERT INTO chado.cvterm_dbxref VALUES (139, 1614, 1753, 0);
INSERT INTO chado.cvterm_dbxref VALUES (140, 1615, 1755, 0);
INSERT INTO chado.cvterm_dbxref VALUES (141, 1616, 1757, 0);
INSERT INTO chado.cvterm_dbxref VALUES (142, 1617, 1759, 0);
INSERT INTO chado.cvterm_dbxref VALUES (143, 1618, 1761, 0);
INSERT INTO chado.cvterm_dbxref VALUES (144, 1619, 1763, 0);
INSERT INTO chado.cvterm_dbxref VALUES (145, 1620, 1765, 0);
INSERT INTO chado.cvterm_dbxref VALUES (146, 1621, 1767, 0);
INSERT INTO chado.cvterm_dbxref VALUES (147, 1622, 1769, 0);
INSERT INTO chado.cvterm_dbxref VALUES (148, 1623, 1771, 0);
INSERT INTO chado.cvterm_dbxref VALUES (149, 1624, 1773, 0);
INSERT INTO chado.cvterm_dbxref VALUES (150, 1625, 1775, 0);
INSERT INTO chado.cvterm_dbxref VALUES (151, 1626, 1777, 0);
INSERT INTO chado.cvterm_dbxref VALUES (152, 1627, 1779, 0);
INSERT INTO chado.cvterm_dbxref VALUES (153, 1628, 1781, 0);
INSERT INTO chado.cvterm_dbxref VALUES (154, 1629, 1783, 0);
INSERT INTO chado.cvterm_dbxref VALUES (155, 1630, 1785, 0);
INSERT INTO chado.cvterm_dbxref VALUES (156, 1631, 1787, 0);
INSERT INTO chado.cvterm_dbxref VALUES (157, 1632, 1789, 0);
INSERT INTO chado.cvterm_dbxref VALUES (158, 1633, 1791, 0);
INSERT INTO chado.cvterm_dbxref VALUES (159, 1634, 1793, 0);
INSERT INTO chado.cvterm_dbxref VALUES (160, 1636, 1796, 0);
INSERT INTO chado.cvterm_dbxref VALUES (161, 1637, 1798, 0);
INSERT INTO chado.cvterm_dbxref VALUES (162, 1638, 1800, 0);
INSERT INTO chado.cvterm_dbxref VALUES (163, 1639, 1802, 0);
INSERT INTO chado.cvterm_dbxref VALUES (164, 1640, 1804, 0);
INSERT INTO chado.cvterm_dbxref VALUES (165, 1641, 1806, 0);
INSERT INTO chado.cvterm_dbxref VALUES (166, 1642, 1808, 0);
INSERT INTO chado.cvterm_dbxref VALUES (167, 1643, 1810, 0);
INSERT INTO chado.cvterm_dbxref VALUES (168, 1644, 1812, 0);
INSERT INTO chado.cvterm_dbxref VALUES (169, 1645, 1814, 0);
INSERT INTO chado.cvterm_dbxref VALUES (170, 1646, 1816, 0);
INSERT INTO chado.cvterm_dbxref VALUES (171, 1647, 1818, 0);
INSERT INTO chado.cvterm_dbxref VALUES (172, 1648, 1820, 0);
INSERT INTO chado.cvterm_dbxref VALUES (173, 1649, 1822, 0);
INSERT INTO chado.cvterm_dbxref VALUES (174, 1650, 1824, 0);
INSERT INTO chado.cvterm_dbxref VALUES (175, 1651, 1826, 0);
INSERT INTO chado.cvterm_dbxref VALUES (176, 1652, 1828, 0);
INSERT INTO chado.cvterm_dbxref VALUES (177, 1653, 1830, 0);
INSERT INTO chado.cvterm_dbxref VALUES (178, 1654, 1832, 0);
INSERT INTO chado.cvterm_dbxref VALUES (179, 1655, 1834, 0);
INSERT INTO chado.cvterm_dbxref VALUES (180, 1656, 1836, 0);
INSERT INTO chado.cvterm_dbxref VALUES (181, 1657, 1838, 0);
INSERT INTO chado.cvterm_dbxref VALUES (182, 1658, 1840, 0);
INSERT INTO chado.cvterm_dbxref VALUES (183, 1659, 1842, 0);
INSERT INTO chado.cvterm_dbxref VALUES (184, 1660, 1844, 0);
INSERT INTO chado.cvterm_dbxref VALUES (185, 1661, 1846, 0);
INSERT INTO chado.cvterm_dbxref VALUES (186, 1662, 1848, 0);
INSERT INTO chado.cvterm_dbxref VALUES (187, 1663, 1850, 0);
INSERT INTO chado.cvterm_dbxref VALUES (188, 1664, 1852, 0);
INSERT INTO chado.cvterm_dbxref VALUES (189, 1665, 1854, 0);
INSERT INTO chado.cvterm_dbxref VALUES (190, 1666, 1856, 0);
INSERT INTO chado.cvterm_dbxref VALUES (191, 1667, 1858, 0);
INSERT INTO chado.cvterm_dbxref VALUES (192, 1668, 1860, 0);
INSERT INTO chado.cvterm_dbxref VALUES (193, 1669, 1862, 0);
INSERT INTO chado.cvterm_dbxref VALUES (194, 1670, 1864, 0);
INSERT INTO chado.cvterm_dbxref VALUES (195, 1671, 1866, 0);
INSERT INTO chado.cvterm_dbxref VALUES (196, 1672, 1868, 0);
INSERT INTO chado.cvterm_dbxref VALUES (197, 1673, 1866, 0);
INSERT INTO chado.cvterm_dbxref VALUES (198, 1674, 1871, 0);
INSERT INTO chado.cvterm_dbxref VALUES (199, 1675, 1873, 0);
INSERT INTO chado.cvterm_dbxref VALUES (200, 1676, 1875, 0);
INSERT INTO chado.cvterm_dbxref VALUES (201, 1677, 1877, 0);
INSERT INTO chado.cvterm_dbxref VALUES (202, 1678, 1879, 0);
INSERT INTO chado.cvterm_dbxref VALUES (203, 1679, 1881, 0);
INSERT INTO chado.cvterm_dbxref VALUES (204, 1680, 1883, 0);
INSERT INTO chado.cvterm_dbxref VALUES (205, 1681, 1885, 0);
INSERT INTO chado.cvterm_dbxref VALUES (206, 1682, 1887, 0);
INSERT INTO chado.cvterm_dbxref VALUES (207, 1683, 1889, 0);
INSERT INTO chado.cvterm_dbxref VALUES (208, 1684, 1891, 0);
INSERT INTO chado.cvterm_dbxref VALUES (209, 1685, 1893, 0);
INSERT INTO chado.cvterm_dbxref VALUES (210, 1686, 1895, 0);
INSERT INTO chado.cvterm_dbxref VALUES (211, 1687, 1897, 0);
INSERT INTO chado.cvterm_dbxref VALUES (212, 1688, 1899, 0);
INSERT INTO chado.cvterm_dbxref VALUES (213, 1689, 1901, 0);
INSERT INTO chado.cvterm_dbxref VALUES (214, 1690, 1903, 0);
INSERT INTO chado.cvterm_dbxref VALUES (215, 1691, 1905, 0);
INSERT INTO chado.cvterm_dbxref VALUES (216, 1692, 1907, 0);
INSERT INTO chado.cvterm_dbxref VALUES (217, 1693, 1909, 0);
INSERT INTO chado.cvterm_dbxref VALUES (218, 1694, 1911, 0);
INSERT INTO chado.cvterm_dbxref VALUES (219, 1695, 1913, 0);
INSERT INTO chado.cvterm_dbxref VALUES (220, 1696, 1915, 0);
INSERT INTO chado.cvterm_dbxref VALUES (221, 1697, 1917, 0);
INSERT INTO chado.cvterm_dbxref VALUES (222, 1698, 1919, 0);
INSERT INTO chado.cvterm_dbxref VALUES (223, 1699, 1921, 0);
INSERT INTO chado.cvterm_dbxref VALUES (224, 1700, 1923, 0);
INSERT INTO chado.cvterm_dbxref VALUES (225, 1701, 1925, 0);
INSERT INTO chado.cvterm_dbxref VALUES (226, 1705, 1930, 0);
INSERT INTO chado.cvterm_dbxref VALUES (227, 1706, 1932, 0);
INSERT INTO chado.cvterm_dbxref VALUES (228, 1707, 1934, 0);
INSERT INTO chado.cvterm_dbxref VALUES (229, 1708, 1936, 0);
INSERT INTO chado.cvterm_dbxref VALUES (230, 1709, 1938, 0);
INSERT INTO chado.cvterm_dbxref VALUES (231, 1710, 1940, 0);
INSERT INTO chado.cvterm_dbxref VALUES (232, 1711, 1942, 0);
INSERT INTO chado.cvterm_dbxref VALUES (233, 1712, 1944, 0);
INSERT INTO chado.cvterm_dbxref VALUES (234, 1713, 1946, 0);
INSERT INTO chado.cvterm_dbxref VALUES (235, 1714, 1948, 0);
INSERT INTO chado.cvterm_dbxref VALUES (236, 1715, 1950, 0);
INSERT INTO chado.cvterm_dbxref VALUES (237, 1716, 1952, 0);
INSERT INTO chado.cvterm_dbxref VALUES (238, 1717, 1954, 0);
INSERT INTO chado.cvterm_dbxref VALUES (239, 1718, 1956, 0);
INSERT INTO chado.cvterm_dbxref VALUES (240, 1719, 1958, 0);
INSERT INTO chado.cvterm_dbxref VALUES (241, 1720, 1960, 0);
INSERT INTO chado.cvterm_dbxref VALUES (242, 1721, 1962, 0);
INSERT INTO chado.cvterm_dbxref VALUES (243, 1722, 1964, 0);
INSERT INTO chado.cvterm_dbxref VALUES (244, 1723, 1966, 0);
INSERT INTO chado.cvterm_dbxref VALUES (245, 1724, 1968, 0);
INSERT INTO chado.cvterm_dbxref VALUES (246, 1725, 1970, 0);
INSERT INTO chado.cvterm_dbxref VALUES (247, 1843, 2089, 0);
INSERT INTO chado.cvterm_dbxref VALUES (248, 1882, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (249, 1884, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (250, 1888, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (251, 1883, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (252, 1897, 2145, 0);
INSERT INTO chado.cvterm_dbxref VALUES (253, 1897, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (254, 1900, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (255, 1900, 2149, 0);
INSERT INTO chado.cvterm_dbxref VALUES (256, 1901, 2151, 0);
INSERT INTO chado.cvterm_dbxref VALUES (257, 1901, 2152, 0);
INSERT INTO chado.cvterm_dbxref VALUES (258, 1901, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (259, 1901, 2153, 0);
INSERT INTO chado.cvterm_dbxref VALUES (260, 1902, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (261, 1903, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (262, 1904, 2157, 0);
INSERT INTO chado.cvterm_dbxref VALUES (263, 1906, 2160, 0);
INSERT INTO chado.cvterm_dbxref VALUES (264, 1880, 2162, 0);
INSERT INTO chado.cvterm_dbxref VALUES (265, 1880, 2163, 0);
INSERT INTO chado.cvterm_dbxref VALUES (266, 1915, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (267, 1921, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (268, 1922, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (269, 1923, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (270, 1926, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (271, 1936, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (272, 1939, 2196, 0);
INSERT INTO chado.cvterm_dbxref VALUES (273, 2090, 2348, 0);
INSERT INTO chado.cvterm_dbxref VALUES (274, 1881, 2379, 0);
INSERT INTO chado.cvterm_dbxref VALUES (275, 1881, 2129, 0);
INSERT INTO chado.cvterm_dbxref VALUES (276, 2122, 2382, 0);
INSERT INTO chado.cvterm_dbxref VALUES (277, 2124, 2385, 0);
INSERT INTO chado.cvterm_dbxref VALUES (278, 2145, 2407, 0);
INSERT INTO chado.cvterm_dbxref VALUES (279, 2311, 2574, 0);
INSERT INTO chado.cvterm_dbxref VALUES (280, 2314, 2578, 0);
INSERT INTO chado.cvterm_dbxref VALUES (281, 2408, 2673, 0);
INSERT INTO chado.cvterm_dbxref VALUES (282, 2419, 2685, 0);
INSERT INTO chado.cvterm_dbxref VALUES (283, 2453, 2720, 0);
INSERT INTO chado.cvterm_dbxref VALUES (284, 2503, 2771, 0);
INSERT INTO chado.cvterm_dbxref VALUES (285, 2539, 2808, 0);
INSERT INTO chado.cvterm_dbxref VALUES (286, 2559, 2829, 0);
INSERT INTO chado.cvterm_dbxref VALUES (287, 2595, 2866, 0);
INSERT INTO chado.cvterm_dbxref VALUES (288, 1796, 2940, 0);
INSERT INTO chado.cvterm_dbxref VALUES (289, 2692, 2965, 0);
INSERT INTO chado.cvterm_dbxref VALUES (290, 2221, 2966, 0);
INSERT INTO chado.cvterm_dbxref VALUES (291, 752, 2967, 0);
INSERT INTO chado.cvterm_dbxref VALUES (292, 2700, 2976, 0);
INSERT INTO chado.cvterm_dbxref VALUES (293, 2700, 2977, 0);
INSERT INTO chado.cvterm_dbxref VALUES (294, 2735, 3013, 0);
INSERT INTO chado.cvterm_dbxref VALUES (295, 2735, 3014, 0);
INSERT INTO chado.cvterm_dbxref VALUES (296, 2756, 3036, 0);
INSERT INTO chado.cvterm_dbxref VALUES (297, 2756, 3037, 0);
INSERT INTO chado.cvterm_dbxref VALUES (298, 2852, 3134, 0);
INSERT INTO chado.cvterm_dbxref VALUES (299, 2853, 3136, 0);
INSERT INTO chado.cvterm_dbxref VALUES (300, 2854, 3138, 0);
INSERT INTO chado.cvterm_dbxref VALUES (301, 2855, 3140, 0);
INSERT INTO chado.cvterm_dbxref VALUES (302, 169, 3141, 0);
INSERT INTO chado.cvterm_dbxref VALUES (303, 170, 3142, 0);
INSERT INTO chado.cvterm_dbxref VALUES (304, 2856, 3144, 0);
INSERT INTO chado.cvterm_dbxref VALUES (305, 2857, 3146, 0);
INSERT INTO chado.cvterm_dbxref VALUES (306, 2858, 3148, 0);
INSERT INTO chado.cvterm_dbxref VALUES (307, 2859, 3150, 0);
INSERT INTO chado.cvterm_dbxref VALUES (308, 2860, 3152, 0);
INSERT INTO chado.cvterm_dbxref VALUES (309, 2862, 3155, 0);
INSERT INTO chado.cvterm_dbxref VALUES (310, 2863, 3157, 0);
INSERT INTO chado.cvterm_dbxref VALUES (311, 2864, 3159, 0);
INSERT INTO chado.cvterm_dbxref VALUES (312, 2865, 3161, 0);
INSERT INTO chado.cvterm_dbxref VALUES (313, 2866, 3163, 0);
INSERT INTO chado.cvterm_dbxref VALUES (314, 2867, 3165, 0);
INSERT INTO chado.cvterm_dbxref VALUES (315, 2868, 3167, 0);
INSERT INTO chado.cvterm_dbxref VALUES (316, 2869, 3169, 0);
INSERT INTO chado.cvterm_dbxref VALUES (317, 2870, 3171, 0);
INSERT INTO chado.cvterm_dbxref VALUES (318, 2871, 3173, 0);
INSERT INTO chado.cvterm_dbxref VALUES (319, 2872, 3175, 0);
INSERT INTO chado.cvterm_dbxref VALUES (320, 2873, 3177, 0);
INSERT INTO chado.cvterm_dbxref VALUES (321, 2874, 3179, 0);
INSERT INTO chado.cvterm_dbxref VALUES (322, 2875, 3181, 0);
INSERT INTO chado.cvterm_dbxref VALUES (323, 2876, 3183, 0);
INSERT INTO chado.cvterm_dbxref VALUES (324, 2877, 3185, 0);
INSERT INTO chado.cvterm_dbxref VALUES (325, 2878, 3187, 0);
INSERT INTO chado.cvterm_relationship VALUES (1, 211, 210, 212);
INSERT INTO chado.cvterm_relationship VALUES (2, 211, 227, 228);
INSERT INTO chado.cvterm_relationship VALUES (3, 211, 231, 232);
INSERT INTO chado.cvterm_relationship VALUES (4, 211, 233, 234);
INSERT INTO chado.cvterm_relationship VALUES (5, 211, 238, 234);
INSERT INTO chado.cvterm_relationship VALUES (6, 211, 239, 231);
INSERT INTO chado.cvterm_relationship VALUES (7, 211, 240, 231);
INSERT INTO chado.cvterm_relationship VALUES (8, 211, 242, 231);
INSERT INTO chado.cvterm_relationship VALUES (9, 211, 243, 212);
INSERT INTO chado.cvterm_relationship VALUES (10, 211, 260, 162);
INSERT INTO chado.cvterm_relationship VALUES (11, 211, 261, 262);
INSERT INTO chado.cvterm_relationship VALUES (12, 211, 263, 261);
INSERT INTO chado.cvterm_relationship VALUES (13, 211, 264, 265);
INSERT INTO chado.cvterm_relationship VALUES (14, 211, 266, 267);
INSERT INTO chado.cvterm_relationship VALUES (15, 211, 268, 269);
INSERT INTO chado.cvterm_relationship VALUES (16, 211, 270, 271);
INSERT INTO chado.cvterm_relationship VALUES (17, 234, 270, 272);
INSERT INTO chado.cvterm_relationship VALUES (18, 234, 270, 273);
INSERT INTO chado.cvterm_relationship VALUES (19, 211, 276, 277);
INSERT INTO chado.cvterm_relationship VALUES (20, 211, 278, 277);
INSERT INTO chado.cvterm_relationship VALUES (21, 211, 279, 280);
INSERT INTO chado.cvterm_relationship VALUES (22, 211, 281, 282);
INSERT INTO chado.cvterm_relationship VALUES (23, 216, 281, 279);
INSERT INTO chado.cvterm_relationship VALUES (24, 211, 283, 284);
INSERT INTO chado.cvterm_relationship VALUES (25, 234, 283, 285);
INSERT INTO chado.cvterm_relationship VALUES (26, 211, 286, 284);
INSERT INTO chado.cvterm_relationship VALUES (27, 234, 286, 285);
INSERT INTO chado.cvterm_relationship VALUES (28, 211, 287, 284);
INSERT INTO chado.cvterm_relationship VALUES (29, 234, 287, 285);
INSERT INTO chado.cvterm_relationship VALUES (30, 211, 288, 289);
INSERT INTO chado.cvterm_relationship VALUES (31, 234, 288, 290);
INSERT INTO chado.cvterm_relationship VALUES (32, 211, 291, 262);
INSERT INTO chado.cvterm_relationship VALUES (33, 211, 292, 293);
INSERT INTO chado.cvterm_relationship VALUES (34, 211, 294, 292);
INSERT INTO chado.cvterm_relationship VALUES (35, 211, 295, 293);
INSERT INTO chado.cvterm_relationship VALUES (36, 211, 296, 294);
INSERT INTO chado.cvterm_relationship VALUES (37, 211, 297, 294);
INSERT INTO chado.cvterm_relationship VALUES (38, 211, 298, 292);
INSERT INTO chado.cvterm_relationship VALUES (39, 211, 299, 293);
INSERT INTO chado.cvterm_relationship VALUES (40, 211, 300, 299);
INSERT INTO chado.cvterm_relationship VALUES (41, 211, 301, 261);
INSERT INTO chado.cvterm_relationship VALUES (42, 211, 302, 301);
INSERT INTO chado.cvterm_relationship VALUES (43, 211, 303, 301);
INSERT INTO chado.cvterm_relationship VALUES (44, 211, 304, 305);
INSERT INTO chado.cvterm_relationship VALUES (45, 211, 306, 304);
INSERT INTO chado.cvterm_relationship VALUES (46, 211, 307, 304);
INSERT INTO chado.cvterm_relationship VALUES (47, 211, 308, 309);
INSERT INTO chado.cvterm_relationship VALUES (48, 230, 308, 310);
INSERT INTO chado.cvterm_relationship VALUES (49, 211, 311, 312);
INSERT INTO chado.cvterm_relationship VALUES (50, 234, 311, 164);
INSERT INTO chado.cvterm_relationship VALUES (51, 211, 313, 314);
INSERT INTO chado.cvterm_relationship VALUES (52, 211, 315, 316);
INSERT INTO chado.cvterm_relationship VALUES (53, 211, 318, 319);
INSERT INTO chado.cvterm_relationship VALUES (54, 234, 318, 320);
INSERT INTO chado.cvterm_relationship VALUES (55, 211, 321, 322);
INSERT INTO chado.cvterm_relationship VALUES (56, 230, 321, 323);
INSERT INTO chado.cvterm_relationship VALUES (57, 211, 326, 327);
INSERT INTO chado.cvterm_relationship VALUES (58, 211, 328, 329);
INSERT INTO chado.cvterm_relationship VALUES (59, 211, 336, 305);
INSERT INTO chado.cvterm_relationship VALUES (60, 211, 339, 340);
INSERT INTO chado.cvterm_relationship VALUES (61, 211, 341, 339);
INSERT INTO chado.cvterm_relationship VALUES (62, 211, 342, 339);
INSERT INTO chado.cvterm_relationship VALUES (63, 211, 343, 344);
INSERT INTO chado.cvterm_relationship VALUES (64, 211, 346, 347);
INSERT INTO chado.cvterm_relationship VALUES (65, 211, 348, 349);
INSERT INTO chado.cvterm_relationship VALUES (66, 211, 350, 346);
INSERT INTO chado.cvterm_relationship VALUES (67, 211, 351, 352);
INSERT INTO chado.cvterm_relationship VALUES (68, 211, 351, 353);
INSERT INTO chado.cvterm_relationship VALUES (69, 228, 351, 354);
INSERT INTO chado.cvterm_relationship VALUES (70, 211, 355, 356);
INSERT INTO chado.cvterm_relationship VALUES (71, 211, 358, 359);
INSERT INTO chado.cvterm_relationship VALUES (72, 211, 361, 277);
INSERT INTO chado.cvterm_relationship VALUES (73, 211, 362, 361);
INSERT INTO chado.cvterm_relationship VALUES (74, 211, 363, 362);
INSERT INTO chado.cvterm_relationship VALUES (75, 211, 364, 363);
INSERT INTO chado.cvterm_relationship VALUES (76, 211, 365, 363);
INSERT INTO chado.cvterm_relationship VALUES (77, 211, 367, 362);
INSERT INTO chado.cvterm_relationship VALUES (78, 211, 368, 362);
INSERT INTO chado.cvterm_relationship VALUES (79, 211, 369, 362);
INSERT INTO chado.cvterm_relationship VALUES (80, 211, 370, 362);
INSERT INTO chado.cvterm_relationship VALUES (81, 211, 371, 362);
INSERT INTO chado.cvterm_relationship VALUES (82, 211, 372, 373);
INSERT INTO chado.cvterm_relationship VALUES (83, 230, 372, 374);
INSERT INTO chado.cvterm_relationship VALUES (84, 211, 375, 372);
INSERT INTO chado.cvterm_relationship VALUES (85, 230, 375, 376);
INSERT INTO chado.cvterm_relationship VALUES (86, 211, 377, 378);
INSERT INTO chado.cvterm_relationship VALUES (87, 211, 378, 277);
INSERT INTO chado.cvterm_relationship VALUES (88, 211, 380, 381);
INSERT INTO chado.cvterm_relationship VALUES (89, 211, 382, 381);
INSERT INTO chado.cvterm_relationship VALUES (90, 211, 385, 163);
INSERT INTO chado.cvterm_relationship VALUES (91, 229, 385, 386);
INSERT INTO chado.cvterm_relationship VALUES (92, 211, 387, 163);
INSERT INTO chado.cvterm_relationship VALUES (93, 229, 387, 388);
INSERT INTO chado.cvterm_relationship VALUES (94, 211, 389, 387);
INSERT INTO chado.cvterm_relationship VALUES (95, 229, 389, 390);
INSERT INTO chado.cvterm_relationship VALUES (96, 211, 391, 163);
INSERT INTO chado.cvterm_relationship VALUES (97, 229, 391, 392);
INSERT INTO chado.cvterm_relationship VALUES (98, 211, 393, 391);
INSERT INTO chado.cvterm_relationship VALUES (99, 229, 393, 394);
INSERT INTO chado.cvterm_relationship VALUES (100, 211, 395, 391);
INSERT INTO chado.cvterm_relationship VALUES (101, 229, 395, 396);
INSERT INTO chado.cvterm_relationship VALUES (102, 211, 397, 391);
INSERT INTO chado.cvterm_relationship VALUES (103, 229, 397, 398);
INSERT INTO chado.cvterm_relationship VALUES (104, 211, 399, 391);
INSERT INTO chado.cvterm_relationship VALUES (105, 229, 399, 400);
INSERT INTO chado.cvterm_relationship VALUES (106, 211, 401, 391);
INSERT INTO chado.cvterm_relationship VALUES (107, 229, 401, 402);
INSERT INTO chado.cvterm_relationship VALUES (108, 211, 403, 391);
INSERT INTO chado.cvterm_relationship VALUES (109, 229, 403, 404);
INSERT INTO chado.cvterm_relationship VALUES (110, 211, 405, 163);
INSERT INTO chado.cvterm_relationship VALUES (111, 229, 405, 406);
INSERT INTO chado.cvterm_relationship VALUES (112, 211, 407, 163);
INSERT INTO chado.cvterm_relationship VALUES (113, 229, 407, 408);
INSERT INTO chado.cvterm_relationship VALUES (114, 211, 409, 163);
INSERT INTO chado.cvterm_relationship VALUES (115, 229, 409, 410);
INSERT INTO chado.cvterm_relationship VALUES (116, 211, 411, 409);
INSERT INTO chado.cvterm_relationship VALUES (117, 229, 411, 412);
INSERT INTO chado.cvterm_relationship VALUES (118, 211, 413, 414);
INSERT INTO chado.cvterm_relationship VALUES (119, 211, 415, 416);
INSERT INTO chado.cvterm_relationship VALUES (120, 211, 417, 418);
INSERT INTO chado.cvterm_relationship VALUES (121, 234, 417, 419);
INSERT INTO chado.cvterm_relationship VALUES (122, 211, 420, 262);
INSERT INTO chado.cvterm_relationship VALUES (123, 216, 420, 421);
INSERT INTO chado.cvterm_relationship VALUES (124, 211, 422, 423);
INSERT INTO chado.cvterm_relationship VALUES (125, 211, 425, 426);
INSERT INTO chado.cvterm_relationship VALUES (126, 211, 427, 164);
INSERT INTO chado.cvterm_relationship VALUES (127, 230, 427, 428);
INSERT INTO chado.cvterm_relationship VALUES (128, 211, 430, 163);
INSERT INTO chado.cvterm_relationship VALUES (129, 234, 430, 413);
INSERT INTO chado.cvterm_relationship VALUES (130, 211, 426, 431);
INSERT INTO chado.cvterm_relationship VALUES (131, 211, 432, 414);
INSERT INTO chado.cvterm_relationship VALUES (132, 211, 433, 434);
INSERT INTO chado.cvterm_relationship VALUES (133, 211, 433, 435);
INSERT INTO chado.cvterm_relationship VALUES (134, 211, 437, 438);
INSERT INTO chado.cvterm_relationship VALUES (135, 211, 440, 373);
INSERT INTO chado.cvterm_relationship VALUES (136, 230, 440, 441);
INSERT INTO chado.cvterm_relationship VALUES (137, 211, 442, 277);
INSERT INTO chado.cvterm_relationship VALUES (138, 211, 443, 444);
INSERT INTO chado.cvterm_relationship VALUES (139, 211, 445, 426);
INSERT INTO chado.cvterm_relationship VALUES (140, 230, 445, 446);
INSERT INTO chado.cvterm_relationship VALUES (141, 211, 447, 261);
INSERT INTO chado.cvterm_relationship VALUES (142, 211, 448, 442);
INSERT INTO chado.cvterm_relationship VALUES (143, 211, 449, 448);
INSERT INTO chado.cvterm_relationship VALUES (144, 211, 450, 448);
INSERT INTO chado.cvterm_relationship VALUES (145, 211, 451, 448);
INSERT INTO chado.cvterm_relationship VALUES (146, 211, 452, 163);
INSERT INTO chado.cvterm_relationship VALUES (147, 230, 452, 453);
INSERT INTO chado.cvterm_relationship VALUES (148, 211, 454, 452);
INSERT INTO chado.cvterm_relationship VALUES (149, 230, 454, 455);
INSERT INTO chado.cvterm_relationship VALUES (150, 211, 456, 454);
INSERT INTO chado.cvterm_relationship VALUES (151, 230, 456, 457);
INSERT INTO chado.cvterm_relationship VALUES (152, 211, 458, 442);
INSERT INTO chado.cvterm_relationship VALUES (153, 211, 459, 442);
INSERT INTO chado.cvterm_relationship VALUES (154, 211, 460, 426);
INSERT INTO chado.cvterm_relationship VALUES (155, 230, 460, 461);
INSERT INTO chado.cvterm_relationship VALUES (156, 211, 462, 277);
INSERT INTO chado.cvterm_relationship VALUES (157, 211, 463, 442);
INSERT INTO chado.cvterm_relationship VALUES (158, 211, 463, 462);
INSERT INTO chado.cvterm_relationship VALUES (159, 211, 464, 463);
INSERT INTO chado.cvterm_relationship VALUES (160, 211, 465, 463);
INSERT INTO chado.cvterm_relationship VALUES (161, 211, 466, 462);
INSERT INTO chado.cvterm_relationship VALUES (162, 211, 467, 468);
INSERT INTO chado.cvterm_relationship VALUES (163, 230, 467, 469);
INSERT INTO chado.cvterm_relationship VALUES (164, 211, 470, 312);
INSERT INTO chado.cvterm_relationship VALUES (165, 234, 470, 471);
INSERT INTO chado.cvterm_relationship VALUES (166, 211, 472, 473);
INSERT INTO chado.cvterm_relationship VALUES (167, 234, 472, 164);
INSERT INTO chado.cvterm_relationship VALUES (168, 211, 474, 344);
INSERT INTO chado.cvterm_relationship VALUES (169, 234, 474, 373);
INSERT INTO chado.cvterm_relationship VALUES (170, 211, 475, 261);
INSERT INTO chado.cvterm_relationship VALUES (171, 211, 476, 319);
INSERT INTO chado.cvterm_relationship VALUES (172, 211, 478, 479);
INSERT INTO chado.cvterm_relationship VALUES (173, 211, 480, 438);
INSERT INTO chado.cvterm_relationship VALUES (174, 211, 481, 482);
INSERT INTO chado.cvterm_relationship VALUES (175, 211, 483, 484);
INSERT INTO chado.cvterm_relationship VALUES (176, 234, 483, 485);
INSERT INTO chado.cvterm_relationship VALUES (177, 211, 272, 476);
INSERT INTO chado.cvterm_relationship VALUES (178, 211, 272, 486);
INSERT INTO chado.cvterm_relationship VALUES (179, 234, 272, 483);
INSERT INTO chado.cvterm_relationship VALUES (180, 211, 271, 476);
INSERT INTO chado.cvterm_relationship VALUES (181, 234, 271, 272);
INSERT INTO chado.cvterm_relationship VALUES (182, 211, 322, 269);
INSERT INTO chado.cvterm_relationship VALUES (183, 211, 487, 488);
INSERT INTO chado.cvterm_relationship VALUES (184, 211, 489, 488);
INSERT INTO chado.cvterm_relationship VALUES (185, 211, 490, 488);
INSERT INTO chado.cvterm_relationship VALUES (186, 211, 491, 492);
INSERT INTO chado.cvterm_relationship VALUES (187, 211, 493, 488);
INSERT INTO chado.cvterm_relationship VALUES (188, 211, 494, 488);
INSERT INTO chado.cvterm_relationship VALUES (189, 211, 495, 488);
INSERT INTO chado.cvterm_relationship VALUES (190, 211, 354, 496);
INSERT INTO chado.cvterm_relationship VALUES (191, 211, 354, 262);
INSERT INTO chado.cvterm_relationship VALUES (192, 211, 498, 434);
INSERT INTO chado.cvterm_relationship VALUES (193, 211, 498, 499);
INSERT INTO chado.cvterm_relationship VALUES (194, 211, 500, 501);
INSERT INTO chado.cvterm_relationship VALUES (195, 211, 502, 503);
INSERT INTO chado.cvterm_relationship VALUES (196, 211, 504, 503);
INSERT INTO chado.cvterm_relationship VALUES (197, 211, 505, 316);
INSERT INTO chado.cvterm_relationship VALUES (198, 211, 506, 505);
INSERT INTO chado.cvterm_relationship VALUES (199, 230, 506, 507);
INSERT INTO chado.cvterm_relationship VALUES (200, 211, 290, 508);
INSERT INTO chado.cvterm_relationship VALUES (201, 211, 290, 344);
INSERT INTO chado.cvterm_relationship VALUES (202, 211, 510, 511);
INSERT INTO chado.cvterm_relationship VALUES (203, 211, 512, 511);
INSERT INTO chado.cvterm_relationship VALUES (204, 211, 513, 511);
INSERT INTO chado.cvterm_relationship VALUES (205, 211, 514, 289);
INSERT INTO chado.cvterm_relationship VALUES (206, 234, 514, 512);
INSERT INTO chado.cvterm_relationship VALUES (207, 211, 515, 516);
INSERT INTO chado.cvterm_relationship VALUES (208, 234, 515, 512);
INSERT INTO chado.cvterm_relationship VALUES (209, 211, 517, 284);
INSERT INTO chado.cvterm_relationship VALUES (210, 211, 518, 289);
INSERT INTO chado.cvterm_relationship VALUES (211, 234, 518, 519);
INSERT INTO chado.cvterm_relationship VALUES (212, 234, 518, 520);
INSERT INTO chado.cvterm_relationship VALUES (213, 211, 521, 289);
INSERT INTO chado.cvterm_relationship VALUES (214, 234, 521, 519);
INSERT INTO chado.cvterm_relationship VALUES (215, 234, 521, 520);
INSERT INTO chado.cvterm_relationship VALUES (216, 211, 522, 416);
INSERT INTO chado.cvterm_relationship VALUES (217, 211, 523, 524);
INSERT INTO chado.cvterm_relationship VALUES (218, 211, 525, 418);
INSERT INTO chado.cvterm_relationship VALUES (219, 234, 525, 419);
INSERT INTO chado.cvterm_relationship VALUES (220, 211, 526, 413);
INSERT INTO chado.cvterm_relationship VALUES (221, 211, 527, 416);
INSERT INTO chado.cvterm_relationship VALUES (222, 211, 528, 413);
INSERT INTO chado.cvterm_relationship VALUES (223, 211, 529, 508);
INSERT INTO chado.cvterm_relationship VALUES (224, 211, 530, 531);
INSERT INTO chado.cvterm_relationship VALUES (225, 211, 444, 373);
INSERT INTO chado.cvterm_relationship VALUES (226, 211, 532, 526);
INSERT INTO chado.cvterm_relationship VALUES (227, 211, 534, 501);
INSERT INTO chado.cvterm_relationship VALUES (228, 211, 535, 526);
INSERT INTO chado.cvterm_relationship VALUES (229, 211, 536, 534);
INSERT INTO chado.cvterm_relationship VALUES (230, 211, 537, 534);
INSERT INTO chado.cvterm_relationship VALUES (231, 211, 538, 534);
INSERT INTO chado.cvterm_relationship VALUES (232, 211, 539, 540);
INSERT INTO chado.cvterm_relationship VALUES (233, 211, 541, 535);
INSERT INTO chado.cvterm_relationship VALUES (234, 211, 265, 481);
INSERT INTO chado.cvterm_relationship VALUES (235, 211, 542, 543);
INSERT INTO chado.cvterm_relationship VALUES (236, 234, 542, 544);
INSERT INTO chado.cvterm_relationship VALUES (237, 211, 545, 543);
INSERT INTO chado.cvterm_relationship VALUES (238, 234, 545, 546);
INSERT INTO chado.cvterm_relationship VALUES (239, 211, 547, 481);
INSERT INTO chado.cvterm_relationship VALUES (240, 211, 548, 549);
INSERT INTO chado.cvterm_relationship VALUES (241, 211, 544, 265);
INSERT INTO chado.cvterm_relationship VALUES (242, 211, 550, 481);
INSERT INTO chado.cvterm_relationship VALUES (243, 211, 546, 265);
INSERT INTO chado.cvterm_relationship VALUES (244, 211, 551, 312);
INSERT INTO chado.cvterm_relationship VALUES (245, 211, 471, 551);
INSERT INTO chado.cvterm_relationship VALUES (246, 211, 552, 551);
INSERT INTO chado.cvterm_relationship VALUES (247, 211, 553, 535);
INSERT INTO chado.cvterm_relationship VALUES (248, 211, 554, 555);
INSERT INTO chado.cvterm_relationship VALUES (249, 211, 556, 528);
INSERT INTO chado.cvterm_relationship VALUES (250, 211, 557, 280);
INSERT INTO chado.cvterm_relationship VALUES (251, 211, 558, 280);
INSERT INTO chado.cvterm_relationship VALUES (252, 211, 559, 558);
INSERT INTO chado.cvterm_relationship VALUES (253, 211, 560, 558);
INSERT INTO chado.cvterm_relationship VALUES (254, 211, 561, 558);
INSERT INTO chado.cvterm_relationship VALUES (255, 211, 562, 558);
INSERT INTO chado.cvterm_relationship VALUES (256, 211, 563, 558);
INSERT INTO chado.cvterm_relationship VALUES (257, 211, 564, 558);
INSERT INTO chado.cvterm_relationship VALUES (258, 211, 565, 558);
INSERT INTO chado.cvterm_relationship VALUES (259, 211, 566, 558);
INSERT INTO chado.cvterm_relationship VALUES (260, 211, 567, 558);
INSERT INTO chado.cvterm_relationship VALUES (261, 211, 568, 558);
INSERT INTO chado.cvterm_relationship VALUES (262, 211, 569, 558);
INSERT INTO chado.cvterm_relationship VALUES (263, 211, 570, 558);
INSERT INTO chado.cvterm_relationship VALUES (264, 211, 571, 558);
INSERT INTO chado.cvterm_relationship VALUES (265, 211, 572, 558);
INSERT INTO chado.cvterm_relationship VALUES (266, 211, 573, 558);
INSERT INTO chado.cvterm_relationship VALUES (267, 211, 574, 558);
INSERT INTO chado.cvterm_relationship VALUES (268, 211, 575, 558);
INSERT INTO chado.cvterm_relationship VALUES (269, 211, 576, 558);
INSERT INTO chado.cvterm_relationship VALUES (270, 211, 577, 558);
INSERT INTO chado.cvterm_relationship VALUES (271, 211, 578, 558);
INSERT INTO chado.cvterm_relationship VALUES (272, 211, 579, 280);
INSERT INTO chado.cvterm_relationship VALUES (273, 211, 580, 280);
INSERT INTO chado.cvterm_relationship VALUES (274, 211, 581, 373);
INSERT INTO chado.cvterm_relationship VALUES (275, 216, 581, 444);
INSERT INTO chado.cvterm_relationship VALUES (276, 211, 164, 581);
INSERT INTO chado.cvterm_relationship VALUES (277, 211, 582, 344);
INSERT INTO chado.cvterm_relationship VALUES (278, 211, 582, 347);
INSERT INTO chado.cvterm_relationship VALUES (279, 234, 582, 316);
INSERT INTO chado.cvterm_relationship VALUES (280, 211, 583, 584);
INSERT INTO chado.cvterm_relationship VALUES (281, 211, 438, 585);
INSERT INTO chado.cvterm_relationship VALUES (282, 211, 586, 528);
INSERT INTO chado.cvterm_relationship VALUES (283, 211, 587, 588);
INSERT INTO chado.cvterm_relationship VALUES (284, 211, 589, 590);
INSERT INTO chado.cvterm_relationship VALUES (285, 234, 589, 591);
INSERT INTO chado.cvterm_relationship VALUES (286, 211, 592, 551);
INSERT INTO chado.cvterm_relationship VALUES (287, 211, 593, 551);
INSERT INTO chado.cvterm_relationship VALUES (288, 211, 594, 470);
INSERT INTO chado.cvterm_relationship VALUES (289, 211, 597, 598);
INSERT INTO chado.cvterm_relationship VALUES (290, 211, 555, 496);
INSERT INTO chado.cvterm_relationship VALUES (291, 211, 601, 602);
INSERT INTO chado.cvterm_relationship VALUES (292, 211, 604, 282);
INSERT INTO chado.cvterm_relationship VALUES (293, 216, 604, 557);
INSERT INTO chado.cvterm_relationship VALUES (294, 211, 605, 606);
INSERT INTO chado.cvterm_relationship VALUES (295, 216, 605, 558);
INSERT INTO chado.cvterm_relationship VALUES (296, 211, 607, 605);
INSERT INTO chado.cvterm_relationship VALUES (297, 216, 607, 559);
INSERT INTO chado.cvterm_relationship VALUES (298, 211, 608, 557);
INSERT INTO chado.cvterm_relationship VALUES (299, 211, 609, 605);
INSERT INTO chado.cvterm_relationship VALUES (300, 216, 609, 561);
INSERT INTO chado.cvterm_relationship VALUES (301, 211, 610, 605);
INSERT INTO chado.cvterm_relationship VALUES (302, 216, 610, 562);
INSERT INTO chado.cvterm_relationship VALUES (303, 211, 611, 605);
INSERT INTO chado.cvterm_relationship VALUES (304, 216, 611, 563);
INSERT INTO chado.cvterm_relationship VALUES (305, 211, 612, 605);
INSERT INTO chado.cvterm_relationship VALUES (306, 216, 612, 564);
INSERT INTO chado.cvterm_relationship VALUES (307, 211, 613, 605);
INSERT INTO chado.cvterm_relationship VALUES (308, 216, 613, 565);
INSERT INTO chado.cvterm_relationship VALUES (309, 211, 614, 605);
INSERT INTO chado.cvterm_relationship VALUES (310, 216, 614, 566);
INSERT INTO chado.cvterm_relationship VALUES (311, 211, 615, 605);
INSERT INTO chado.cvterm_relationship VALUES (312, 216, 615, 567);
INSERT INTO chado.cvterm_relationship VALUES (313, 211, 616, 605);
INSERT INTO chado.cvterm_relationship VALUES (314, 216, 616, 568);
INSERT INTO chado.cvterm_relationship VALUES (315, 211, 617, 605);
INSERT INTO chado.cvterm_relationship VALUES (316, 216, 617, 569);
INSERT INTO chado.cvterm_relationship VALUES (317, 211, 618, 605);
INSERT INTO chado.cvterm_relationship VALUES (318, 216, 618, 570);
INSERT INTO chado.cvterm_relationship VALUES (319, 211, 619, 605);
INSERT INTO chado.cvterm_relationship VALUES (320, 216, 619, 571);
INSERT INTO chado.cvterm_relationship VALUES (321, 211, 620, 605);
INSERT INTO chado.cvterm_relationship VALUES (322, 216, 620, 572);
INSERT INTO chado.cvterm_relationship VALUES (323, 211, 621, 605);
INSERT INTO chado.cvterm_relationship VALUES (324, 216, 621, 573);
INSERT INTO chado.cvterm_relationship VALUES (325, 211, 622, 605);
INSERT INTO chado.cvterm_relationship VALUES (326, 216, 622, 574);
INSERT INTO chado.cvterm_relationship VALUES (327, 211, 623, 605);
INSERT INTO chado.cvterm_relationship VALUES (328, 216, 623, 575);
INSERT INTO chado.cvterm_relationship VALUES (329, 211, 624, 605);
INSERT INTO chado.cvterm_relationship VALUES (330, 216, 624, 576);
INSERT INTO chado.cvterm_relationship VALUES (331, 211, 625, 605);
INSERT INTO chado.cvterm_relationship VALUES (332, 216, 625, 577);
INSERT INTO chado.cvterm_relationship VALUES (333, 211, 626, 605);
INSERT INTO chado.cvterm_relationship VALUES (334, 216, 626, 578);
INSERT INTO chado.cvterm_relationship VALUES (335, 211, 627, 606);
INSERT INTO chado.cvterm_relationship VALUES (336, 216, 627, 579);
INSERT INTO chado.cvterm_relationship VALUES (337, 211, 628, 606);
INSERT INTO chado.cvterm_relationship VALUES (338, 216, 628, 580);
INSERT INTO chado.cvterm_relationship VALUES (339, 211, 629, 630);
INSERT INTO chado.cvterm_relationship VALUES (340, 216, 629, 631);
INSERT INTO chado.cvterm_relationship VALUES (341, 211, 507, 585);
INSERT INTO chado.cvterm_relationship VALUES (342, 211, 632, 373);
INSERT INTO chado.cvterm_relationship VALUES (343, 230, 632, 633);
INSERT INTO chado.cvterm_relationship VALUES (344, 211, 634, 373);
INSERT INTO chado.cvterm_relationship VALUES (345, 230, 634, 635);
INSERT INTO chado.cvterm_relationship VALUES (346, 211, 636, 163);
INSERT INTO chado.cvterm_relationship VALUES (347, 211, 636, 637);
INSERT INTO chado.cvterm_relationship VALUES (348, 230, 636, 638);
INSERT INTO chado.cvterm_relationship VALUES (349, 211, 639, 636);
INSERT INTO chado.cvterm_relationship VALUES (350, 211, 639, 640);
INSERT INTO chado.cvterm_relationship VALUES (351, 211, 639, 641);
INSERT INTO chado.cvterm_relationship VALUES (352, 230, 639, 638);
INSERT INTO chado.cvterm_relationship VALUES (353, 230, 639, 642);
INSERT INTO chado.cvterm_relationship VALUES (354, 211, 643, 427);
INSERT INTO chado.cvterm_relationship VALUES (355, 230, 643, 644);
INSERT INTO chado.cvterm_relationship VALUES (356, 211, 645, 430);
INSERT INTO chado.cvterm_relationship VALUES (357, 211, 645, 639);
INSERT INTO chado.cvterm_relationship VALUES (358, 230, 645, 638);
INSERT INTO chado.cvterm_relationship VALUES (359, 230, 645, 642);
INSERT INTO chado.cvterm_relationship VALUES (360, 211, 640, 163);
INSERT INTO chado.cvterm_relationship VALUES (361, 230, 640, 642);
INSERT INTO chado.cvterm_relationship VALUES (362, 211, 647, 648);
INSERT INTO chado.cvterm_relationship VALUES (363, 234, 647, 532);
INSERT INTO chado.cvterm_relationship VALUES (364, 211, 649, 163);
INSERT INTO chado.cvterm_relationship VALUES (365, 230, 649, 650);
INSERT INTO chado.cvterm_relationship VALUES (366, 211, 651, 636);
INSERT INTO chado.cvterm_relationship VALUES (367, 211, 651, 649);
INSERT INTO chado.cvterm_relationship VALUES (368, 230, 651, 638);
INSERT INTO chado.cvterm_relationship VALUES (369, 211, 652, 266);
INSERT INTO chado.cvterm_relationship VALUES (370, 211, 653, 652);
INSERT INTO chado.cvterm_relationship VALUES (371, 211, 654, 652);
INSERT INTO chado.cvterm_relationship VALUES (372, 211, 656, 648);
INSERT INTO chado.cvterm_relationship VALUES (373, 211, 656, 641);
INSERT INTO chado.cvterm_relationship VALUES (374, 230, 656, 638);
INSERT INTO chado.cvterm_relationship VALUES (375, 230, 656, 642);
INSERT INTO chado.cvterm_relationship VALUES (376, 211, 657, 648);
INSERT INTO chado.cvterm_relationship VALUES (377, 211, 658, 531);
INSERT INTO chado.cvterm_relationship VALUES (378, 211, 659, 262);
INSERT INTO chado.cvterm_relationship VALUES (379, 234, 659, 492);
INSERT INTO chado.cvterm_relationship VALUES (380, 211, 660, 262);
INSERT INTO chado.cvterm_relationship VALUES (381, 211, 661, 262);
INSERT INTO chado.cvterm_relationship VALUES (382, 211, 662, 663);
INSERT INTO chado.cvterm_relationship VALUES (383, 211, 664, 662);
INSERT INTO chado.cvterm_relationship VALUES (384, 211, 665, 664);
INSERT INTO chado.cvterm_relationship VALUES (385, 211, 666, 667);
INSERT INTO chado.cvterm_relationship VALUES (386, 211, 668, 501);
INSERT INTO chado.cvterm_relationship VALUES (387, 211, 670, 602);
INSERT INTO chado.cvterm_relationship VALUES (388, 211, 670, 671);
INSERT INTO chado.cvterm_relationship VALUES (389, 211, 434, 670);
INSERT INTO chado.cvterm_relationship VALUES (390, 211, 672, 262);
INSERT INTO chado.cvterm_relationship VALUES (391, 211, 677, 678);
INSERT INTO chado.cvterm_relationship VALUES (392, 211, 679, 447);
INSERT INTO chado.cvterm_relationship VALUES (393, 211, 680, 648);
INSERT INTO chado.cvterm_relationship VALUES (394, 211, 681, 501);
INSERT INTO chado.cvterm_relationship VALUES (395, 211, 681, 682);
INSERT INTO chado.cvterm_relationship VALUES (396, 211, 421, 312);
INSERT INTO chado.cvterm_relationship VALUES (397, 211, 683, 322);
INSERT INTO chado.cvterm_relationship VALUES (398, 230, 683, 684);
INSERT INTO chado.cvterm_relationship VALUES (399, 211, 685, 479);
INSERT INTO chado.cvterm_relationship VALUES (400, 211, 686, 479);
INSERT INTO chado.cvterm_relationship VALUES (401, 211, 687, 688);
INSERT INTO chado.cvterm_relationship VALUES (402, 234, 687, 689);
INSERT INTO chado.cvterm_relationship VALUES (403, 211, 690, 427);
INSERT INTO chado.cvterm_relationship VALUES (404, 230, 690, 691);
INSERT INTO chado.cvterm_relationship VALUES (405, 211, 692, 693);
INSERT INTO chado.cvterm_relationship VALUES (406, 211, 692, 694);
INSERT INTO chado.cvterm_relationship VALUES (407, 211, 695, 696);
INSERT INTO chado.cvterm_relationship VALUES (408, 211, 697, 305);
INSERT INTO chado.cvterm_relationship VALUES (409, 211, 698, 557);
INSERT INTO chado.cvterm_relationship VALUES (410, 211, 699, 697);
INSERT INTO chado.cvterm_relationship VALUES (411, 211, 700, 696);
INSERT INTO chado.cvterm_relationship VALUES (412, 211, 701, 336);
INSERT INTO chado.cvterm_relationship VALUES (413, 211, 702, 427);
INSERT INTO chado.cvterm_relationship VALUES (414, 230, 702, 703);
INSERT INTO chado.cvterm_relationship VALUES (415, 211, 704, 319);
INSERT INTO chado.cvterm_relationship VALUES (416, 211, 705, 697);
INSERT INTO chado.cvterm_relationship VALUES (417, 211, 706, 704);
INSERT INTO chado.cvterm_relationship VALUES (418, 211, 707, 418);
INSERT INTO chado.cvterm_relationship VALUES (419, 234, 707, 581);
INSERT INTO chado.cvterm_relationship VALUES (420, 211, 708, 704);
INSERT INTO chado.cvterm_relationship VALUES (421, 211, 709, 427);
INSERT INTO chado.cvterm_relationship VALUES (422, 230, 709, 710);
INSERT INTO chado.cvterm_relationship VALUES (423, 211, 327, 262);
INSERT INTO chado.cvterm_relationship VALUES (424, 239, 327, 163);
INSERT INTO chado.cvterm_relationship VALUES (425, 211, 711, 712);
INSERT INTO chado.cvterm_relationship VALUES (426, 211, 713, 556);
INSERT INTO chado.cvterm_relationship VALUES (427, 211, 714, 661);
INSERT INTO chado.cvterm_relationship VALUES (428, 211, 715, 492);
INSERT INTO chado.cvterm_relationship VALUES (429, 211, 716, 423);
INSERT INTO chado.cvterm_relationship VALUES (430, 211, 717, 662);
INSERT INTO chado.cvterm_relationship VALUES (431, 211, 320, 319);
INSERT INTO chado.cvterm_relationship VALUES (432, 211, 688, 718);
INSERT INTO chado.cvterm_relationship VALUES (433, 211, 719, 697);
INSERT INTO chado.cvterm_relationship VALUES (434, 216, 719, 164);
INSERT INTO chado.cvterm_relationship VALUES (435, 211, 720, 721);
INSERT INTO chado.cvterm_relationship VALUES (436, 211, 416, 320);
INSERT INTO chado.cvterm_relationship VALUES (437, 211, 722, 723);
INSERT INTO chado.cvterm_relationship VALUES (438, 211, 724, 320);
INSERT INTO chado.cvterm_relationship VALUES (439, 211, 725, 726);
INSERT INTO chado.cvterm_relationship VALUES (440, 211, 727, 723);
INSERT INTO chado.cvterm_relationship VALUES (441, 211, 728, 722);
INSERT INTO chado.cvterm_relationship VALUES (442, 211, 486, 729);
INSERT INTO chado.cvterm_relationship VALUES (443, 211, 730, 693);
INSERT INTO chado.cvterm_relationship VALUES (444, 211, 731, 661);
INSERT INTO chado.cvterm_relationship VALUES (445, 211, 732, 722);
INSERT INTO chado.cvterm_relationship VALUES (446, 211, 733, 585);
INSERT INTO chado.cvterm_relationship VALUES (447, 211, 734, 733);
INSERT INTO chado.cvterm_relationship VALUES (448, 211, 479, 696);
INSERT INTO chado.cvterm_relationship VALUES (449, 211, 735, 733);
INSERT INTO chado.cvterm_relationship VALUES (450, 211, 736, 737);
INSERT INTO chado.cvterm_relationship VALUES (451, 211, 738, 739);
INSERT INTO chado.cvterm_relationship VALUES (452, 230, 738, 734);
INSERT INTO chado.cvterm_relationship VALUES (453, 211, 740, 587);
INSERT INTO chado.cvterm_relationship VALUES (454, 211, 741, 414);
INSERT INTO chado.cvterm_relationship VALUES (455, 211, 742, 418);
INSERT INTO chado.cvterm_relationship VALUES (456, 211, 743, 744);
INSERT INTO chado.cvterm_relationship VALUES (457, 234, 743, 741);
INSERT INTO chado.cvterm_relationship VALUES (458, 211, 745, 742);
INSERT INTO chado.cvterm_relationship VALUES (459, 211, 630, 606);
INSERT INTO chado.cvterm_relationship VALUES (460, 211, 747, 528);
INSERT INTO chado.cvterm_relationship VALUES (461, 211, 748, 282);
INSERT INTO chado.cvterm_relationship VALUES (462, 230, 748, 749);
INSERT INTO chado.cvterm_relationship VALUES (463, 211, 750, 751);
INSERT INTO chado.cvterm_relationship VALUES (464, 230, 750, 752);
INSERT INTO chado.cvterm_relationship VALUES (465, 211, 753, 748);
INSERT INTO chado.cvterm_relationship VALUES (466, 230, 753, 754);
INSERT INTO chado.cvterm_relationship VALUES (467, 211, 755, 756);
INSERT INTO chado.cvterm_relationship VALUES (468, 216, 755, 757);
INSERT INTO chado.cvterm_relationship VALUES (469, 211, 758, 630);
INSERT INTO chado.cvterm_relationship VALUES (470, 211, 759, 630);
INSERT INTO chado.cvterm_relationship VALUES (471, 211, 760, 630);
INSERT INTO chado.cvterm_relationship VALUES (472, 211, 761, 760);
INSERT INTO chado.cvterm_relationship VALUES (473, 211, 762, 293);
INSERT INTO chado.cvterm_relationship VALUES (474, 230, 762, 754);
INSERT INTO chado.cvterm_relationship VALUES (475, 211, 763, 764);
INSERT INTO chado.cvterm_relationship VALUES (476, 211, 765, 764);
INSERT INTO chado.cvterm_relationship VALUES (477, 211, 766, 767);
INSERT INTO chado.cvterm_relationship VALUES (478, 211, 768, 630);
INSERT INTO chado.cvterm_relationship VALUES (479, 211, 769, 748);
INSERT INTO chado.cvterm_relationship VALUES (480, 211, 770, 748);
INSERT INTO chado.cvterm_relationship VALUES (481, 211, 771, 630);
INSERT INTO chado.cvterm_relationship VALUES (482, 211, 772, 630);
INSERT INTO chado.cvterm_relationship VALUES (483, 211, 773, 630);
INSERT INTO chado.cvterm_relationship VALUES (484, 211, 774, 282);
INSERT INTO chado.cvterm_relationship VALUES (485, 211, 775, 627);
INSERT INTO chado.cvterm_relationship VALUES (486, 211, 776, 627);
INSERT INTO chado.cvterm_relationship VALUES (487, 211, 777, 627);
INSERT INTO chado.cvterm_relationship VALUES (488, 211, 778, 627);
INSERT INTO chado.cvterm_relationship VALUES (489, 211, 779, 627);
INSERT INTO chado.cvterm_relationship VALUES (490, 211, 780, 627);
INSERT INTO chado.cvterm_relationship VALUES (491, 211, 781, 627);
INSERT INTO chado.cvterm_relationship VALUES (492, 211, 782, 627);
INSERT INTO chado.cvterm_relationship VALUES (493, 211, 783, 627);
INSERT INTO chado.cvterm_relationship VALUES (494, 211, 277, 585);
INSERT INTO chado.cvterm_relationship VALUES (495, 211, 786, 787);
INSERT INTO chado.cvterm_relationship VALUES (496, 216, 786, 788);
INSERT INTO chado.cvterm_relationship VALUES (497, 211, 789, 282);
INSERT INTO chado.cvterm_relationship VALUES (498, 211, 790, 282);
INSERT INTO chado.cvterm_relationship VALUES (499, 211, 791, 534);
INSERT INTO chado.cvterm_relationship VALUES (500, 211, 792, 793);
INSERT INTO chado.cvterm_relationship VALUES (501, 216, 792, 794);
INSERT INTO chado.cvterm_relationship VALUES (502, 211, 796, 262);
INSERT INTO chado.cvterm_relationship VALUES (503, 211, 797, 796);
INSERT INTO chado.cvterm_relationship VALUES (504, 211, 798, 269);
INSERT INTO chado.cvterm_relationship VALUES (505, 230, 798, 799);
INSERT INTO chado.cvterm_relationship VALUES (506, 211, 540, 476);
INSERT INTO chado.cvterm_relationship VALUES (507, 211, 800, 801);
INSERT INTO chado.cvterm_relationship VALUES (508, 211, 802, 737);
INSERT INTO chado.cvterm_relationship VALUES (509, 211, 803, 737);
INSERT INTO chado.cvterm_relationship VALUES (510, 211, 804, 737);
INSERT INTO chado.cvterm_relationship VALUES (511, 211, 805, 806);
INSERT INTO chado.cvterm_relationship VALUES (512, 211, 805, 807);
INSERT INTO chado.cvterm_relationship VALUES (513, 211, 808, 809);
INSERT INTO chado.cvterm_relationship VALUES (514, 216, 808, 810);
INSERT INTO chado.cvterm_relationship VALUES (515, 234, 808, 811);
INSERT INTO chado.cvterm_relationship VALUES (516, 211, 812, 813);
INSERT INTO chado.cvterm_relationship VALUES (517, 216, 812, 814);
INSERT INTO chado.cvterm_relationship VALUES (518, 234, 812, 815);
INSERT INTO chado.cvterm_relationship VALUES (519, 211, 816, 817);
INSERT INTO chado.cvterm_relationship VALUES (520, 211, 818, 817);
INSERT INTO chado.cvterm_relationship VALUES (521, 211, 819, 820);
INSERT INTO chado.cvterm_relationship VALUES (522, 211, 821, 820);
INSERT INTO chado.cvterm_relationship VALUES (523, 211, 822, 820);
INSERT INTO chado.cvterm_relationship VALUES (524, 211, 823, 647);
INSERT INTO chado.cvterm_relationship VALUES (525, 211, 824, 647);
INSERT INTO chado.cvterm_relationship VALUES (526, 211, 825, 821);
INSERT INTO chado.cvterm_relationship VALUES (527, 211, 825, 826);
INSERT INTO chado.cvterm_relationship VALUES (528, 211, 827, 819);
INSERT INTO chado.cvterm_relationship VALUES (529, 211, 827, 826);
INSERT INTO chado.cvterm_relationship VALUES (530, 211, 828, 822);
INSERT INTO chado.cvterm_relationship VALUES (531, 211, 828, 826);
INSERT INTO chado.cvterm_relationship VALUES (532, 211, 829, 830);
INSERT INTO chado.cvterm_relationship VALUES (533, 211, 831, 830);
INSERT INTO chado.cvterm_relationship VALUES (534, 211, 832, 830);
INSERT INTO chado.cvterm_relationship VALUES (535, 211, 833, 648);
INSERT INTO chado.cvterm_relationship VALUES (536, 211, 833, 834);
INSERT INTO chado.cvterm_relationship VALUES (537, 234, 833, 535);
INSERT INTO chado.cvterm_relationship VALUES (538, 211, 835, 680);
INSERT INTO chado.cvterm_relationship VALUES (539, 216, 835, 413);
INSERT INTO chado.cvterm_relationship VALUES (540, 211, 836, 704);
INSERT INTO chado.cvterm_relationship VALUES (541, 234, 836, 532);
INSERT INTO chado.cvterm_relationship VALUES (542, 211, 837, 659);
INSERT INTO chado.cvterm_relationship VALUES (543, 211, 840, 841);
INSERT INTO chado.cvterm_relationship VALUES (544, 211, 840, 842);
INSERT INTO chado.cvterm_relationship VALUES (545, 211, 488, 492);
INSERT INTO chado.cvterm_relationship VALUES (546, 234, 488, 322);
INSERT INTO chado.cvterm_relationship VALUES (547, 211, 431, 305);
INSERT INTO chado.cvterm_relationship VALUES (548, 211, 712, 305);
INSERT INTO chado.cvterm_relationship VALUES (549, 211, 723, 784);
INSERT INTO chado.cvterm_relationship VALUES (550, 211, 843, 547);
INSERT INTO chado.cvterm_relationship VALUES (551, 211, 844, 547);
INSERT INTO chado.cvterm_relationship VALUES (552, 211, 845, 534);
INSERT INTO chado.cvterm_relationship VALUES (553, 211, 846, 845);
INSERT INTO chado.cvterm_relationship VALUES (554, 211, 847, 845);
INSERT INTO chado.cvterm_relationship VALUES (555, 211, 848, 727);
INSERT INTO chado.cvterm_relationship VALUES (556, 211, 849, 423);
INSERT INTO chado.cvterm_relationship VALUES (557, 211, 850, 851);
INSERT INTO chado.cvterm_relationship VALUES (558, 255, 850, 852);
INSERT INTO chado.cvterm_relationship VALUES (559, 211, 854, 359);
INSERT INTO chado.cvterm_relationship VALUES (560, 211, 855, 856);
INSERT INTO chado.cvterm_relationship VALUES (561, 211, 857, 851);
INSERT INTO chado.cvterm_relationship VALUES (562, 230, 857, 428);
INSERT INTO chado.cvterm_relationship VALUES (563, 211, 751, 163);
INSERT INTO chado.cvterm_relationship VALUES (564, 230, 751, 858);
INSERT INTO chado.cvterm_relationship VALUES (565, 211, 859, 860);
INSERT INTO chado.cvterm_relationship VALUES (566, 211, 861, 862);
INSERT INTO chado.cvterm_relationship VALUES (567, 211, 863, 163);
INSERT INTO chado.cvterm_relationship VALUES (568, 255, 863, 864);
INSERT INTO chado.cvterm_relationship VALUES (569, 211, 862, 665);
INSERT INTO chado.cvterm_relationship VALUES (570, 211, 865, 352);
INSERT INTO chado.cvterm_relationship VALUES (571, 211, 866, 262);
INSERT INTO chado.cvterm_relationship VALUES (572, 211, 867, 277);
INSERT INTO chado.cvterm_relationship VALUES (573, 211, 868, 866);
INSERT INTO chado.cvterm_relationship VALUES (574, 239, 868, 481);
INSERT INTO chado.cvterm_relationship VALUES (575, 211, 869, 352);
INSERT INTO chado.cvterm_relationship VALUES (576, 211, 869, 870);
INSERT INTO chado.cvterm_relationship VALUES (577, 211, 871, 862);
INSERT INTO chado.cvterm_relationship VALUES (578, 211, 872, 458);
INSERT INTO chado.cvterm_relationship VALUES (579, 211, 873, 476);
INSERT INTO chado.cvterm_relationship VALUES (580, 234, 873, 874);
INSERT INTO chado.cvterm_relationship VALUES (581, 211, 875, 458);
INSERT INTO chado.cvterm_relationship VALUES (582, 211, 876, 862);
INSERT INTO chado.cvterm_relationship VALUES (583, 211, 877, 448);
INSERT INTO chado.cvterm_relationship VALUES (584, 211, 878, 486);
INSERT INTO chado.cvterm_relationship VALUES (585, 211, 879, 451);
INSERT INTO chado.cvterm_relationship VALUES (586, 211, 879, 877);
INSERT INTO chado.cvterm_relationship VALUES (587, 211, 880, 476);
INSERT INTO chado.cvterm_relationship VALUES (588, 234, 880, 878);
INSERT INTO chado.cvterm_relationship VALUES (589, 211, 881, 450);
INSERT INTO chado.cvterm_relationship VALUES (590, 211, 881, 877);
INSERT INTO chado.cvterm_relationship VALUES (591, 211, 882, 271);
INSERT INTO chado.cvterm_relationship VALUES (592, 211, 884, 862);
INSERT INTO chado.cvterm_relationship VALUES (593, 211, 864, 373);
INSERT INTO chado.cvterm_relationship VALUES (594, 230, 864, 885);
INSERT INTO chado.cvterm_relationship VALUES (595, 211, 886, 322);
INSERT INTO chado.cvterm_relationship VALUES (596, 211, 886, 880);
INSERT INTO chado.cvterm_relationship VALUES (597, 211, 817, 657);
INSERT INTO chado.cvterm_relationship VALUES (598, 234, 817, 556);
INSERT INTO chado.cvterm_relationship VALUES (599, 211, 887, 665);
INSERT INTO chado.cvterm_relationship VALUES (600, 211, 280, 444);
INSERT INTO chado.cvterm_relationship VALUES (601, 211, 888, 889);
INSERT INTO chado.cvterm_relationship VALUES (602, 234, 888, 546);
INSERT INTO chado.cvterm_relationship VALUES (603, 211, 890, 891);
INSERT INTO chado.cvterm_relationship VALUES (604, 228, 890, 876);
INSERT INTO chado.cvterm_relationship VALUES (605, 228, 890, 892);
INSERT INTO chado.cvterm_relationship VALUES (606, 211, 893, 889);
INSERT INTO chado.cvterm_relationship VALUES (607, 234, 893, 544);
INSERT INTO chado.cvterm_relationship VALUES (608, 211, 894, 891);
INSERT INTO chado.cvterm_relationship VALUES (609, 228, 894, 876);
INSERT INTO chado.cvterm_relationship VALUES (610, 228, 894, 884);
INSERT INTO chado.cvterm_relationship VALUES (611, 228, 894, 895);
INSERT INTO chado.cvterm_relationship VALUES (612, 211, 896, 891);
INSERT INTO chado.cvterm_relationship VALUES (613, 228, 896, 876);
INSERT INTO chado.cvterm_relationship VALUES (614, 228, 896, 895);
INSERT INTO chado.cvterm_relationship VALUES (615, 211, 897, 891);
INSERT INTO chado.cvterm_relationship VALUES (616, 228, 897, 884);
INSERT INTO chado.cvterm_relationship VALUES (617, 228, 897, 898);
INSERT INTO chado.cvterm_relationship VALUES (618, 211, 899, 891);
INSERT INTO chado.cvterm_relationship VALUES (619, 228, 899, 876);
INSERT INTO chado.cvterm_relationship VALUES (620, 228, 899, 884);
INSERT INTO chado.cvterm_relationship VALUES (621, 228, 899, 898);
INSERT INTO chado.cvterm_relationship VALUES (622, 211, 900, 891);
INSERT INTO chado.cvterm_relationship VALUES (623, 228, 900, 876);
INSERT INTO chado.cvterm_relationship VALUES (624, 228, 900, 898);
INSERT INTO chado.cvterm_relationship VALUES (625, 211, 901, 667);
INSERT INTO chado.cvterm_relationship VALUES (626, 211, 902, 903);
INSERT INTO chado.cvterm_relationship VALUES (627, 234, 902, 904);
INSERT INTO chado.cvterm_relationship VALUES (628, 211, 905, 906);
INSERT INTO chado.cvterm_relationship VALUES (629, 234, 905, 904);
INSERT INTO chado.cvterm_relationship VALUES (630, 211, 907, 908);
INSERT INTO chado.cvterm_relationship VALUES (631, 234, 907, 904);
INSERT INTO chado.cvterm_relationship VALUES (632, 211, 909, 903);
INSERT INTO chado.cvterm_relationship VALUES (633, 234, 909, 910);
INSERT INTO chado.cvterm_relationship VALUES (634, 211, 911, 906);
INSERT INTO chado.cvterm_relationship VALUES (635, 234, 911, 910);
INSERT INTO chado.cvterm_relationship VALUES (636, 211, 912, 908);
INSERT INTO chado.cvterm_relationship VALUES (637, 234, 912, 910);
INSERT INTO chado.cvterm_relationship VALUES (638, 211, 913, 486);
INSERT INTO chado.cvterm_relationship VALUES (639, 211, 914, 301);
INSERT INTO chado.cvterm_relationship VALUES (640, 211, 915, 301);
INSERT INTO chado.cvterm_relationship VALUES (641, 211, 918, 891);
INSERT INTO chado.cvterm_relationship VALUES (642, 228, 918, 861);
INSERT INTO chado.cvterm_relationship VALUES (643, 228, 918, 884);
INSERT INTO chado.cvterm_relationship VALUES (644, 228, 918, 892);
INSERT INTO chado.cvterm_relationship VALUES (645, 211, 919, 891);
INSERT INTO chado.cvterm_relationship VALUES (646, 228, 919, 861);
INSERT INTO chado.cvterm_relationship VALUES (647, 228, 919, 892);
INSERT INTO chado.cvterm_relationship VALUES (648, 211, 920, 891);
INSERT INTO chado.cvterm_relationship VALUES (649, 228, 920, 861);
INSERT INTO chado.cvterm_relationship VALUES (650, 228, 920, 876);
INSERT INTO chado.cvterm_relationship VALUES (651, 228, 920, 884);
INSERT INTO chado.cvterm_relationship VALUES (652, 228, 920, 892);
INSERT INTO chado.cvterm_relationship VALUES (653, 211, 921, 866);
INSERT INTO chado.cvterm_relationship VALUES (654, 239, 921, 481);
INSERT INTO chado.cvterm_relationship VALUES (655, 234, 921, 922);
INSERT INTO chado.cvterm_relationship VALUES (656, 211, 923, 891);
INSERT INTO chado.cvterm_relationship VALUES (657, 228, 923, 861);
INSERT INTO chado.cvterm_relationship VALUES (658, 228, 923, 876);
INSERT INTO chado.cvterm_relationship VALUES (659, 228, 923, 892);
INSERT INTO chado.cvterm_relationship VALUES (660, 211, 924, 887);
INSERT INTO chado.cvterm_relationship VALUES (661, 228, 924, 861);
INSERT INTO chado.cvterm_relationship VALUES (662, 228, 924, 876);
INSERT INTO chado.cvterm_relationship VALUES (663, 228, 924, 884);
INSERT INTO chado.cvterm_relationship VALUES (664, 211, 925, 926);
INSERT INTO chado.cvterm_relationship VALUES (665, 211, 927, 887);
INSERT INTO chado.cvterm_relationship VALUES (666, 228, 927, 876);
INSERT INTO chado.cvterm_relationship VALUES (667, 228, 927, 884);
INSERT INTO chado.cvterm_relationship VALUES (668, 211, 928, 352);
INSERT INTO chado.cvterm_relationship VALUES (669, 211, 929, 887);
INSERT INTO chado.cvterm_relationship VALUES (670, 228, 929, 876);
INSERT INTO chado.cvterm_relationship VALUES (671, 211, 930, 906);
INSERT INTO chado.cvterm_relationship VALUES (672, 234, 930, 666);
INSERT INTO chado.cvterm_relationship VALUES (673, 211, 931, 903);
INSERT INTO chado.cvterm_relationship VALUES (674, 234, 931, 666);
INSERT INTO chado.cvterm_relationship VALUES (675, 211, 922, 866);
INSERT INTO chado.cvterm_relationship VALUES (676, 239, 922, 373);
INSERT INTO chado.cvterm_relationship VALUES (677, 234, 922, 327);
INSERT INTO chado.cvterm_relationship VALUES (678, 211, 932, 908);
INSERT INTO chado.cvterm_relationship VALUES (679, 234, 932, 666);
INSERT INTO chado.cvterm_relationship VALUES (680, 211, 933, 891);
INSERT INTO chado.cvterm_relationship VALUES (681, 228, 933, 871);
INSERT INTO chado.cvterm_relationship VALUES (682, 228, 933, 892);
INSERT INTO chado.cvterm_relationship VALUES (683, 211, 934, 891);
INSERT INTO chado.cvterm_relationship VALUES (684, 228, 934, 871);
INSERT INTO chado.cvterm_relationship VALUES (685, 228, 934, 876);
INSERT INTO chado.cvterm_relationship VALUES (686, 228, 934, 892);
INSERT INTO chado.cvterm_relationship VALUES (687, 211, 935, 891);
INSERT INTO chado.cvterm_relationship VALUES (688, 228, 935, 871);
INSERT INTO chado.cvterm_relationship VALUES (689, 228, 935, 884);
INSERT INTO chado.cvterm_relationship VALUES (690, 228, 935, 895);
INSERT INTO chado.cvterm_relationship VALUES (691, 211, 936, 891);
INSERT INTO chado.cvterm_relationship VALUES (692, 228, 936, 871);
INSERT INTO chado.cvterm_relationship VALUES (693, 228, 936, 895);
INSERT INTO chado.cvterm_relationship VALUES (694, 211, 937, 891);
INSERT INTO chado.cvterm_relationship VALUES (695, 228, 937, 871);
INSERT INTO chado.cvterm_relationship VALUES (696, 228, 937, 876);
INSERT INTO chado.cvterm_relationship VALUES (697, 228, 937, 895);
INSERT INTO chado.cvterm_relationship VALUES (698, 211, 938, 891);
INSERT INTO chado.cvterm_relationship VALUES (699, 228, 938, 871);
INSERT INTO chado.cvterm_relationship VALUES (700, 228, 938, 884);
INSERT INTO chado.cvterm_relationship VALUES (701, 228, 938, 898);
INSERT INTO chado.cvterm_relationship VALUES (702, 211, 939, 891);
INSERT INTO chado.cvterm_relationship VALUES (703, 228, 939, 871);
INSERT INTO chado.cvterm_relationship VALUES (704, 228, 939, 898);
INSERT INTO chado.cvterm_relationship VALUES (705, 211, 940, 891);
INSERT INTO chado.cvterm_relationship VALUES (706, 228, 940, 871);
INSERT INTO chado.cvterm_relationship VALUES (707, 228, 940, 876);
INSERT INTO chado.cvterm_relationship VALUES (708, 228, 940, 898);
INSERT INTO chado.cvterm_relationship VALUES (709, 211, 941, 887);
INSERT INTO chado.cvterm_relationship VALUES (710, 228, 941, 871);
INSERT INTO chado.cvterm_relationship VALUES (711, 211, 942, 891);
INSERT INTO chado.cvterm_relationship VALUES (712, 228, 942, 861);
INSERT INTO chado.cvterm_relationship VALUES (713, 228, 942, 871);
INSERT INTO chado.cvterm_relationship VALUES (714, 228, 942, 884);
INSERT INTO chado.cvterm_relationship VALUES (715, 228, 942, 892);
INSERT INTO chado.cvterm_relationship VALUES (716, 211, 943, 891);
INSERT INTO chado.cvterm_relationship VALUES (717, 228, 943, 861);
INSERT INTO chado.cvterm_relationship VALUES (718, 228, 943, 871);
INSERT INTO chado.cvterm_relationship VALUES (719, 228, 943, 892);
INSERT INTO chado.cvterm_relationship VALUES (720, 211, 944, 891);
INSERT INTO chado.cvterm_relationship VALUES (721, 228, 944, 861);
INSERT INTO chado.cvterm_relationship VALUES (722, 228, 944, 871);
INSERT INTO chado.cvterm_relationship VALUES (723, 228, 944, 876);
INSERT INTO chado.cvterm_relationship VALUES (724, 228, 944, 884);
INSERT INTO chado.cvterm_relationship VALUES (725, 228, 944, 892);
INSERT INTO chado.cvterm_relationship VALUES (726, 211, 945, 891);
INSERT INTO chado.cvterm_relationship VALUES (727, 228, 945, 861);
INSERT INTO chado.cvterm_relationship VALUES (728, 228, 945, 871);
INSERT INTO chado.cvterm_relationship VALUES (729, 228, 945, 876);
INSERT INTO chado.cvterm_relationship VALUES (730, 228, 945, 892);
INSERT INTO chado.cvterm_relationship VALUES (731, 211, 946, 891);
INSERT INTO chado.cvterm_relationship VALUES (732, 228, 946, 861);
INSERT INTO chado.cvterm_relationship VALUES (733, 228, 946, 871);
INSERT INTO chado.cvterm_relationship VALUES (734, 228, 946, 876);
INSERT INTO chado.cvterm_relationship VALUES (735, 228, 946, 884);
INSERT INTO chado.cvterm_relationship VALUES (736, 211, 947, 891);
INSERT INTO chado.cvterm_relationship VALUES (737, 228, 947, 861);
INSERT INTO chado.cvterm_relationship VALUES (738, 228, 947, 871);
INSERT INTO chado.cvterm_relationship VALUES (739, 228, 947, 876);
INSERT INTO chado.cvterm_relationship VALUES (740, 211, 948, 903);
INSERT INTO chado.cvterm_relationship VALUES (741, 234, 948, 949);
INSERT INTO chado.cvterm_relationship VALUES (742, 211, 950, 887);
INSERT INTO chado.cvterm_relationship VALUES (743, 228, 950, 871);
INSERT INTO chado.cvterm_relationship VALUES (744, 228, 950, 876);
INSERT INTO chado.cvterm_relationship VALUES (745, 211, 951, 887);
INSERT INTO chado.cvterm_relationship VALUES (746, 228, 951, 871);
INSERT INTO chado.cvterm_relationship VALUES (747, 228, 951, 876);
INSERT INTO chado.cvterm_relationship VALUES (748, 228, 951, 884);
INSERT INTO chado.cvterm_relationship VALUES (749, 211, 952, 906);
INSERT INTO chado.cvterm_relationship VALUES (750, 234, 952, 949);
INSERT INTO chado.cvterm_relationship VALUES (751, 211, 953, 908);
INSERT INTO chado.cvterm_relationship VALUES (752, 234, 953, 949);
INSERT INTO chado.cvterm_relationship VALUES (753, 211, 949, 667);
INSERT INTO chado.cvterm_relationship VALUES (754, 211, 954, 891);
INSERT INTO chado.cvterm_relationship VALUES (755, 228, 954, 884);
INSERT INTO chado.cvterm_relationship VALUES (756, 228, 954, 892);
INSERT INTO chado.cvterm_relationship VALUES (757, 211, 955, 891);
INSERT INTO chado.cvterm_relationship VALUES (758, 228, 955, 876);
INSERT INTO chado.cvterm_relationship VALUES (759, 228, 955, 884);
INSERT INTO chado.cvterm_relationship VALUES (760, 228, 955, 892);
INSERT INTO chado.cvterm_relationship VALUES (761, 211, 956, 891);
INSERT INTO chado.cvterm_relationship VALUES (762, 228, 956, 884);
INSERT INTO chado.cvterm_relationship VALUES (763, 228, 956, 895);
INSERT INTO chado.cvterm_relationship VALUES (764, 211, 957, 891);
INSERT INTO chado.cvterm_relationship VALUES (765, 228, 957, 871);
INSERT INTO chado.cvterm_relationship VALUES (766, 228, 957, 884);
INSERT INTO chado.cvterm_relationship VALUES (767, 228, 957, 892);
INSERT INTO chado.cvterm_relationship VALUES (768, 211, 959, 528);
INSERT INTO chado.cvterm_relationship VALUES (769, 211, 960, 961);
INSERT INTO chado.cvterm_relationship VALUES (770, 234, 960, 962);
INSERT INTO chado.cvterm_relationship VALUES (771, 211, 963, 727);
INSERT INTO chado.cvterm_relationship VALUES (772, 211, 964, 870);
INSERT INTO chado.cvterm_relationship VALUES (773, 211, 965, 851);
INSERT INTO chado.cvterm_relationship VALUES (774, 255, 965, 966);
INSERT INTO chado.cvterm_relationship VALUES (775, 211, 967, 870);
INSERT INTO chado.cvterm_relationship VALUES (776, 211, 968, 359);
INSERT INTO chado.cvterm_relationship VALUES (777, 211, 969, 344);
INSERT INTO chado.cvterm_relationship VALUES (778, 211, 970, 470);
INSERT INTO chado.cvterm_relationship VALUES (779, 211, 971, 418);
INSERT INTO chado.cvterm_relationship VALUES (780, 234, 971, 552);
INSERT INTO chado.cvterm_relationship VALUES (781, 234, 971, 581);
INSERT INTO chado.cvterm_relationship VALUES (782, 211, 973, 668);
INSERT INTO chado.cvterm_relationship VALUES (783, 211, 910, 901);
INSERT INTO chado.cvterm_relationship VALUES (784, 211, 974, 668);
INSERT INTO chado.cvterm_relationship VALUES (785, 211, 975, 887);
INSERT INTO chado.cvterm_relationship VALUES (786, 228, 975, 884);
INSERT INTO chado.cvterm_relationship VALUES (787, 211, 976, 887);
INSERT INTO chado.cvterm_relationship VALUES (788, 228, 976, 861);
INSERT INTO chado.cvterm_relationship VALUES (789, 211, 977, 887);
INSERT INTO chado.cvterm_relationship VALUES (790, 228, 977, 861);
INSERT INTO chado.cvterm_relationship VALUES (791, 228, 977, 876);
INSERT INTO chado.cvterm_relationship VALUES (792, 211, 903, 667);
INSERT INTO chado.cvterm_relationship VALUES (793, 211, 906, 667);
INSERT INTO chado.cvterm_relationship VALUES (794, 211, 908, 665);
INSERT INTO chado.cvterm_relationship VALUES (795, 211, 978, 891);
INSERT INTO chado.cvterm_relationship VALUES (796, 228, 978, 871);
INSERT INTO chado.cvterm_relationship VALUES (797, 228, 978, 876);
INSERT INTO chado.cvterm_relationship VALUES (798, 228, 978, 884);
INSERT INTO chado.cvterm_relationship VALUES (799, 228, 978, 892);
INSERT INTO chado.cvterm_relationship VALUES (800, 211, 979, 891);
INSERT INTO chado.cvterm_relationship VALUES (801, 228, 979, 871);
INSERT INTO chado.cvterm_relationship VALUES (802, 228, 979, 876);
INSERT INTO chado.cvterm_relationship VALUES (803, 228, 979, 884);
INSERT INTO chado.cvterm_relationship VALUES (804, 228, 979, 895);
INSERT INTO chado.cvterm_relationship VALUES (805, 211, 980, 891);
INSERT INTO chado.cvterm_relationship VALUES (806, 228, 980, 871);
INSERT INTO chado.cvterm_relationship VALUES (807, 228, 980, 876);
INSERT INTO chado.cvterm_relationship VALUES (808, 228, 980, 884);
INSERT INTO chado.cvterm_relationship VALUES (809, 228, 980, 898);
INSERT INTO chado.cvterm_relationship VALUES (810, 211, 981, 968);
INSERT INTO chado.cvterm_relationship VALUES (811, 211, 982, 290);
INSERT INTO chado.cvterm_relationship VALUES (812, 211, 983, 585);
INSERT INTO chado.cvterm_relationship VALUES (813, 211, 904, 901);
INSERT INTO chado.cvterm_relationship VALUES (814, 211, 984, 278);
INSERT INTO chado.cvterm_relationship VALUES (815, 211, 892, 926);
INSERT INTO chado.cvterm_relationship VALUES (816, 211, 985, 278);
INSERT INTO chado.cvterm_relationship VALUES (817, 211, 895, 926);
INSERT INTO chado.cvterm_relationship VALUES (818, 211, 986, 278);
INSERT INTO chado.cvterm_relationship VALUES (819, 211, 898, 926);
INSERT INTO chado.cvterm_relationship VALUES (820, 211, 987, 988);
INSERT INTO chado.cvterm_relationship VALUES (821, 211, 989, 278);
INSERT INTO chado.cvterm_relationship VALUES (822, 211, 990, 482);
INSERT INTO chado.cvterm_relationship VALUES (823, 211, 991, 580);
INSERT INTO chado.cvterm_relationship VALUES (824, 211, 992, 262);
INSERT INTO chado.cvterm_relationship VALUES (825, 211, 993, 580);
INSERT INTO chado.cvterm_relationship VALUES (826, 211, 994, 990);
INSERT INTO chado.cvterm_relationship VALUES (827, 211, 995, 630);
INSERT INTO chado.cvterm_relationship VALUES (828, 211, 996, 989);
INSERT INTO chado.cvterm_relationship VALUES (829, 211, 997, 280);
INSERT INTO chado.cvterm_relationship VALUES (830, 211, 998, 999);
INSERT INTO chado.cvterm_relationship VALUES (831, 211, 999, 534);
INSERT INTO chado.cvterm_relationship VALUES (832, 230, 999, 754);
INSERT INTO chado.cvterm_relationship VALUES (833, 211, 1000, 280);
INSERT INTO chado.cvterm_relationship VALUES (834, 211, 1001, 282);
INSERT INTO chado.cvterm_relationship VALUES (835, 216, 1001, 1000);
INSERT INTO chado.cvterm_relationship VALUES (836, 211, 961, 261);
INSERT INTO chado.cvterm_relationship VALUES (837, 211, 1002, 961);
INSERT INTO chado.cvterm_relationship VALUES (838, 211, 787, 628);
INSERT INTO chado.cvterm_relationship VALUES (839, 216, 787, 1003);
INSERT INTO chado.cvterm_relationship VALUES (840, 211, 1004, 628);
INSERT INTO chado.cvterm_relationship VALUES (841, 216, 1004, 1005);
INSERT INTO chado.cvterm_relationship VALUES (842, 211, 1003, 580);
INSERT INTO chado.cvterm_relationship VALUES (843, 211, 1005, 580);
INSERT INTO chado.cvterm_relationship VALUES (844, 211, 1011, 282);
INSERT INTO chado.cvterm_relationship VALUES (845, 211, 764, 999);
INSERT INTO chado.cvterm_relationship VALUES (846, 211, 1012, 990);
INSERT INTO chado.cvterm_relationship VALUES (847, 211, 1013, 262);
INSERT INTO chado.cvterm_relationship VALUES (848, 211, 1014, 990);
INSERT INTO chado.cvterm_relationship VALUES (849, 211, 1015, 990);
INSERT INTO chado.cvterm_relationship VALUES (850, 211, 1016, 989);
INSERT INTO chado.cvterm_relationship VALUES (851, 211, 1017, 262);
INSERT INTO chado.cvterm_relationship VALUES (852, 208, 1017, 1011);
INSERT INTO chado.cvterm_relationship VALUES (853, 211, 1018, 262);
INSERT INTO chado.cvterm_relationship VALUES (854, 208, 1018, 164);
INSERT INTO chado.cvterm_relationship VALUES (855, 211, 1019, 689);
INSERT INTO chado.cvterm_relationship VALUES (856, 211, 1020, 689);
INSERT INTO chado.cvterm_relationship VALUES (857, 211, 1021, 1022);
INSERT INTO chado.cvterm_relationship VALUES (858, 211, 1023, 474);
INSERT INTO chado.cvterm_relationship VALUES (859, 211, 1024, 1025);
INSERT INTO chado.cvterm_relationship VALUES (860, 211, 1026, 501);
INSERT INTO chado.cvterm_relationship VALUES (861, 211, 1027, 513);
INSERT INTO chado.cvterm_relationship VALUES (862, 211, 1028, 513);
INSERT INTO chado.cvterm_relationship VALUES (863, 211, 1029, 284);
INSERT INTO chado.cvterm_relationship VALUES (864, 211, 1030, 284);
INSERT INTO chado.cvterm_relationship VALUES (865, 234, 1030, 1028);
INSERT INTO chado.cvterm_relationship VALUES (866, 211, 1031, 513);
INSERT INTO chado.cvterm_relationship VALUES (867, 211, 1032, 284);
INSERT INTO chado.cvterm_relationship VALUES (868, 234, 1032, 1027);
INSERT INTO chado.cvterm_relationship VALUES (869, 211, 1033, 278);
INSERT INTO chado.cvterm_relationship VALUES (870, 211, 1034, 988);
INSERT INTO chado.cvterm_relationship VALUES (871, 211, 1035, 316);
INSERT INTO chado.cvterm_relationship VALUES (872, 211, 314, 423);
INSERT INTO chado.cvterm_relationship VALUES (873, 211, 1036, 316);
INSERT INTO chado.cvterm_relationship VALUES (874, 211, 988, 423);
INSERT INTO chado.cvterm_relationship VALUES (875, 211, 1037, 312);
INSERT INTO chado.cvterm_relationship VALUES (876, 234, 1037, 471);
INSERT INTO chado.cvterm_relationship VALUES (877, 211, 1038, 1039);
INSERT INTO chado.cvterm_relationship VALUES (878, 234, 1038, 551);
INSERT INTO chado.cvterm_relationship VALUES (879, 211, 1040, 372);
INSERT INTO chado.cvterm_relationship VALUES (880, 211, 1040, 444);
INSERT INTO chado.cvterm_relationship VALUES (881, 230, 1040, 374);
INSERT INTO chado.cvterm_relationship VALUES (882, 211, 1041, 444);
INSERT INTO chado.cvterm_relationship VALUES (883, 211, 1041, 1042);
INSERT INTO chado.cvterm_relationship VALUES (884, 230, 1041, 1043);
INSERT INTO chado.cvterm_relationship VALUES (885, 211, 1044, 164);
INSERT INTO chado.cvterm_relationship VALUES (886, 211, 1044, 1042);
INSERT INTO chado.cvterm_relationship VALUES (887, 230, 1044, 1043);
INSERT INTO chado.cvterm_relationship VALUES (888, 211, 1045, 372);
INSERT INTO chado.cvterm_relationship VALUES (889, 211, 1045, 164);
INSERT INTO chado.cvterm_relationship VALUES (890, 230, 1045, 374);
INSERT INTO chado.cvterm_relationship VALUES (891, 211, 1046, 444);
INSERT INTO chado.cvterm_relationship VALUES (892, 211, 1047, 501);
INSERT INTO chado.cvterm_relationship VALUES (893, 234, 1047, 1046);
INSERT INTO chado.cvterm_relationship VALUES (894, 211, 1048, 491);
INSERT INTO chado.cvterm_relationship VALUES (895, 211, 1048, 637);
INSERT INTO chado.cvterm_relationship VALUES (896, 230, 1048, 638);
INSERT INTO chado.cvterm_relationship VALUES (897, 211, 1049, 1050);
INSERT INTO chado.cvterm_relationship VALUES (898, 211, 1051, 1049);
INSERT INTO chado.cvterm_relationship VALUES (899, 211, 1052, 1049);
INSERT INTO chado.cvterm_relationship VALUES (900, 211, 1053, 652);
INSERT INTO chado.cvterm_relationship VALUES (901, 211, 1054, 278);
INSERT INTO chado.cvterm_relationship VALUES (902, 211, 1055, 266);
INSERT INTO chado.cvterm_relationship VALUES (903, 211, 767, 282);
INSERT INTO chado.cvterm_relationship VALUES (904, 216, 767, 1056);
INSERT INTO chado.cvterm_relationship VALUES (905, 211, 1056, 444);
INSERT INTO chado.cvterm_relationship VALUES (906, 211, 1057, 630);
INSERT INTO chado.cvterm_relationship VALUES (907, 211, 1058, 280);
INSERT INTO chado.cvterm_relationship VALUES (908, 228, 1058, 631);
INSERT INTO chado.cvterm_relationship VALUES (909, 211, 793, 1059);
INSERT INTO chado.cvterm_relationship VALUES (910, 216, 793, 608);
INSERT INTO chado.cvterm_relationship VALUES (911, 211, 756, 1059);
INSERT INTO chado.cvterm_relationship VALUES (912, 216, 756, 698);
INSERT INTO chado.cvterm_relationship VALUES (913, 211, 1060, 756);
INSERT INTO chado.cvterm_relationship VALUES (914, 216, 1060, 1061);
INSERT INTO chado.cvterm_relationship VALUES (915, 211, 1062, 756);
INSERT INTO chado.cvterm_relationship VALUES (916, 216, 1062, 1063);
INSERT INTO chado.cvterm_relationship VALUES (917, 211, 1064, 389);
INSERT INTO chado.cvterm_relationship VALUES (918, 234, 1064, 1065);
INSERT INTO chado.cvterm_relationship VALUES (919, 211, 282, 581);
INSERT INTO chado.cvterm_relationship VALUES (920, 211, 1066, 278);
INSERT INTO chado.cvterm_relationship VALUES (921, 211, 648, 262);
INSERT INTO chado.cvterm_relationship VALUES (922, 228, 648, 1067);
INSERT INTO chado.cvterm_relationship VALUES (923, 211, 1068, 648);
INSERT INTO chado.cvterm_relationship VALUES (924, 211, 1069, 278);
INSERT INTO chado.cvterm_relationship VALUES (925, 211, 531, 534);
INSERT INTO chado.cvterm_relationship VALUES (926, 211, 1072, 278);
INSERT INTO chado.cvterm_relationship VALUES (927, 211, 1073, 423);
INSERT INTO chado.cvterm_relationship VALUES (928, 211, 1042, 373);
INSERT INTO chado.cvterm_relationship VALUES (929, 230, 1042, 1043);
INSERT INTO chado.cvterm_relationship VALUES (930, 211, 1074, 534);
INSERT INTO chado.cvterm_relationship VALUES (931, 211, 1074, 1075);
INSERT INTO chado.cvterm_relationship VALUES (932, 230, 1074, 1076);
INSERT INTO chado.cvterm_relationship VALUES (933, 211, 1077, 496);
INSERT INTO chado.cvterm_relationship VALUES (934, 211, 1077, 262);
INSERT INTO chado.cvterm_relationship VALUES (935, 211, 1078, 415);
INSERT INTO chado.cvterm_relationship VALUES (936, 211, 663, 661);
INSERT INTO chado.cvterm_relationship VALUES (937, 211, 1079, 663);
INSERT INTO chado.cvterm_relationship VALUES (938, 211, 1080, 663);
INSERT INTO chado.cvterm_relationship VALUES (939, 211, 1081, 663);
INSERT INTO chado.cvterm_relationship VALUES (940, 211, 373, 1082);
INSERT INTO chado.cvterm_relationship VALUES (941, 241, 373, 1083);
INSERT INTO chado.cvterm_relationship VALUES (942, 211, 1086, 504);
INSERT INTO chado.cvterm_relationship VALUES (943, 211, 1087, 502);
INSERT INTO chado.cvterm_relationship VALUES (944, 211, 1088, 504);
INSERT INTO chado.cvterm_relationship VALUES (945, 211, 1089, 502);
INSERT INTO chado.cvterm_relationship VALUES (946, 211, 1090, 685);
INSERT INTO chado.cvterm_relationship VALUES (947, 211, 1091, 373);
INSERT INTO chado.cvterm_relationship VALUES (948, 211, 1093, 688);
INSERT INTO chado.cvterm_relationship VALUES (949, 211, 693, 346);
INSERT INTO chado.cvterm_relationship VALUES (950, 211, 1094, 692);
INSERT INTO chado.cvterm_relationship VALUES (951, 211, 1095, 1096);
INSERT INTO chado.cvterm_relationship VALUES (952, 211, 1097, 418);
INSERT INTO chado.cvterm_relationship VALUES (953, 211, 874, 486);
INSERT INTO chado.cvterm_relationship VALUES (954, 211, 1098, 415);
INSERT INTO chado.cvterm_relationship VALUES (955, 211, 1099, 163);
INSERT INTO chado.cvterm_relationship VALUES (956, 255, 1099, 372);
INSERT INTO chado.cvterm_relationship VALUES (957, 211, 1100, 1101);
INSERT INTO chado.cvterm_relationship VALUES (958, 211, 1102, 1099);
INSERT INTO chado.cvterm_relationship VALUES (959, 255, 1102, 375);
INSERT INTO chado.cvterm_relationship VALUES (960, 211, 1103, 851);
INSERT INTO chado.cvterm_relationship VALUES (961, 230, 1103, 1104);
INSERT INTO chado.cvterm_relationship VALUES (962, 211, 1105, 1106);
INSERT INTO chado.cvterm_relationship VALUES (963, 211, 269, 1107);
INSERT INTO chado.cvterm_relationship VALUES (964, 211, 305, 269);
INSERT INTO chado.cvterm_relationship VALUES (965, 211, 1108, 1103);
INSERT INTO chado.cvterm_relationship VALUES (966, 228, 1108, 1109);
INSERT INTO chado.cvterm_relationship VALUES (967, 211, 1110, 1108);
INSERT INTO chado.cvterm_relationship VALUES (968, 228, 1110, 1111);
INSERT INTO chado.cvterm_relationship VALUES (969, 211, 418, 162);
INSERT INTO chado.cvterm_relationship VALUES (970, 211, 801, 319);
INSERT INTO chado.cvterm_relationship VALUES (971, 211, 1112, 800);
INSERT INTO chado.cvterm_relationship VALUES (972, 211, 1113, 800);
INSERT INTO chado.cvterm_relationship VALUES (973, 211, 1114, 801);
INSERT INTO chado.cvterm_relationship VALUES (974, 211, 163, 262);
INSERT INTO chado.cvterm_relationship VALUES (975, 238, 163, 524);
INSERT INTO chado.cvterm_relationship VALUES (976, 211, 267, 648);
INSERT INTO chado.cvterm_relationship VALUES (977, 211, 1115, 1116);
INSERT INTO chado.cvterm_relationship VALUES (978, 211, 1117, 1116);
INSERT INTO chado.cvterm_relationship VALUES (979, 211, 1118, 1115);
INSERT INTO chado.cvterm_relationship VALUES (980, 211, 1119, 1115);
INSERT INTO chado.cvterm_relationship VALUES (981, 211, 1120, 1108);
INSERT INTO chado.cvterm_relationship VALUES (982, 228, 1120, 1121);
INSERT INTO chado.cvterm_relationship VALUES (983, 211, 1122, 1103);
INSERT INTO chado.cvterm_relationship VALUES (984, 230, 1122, 1123);
INSERT INTO chado.cvterm_relationship VALUES (985, 211, 1124, 1103);
INSERT INTO chado.cvterm_relationship VALUES (986, 230, 1124, 441);
INSERT INTO chado.cvterm_relationship VALUES (987, 211, 289, 1125);
INSERT INTO chado.cvterm_relationship VALUES (988, 211, 1125, 1126);
INSERT INTO chado.cvterm_relationship VALUES (989, 211, 293, 1125);
INSERT INTO chado.cvterm_relationship VALUES (990, 211, 1127, 375);
INSERT INTO chado.cvterm_relationship VALUES (991, 211, 1127, 1045);
INSERT INTO chado.cvterm_relationship VALUES (992, 230, 1127, 376);
INSERT INTO chado.cvterm_relationship VALUES (993, 211, 584, 319);
INSERT INTO chado.cvterm_relationship VALUES (994, 211, 1128, 584);
INSERT INTO chado.cvterm_relationship VALUES (995, 211, 485, 484);
INSERT INTO chado.cvterm_relationship VALUES (996, 211, 1129, 413);
INSERT INTO chado.cvterm_relationship VALUES (997, 230, 1129, 642);
INSERT INTO chado.cvterm_relationship VALUES (998, 211, 1130, 1102);
INSERT INTO chado.cvterm_relationship VALUES (999, 255, 1130, 1131);
INSERT INTO chado.cvterm_relationship VALUES (1000, 211, 1132, 1102);
INSERT INTO chado.cvterm_relationship VALUES (1001, 255, 1132, 1127);
INSERT INTO chado.cvterm_relationship VALUES (1002, 211, 1133, 661);
INSERT INTO chado.cvterm_relationship VALUES (1003, 211, 1134, 659);
INSERT INTO chado.cvterm_relationship VALUES (1004, 211, 1135, 809);
INSERT INTO chado.cvterm_relationship VALUES (1005, 216, 1135, 1136);
INSERT INTO chado.cvterm_relationship VALUES (1006, 211, 1067, 262);
INSERT INTO chado.cvterm_relationship VALUES (1007, 211, 316, 344);
INSERT INTO chado.cvterm_relationship VALUES (1008, 211, 1137, 1101);
INSERT INTO chado.cvterm_relationship VALUES (1009, 211, 1138, 276);
INSERT INTO chado.cvterm_relationship VALUES (1010, 211, 1139, 476);
INSERT INTO chado.cvterm_relationship VALUES (1011, 234, 1139, 486);
INSERT INTO chado.cvterm_relationship VALUES (1012, 211, 1140, 1141);
INSERT INTO chado.cvterm_relationship VALUES (1013, 211, 1142, 1141);
INSERT INTO chado.cvterm_relationship VALUES (1014, 211, 585, 784);
INSERT INTO chado.cvterm_relationship VALUES (1015, 211, 1143, 164);
INSERT INTO chado.cvterm_relationship VALUES (1016, 230, 1143, 1144);
INSERT INTO chado.cvterm_relationship VALUES (1017, 211, 1145, 784);
INSERT INTO chado.cvterm_relationship VALUES (1018, 211, 381, 1145);
INSERT INTO chado.cvterm_relationship VALUES (1019, 211, 388, 381);
INSERT INTO chado.cvterm_relationship VALUES (1020, 211, 386, 1145);
INSERT INTO chado.cvterm_relationship VALUES (1021, 211, 406, 381);
INSERT INTO chado.cvterm_relationship VALUES (1022, 211, 392, 381);
INSERT INTO chado.cvterm_relationship VALUES (1023, 211, 390, 1146);
INSERT INTO chado.cvterm_relationship VALUES (1024, 228, 390, 1065);
INSERT INTO chado.cvterm_relationship VALUES (1025, 228, 390, 1147);
INSERT INTO chado.cvterm_relationship VALUES (1026, 211, 1065, 492);
INSERT INTO chado.cvterm_relationship VALUES (1027, 211, 394, 392);
INSERT INTO chado.cvterm_relationship VALUES (1028, 211, 398, 392);
INSERT INTO chado.cvterm_relationship VALUES (1029, 211, 396, 392);
INSERT INTO chado.cvterm_relationship VALUES (1030, 211, 400, 392);
INSERT INTO chado.cvterm_relationship VALUES (1031, 211, 402, 392);
INSERT INTO chado.cvterm_relationship VALUES (1032, 211, 404, 392);
INSERT INTO chado.cvterm_relationship VALUES (1033, 211, 408, 1145);
INSERT INTO chado.cvterm_relationship VALUES (1034, 211, 1148, 659);
INSERT INTO chado.cvterm_relationship VALUES (1035, 211, 410, 1145);
INSERT INTO chado.cvterm_relationship VALUES (1036, 211, 419, 269);
INSERT INTO chado.cvterm_relationship VALUES (1037, 234, 419, 322);
INSERT INTO chado.cvterm_relationship VALUES (1038, 211, 1150, 488);
INSERT INTO chado.cvterm_relationship VALUES (1039, 211, 1151, 488);
INSERT INTO chado.cvterm_relationship VALUES (1040, 216, 1151, 491);
INSERT INTO chado.cvterm_relationship VALUES (1041, 211, 684, 728);
INSERT INTO chado.cvterm_relationship VALUES (1042, 211, 1152, 684);
INSERT INTO chado.cvterm_relationship VALUES (1043, 211, 1153, 684);
INSERT INTO chado.cvterm_relationship VALUES (1044, 211, 1161, 605);
INSERT INTO chado.cvterm_relationship VALUES (1045, 216, 1161, 1162);
INSERT INTO chado.cvterm_relationship VALUES (1046, 211, 1164, 491);
INSERT INTO chado.cvterm_relationship VALUES (1047, 211, 1165, 1166);
INSERT INTO chado.cvterm_relationship VALUES (1048, 211, 1167, 1166);
INSERT INTO chado.cvterm_relationship VALUES (1049, 211, 165, 262);
INSERT INTO chado.cvterm_relationship VALUES (1050, 211, 1168, 414);
INSERT INTO chado.cvterm_relationship VALUES (1051, 211, 1169, 1168);
INSERT INTO chado.cvterm_relationship VALUES (1052, 211, 1170, 1168);
INSERT INTO chado.cvterm_relationship VALUES (1053, 211, 1171, 1168);
INSERT INTO chado.cvterm_relationship VALUES (1054, 211, 1172, 1168);
INSERT INTO chado.cvterm_relationship VALUES (1055, 211, 1173, 922);
INSERT INTO chado.cvterm_relationship VALUES (1056, 211, 1174, 922);
INSERT INTO chado.cvterm_relationship VALUES (1057, 211, 1175, 1048);
INSERT INTO chado.cvterm_relationship VALUES (1058, 211, 1175, 1164);
INSERT INTO chado.cvterm_relationship VALUES (1059, 230, 1175, 638);
INSERT INTO chado.cvterm_relationship VALUES (1060, 211, 1177, 585);
INSERT INTO chado.cvterm_relationship VALUES (1061, 211, 1178, 585);
INSERT INTO chado.cvterm_relationship VALUES (1062, 211, 638, 585);
INSERT INTO chado.cvterm_relationship VALUES (1063, 211, 642, 585);
INSERT INTO chado.cvterm_relationship VALUES (1064, 211, 1179, 269);
INSERT INTO chado.cvterm_relationship VALUES (1065, 234, 1179, 419);
INSERT INTO chado.cvterm_relationship VALUES (1066, 211, 678, 1141);
INSERT INTO chado.cvterm_relationship VALUES (1067, 211, 737, 1141);
INSERT INTO chado.cvterm_relationship VALUES (1068, 211, 1186, 798);
INSERT INTO chado.cvterm_relationship VALUES (1069, 211, 1186, 637);
INSERT INTO chado.cvterm_relationship VALUES (1070, 230, 1186, 638);
INSERT INTO chado.cvterm_relationship VALUES (1071, 211, 1187, 1188);
INSERT INTO chado.cvterm_relationship VALUES (1072, 230, 1187, 799);
INSERT INTO chado.cvterm_relationship VALUES (1073, 211, 1189, 413);
INSERT INTO chado.cvterm_relationship VALUES (1074, 216, 1189, 322);
INSERT INTO chado.cvterm_relationship VALUES (1075, 230, 1189, 1177);
INSERT INTO chado.cvterm_relationship VALUES (1076, 211, 1190, 413);
INSERT INTO chado.cvterm_relationship VALUES (1077, 211, 1190, 1191);
INSERT INTO chado.cvterm_relationship VALUES (1078, 230, 1190, 1178);
INSERT INTO chado.cvterm_relationship VALUES (1079, 211, 1192, 413);
INSERT INTO chado.cvterm_relationship VALUES (1080, 211, 1192, 637);
INSERT INTO chado.cvterm_relationship VALUES (1081, 230, 1192, 638);
INSERT INTO chado.cvterm_relationship VALUES (1082, 211, 1193, 1129);
INSERT INTO chado.cvterm_relationship VALUES (1083, 211, 1193, 1192);
INSERT INTO chado.cvterm_relationship VALUES (1084, 211, 1193, 641);
INSERT INTO chado.cvterm_relationship VALUES (1085, 230, 1193, 638);
INSERT INTO chado.cvterm_relationship VALUES (1086, 230, 1193, 642);
INSERT INTO chado.cvterm_relationship VALUES (1087, 211, 1194, 1195);
INSERT INTO chado.cvterm_relationship VALUES (1088, 211, 1196, 1195);
INSERT INTO chado.cvterm_relationship VALUES (1089, 211, 1197, 1195);
INSERT INTO chado.cvterm_relationship VALUES (1090, 211, 1198, 1195);
INSERT INTO chado.cvterm_relationship VALUES (1091, 211, 637, 1107);
INSERT INTO chado.cvterm_relationship VALUES (1092, 230, 637, 638);
INSERT INTO chado.cvterm_relationship VALUES (1093, 211, 641, 637);
INSERT INTO chado.cvterm_relationship VALUES (1094, 230, 641, 638);
INSERT INTO chado.cvterm_relationship VALUES (1095, 230, 641, 642);
INSERT INTO chado.cvterm_relationship VALUES (1096, 211, 650, 585);
INSERT INTO chado.cvterm_relationship VALUES (1097, 211, 1199, 697);
INSERT INTO chado.cvterm_relationship VALUES (1098, 211, 1199, 637);
INSERT INTO chado.cvterm_relationship VALUES (1099, 230, 1199, 638);
INSERT INTO chado.cvterm_relationship VALUES (1100, 211, 1200, 683);
INSERT INTO chado.cvterm_relationship VALUES (1101, 230, 1200, 678);
INSERT INTO chado.cvterm_relationship VALUES (1102, 211, 1201, 683);
INSERT INTO chado.cvterm_relationship VALUES (1103, 230, 1201, 737);
INSERT INTO chado.cvterm_relationship VALUES (1104, 211, 1202, 1201);
INSERT INTO chado.cvterm_relationship VALUES (1105, 230, 1202, 736);
INSERT INTO chado.cvterm_relationship VALUES (1106, 211, 1203, 1201);
INSERT INTO chado.cvterm_relationship VALUES (1107, 230, 1203, 802);
INSERT INTO chado.cvterm_relationship VALUES (1108, 211, 1204, 1201);
INSERT INTO chado.cvterm_relationship VALUES (1109, 230, 1204, 803);
INSERT INTO chado.cvterm_relationship VALUES (1110, 211, 1205, 1201);
INSERT INTO chado.cvterm_relationship VALUES (1111, 230, 1205, 804);
INSERT INTO chado.cvterm_relationship VALUES (1112, 211, 799, 585);
INSERT INTO chado.cvterm_relationship VALUES (1113, 211, 1188, 583);
INSERT INTO chado.cvterm_relationship VALUES (1114, 211, 1206, 163);
INSERT INTO chado.cvterm_relationship VALUES (1115, 230, 1206, 799);
INSERT INTO chado.cvterm_relationship VALUES (1116, 211, 1207, 585);
INSERT INTO chado.cvterm_relationship VALUES (1117, 211, 1208, 1206);
INSERT INTO chado.cvterm_relationship VALUES (1118, 230, 1208, 1207);
INSERT INTO chado.cvterm_relationship VALUES (1119, 211, 1209, 715);
INSERT INTO chado.cvterm_relationship VALUES (1120, 229, 1209, 388);
INSERT INTO chado.cvterm_relationship VALUES (1121, 211, 1210, 715);
INSERT INTO chado.cvterm_relationship VALUES (1122, 229, 1210, 396);
INSERT INTO chado.cvterm_relationship VALUES (1123, 211, 1211, 715);
INSERT INTO chado.cvterm_relationship VALUES (1124, 229, 1211, 398);
INSERT INTO chado.cvterm_relationship VALUES (1125, 211, 1212, 715);
INSERT INTO chado.cvterm_relationship VALUES (1126, 229, 1212, 400);
INSERT INTO chado.cvterm_relationship VALUES (1127, 211, 1213, 715);
INSERT INTO chado.cvterm_relationship VALUES (1128, 229, 1213, 402);
INSERT INTO chado.cvterm_relationship VALUES (1129, 211, 1214, 715);
INSERT INTO chado.cvterm_relationship VALUES (1130, 229, 1214, 380);
INSERT INTO chado.cvterm_relationship VALUES (1131, 211, 1215, 715);
INSERT INTO chado.cvterm_relationship VALUES (1132, 229, 1215, 382);
INSERT INTO chado.cvterm_relationship VALUES (1133, 211, 1216, 715);
INSERT INTO chado.cvterm_relationship VALUES (1134, 229, 1216, 386);
INSERT INTO chado.cvterm_relationship VALUES (1135, 211, 1217, 715);
INSERT INTO chado.cvterm_relationship VALUES (1136, 229, 1217, 406);
INSERT INTO chado.cvterm_relationship VALUES (1137, 211, 423, 262);
INSERT INTO chado.cvterm_relationship VALUES (1138, 234, 423, 715);
INSERT INTO chado.cvterm_relationship VALUES (1139, 211, 1082, 262);
INSERT INTO chado.cvterm_relationship VALUES (1140, 238, 1082, 163);
INSERT INTO chado.cvterm_relationship VALUES (1141, 211, 482, 262);
INSERT INTO chado.cvterm_relationship VALUES (1142, 234, 482, 373);
INSERT INTO chado.cvterm_relationship VALUES (1143, 211, 1219, 482);
INSERT INTO chado.cvterm_relationship VALUES (1144, 211, 501, 482);
INSERT INTO chado.cvterm_relationship VALUES (1145, 234, 501, 444);
INSERT INTO chado.cvterm_relationship VALUES (1146, 211, 312, 1219);
INSERT INTO chado.cvterm_relationship VALUES (1147, 234, 312, 164);
INSERT INTO chado.cvterm_relationship VALUES (1148, 211, 1039, 312);
INSERT INTO chado.cvterm_relationship VALUES (1149, 211, 1050, 501);
INSERT INTO chado.cvterm_relationship VALUES (1150, 234, 1050, 557);
INSERT INTO chado.cvterm_relationship VALUES (1151, 211, 813, 262);
INSERT INTO chado.cvterm_relationship VALUES (1152, 234, 813, 420);
INSERT INTO chado.cvterm_relationship VALUES (1153, 211, 834, 588);
INSERT INTO chado.cvterm_relationship VALUES (1154, 211, 689, 501);
INSERT INTO chado.cvterm_relationship VALUES (1155, 234, 689, 531);
INSERT INTO chado.cvterm_relationship VALUES (1156, 211, 508, 262);
INSERT INTO chado.cvterm_relationship VALUES (1157, 234, 508, 163);
INSERT INTO chado.cvterm_relationship VALUES (1158, 211, 1166, 1219);
INSERT INTO chado.cvterm_relationship VALUES (1159, 234, 1166, 995);
INSERT INTO chado.cvterm_relationship VALUES (1160, 211, 820, 834);
INSERT INTO chado.cvterm_relationship VALUES (1161, 234, 820, 647);
INSERT INTO chado.cvterm_relationship VALUES (1162, 211, 830, 820);
INSERT INTO chado.cvterm_relationship VALUES (1163, 234, 830, 824);
INSERT INTO chado.cvterm_relationship VALUES (1164, 211, 826, 820);
INSERT INTO chado.cvterm_relationship VALUES (1165, 234, 826, 823);
INSERT INTO chado.cvterm_relationship VALUES (1166, 211, 696, 312);
INSERT INTO chado.cvterm_relationship VALUES (1167, 234, 696, 421);
INSERT INTO chado.cvterm_relationship VALUES (1168, 211, 1224, 482);
INSERT INTO chado.cvterm_relationship VALUES (1169, 234, 1224, 481);
INSERT INTO chado.cvterm_relationship VALUES (1170, 211, 1225, 704);
INSERT INTO chado.cvterm_relationship VALUES (1171, 230, 1225, 1226);
INSERT INTO chado.cvterm_relationship VALUES (1172, 211, 1227, 1225);
INSERT INTO chado.cvterm_relationship VALUES (1173, 230, 1227, 1228);
INSERT INTO chado.cvterm_relationship VALUES (1174, 211, 1229, 1225);
INSERT INTO chado.cvterm_relationship VALUES (1175, 230, 1229, 1230);
INSERT INTO chado.cvterm_relationship VALUES (1176, 211, 1231, 585);
INSERT INTO chado.cvterm_relationship VALUES (1177, 211, 1226, 1231);
INSERT INTO chado.cvterm_relationship VALUES (1178, 211, 1230, 1226);
INSERT INTO chado.cvterm_relationship VALUES (1179, 211, 1228, 1226);
INSERT INTO chado.cvterm_relationship VALUES (1180, 211, 1232, 1231);
INSERT INTO chado.cvterm_relationship VALUES (1181, 211, 1233, 444);
INSERT INTO chado.cvterm_relationship VALUES (1182, 208, 1233, 992);
INSERT INTO chado.cvterm_relationship VALUES (1183, 230, 1233, 480);
INSERT INTO chado.cvterm_relationship VALUES (1184, 211, 1234, 164);
INSERT INTO chado.cvterm_relationship VALUES (1185, 208, 1234, 992);
INSERT INTO chado.cvterm_relationship VALUES (1186, 230, 1234, 480);
INSERT INTO chado.cvterm_relationship VALUES (1187, 211, 598, 438);
INSERT INTO chado.cvterm_relationship VALUES (1188, 211, 1144, 598);
INSERT INTO chado.cvterm_relationship VALUES (1189, 211, 428, 598);
INSERT INTO chado.cvterm_relationship VALUES (1190, 211, 644, 428);
INSERT INTO chado.cvterm_relationship VALUES (1191, 211, 710, 428);
INSERT INTO chado.cvterm_relationship VALUES (1192, 211, 691, 428);
INSERT INTO chado.cvterm_relationship VALUES (1193, 211, 703, 428);
INSERT INTO chado.cvterm_relationship VALUES (1194, 211, 885, 438);
INSERT INTO chado.cvterm_relationship VALUES (1195, 211, 852, 164);
INSERT INTO chado.cvterm_relationship VALUES (1196, 208, 852, 1018);
INSERT INTO chado.cvterm_relationship VALUES (1197, 230, 852, 597);
INSERT INTO chado.cvterm_relationship VALUES (1198, 211, 1235, 164);
INSERT INTO chado.cvterm_relationship VALUES (1199, 211, 1235, 864);
INSERT INTO chado.cvterm_relationship VALUES (1200, 208, 1235, 1047);
INSERT INTO chado.cvterm_relationship VALUES (1201, 230, 1235, 885);
INSERT INTO chado.cvterm_relationship VALUES (1202, 211, 966, 373);
INSERT INTO chado.cvterm_relationship VALUES (1203, 225, 966, 1011);
INSERT INTO chado.cvterm_relationship VALUES (1204, 228, 966, 1236);
INSERT INTO chado.cvterm_relationship VALUES (1205, 230, 966, 437);
INSERT INTO chado.cvterm_relationship VALUES (1206, 211, 1237, 966);
INSERT INTO chado.cvterm_relationship VALUES (1207, 211, 635, 507);
INSERT INTO chado.cvterm_relationship VALUES (1208, 211, 633, 507);
INSERT INTO chado.cvterm_relationship VALUES (1209, 211, 1238, 438);
INSERT INTO chado.cvterm_relationship VALUES (1210, 211, 1043, 438);
INSERT INTO chado.cvterm_relationship VALUES (1211, 211, 376, 374);
INSERT INTO chado.cvterm_relationship VALUES (1212, 211, 374, 438);
INSERT INTO chado.cvterm_relationship VALUES (1213, 211, 1104, 598);
INSERT INTO chado.cvterm_relationship VALUES (1214, 211, 1239, 1104);
INSERT INTO chado.cvterm_relationship VALUES (1215, 211, 1109, 478);
INSERT INTO chado.cvterm_relationship VALUES (1216, 211, 1111, 1109);
INSERT INTO chado.cvterm_relationship VALUES (1217, 211, 1121, 1109);
INSERT INTO chado.cvterm_relationship VALUES (1218, 211, 1123, 1104);
INSERT INTO chado.cvterm_relationship VALUES (1219, 211, 441, 1104);
INSERT INTO chado.cvterm_relationship VALUES (1220, 211, 1240, 468);
INSERT INTO chado.cvterm_relationship VALUES (1221, 230, 1240, 464);
INSERT INTO chado.cvterm_relationship VALUES (1222, 211, 1241, 468);
INSERT INTO chado.cvterm_relationship VALUES (1223, 230, 1241, 465);
INSERT INTO chado.cvterm_relationship VALUES (1224, 211, 1242, 163);
INSERT INTO chado.cvterm_relationship VALUES (1225, 230, 1242, 458);
INSERT INTO chado.cvterm_relationship VALUES (1226, 211, 1243, 163);
INSERT INTO chado.cvterm_relationship VALUES (1227, 230, 1243, 879);
INSERT INTO chado.cvterm_relationship VALUES (1228, 211, 1244, 163);
INSERT INTO chado.cvterm_relationship VALUES (1229, 230, 1244, 881);
INSERT INTO chado.cvterm_relationship VALUES (1230, 211, 453, 451);
INSERT INTO chado.cvterm_relationship VALUES (1231, 211, 455, 453);
INSERT INTO chado.cvterm_relationship VALUES (1232, 211, 457, 455);
INSERT INTO chado.cvterm_relationship VALUES (1233, 211, 1245, 163);
INSERT INTO chado.cvterm_relationship VALUES (1234, 230, 1245, 459);
INSERT INTO chado.cvterm_relationship VALUES (1235, 211, 1246, 468);
INSERT INTO chado.cvterm_relationship VALUES (1236, 230, 1246, 466);
INSERT INTO chado.cvterm_relationship VALUES (1237, 211, 468, 163);
INSERT INTO chado.cvterm_relationship VALUES (1238, 211, 468, 671);
INSERT INTO chado.cvterm_relationship VALUES (1239, 230, 468, 462);
INSERT INTO chado.cvterm_relationship VALUES (1240, 211, 739, 163);
INSERT INTO chado.cvterm_relationship VALUES (1241, 230, 739, 1177);
INSERT INTO chado.cvterm_relationship VALUES (1242, 211, 412, 410);
INSERT INTO chado.cvterm_relationship VALUES (1243, 211, 469, 462);
INSERT INTO chado.cvterm_relationship VALUES (1244, 211, 1141, 585);
INSERT INTO chado.cvterm_relationship VALUES (1245, 211, 1250, 1141);
INSERT INTO chado.cvterm_relationship VALUES (1246, 211, 1251, 1142);
INSERT INTO chado.cvterm_relationship VALUES (1247, 211, 1252, 1251);
INSERT INTO chado.cvterm_relationship VALUES (1248, 211, 1253, 1251);
INSERT INTO chado.cvterm_relationship VALUES (1249, 211, 1254, 1142);
INSERT INTO chado.cvterm_relationship VALUES (1250, 211, 1255, 1142);
INSERT INTO chado.cvterm_relationship VALUES (1251, 211, 1256, 1257);
INSERT INTO chado.cvterm_relationship VALUES (1252, 211, 1258, 419);
INSERT INTO chado.cvterm_relationship VALUES (1253, 230, 1258, 684);
INSERT INTO chado.cvterm_relationship VALUES (1254, 211, 1259, 419);
INSERT INTO chado.cvterm_relationship VALUES (1255, 230, 1259, 323);
INSERT INTO chado.cvterm_relationship VALUES (1256, 211, 1260, 419);
INSERT INTO chado.cvterm_relationship VALUES (1257, 211, 1260, 637);
INSERT INTO chado.cvterm_relationship VALUES (1258, 230, 1260, 638);
INSERT INTO chado.cvterm_relationship VALUES (1259, 211, 1274, 164);
INSERT INTO chado.cvterm_relationship VALUES (1260, 211, 1274, 966);
INSERT INTO chado.cvterm_relationship VALUES (1261, 230, 1274, 437);
INSERT INTO chado.cvterm_relationship VALUES (1262, 211, 1275, 1219);
INSERT INTO chado.cvterm_relationship VALUES (1263, 234, 1275, 1011);
INSERT INTO chado.cvterm_relationship VALUES (1264, 211, 1276, 1275);
INSERT INTO chado.cvterm_relationship VALUES (1265, 211, 1277, 443);
INSERT INTO chado.cvterm_relationship VALUES (1266, 211, 1278, 585);
INSERT INTO chado.cvterm_relationship VALUES (1267, 211, 1279, 1280);
INSERT INTO chado.cvterm_relationship VALUES (1268, 211, 1281, 421);
INSERT INTO chado.cvterm_relationship VALUES (1269, 230, 1281, 437);
INSERT INTO chado.cvterm_relationship VALUES (1270, 211, 926, 665);
INSERT INTO chado.cvterm_relationship VALUES (1271, 211, 891, 665);
INSERT INTO chado.cvterm_relationship VALUES (1272, 211, 667, 665);
INSERT INTO chado.cvterm_relationship VALUES (1273, 211, 858, 585);
INSERT INTO chado.cvterm_relationship VALUES (1274, 211, 1283, 751);
INSERT INTO chado.cvterm_relationship VALUES (1275, 211, 1284, 744);
INSERT INTO chado.cvterm_relationship VALUES (1276, 234, 1284, 1285);
INSERT INTO chado.cvterm_relationship VALUES (1277, 211, 1286, 744);
INSERT INTO chado.cvterm_relationship VALUES (1278, 211, 1287, 744);
INSERT INTO chado.cvterm_relationship VALUES (1279, 211, 1288, 744);
INSERT INTO chado.cvterm_relationship VALUES (1280, 211, 744, 717);
INSERT INTO chado.cvterm_relationship VALUES (1281, 211, 721, 717);
INSERT INTO chado.cvterm_relationship VALUES (1282, 211, 726, 717);
INSERT INTO chado.cvterm_relationship VALUES (1283, 211, 1289, 721);
INSERT INTO chado.cvterm_relationship VALUES (1284, 211, 1290, 744);
INSERT INTO chado.cvterm_relationship VALUES (1285, 234, 1290, 741);
INSERT INTO chado.cvterm_relationship VALUES (1286, 211, 1025, 474);
INSERT INTO chado.cvterm_relationship VALUES (1287, 211, 1291, 659);
INSERT INTO chado.cvterm_relationship VALUES (1288, 211, 1292, 659);
INSERT INTO chado.cvterm_relationship VALUES (1289, 211, 1293, 715);
INSERT INTO chado.cvterm_relationship VALUES (1290, 230, 1293, 728);
INSERT INTO chado.cvterm_relationship VALUES (1291, 211, 1294, 1293);
INSERT INTO chado.cvterm_relationship VALUES (1292, 230, 1294, 1295);
INSERT INTO chado.cvterm_relationship VALUES (1293, 211, 1296, 1293);
INSERT INTO chado.cvterm_relationship VALUES (1294, 230, 1296, 1297);
INSERT INTO chado.cvterm_relationship VALUES (1295, 211, 1298, 1294);
INSERT INTO chado.cvterm_relationship VALUES (1296, 230, 1298, 1299);
INSERT INTO chado.cvterm_relationship VALUES (1297, 211, 1300, 1294);
INSERT INTO chado.cvterm_relationship VALUES (1298, 230, 1300, 1301);
INSERT INTO chado.cvterm_relationship VALUES (1299, 211, 1302, 1296);
INSERT INTO chado.cvterm_relationship VALUES (1300, 230, 1302, 1299);
INSERT INTO chado.cvterm_relationship VALUES (1301, 211, 1303, 1296);
INSERT INTO chado.cvterm_relationship VALUES (1302, 230, 1303, 1301);
INSERT INTO chado.cvterm_relationship VALUES (1303, 211, 1304, 715);
INSERT INTO chado.cvterm_relationship VALUES (1304, 230, 1304, 732);
INSERT INTO chado.cvterm_relationship VALUES (1305, 211, 1305, 1304);
INSERT INTO chado.cvterm_relationship VALUES (1306, 230, 1305, 1297);
INSERT INTO chado.cvterm_relationship VALUES (1307, 211, 1306, 1305);
INSERT INTO chado.cvterm_relationship VALUES (1308, 230, 1306, 1299);
INSERT INTO chado.cvterm_relationship VALUES (1309, 211, 1307, 1308);
INSERT INTO chado.cvterm_relationship VALUES (1310, 230, 1307, 1299);
INSERT INTO chado.cvterm_relationship VALUES (1311, 211, 1308, 1304);
INSERT INTO chado.cvterm_relationship VALUES (1312, 230, 1308, 1295);
INSERT INTO chado.cvterm_relationship VALUES (1313, 211, 1309, 1305);
INSERT INTO chado.cvterm_relationship VALUES (1314, 230, 1309, 1301);
INSERT INTO chado.cvterm_relationship VALUES (1315, 211, 1310, 1308);
INSERT INTO chado.cvterm_relationship VALUES (1316, 230, 1310, 1301);
INSERT INTO chado.cvterm_relationship VALUES (1317, 211, 1316, 556);
INSERT INTO chado.cvterm_relationship VALUES (1318, 211, 1317, 389);
INSERT INTO chado.cvterm_relationship VALUES (1319, 234, 1317, 1147);
INSERT INTO chado.cvterm_relationship VALUES (1320, 211, 1318, 585);
INSERT INTO chado.cvterm_relationship VALUES (1321, 211, 1236, 482);
INSERT INTO chado.cvterm_relationship VALUES (1322, 211, 1319, 1275);
INSERT INTO chado.cvterm_relationship VALUES (1323, 211, 1320, 278);
INSERT INTO chado.cvterm_relationship VALUES (1324, 211, 1147, 492);
INSERT INTO chado.cvterm_relationship VALUES (1325, 211, 1321, 1023);
INSERT INTO chado.cvterm_relationship VALUES (1326, 211, 1322, 1023);
INSERT INTO chado.cvterm_relationship VALUES (1327, 211, 1323, 585);
INSERT INTO chado.cvterm_relationship VALUES (1328, 211, 1297, 1323);
INSERT INTO chado.cvterm_relationship VALUES (1329, 211, 1295, 1323);
INSERT INTO chado.cvterm_relationship VALUES (1330, 211, 1324, 723);
INSERT INTO chado.cvterm_relationship VALUES (1331, 211, 1299, 1324);
INSERT INTO chado.cvterm_relationship VALUES (1332, 211, 1301, 1324);
INSERT INTO chado.cvterm_relationship VALUES (1333, 211, 1325, 282);
INSERT INTO chado.cvterm_relationship VALUES (1334, 211, 1326, 282);
INSERT INTO chado.cvterm_relationship VALUES (1335, 211, 323, 728);
INSERT INTO chado.cvterm_relationship VALUES (1336, 211, 1327, 1259);
INSERT INTO chado.cvterm_relationship VALUES (1337, 216, 1327, 489);
INSERT INTO chado.cvterm_relationship VALUES (1338, 211, 1328, 1141);
INSERT INTO chado.cvterm_relationship VALUES (1339, 211, 1329, 319);
INSERT INTO chado.cvterm_relationship VALUES (1340, 230, 1329, 1328);
INSERT INTO chado.cvterm_relationship VALUES (1341, 211, 1330, 164);
INSERT INTO chado.cvterm_relationship VALUES (1342, 211, 1330, 1329);
INSERT INTO chado.cvterm_relationship VALUES (1343, 230, 1330, 1328);
INSERT INTO chado.cvterm_relationship VALUES (1344, 211, 1331, 163);
INSERT INTO chado.cvterm_relationship VALUES (1345, 230, 1331, 1142);
INSERT INTO chado.cvterm_relationship VALUES (1346, 211, 1332, 508);
INSERT INTO chado.cvterm_relationship VALUES (1347, 230, 1332, 1140);
INSERT INTO chado.cvterm_relationship VALUES (1348, 211, 1333, 503);
INSERT INTO chado.cvterm_relationship VALUES (1349, 211, 1334, 271);
INSERT INTO chado.cvterm_relationship VALUES (1350, 234, 1334, 489);
INSERT INTO chado.cvterm_relationship VALUES (1351, 211, 1335, 793);
INSERT INTO chado.cvterm_relationship VALUES (1352, 216, 1335, 1336);
INSERT INTO chado.cvterm_relationship VALUES (1353, 211, 1337, 756);
INSERT INTO chado.cvterm_relationship VALUES (1354, 216, 1337, 1338);
INSERT INTO chado.cvterm_relationship VALUES (1355, 211, 1339, 756);
INSERT INTO chado.cvterm_relationship VALUES (1356, 216, 1339, 1340);
INSERT INTO chado.cvterm_relationship VALUES (1357, 211, 1341, 647);
INSERT INTO chado.cvterm_relationship VALUES (1358, 211, 1342, 1141);
INSERT INTO chado.cvterm_relationship VALUES (1359, 211, 1343, 319);
INSERT INTO chado.cvterm_relationship VALUES (1360, 230, 1343, 1342);
INSERT INTO chado.cvterm_relationship VALUES (1361, 211, 1344, 432);
INSERT INTO chado.cvterm_relationship VALUES (1362, 211, 1345, 1168);
INSERT INTO chado.cvterm_relationship VALUES (1363, 211, 1346, 679);
INSERT INTO chado.cvterm_relationship VALUES (1364, 211, 1347, 712);
INSERT INTO chado.cvterm_relationship VALUES (1365, 211, 1348, 475);
INSERT INTO chado.cvterm_relationship VALUES (1366, 211, 1349, 309);
INSERT INTO chado.cvterm_relationship VALUES (1367, 230, 1349, 1350);
INSERT INTO chado.cvterm_relationship VALUES (1368, 211, 1351, 305);
INSERT INTO chado.cvterm_relationship VALUES (1369, 230, 1351, 749);
INSERT INTO chado.cvterm_relationship VALUES (1370, 211, 1352, 1353);
INSERT INTO chado.cvterm_relationship VALUES (1371, 211, 1354, 501);
INSERT INTO chado.cvterm_relationship VALUES (1372, 234, 1354, 534);
INSERT INTO chado.cvterm_relationship VALUES (1373, 211, 1355, 301);
INSERT INTO chado.cvterm_relationship VALUES (1374, 211, 1356, 1354);
INSERT INTO chado.cvterm_relationship VALUES (1375, 234, 1356, 998);
INSERT INTO chado.cvterm_relationship VALUES (1376, 211, 1357, 1358);
INSERT INTO chado.cvterm_relationship VALUES (1377, 211, 1359, 796);
INSERT INTO chado.cvterm_relationship VALUES (1378, 211, 1360, 555);
INSERT INTO chado.cvterm_relationship VALUES (1379, 211, 1362, 418);
INSERT INTO chado.cvterm_relationship VALUES (1380, 234, 1362, 715);
INSERT INTO chado.cvterm_relationship VALUES (1381, 211, 1363, 1362);
INSERT INTO chado.cvterm_relationship VALUES (1382, 211, 1364, 590);
INSERT INTO chado.cvterm_relationship VALUES (1383, 258, 1364, 163);
INSERT INTO chado.cvterm_relationship VALUES (1384, 211, 1365, 590);
INSERT INTO chado.cvterm_relationship VALUES (1385, 258, 1365, 731);
INSERT INTO chado.cvterm_relationship VALUES (1386, 211, 1366, 1364);
INSERT INTO chado.cvterm_relationship VALUES (1387, 211, 1146, 1367);
INSERT INTO chado.cvterm_relationship VALUES (1388, 228, 1146, 492);
INSERT INTO chado.cvterm_relationship VALUES (1389, 211, 1368, 590);
INSERT INTO chado.cvterm_relationship VALUES (1390, 258, 1368, 1146);
INSERT INTO chado.cvterm_relationship VALUES (1391, 211, 1369, 590);
INSERT INTO chado.cvterm_relationship VALUES (1392, 211, 1370, 585);
INSERT INTO chado.cvterm_relationship VALUES (1393, 211, 446, 1370);
INSERT INTO chado.cvterm_relationship VALUES (1394, 211, 461, 1370);
INSERT INTO chado.cvterm_relationship VALUES (1395, 211, 1371, 388);
INSERT INTO chado.cvterm_relationship VALUES (1396, 230, 1371, 728);
INSERT INTO chado.cvterm_relationship VALUES (1397, 211, 1372, 396);
INSERT INTO chado.cvterm_relationship VALUES (1398, 230, 1372, 728);
INSERT INTO chado.cvterm_relationship VALUES (1399, 211, 1373, 1354);
INSERT INTO chado.cvterm_relationship VALUES (1400, 228, 1373, 631);
INSERT INTO chado.cvterm_relationship VALUES (1401, 211, 856, 630);
INSERT INTO chado.cvterm_relationship VALUES (1402, 211, 1374, 605);
INSERT INTO chado.cvterm_relationship VALUES (1403, 216, 1374, 560);
INSERT INTO chado.cvterm_relationship VALUES (1404, 211, 1075, 262);
INSERT INTO chado.cvterm_relationship VALUES (1405, 230, 1075, 1076);
INSERT INTO chado.cvterm_relationship VALUES (1406, 211, 1191, 1075);
INSERT INTO chado.cvterm_relationship VALUES (1407, 211, 414, 1075);
INSERT INTO chado.cvterm_relationship VALUES (1408, 211, 1375, 414);
INSERT INTO chado.cvterm_relationship VALUES (1409, 216, 1375, 491);
INSERT INTO chado.cvterm_relationship VALUES (1410, 211, 1376, 1191);
INSERT INTO chado.cvterm_relationship VALUES (1411, 211, 1376, 492);
INSERT INTO chado.cvterm_relationship VALUES (1412, 211, 1285, 1376);
INSERT INTO chado.cvterm_relationship VALUES (1413, 211, 1377, 744);
INSERT INTO chado.cvterm_relationship VALUES (1414, 234, 1377, 747);
INSERT INTO chado.cvterm_relationship VALUES (1415, 211, 1378, 329);
INSERT INTO chado.cvterm_relationship VALUES (1416, 211, 1379, 414);
INSERT INTO chado.cvterm_relationship VALUES (1417, 211, 1380, 1381);
INSERT INTO chado.cvterm_relationship VALUES (1418, 234, 1380, 726);
INSERT INTO chado.cvterm_relationship VALUES (1419, 211, 1382, 1381);
INSERT INTO chado.cvterm_relationship VALUES (1420, 234, 1382, 726);
INSERT INTO chado.cvterm_relationship VALUES (1421, 211, 1381, 717);
INSERT INTO chado.cvterm_relationship VALUES (1422, 211, 1383, 1168);
INSERT INTO chado.cvterm_relationship VALUES (1423, 211, 1384, 834);
INSERT INTO chado.cvterm_relationship VALUES (1424, 234, 1384, 1385);
INSERT INTO chado.cvterm_relationship VALUES (1425, 211, 1389, 834);
INSERT INTO chado.cvterm_relationship VALUES (1426, 234, 1389, 1390);
INSERT INTO chado.cvterm_relationship VALUES (1427, 211, 344, 1391);
INSERT INTO chado.cvterm_relationship VALUES (1428, 211, 718, 344);
INSERT INTO chado.cvterm_relationship VALUES (1429, 211, 1393, 344);
INSERT INTO chado.cvterm_relationship VALUES (1430, 211, 496, 1394);
INSERT INTO chado.cvterm_relationship VALUES (1431, 211, 1395, 1101);
INSERT INTO chado.cvterm_relationship VALUES (1432, 234, 1395, 811);
INSERT INTO chado.cvterm_relationship VALUES (1433, 211, 811, 1101);
INSERT INTO chado.cvterm_relationship VALUES (1434, 216, 811, 1396);
INSERT INTO chado.cvterm_relationship VALUES (1435, 211, 815, 813);
INSERT INTO chado.cvterm_relationship VALUES (1436, 211, 1397, 812);
INSERT INTO chado.cvterm_relationship VALUES (1437, 211, 1398, 813);
INSERT INTO chado.cvterm_relationship VALUES (1438, 211, 1399, 807);
INSERT INTO chado.cvterm_relationship VALUES (1439, 211, 1400, 807);
INSERT INTO chado.cvterm_relationship VALUES (1440, 211, 806, 813);
INSERT INTO chado.cvterm_relationship VALUES (1441, 211, 1401, 806);
INSERT INTO chado.cvterm_relationship VALUES (1442, 211, 1402, 806);
INSERT INTO chado.cvterm_relationship VALUES (1443, 234, 1402, 1401);
INSERT INTO chado.cvterm_relationship VALUES (1444, 211, 1403, 1402);
INSERT INTO chado.cvterm_relationship VALUES (1445, 211, 1404, 1402);
INSERT INTO chado.cvterm_relationship VALUES (1446, 211, 1405, 806);
INSERT INTO chado.cvterm_relationship VALUES (1447, 234, 1405, 1401);
INSERT INTO chado.cvterm_relationship VALUES (1448, 211, 1406, 1405);
INSERT INTO chado.cvterm_relationship VALUES (1449, 211, 1407, 1405);
INSERT INTO chado.cvterm_relationship VALUES (1450, 211, 1408, 806);
INSERT INTO chado.cvterm_relationship VALUES (1451, 211, 1409, 806);
INSERT INTO chado.cvterm_relationship VALUES (1452, 211, 1410, 1409);
INSERT INTO chado.cvterm_relationship VALUES (1453, 211, 1411, 1409);
INSERT INTO chado.cvterm_relationship VALUES (1454, 228, 1411, 1412);
INSERT INTO chado.cvterm_relationship VALUES (1455, 228, 1411, 1257);
INSERT INTO chado.cvterm_relationship VALUES (1456, 211, 1413, 801);
INSERT INTO chado.cvterm_relationship VALUES (1457, 211, 1414, 1413);
INSERT INTO chado.cvterm_relationship VALUES (1458, 211, 1415, 1413);
INSERT INTO chado.cvterm_relationship VALUES (1459, 211, 1416, 1413);
INSERT INTO chado.cvterm_relationship VALUES (1460, 211, 1417, 1413);
INSERT INTO chado.cvterm_relationship VALUES (1461, 211, 1420, 1421);
INSERT INTO chado.cvterm_relationship VALUES (1462, 211, 1424, 1425);
INSERT INTO chado.cvterm_relationship VALUES (1463, 211, 1424, 1426);
INSERT INTO chado.cvterm_relationship VALUES (1464, 211, 1427, 797);
INSERT INTO chado.cvterm_relationship VALUES (1465, 211, 1427, 1426);
INSERT INTO chado.cvterm_relationship VALUES (1466, 211, 1428, 1424);
INSERT INTO chado.cvterm_relationship VALUES (1467, 211, 1429, 1424);
INSERT INTO chado.cvterm_relationship VALUES (1468, 211, 1430, 1424);
INSERT INTO chado.cvterm_relationship VALUES (1469, 211, 1431, 1424);
INSERT INTO chado.cvterm_relationship VALUES (1470, 211, 1432, 1424);
INSERT INTO chado.cvterm_relationship VALUES (1471, 211, 1433, 1424);
INSERT INTO chado.cvterm_relationship VALUES (1472, 211, 1434, 1424);
INSERT INTO chado.cvterm_relationship VALUES (1473, 211, 1435, 1424);
INSERT INTO chado.cvterm_relationship VALUES (1474, 211, 1436, 1424);
INSERT INTO chado.cvterm_relationship VALUES (1475, 211, 1437, 1424);
INSERT INTO chado.cvterm_relationship VALUES (1476, 211, 1438, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1477, 234, 1438, 1440);
INSERT INTO chado.cvterm_relationship VALUES (1478, 211, 1441, 1442);
INSERT INTO chado.cvterm_relationship VALUES (1479, 211, 1441, 1426);
INSERT INTO chado.cvterm_relationship VALUES (1480, 211, 1443, 1408);
INSERT INTO chado.cvterm_relationship VALUES (1481, 211, 1444, 1408);
INSERT INTO chado.cvterm_relationship VALUES (1482, 211, 1445, 1408);
INSERT INTO chado.cvterm_relationship VALUES (1483, 211, 1446, 1445);
INSERT INTO chado.cvterm_relationship VALUES (1484, 211, 1447, 1445);
INSERT INTO chado.cvterm_relationship VALUES (1485, 211, 1448, 1408);
INSERT INTO chado.cvterm_relationship VALUES (1486, 211, 1449, 1448);
INSERT INTO chado.cvterm_relationship VALUES (1487, 211, 1450, 1448);
INSERT INTO chado.cvterm_relationship VALUES (1488, 211, 1412, 1408);
INSERT INTO chado.cvterm_relationship VALUES (1489, 211, 1451, 1412);
INSERT INTO chado.cvterm_relationship VALUES (1490, 211, 1452, 1412);
INSERT INTO chado.cvterm_relationship VALUES (1491, 211, 1453, 1452);
INSERT INTO chado.cvterm_relationship VALUES (1492, 211, 1454, 1452);
INSERT INTO chado.cvterm_relationship VALUES (1493, 211, 1455, 1452);
INSERT INTO chado.cvterm_relationship VALUES (1494, 211, 1456, 1408);
INSERT INTO chado.cvterm_relationship VALUES (1495, 211, 1457, 1456);
INSERT INTO chado.cvterm_relationship VALUES (1496, 211, 1458, 1456);
INSERT INTO chado.cvterm_relationship VALUES (1497, 211, 1459, 1408);
INSERT INTO chado.cvterm_relationship VALUES (1498, 211, 1460, 1459);
INSERT INTO chado.cvterm_relationship VALUES (1499, 211, 1461, 1459);
INSERT INTO chado.cvterm_relationship VALUES (1500, 211, 1462, 1408);
INSERT INTO chado.cvterm_relationship VALUES (1501, 211, 1463, 1408);
INSERT INTO chado.cvterm_relationship VALUES (1502, 211, 1257, 1408);
INSERT INTO chado.cvterm_relationship VALUES (1503, 211, 1464, 1256);
INSERT INTO chado.cvterm_relationship VALUES (1504, 211, 1465, 1256);
INSERT INTO chado.cvterm_relationship VALUES (1505, 211, 1466, 1256);
INSERT INTO chado.cvterm_relationship VALUES (1506, 211, 1467, 1256);
INSERT INTO chado.cvterm_relationship VALUES (1507, 211, 1468, 1257);
INSERT INTO chado.cvterm_relationship VALUES (1508, 211, 1469, 1468);
INSERT INTO chado.cvterm_relationship VALUES (1509, 211, 1470, 1468);
INSERT INTO chado.cvterm_relationship VALUES (1510, 211, 1471, 1468);
INSERT INTO chado.cvterm_relationship VALUES (1511, 211, 1472, 1468);
INSERT INTO chado.cvterm_relationship VALUES (1512, 211, 1473, 1257);
INSERT INTO chado.cvterm_relationship VALUES (1513, 211, 1474, 1473);
INSERT INTO chado.cvterm_relationship VALUES (1514, 211, 1475, 1473);
INSERT INTO chado.cvterm_relationship VALUES (1515, 211, 1476, 1257);
INSERT INTO chado.cvterm_relationship VALUES (1516, 211, 1477, 1476);
INSERT INTO chado.cvterm_relationship VALUES (1517, 211, 1478, 1476);
INSERT INTO chado.cvterm_relationship VALUES (1518, 211, 1479, 1476);
INSERT INTO chado.cvterm_relationship VALUES (1519, 211, 1480, 1476);
INSERT INTO chado.cvterm_relationship VALUES (1520, 211, 1481, 813);
INSERT INTO chado.cvterm_relationship VALUES (1521, 211, 1482, 1481);
INSERT INTO chado.cvterm_relationship VALUES (1522, 211, 1483, 1481);
INSERT INTO chado.cvterm_relationship VALUES (1523, 211, 1484, 1481);
INSERT INTO chado.cvterm_relationship VALUES (1524, 211, 1485, 1468);
INSERT INTO chado.cvterm_relationship VALUES (1525, 211, 1486, 1485);
INSERT INTO chado.cvterm_relationship VALUES (1526, 211, 1487, 1486);
INSERT INTO chado.cvterm_relationship VALUES (1527, 211, 1488, 1486);
INSERT INTO chado.cvterm_relationship VALUES (1528, 211, 1489, 1485);
INSERT INTO chado.cvterm_relationship VALUES (1529, 211, 1490, 1468);
INSERT INTO chado.cvterm_relationship VALUES (1530, 211, 1491, 289);
INSERT INTO chado.cvterm_relationship VALUES (1531, 234, 1491, 512);
INSERT INTO chado.cvterm_relationship VALUES (1532, 211, 1492, 516);
INSERT INTO chado.cvterm_relationship VALUES (1533, 211, 1493, 289);
INSERT INTO chado.cvterm_relationship VALUES (1534, 234, 1493, 512);
INSERT INTO chado.cvterm_relationship VALUES (1535, 211, 1494, 516);
INSERT INTO chado.cvterm_relationship VALUES (1536, 234, 1494, 512);
INSERT INTO chado.cvterm_relationship VALUES (1537, 211, 1495, 516);
INSERT INTO chado.cvterm_relationship VALUES (1538, 234, 1495, 512);
INSERT INTO chado.cvterm_relationship VALUES (1539, 211, 1496, 516);
INSERT INTO chado.cvterm_relationship VALUES (1540, 234, 1496, 512);
INSERT INTO chado.cvterm_relationship VALUES (1541, 211, 1497, 284);
INSERT INTO chado.cvterm_relationship VALUES (1542, 234, 1497, 285);
INSERT INTO chado.cvterm_relationship VALUES (1543, 211, 1498, 289);
INSERT INTO chado.cvterm_relationship VALUES (1544, 234, 1498, 512);
INSERT INTO chado.cvterm_relationship VALUES (1545, 211, 1499, 516);
INSERT INTO chado.cvterm_relationship VALUES (1546, 234, 1499, 512);
INSERT INTO chado.cvterm_relationship VALUES (1547, 211, 1500, 516);
INSERT INTO chado.cvterm_relationship VALUES (1548, 234, 1500, 512);
INSERT INTO chado.cvterm_relationship VALUES (1549, 211, 1501, 289);
INSERT INTO chado.cvterm_relationship VALUES (1550, 234, 1501, 512);
INSERT INTO chado.cvterm_relationship VALUES (1551, 211, 1502, 516);
INSERT INTO chado.cvterm_relationship VALUES (1552, 234, 1502, 512);
INSERT INTO chado.cvterm_relationship VALUES (1553, 211, 1503, 516);
INSERT INTO chado.cvterm_relationship VALUES (1554, 234, 1503, 512);
INSERT INTO chado.cvterm_relationship VALUES (1555, 211, 1504, 1376);
INSERT INTO chado.cvterm_relationship VALUES (1556, 211, 1505, 556);
INSERT INTO chado.cvterm_relationship VALUES (1557, 211, 1507, 1219);
INSERT INTO chado.cvterm_relationship VALUES (1558, 234, 1507, 605);
INSERT INTO chado.cvterm_relationship VALUES (1559, 211, 1508, 1507);
INSERT INTO chado.cvterm_relationship VALUES (1560, 211, 1509, 1507);
INSERT INTO chado.cvterm_relationship VALUES (1561, 234, 1509, 1508);
INSERT INTO chado.cvterm_relationship VALUES (1562, 211, 1510, 1507);
INSERT INTO chado.cvterm_relationship VALUES (1563, 211, 1511, 1507);
INSERT INTO chado.cvterm_relationship VALUES (1564, 211, 1512, 1507);
INSERT INTO chado.cvterm_relationship VALUES (1565, 211, 1162, 558);
INSERT INTO chado.cvterm_relationship VALUES (1566, 211, 1513, 787);
INSERT INTO chado.cvterm_relationship VALUES (1567, 211, 1514, 1039);
INSERT INTO chado.cvterm_relationship VALUES (1568, 234, 1514, 552);
INSERT INTO chado.cvterm_relationship VALUES (1569, 211, 1515, 1039);
INSERT INTO chado.cvterm_relationship VALUES (1570, 234, 1515, 552);
INSERT INTO chado.cvterm_relationship VALUES (1571, 211, 1516, 1039);
INSERT INTO chado.cvterm_relationship VALUES (1572, 234, 1516, 551);
INSERT INTO chado.cvterm_relationship VALUES (1573, 211, 310, 722);
INSERT INTO chado.cvterm_relationship VALUES (1574, 211, 1350, 722);
INSERT INTO chado.cvterm_relationship VALUES (1575, 211, 749, 585);
INSERT INTO chado.cvterm_relationship VALUES (1576, 211, 754, 749);
INSERT INTO chado.cvterm_relationship VALUES (1577, 211, 1517, 1004);
INSERT INTO chado.cvterm_relationship VALUES (1578, 211, 1518, 722);
INSERT INTO chado.cvterm_relationship VALUES (1579, 211, 1519, 309);
INSERT INTO chado.cvterm_relationship VALUES (1580, 230, 1519, 1518);
INSERT INTO chado.cvterm_relationship VALUES (1581, 211, 1520, 722);
INSERT INTO chado.cvterm_relationship VALUES (1582, 211, 1521, 309);
INSERT INTO chado.cvterm_relationship VALUES (1583, 230, 1521, 1520);
INSERT INTO chado.cvterm_relationship VALUES (1584, 211, 1522, 722);
INSERT INTO chado.cvterm_relationship VALUES (1585, 211, 1523, 309);
INSERT INTO chado.cvterm_relationship VALUES (1586, 230, 1523, 1522);
INSERT INTO chado.cvterm_relationship VALUES (1587, 211, 1524, 1522);
INSERT INTO chado.cvterm_relationship VALUES (1588, 211, 1525, 1523);
INSERT INTO chado.cvterm_relationship VALUES (1589, 230, 1525, 1524);
INSERT INTO chado.cvterm_relationship VALUES (1590, 211, 1526, 1522);
INSERT INTO chado.cvterm_relationship VALUES (1591, 211, 1527, 1523);
INSERT INTO chado.cvterm_relationship VALUES (1592, 230, 1527, 1526);
INSERT INTO chado.cvterm_relationship VALUES (1593, 211, 1528, 1376);
INSERT INTO chado.cvterm_relationship VALUES (1594, 211, 1529, 1376);
INSERT INTO chado.cvterm_relationship VALUES (1595, 211, 1530, 1529);
INSERT INTO chado.cvterm_relationship VALUES (1596, 211, 1531, 1529);
INSERT INTO chado.cvterm_relationship VALUES (1597, 211, 1532, 1529);
INSERT INTO chado.cvterm_relationship VALUES (1598, 211, 1534, 1535);
INSERT INTO chado.cvterm_relationship VALUES (1599, 211, 1536, 1534);
INSERT INTO chado.cvterm_relationship VALUES (1600, 211, 1537, 1534);
INSERT INTO chado.cvterm_relationship VALUES (1601, 211, 1538, 1534);
INSERT INTO chado.cvterm_relationship VALUES (1602, 211, 1539, 719);
INSERT INTO chado.cvterm_relationship VALUES (1603, 211, 1540, 719);
INSERT INTO chado.cvterm_relationship VALUES (1604, 211, 1541, 312);
INSERT INTO chado.cvterm_relationship VALUES (1605, 211, 1542, 1541);
INSERT INTO chado.cvterm_relationship VALUES (1606, 211, 1543, 1541);
INSERT INTO chado.cvterm_relationship VALUES (1607, 211, 1544, 999);
INSERT INTO chado.cvterm_relationship VALUES (1608, 211, 889, 1224);
INSERT INTO chado.cvterm_relationship VALUES (1609, 211, 543, 1224);
INSERT INTO chado.cvterm_relationship VALUES (1610, 211, 1545, 534);
INSERT INTO chado.cvterm_relationship VALUES (1611, 211, 851, 163);
INSERT INTO chado.cvterm_relationship VALUES (1612, 230, 851, 276);
INSERT INTO chado.cvterm_relationship VALUES (1613, 211, 1546, 1077);
INSERT INTO chado.cvterm_relationship VALUES (1614, 230, 1546, 1177);
INSERT INTO chado.cvterm_relationship VALUES (1615, 211, 1547, 163);
INSERT INTO chado.cvterm_relationship VALUES (1616, 230, 1547, 983);
INSERT INTO chado.cvterm_relationship VALUES (1617, 211, 1548, 453);
INSERT INTO chado.cvterm_relationship VALUES (1618, 211, 1549, 453);
INSERT INTO chado.cvterm_relationship VALUES (1619, 211, 1550, 1549);
INSERT INTO chado.cvterm_relationship VALUES (1620, 211, 1551, 1549);
INSERT INTO chado.cvterm_relationship VALUES (1621, 211, 1552, 452);
INSERT INTO chado.cvterm_relationship VALUES (1622, 230, 1552, 1548);
INSERT INTO chado.cvterm_relationship VALUES (1623, 211, 1553, 452);
INSERT INTO chado.cvterm_relationship VALUES (1624, 230, 1553, 1549);
INSERT INTO chado.cvterm_relationship VALUES (1625, 211, 1554, 1553);
INSERT INTO chado.cvterm_relationship VALUES (1626, 230, 1554, 1550);
INSERT INTO chado.cvterm_relationship VALUES (1627, 211, 1555, 1553);
INSERT INTO chado.cvterm_relationship VALUES (1628, 230, 1555, 1551);
INSERT INTO chado.cvterm_relationship VALUES (1629, 211, 1556, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1630, 211, 1558, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1631, 211, 1559, 601);
INSERT INTO chado.cvterm_relationship VALUES (1632, 211, 1560, 601);
INSERT INTO chado.cvterm_relationship VALUES (1633, 211, 1561, 601);
INSERT INTO chado.cvterm_relationship VALUES (1634, 211, 1562, 1563);
INSERT INTO chado.cvterm_relationship VALUES (1635, 211, 1076, 585);
INSERT INTO chado.cvterm_relationship VALUES (1636, 211, 492, 262);
INSERT INTO chado.cvterm_relationship VALUES (1637, 211, 602, 262);
INSERT INTO chado.cvterm_relationship VALUES (1638, 211, 1439, 262);
INSERT INTO chado.cvterm_relationship VALUES (1639, 234, 1439, 420);
INSERT INTO chado.cvterm_relationship VALUES (1640, 211, 1564, 681);
INSERT INTO chado.cvterm_relationship VALUES (1641, 211, 1565, 681);
INSERT INTO chado.cvterm_relationship VALUES (1642, 211, 1567, 277);
INSERT INTO chado.cvterm_relationship VALUES (1643, 211, 1568, 501);
INSERT INTO chado.cvterm_relationship VALUES (1644, 211, 631, 1568);
INSERT INTO chado.cvterm_relationship VALUES (1645, 211, 1569, 1568);
INSERT INTO chado.cvterm_relationship VALUES (1646, 234, 1569, 631);
INSERT INTO chado.cvterm_relationship VALUES (1647, 211, 1570, 1568);
INSERT INTO chado.cvterm_relationship VALUES (1648, 234, 1570, 631);
INSERT INTO chado.cvterm_relationship VALUES (1649, 211, 309, 305);
INSERT INTO chado.cvterm_relationship VALUES (1650, 211, 729, 319);
INSERT INTO chado.cvterm_relationship VALUES (1651, 211, 1571, 729);
INSERT INTO chado.cvterm_relationship VALUES (1652, 211, 1572, 1571);
INSERT INTO chado.cvterm_relationship VALUES (1653, 228, 1572, 540);
INSERT INTO chado.cvterm_relationship VALUES (1654, 211, 1573, 1571);
INSERT INTO chado.cvterm_relationship VALUES (1655, 228, 1573, 705);
INSERT INTO chado.cvterm_relationship VALUES (1656, 211, 1574, 1571);
INSERT INTO chado.cvterm_relationship VALUES (1657, 228, 1574, 705);
INSERT INTO chado.cvterm_relationship VALUES (1658, 211, 1575, 476);
INSERT INTO chado.cvterm_relationship VALUES (1659, 211, 1576, 340);
INSERT INTO chado.cvterm_relationship VALUES (1660, 211, 1577, 1576);
INSERT INTO chado.cvterm_relationship VALUES (1661, 211, 1578, 1576);
INSERT INTO chado.cvterm_relationship VALUES (1662, 211, 1579, 346);
INSERT INTO chado.cvterm_relationship VALUES (1663, 211, 1580, 289);
INSERT INTO chado.cvterm_relationship VALUES (1664, 234, 1580, 512);
INSERT INTO chado.cvterm_relationship VALUES (1665, 211, 1581, 715);
INSERT INTO chado.cvterm_relationship VALUES (1666, 229, 1581, 394);
INSERT INTO chado.cvterm_relationship VALUES (1667, 211, 1582, 1114);
INSERT INTO chado.cvterm_relationship VALUES (1668, 211, 1583, 1582);
INSERT INTO chado.cvterm_relationship VALUES (1669, 228, 1583, 719);
INSERT INTO chado.cvterm_relationship VALUES (1670, 211, 1584, 163);
INSERT INTO chado.cvterm_relationship VALUES (1671, 211, 1585, 1584);
INSERT INTO chado.cvterm_relationship VALUES (1672, 230, 1585, 1320);
INSERT INTO chado.cvterm_relationship VALUES (1673, 211, 1586, 1587);
INSERT INTO chado.cvterm_relationship VALUES (1674, 230, 1586, 984);
INSERT INTO chado.cvterm_relationship VALUES (1675, 230, 1586, 1066);
INSERT INTO chado.cvterm_relationship VALUES (1676, 211, 1588, 1584);
INSERT INTO chado.cvterm_relationship VALUES (1677, 230, 1588, 986);
INSERT INTO chado.cvterm_relationship VALUES (1678, 211, 1589, 1587);
INSERT INTO chado.cvterm_relationship VALUES (1679, 230, 1589, 989);
INSERT INTO chado.cvterm_relationship VALUES (1680, 211, 1590, 1587);
INSERT INTO chado.cvterm_relationship VALUES (1681, 211, 1591, 1584);
INSERT INTO chado.cvterm_relationship VALUES (1682, 230, 1591, 1054);
INSERT INTO chado.cvterm_relationship VALUES (1683, 211, 1592, 1587);
INSERT INTO chado.cvterm_relationship VALUES (1684, 230, 1592, 1069);
INSERT INTO chado.cvterm_relationship VALUES (1685, 211, 1593, 1587);
INSERT INTO chado.cvterm_relationship VALUES (1686, 230, 1593, 1072);
INSERT INTO chado.cvterm_relationship VALUES (1687, 211, 1594, 601);
INSERT INTO chado.cvterm_relationship VALUES (1688, 211, 1563, 1559);
INSERT INTO chado.cvterm_relationship VALUES (1689, 211, 1595, 601);
INSERT INTO chado.cvterm_relationship VALUES (1690, 211, 1596, 601);
INSERT INTO chado.cvterm_relationship VALUES (1691, 211, 1557, 601);
INSERT INTO chado.cvterm_relationship VALUES (1692, 211, 1597, 1563);
INSERT INTO chado.cvterm_relationship VALUES (1693, 211, 1598, 1563);
INSERT INTO chado.cvterm_relationship VALUES (1694, 211, 1599, 1563);
INSERT INTO chado.cvterm_relationship VALUES (1695, 211, 1600, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1696, 211, 1601, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1697, 211, 1602, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1698, 211, 1603, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1699, 211, 1604, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1700, 211, 1605, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1701, 211, 1606, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1702, 211, 1607, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1703, 211, 1608, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1704, 211, 1609, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1705, 211, 1610, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1706, 211, 1611, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1707, 211, 1612, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1708, 211, 1613, 1595);
INSERT INTO chado.cvterm_relationship VALUES (1709, 211, 1614, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1710, 211, 1615, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1711, 211, 1616, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1712, 211, 1617, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1713, 211, 1618, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1714, 211, 1619, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1715, 211, 1620, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1716, 211, 1621, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1717, 211, 1622, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1718, 211, 1623, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1719, 211, 1624, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1720, 211, 1625, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1721, 211, 1626, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1722, 211, 1627, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1723, 211, 1628, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1724, 211, 1629, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1725, 211, 1630, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1726, 211, 1631, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1727, 211, 1632, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1728, 211, 1633, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1729, 211, 1634, 1594);
INSERT INTO chado.cvterm_relationship VALUES (1730, 211, 1635, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1731, 211, 1636, 1635);
INSERT INTO chado.cvterm_relationship VALUES (1732, 211, 1637, 1635);
INSERT INTO chado.cvterm_relationship VALUES (1733, 211, 1638, 1635);
INSERT INTO chado.cvterm_relationship VALUES (1734, 211, 1639, 1635);
INSERT INTO chado.cvterm_relationship VALUES (1735, 211, 1640, 1635);
INSERT INTO chado.cvterm_relationship VALUES (1736, 211, 1641, 1635);
INSERT INTO chado.cvterm_relationship VALUES (1737, 211, 1642, 1635);
INSERT INTO chado.cvterm_relationship VALUES (1738, 211, 1643, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1739, 211, 1644, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1740, 211, 1645, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1741, 211, 1646, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1742, 211, 1647, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1743, 211, 1648, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1744, 211, 1649, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1745, 211, 1650, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1746, 211, 1651, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1747, 211, 1652, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1748, 211, 1653, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1749, 211, 1654, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1750, 211, 1655, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1751, 211, 1656, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1752, 211, 1657, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1753, 211, 1658, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1754, 211, 1659, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1755, 211, 1660, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1756, 211, 1661, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1757, 211, 1662, 1596);
INSERT INTO chado.cvterm_relationship VALUES (1758, 211, 1663, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1759, 211, 1664, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1760, 211, 1665, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1761, 211, 1666, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1762, 211, 1667, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1763, 211, 1668, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1764, 211, 1669, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1765, 211, 1670, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1766, 211, 1671, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1767, 211, 1672, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1768, 211, 1673, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1769, 211, 1674, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1770, 211, 1675, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1771, 211, 1676, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1772, 211, 1677, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1773, 211, 1678, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1774, 211, 1679, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1775, 211, 1680, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1776, 211, 1681, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1777, 211, 1682, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1778, 211, 1683, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1779, 211, 1684, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1780, 211, 1685, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1781, 211, 1686, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1782, 211, 1687, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1783, 211, 1688, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1784, 211, 1689, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1785, 211, 1690, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1786, 211, 1691, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1787, 211, 1692, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1788, 211, 1693, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1789, 211, 1694, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1790, 211, 1695, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1791, 211, 1696, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1792, 211, 1697, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1793, 211, 1698, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1794, 211, 1699, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1795, 211, 1700, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1796, 211, 1701, 1557);
INSERT INTO chado.cvterm_relationship VALUES (1797, 211, 1702, 347);
INSERT INTO chado.cvterm_relationship VALUES (1798, 211, 1703, 421);
INSERT INTO chado.cvterm_relationship VALUES (1799, 230, 1703, 1140);
INSERT INTO chado.cvterm_relationship VALUES (1800, 211, 1704, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1801, 211, 1705, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1802, 211, 1706, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1803, 211, 1707, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1804, 211, 1708, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1805, 211, 1709, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1806, 211, 1710, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1807, 211, 1711, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1808, 211, 1712, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1809, 211, 1713, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1810, 211, 1714, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1811, 211, 1715, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1812, 211, 1716, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1813, 211, 1717, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1814, 211, 1718, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1815, 211, 1719, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1816, 211, 1720, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1817, 211, 1721, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1818, 211, 1722, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1819, 211, 1723, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1820, 211, 1724, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1821, 211, 1725, 1704);
INSERT INTO chado.cvterm_relationship VALUES (1822, 211, 1726, 723);
INSERT INTO chado.cvterm_relationship VALUES (1823, 211, 1727, 1101);
INSERT INTO chado.cvterm_relationship VALUES (1824, 211, 1107, 260);
INSERT INTO chado.cvterm_relationship VALUES (1825, 211, 319, 260);
INSERT INTO chado.cvterm_relationship VALUES (1826, 211, 262, 260);
INSERT INTO chado.cvterm_relationship VALUES (1827, 211, 588, 260);
INSERT INTO chado.cvterm_relationship VALUES (1828, 211, 1728, 1362);
INSERT INTO chado.cvterm_relationship VALUES (1829, 211, 1729, 1362);
INSERT INTO chado.cvterm_relationship VALUES (1830, 211, 1730, 1362);
INSERT INTO chado.cvterm_relationship VALUES (1831, 211, 1731, 587);
INSERT INTO chado.cvterm_relationship VALUES (1832, 211, 1732, 587);
INSERT INTO chado.cvterm_relationship VALUES (1833, 211, 1733, 319);
INSERT INTO chado.cvterm_relationship VALUES (1834, 211, 503, 500);
INSERT INTO chado.cvterm_relationship VALUES (1835, 211, 1116, 500);
INSERT INTO chado.cvterm_relationship VALUES (1836, 211, 1734, 418);
INSERT INTO chado.cvterm_relationship VALUES (1837, 211, 1735, 1421);
INSERT INTO chado.cvterm_relationship VALUES (1838, 211, 1736, 271);
INSERT INTO chado.cvterm_relationship VALUES (1839, 211, 1737, 271);
INSERT INTO chado.cvterm_relationship VALUES (1840, 211, 1738, 271);
INSERT INTO chado.cvterm_relationship VALUES (1841, 211, 1739, 271);
INSERT INTO chado.cvterm_relationship VALUES (1842, 211, 1740, 344);
INSERT INTO chado.cvterm_relationship VALUES (1843, 211, 1741, 486);
INSERT INTO chado.cvterm_relationship VALUES (1844, 211, 1742, 1280);
INSERT INTO chado.cvterm_relationship VALUES (1845, 211, 1743, 163);
INSERT INTO chado.cvterm_relationship VALUES (1846, 230, 1743, 1318);
INSERT INTO chado.cvterm_relationship VALUES (1847, 211, 1745, 683);
INSERT INTO chado.cvterm_relationship VALUES (1848, 211, 1746, 329);
INSERT INTO chado.cvterm_relationship VALUES (1849, 211, 1747, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1850, 211, 1748, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1851, 211, 1749, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1852, 211, 1750, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1853, 211, 1751, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1854, 211, 1752, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1855, 211, 1753, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1856, 211, 1754, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1857, 211, 1755, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1858, 211, 1756, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1859, 211, 1757, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1860, 211, 1758, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1861, 211, 1759, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1862, 211, 1760, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1863, 211, 1761, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1864, 211, 1762, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1865, 211, 1763, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1866, 211, 1764, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1867, 211, 1765, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1868, 211, 1766, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1869, 211, 1767, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1870, 211, 1768, 1439);
INSERT INTO chado.cvterm_relationship VALUES (1871, 211, 1769, 319);
INSERT INTO chado.cvterm_relationship VALUES (1872, 228, 1769, 269);
INSERT INTO chado.cvterm_relationship VALUES (1873, 211, 1770, 1769);
INSERT INTO chado.cvterm_relationship VALUES (1874, 211, 1771, 680);
INSERT INTO chado.cvterm_relationship VALUES (1875, 211, 1772, 347);
INSERT INTO chado.cvterm_relationship VALUES (1876, 234, 1772, 1036);
INSERT INTO chado.cvterm_relationship VALUES (1877, 211, 1773, 347);
INSERT INTO chado.cvterm_relationship VALUES (1878, 234, 1773, 505);
INSERT INTO chado.cvterm_relationship VALUES (1879, 211, 1774, 1416);
INSERT INTO chado.cvterm_relationship VALUES (1880, 211, 1774, 1367);
INSERT INTO chado.cvterm_relationship VALUES (1881, 228, 1774, 272);
INSERT INTO chado.cvterm_relationship VALUES (1882, 211, 1775, 1776);
INSERT INTO chado.cvterm_relationship VALUES (1883, 211, 1777, 719);
INSERT INTO chado.cvterm_relationship VALUES (1884, 211, 1778, 1777);
INSERT INTO chado.cvterm_relationship VALUES (1885, 211, 1779, 1777);
INSERT INTO chado.cvterm_relationship VALUES (1886, 211, 1780, 719);
INSERT INTO chado.cvterm_relationship VALUES (1887, 211, 1781, 1780);
INSERT INTO chado.cvterm_relationship VALUES (1888, 211, 1782, 1780);
INSERT INTO chado.cvterm_relationship VALUES (1889, 211, 1783, 415);
INSERT INTO chado.cvterm_relationship VALUES (1890, 211, 1784, 415);
INSERT INTO chado.cvterm_relationship VALUES (1891, 211, 1785, 416);
INSERT INTO chado.cvterm_relationship VALUES (1892, 211, 1786, 1568);
INSERT INTO chado.cvterm_relationship VALUES (1893, 211, 1787, 418);
INSERT INTO chado.cvterm_relationship VALUES (1894, 211, 1788, 501);
INSERT INTO chado.cvterm_relationship VALUES (1895, 211, 1789, 491);
INSERT INTO chado.cvterm_relationship VALUES (1896, 211, 1789, 1191);
INSERT INTO chado.cvterm_relationship VALUES (1897, 230, 1789, 1178);
INSERT INTO chado.cvterm_relationship VALUES (1898, 211, 1790, 1048);
INSERT INTO chado.cvterm_relationship VALUES (1899, 211, 1791, 1048);
INSERT INTO chado.cvterm_relationship VALUES (1900, 211, 1792, 1048);
INSERT INTO chado.cvterm_relationship VALUES (1901, 211, 1793, 271);
INSERT INTO chado.cvterm_relationship VALUES (1902, 234, 1793, 490);
INSERT INTO chado.cvterm_relationship VALUES (1903, 211, 1794, 268);
INSERT INTO chado.cvterm_relationship VALUES (1904, 211, 1795, 505);
INSERT INTO chado.cvterm_relationship VALUES (1905, 211, 1106, 1796);
INSERT INTO chado.cvterm_relationship VALUES (1906, 211, 1797, 648);
INSERT INTO chado.cvterm_relationship VALUES (1907, 234, 1797, 1034);
INSERT INTO chado.cvterm_relationship VALUES (1908, 211, 1798, 648);
INSERT INTO chado.cvterm_relationship VALUES (1909, 234, 1798, 1034);
INSERT INTO chado.cvterm_relationship VALUES (1910, 211, 1799, 1800);
INSERT INTO chado.cvterm_relationship VALUES (1911, 211, 1801, 1800);
INSERT INTO chado.cvterm_relationship VALUES (1912, 211, 1802, 1800);
INSERT INTO chado.cvterm_relationship VALUES (1913, 211, 1803, 1800);
INSERT INTO chado.cvterm_relationship VALUES (1914, 211, 1804, 1800);
INSERT INTO chado.cvterm_relationship VALUES (1915, 211, 1805, 1800);
INSERT INTO chado.cvterm_relationship VALUES (1916, 211, 1806, 344);
INSERT INTO chado.cvterm_relationship VALUES (1917, 234, 1806, 534);
INSERT INTO chado.cvterm_relationship VALUES (1918, 211, 1807, 704);
INSERT INTO chado.cvterm_relationship VALUES (1919, 234, 1807, 1808);
INSERT INTO chado.cvterm_relationship VALUES (1920, 211, 1809, 704);
INSERT INTO chado.cvterm_relationship VALUES (1921, 234, 1809, 1808);
INSERT INTO chado.cvterm_relationship VALUES (1922, 211, 1810, 704);
INSERT INTO chado.cvterm_relationship VALUES (1923, 234, 1810, 1808);
INSERT INTO chado.cvterm_relationship VALUES (1924, 211, 1811, 648);
INSERT INTO chado.cvterm_relationship VALUES (1925, 234, 1811, 1034);
INSERT INTO chado.cvterm_relationship VALUES (1926, 211, 1812, 704);
INSERT INTO chado.cvterm_relationship VALUES (1927, 234, 1812, 1034);
INSERT INTO chado.cvterm_relationship VALUES (1928, 211, 1813, 271);
INSERT INTO chado.cvterm_relationship VALUES (1929, 234, 1813, 487);
INSERT INTO chado.cvterm_relationship VALUES (1930, 211, 1800, 1141);
INSERT INTO chado.cvterm_relationship VALUES (1931, 211, 168, 167);
INSERT INTO chado.cvterm_relationship VALUES (1932, 211, 1814, 1367);
INSERT INTO chado.cvterm_relationship VALUES (1933, 228, 1814, 420);
INSERT INTO chado.cvterm_relationship VALUES (1934, 211, 1815, 319);
INSERT INTO chado.cvterm_relationship VALUES (1935, 211, 1816, 373);
INSERT INTO chado.cvterm_relationship VALUES (1936, 211, 1195, 589);
INSERT INTO chado.cvterm_relationship VALUES (1937, 211, 1817, 1146);
INSERT INTO chado.cvterm_relationship VALUES (1938, 211, 1818, 1146);
INSERT INTO chado.cvterm_relationship VALUES (1939, 211, 590, 1367);
INSERT INTO chado.cvterm_relationship VALUES (1940, 228, 590, 496);
INSERT INTO chado.cvterm_relationship VALUES (1941, 211, 1819, 585);
INSERT INTO chado.cvterm_relationship VALUES (1942, 211, 1820, 1819);
INSERT INTO chado.cvterm_relationship VALUES (1943, 211, 1821, 1820);
INSERT INTO chado.cvterm_relationship VALUES (1944, 211, 1822, 1820);
INSERT INTO chado.cvterm_relationship VALUES (1945, 211, 1823, 1819);
INSERT INTO chado.cvterm_relationship VALUES (1946, 211, 1824, 1823);
INSERT INTO chado.cvterm_relationship VALUES (1947, 211, 1825, 1823);
INSERT INTO chado.cvterm_relationship VALUES (1948, 211, 1826, 1823);
INSERT INTO chado.cvterm_relationship VALUES (1949, 211, 1827, 1828);
INSERT INTO chado.cvterm_relationship VALUES (1950, 211, 1829, 1819);
INSERT INTO chado.cvterm_relationship VALUES (1951, 211, 1830, 1829);
INSERT INTO chado.cvterm_relationship VALUES (1952, 211, 1831, 1829);
INSERT INTO chado.cvterm_relationship VALUES (1953, 211, 1832, 1819);
INSERT INTO chado.cvterm_relationship VALUES (1954, 211, 1833, 1832);
INSERT INTO chado.cvterm_relationship VALUES (1955, 211, 1834, 1832);
INSERT INTO chado.cvterm_relationship VALUES (1956, 211, 1828, 1819);
INSERT INTO chado.cvterm_relationship VALUES (1957, 211, 591, 1818);
INSERT INTO chado.cvterm_relationship VALUES (1958, 211, 1835, 800);
INSERT INTO chado.cvterm_relationship VALUES (1959, 211, 1836, 800);
INSERT INTO chado.cvterm_relationship VALUES (1960, 211, 809, 813);
INSERT INTO chado.cvterm_relationship VALUES (1961, 211, 1837, 809);
INSERT INTO chado.cvterm_relationship VALUES (1962, 211, 1838, 809);
INSERT INTO chado.cvterm_relationship VALUES (1963, 211, 1839, 809);
INSERT INTO chado.cvterm_relationship VALUES (1964, 211, 1840, 809);
INSERT INTO chado.cvterm_relationship VALUES (1965, 211, 1841, 662);
INSERT INTO chado.cvterm_relationship VALUES (1966, 211, 1842, 500);
INSERT INTO chado.cvterm_relationship VALUES (1967, 211, 1843, 809);
INSERT INTO chado.cvterm_relationship VALUES (1968, 211, 1844, 556);
INSERT INTO chado.cvterm_relationship VALUES (1969, 211, 1845, 166);
INSERT INTO chado.cvterm_relationship VALUES (1970, 211, 1846, 166);
INSERT INTO chado.cvterm_relationship VALUES (1971, 211, 1847, 1848);
INSERT INTO chado.cvterm_relationship VALUES (1972, 211, 1849, 1848);
INSERT INTO chado.cvterm_relationship VALUES (1973, 211, 1850, 1847);
INSERT INTO chado.cvterm_relationship VALUES (1974, 211, 1851, 1850);
INSERT INTO chado.cvterm_relationship VALUES (1975, 211, 1852, 1850);
INSERT INTO chado.cvterm_relationship VALUES (1976, 211, 1853, 1847);
INSERT INTO chado.cvterm_relationship VALUES (1977, 211, 1854, 1853);
INSERT INTO chado.cvterm_relationship VALUES (1978, 211, 1855, 1853);
INSERT INTO chado.cvterm_relationship VALUES (1979, 211, 1856, 1847);
INSERT INTO chado.cvterm_relationship VALUES (1980, 211, 1857, 1856);
INSERT INTO chado.cvterm_relationship VALUES (1981, 211, 1858, 1856);
INSERT INTO chado.cvterm_relationship VALUES (1982, 211, 1859, 1847);
INSERT INTO chado.cvterm_relationship VALUES (1983, 211, 1860, 1859);
INSERT INTO chado.cvterm_relationship VALUES (1984, 211, 1861, 1860);
INSERT INTO chado.cvterm_relationship VALUES (1985, 211, 1862, 1860);
INSERT INTO chado.cvterm_relationship VALUES (1986, 211, 1863, 1849);
INSERT INTO chado.cvterm_relationship VALUES (1987, 211, 1864, 1849);
INSERT INTO chado.cvterm_relationship VALUES (1988, 211, 1865, 1863);
INSERT INTO chado.cvterm_relationship VALUES (1989, 211, 1866, 1863);
INSERT INTO chado.cvterm_relationship VALUES (1990, 211, 1867, 1864);
INSERT INTO chado.cvterm_relationship VALUES (1991, 211, 1868, 1864);
INSERT INTO chado.cvterm_relationship VALUES (1992, 211, 1869, 1864);
INSERT INTO chado.cvterm_relationship VALUES (1993, 211, 1870, 1869);
INSERT INTO chado.cvterm_relationship VALUES (1994, 211, 1871, 1869);
INSERT INTO chado.cvterm_relationship VALUES (1995, 211, 1872, 1864);
INSERT INTO chado.cvterm_relationship VALUES (1996, 211, 1873, 1874);
INSERT INTO chado.cvterm_relationship VALUES (1997, 211, 1875, 1358);
INSERT INTO chado.cvterm_relationship VALUES (1998, 211, 1876, 1875);
INSERT INTO chado.cvterm_relationship VALUES (1999, 211, 1876, 1877);
INSERT INTO chado.cvterm_relationship VALUES (2000, 211, 1878, 1358);
INSERT INTO chado.cvterm_relationship VALUES (2001, 211, 1879, 1880);
INSERT INTO chado.cvterm_relationship VALUES (2002, 211, 1879, 1881);
INSERT INTO chado.cvterm_relationship VALUES (2003, 211, 1882, 1883);
INSERT INTO chado.cvterm_relationship VALUES (2004, 211, 1884, 1882);
INSERT INTO chado.cvterm_relationship VALUES (2005, 211, 1885, 1884);
INSERT INTO chado.cvterm_relationship VALUES (2006, 211, 1886, 1884);
INSERT INTO chado.cvterm_relationship VALUES (2007, 211, 1887, 1882);
INSERT INTO chado.cvterm_relationship VALUES (2008, 211, 1888, 1882);
INSERT INTO chado.cvterm_relationship VALUES (2009, 211, 1889, 1890);
INSERT INTO chado.cvterm_relationship VALUES (2010, 211, 1891, 1890);
INSERT INTO chado.cvterm_relationship VALUES (2011, 211, 1883, 1875);
INSERT INTO chado.cvterm_relationship VALUES (2012, 211, 1892, 1883);
INSERT INTO chado.cvterm_relationship VALUES (2013, 211, 1893, 1880);
INSERT INTO chado.cvterm_relationship VALUES (2014, 211, 1893, 1894);
INSERT INTO chado.cvterm_relationship VALUES (2015, 211, 1893, 1895);
INSERT INTO chado.cvterm_relationship VALUES (2016, 211, 1897, 1898);
INSERT INTO chado.cvterm_relationship VALUES (2017, 211, 1897, 1899);
INSERT INTO chado.cvterm_relationship VALUES (2018, 211, 1900, 1897);
INSERT INTO chado.cvterm_relationship VALUES (2019, 211, 1901, 1895);
INSERT INTO chado.cvterm_relationship VALUES (2020, 211, 1902, 1901);
INSERT INTO chado.cvterm_relationship VALUES (2021, 211, 1903, 1901);
INSERT INTO chado.cvterm_relationship VALUES (2022, 211, 1904, 1905);
INSERT INTO chado.cvterm_relationship VALUES (2023, 211, 1904, 1895);
INSERT INTO chado.cvterm_relationship VALUES (2024, 211, 1906, 1907);
INSERT INTO chado.cvterm_relationship VALUES (2025, 211, 1880, 1897);
INSERT INTO chado.cvterm_relationship VALUES (2026, 211, 1908, 1906);
INSERT INTO chado.cvterm_relationship VALUES (2027, 211, 1909, 1906);
INSERT INTO chado.cvterm_relationship VALUES (2028, 211, 1910, 1906);
INSERT INTO chado.cvterm_relationship VALUES (2029, 211, 1911, 1906);
INSERT INTO chado.cvterm_relationship VALUES (2030, 211, 1912, 1906);
INSERT INTO chado.cvterm_relationship VALUES (2031, 211, 1913, 1883);
INSERT INTO chado.cvterm_relationship VALUES (2032, 211, 1914, 1913);
INSERT INTO chado.cvterm_relationship VALUES (2033, 211, 1915, 1875);
INSERT INTO chado.cvterm_relationship VALUES (2034, 211, 1916, 1849);
INSERT INTO chado.cvterm_relationship VALUES (2035, 211, 1917, 1916);
INSERT INTO chado.cvterm_relationship VALUES (2036, 211, 1918, 1916);
INSERT INTO chado.cvterm_relationship VALUES (2037, 211, 1919, 1849);
INSERT INTO chado.cvterm_relationship VALUES (2038, 211, 1920, 1915);
INSERT INTO chado.cvterm_relationship VALUES (2039, 211, 1921, 1920);
INSERT INTO chado.cvterm_relationship VALUES (2040, 211, 1922, 1920);
INSERT INTO chado.cvterm_relationship VALUES (2041, 211, 1923, 1920);
INSERT INTO chado.cvterm_relationship VALUES (2042, 211, 1924, 1923);
INSERT INTO chado.cvterm_relationship VALUES (2043, 211, 1925, 1923);
INSERT INTO chado.cvterm_relationship VALUES (2044, 211, 1926, 1920);
INSERT INTO chado.cvterm_relationship VALUES (2045, 211, 1927, 1926);
INSERT INTO chado.cvterm_relationship VALUES (2046, 216, 1927, 1928);
INSERT INTO chado.cvterm_relationship VALUES (2047, 211, 1929, 1926);
INSERT INTO chado.cvterm_relationship VALUES (2048, 216, 1929, 1930);
INSERT INTO chado.cvterm_relationship VALUES (2049, 211, 1931, 1927);
INSERT INTO chado.cvterm_relationship VALUES (2050, 211, 1932, 1927);
INSERT INTO chado.cvterm_relationship VALUES (2051, 211, 1933, 1929);
INSERT INTO chado.cvterm_relationship VALUES (2052, 211, 1934, 1929);
INSERT INTO chado.cvterm_relationship VALUES (2053, 211, 1935, 1920);
INSERT INTO chado.cvterm_relationship VALUES (2054, 211, 1936, 1920);
INSERT INTO chado.cvterm_relationship VALUES (2055, 211, 1937, 1870);
INSERT INTO chado.cvterm_relationship VALUES (2056, 211, 1938, 1883);
INSERT INTO chado.cvterm_relationship VALUES (2057, 211, 1939, 1938);
INSERT INTO chado.cvterm_relationship VALUES (2058, 211, 1940, 1883);
INSERT INTO chado.cvterm_relationship VALUES (2059, 211, 1941, 1898);
INSERT INTO chado.cvterm_relationship VALUES (2060, 211, 1941, 1899);
INSERT INTO chado.cvterm_relationship VALUES (2061, 211, 1942, 1941);
INSERT INTO chado.cvterm_relationship VALUES (2062, 211, 1943, 1941);
INSERT INTO chado.cvterm_relationship VALUES (2063, 211, 1944, 1880);
INSERT INTO chado.cvterm_relationship VALUES (2064, 211, 1944, 1945);
INSERT INTO chado.cvterm_relationship VALUES (2065, 211, 1946, 1883);
INSERT INTO chado.cvterm_relationship VALUES (2066, 211, 1947, 1358);
INSERT INTO chado.cvterm_relationship VALUES (2067, 211, 1890, 1882);
INSERT INTO chado.cvterm_relationship VALUES (2068, 211, 1890, 1946);
INSERT INTO chado.cvterm_relationship VALUES (2069, 211, 1948, 1882);
INSERT INTO chado.cvterm_relationship VALUES (2070, 211, 1949, 1947);
INSERT INTO chado.cvterm_relationship VALUES (2071, 211, 1950, 1947);
INSERT INTO chado.cvterm_relationship VALUES (2072, 211, 1951, 1950);
INSERT INTO chado.cvterm_relationship VALUES (2073, 211, 1952, 1950);
INSERT INTO chado.cvterm_relationship VALUES (2074, 211, 1953, 1949);
INSERT INTO chado.cvterm_relationship VALUES (2075, 211, 1954, 1949);
INSERT INTO chado.cvterm_relationship VALUES (2076, 211, 1955, 1584);
INSERT INTO chado.cvterm_relationship VALUES (2077, 211, 1956, 1587);
INSERT INTO chado.cvterm_relationship VALUES (2078, 211, 1957, 1958);
INSERT INTO chado.cvterm_relationship VALUES (2079, 211, 1959, 1958);
INSERT INTO chado.cvterm_relationship VALUES (2080, 211, 1960, 1961);
INSERT INTO chado.cvterm_relationship VALUES (2081, 211, 1962, 319);
INSERT INTO chado.cvterm_relationship VALUES (2082, 211, 1963, 1584);
INSERT INTO chado.cvterm_relationship VALUES (2083, 211, 1964, 488);
INSERT INTO chado.cvterm_relationship VALUES (2084, 211, 1964, 637);
INSERT INTO chado.cvterm_relationship VALUES (2085, 228, 1964, 1225);
INSERT INTO chado.cvterm_relationship VALUES (2086, 230, 1964, 638);
INSERT INTO chado.cvterm_relationship VALUES (2087, 211, 167, 262);
INSERT INTO chado.cvterm_relationship VALUES (2088, 211, 1965, 167);
INSERT INTO chado.cvterm_relationship VALUES (2089, 211, 1966, 470);
INSERT INTO chado.cvterm_relationship VALUES (2090, 211, 1390, 413);
INSERT INTO chado.cvterm_relationship VALUES (2091, 211, 1385, 648);
INSERT INTO chado.cvterm_relationship VALUES (2092, 211, 1945, 1907);
INSERT INTO chado.cvterm_relationship VALUES (2093, 211, 1967, 582);
INSERT INTO chado.cvterm_relationship VALUES (2094, 211, 347, 797);
INSERT INTO chado.cvterm_relationship VALUES (2095, 211, 1280, 796);
INSERT INTO chado.cvterm_relationship VALUES (2096, 211, 1425, 796);
INSERT INTO chado.cvterm_relationship VALUES (2097, 211, 1442, 796);
INSERT INTO chado.cvterm_relationship VALUES (2098, 211, 1968, 1385);
INSERT INTO chado.cvterm_relationship VALUES (2099, 211, 516, 289);
INSERT INTO chado.cvterm_relationship VALUES (2100, 241, 516, 582);
INSERT INTO chado.cvterm_relationship VALUES (2101, 234, 516, 290);
INSERT INTO chado.cvterm_relationship VALUES (2102, 211, 284, 682);
INSERT INTO chado.cvterm_relationship VALUES (2103, 234, 284, 511);
INSERT INTO chado.cvterm_relationship VALUES (2104, 211, 1969, 517);
INSERT INTO chado.cvterm_relationship VALUES (2105, 234, 1969, 285);
INSERT INTO chado.cvterm_relationship VALUES (2106, 211, 1970, 517);
INSERT INTO chado.cvterm_relationship VALUES (2107, 234, 1970, 513);
INSERT INTO chado.cvterm_relationship VALUES (2108, 211, 1971, 284);
INSERT INTO chado.cvterm_relationship VALUES (2109, 234, 1971, 285);
INSERT INTO chado.cvterm_relationship VALUES (2110, 211, 1972, 284);
INSERT INTO chado.cvterm_relationship VALUES (2111, 234, 1972, 285);
INSERT INTO chado.cvterm_relationship VALUES (2112, 211, 1973, 289);
INSERT INTO chado.cvterm_relationship VALUES (2113, 234, 1973, 1972);
INSERT INTO chado.cvterm_relationship VALUES (2114, 211, 1974, 289);
INSERT INTO chado.cvterm_relationship VALUES (2115, 234, 1974, 1972);
INSERT INTO chado.cvterm_relationship VALUES (2116, 211, 1975, 289);
INSERT INTO chado.cvterm_relationship VALUES (2117, 234, 1975, 1972);
INSERT INTO chado.cvterm_relationship VALUES (2118, 211, 1976, 1977);
INSERT INTO chado.cvterm_relationship VALUES (2119, 211, 285, 512);
INSERT INTO chado.cvterm_relationship VALUES (2120, 211, 1978, 1977);
INSERT INTO chado.cvterm_relationship VALUES (2121, 211, 519, 1021);
INSERT INTO chado.cvterm_relationship VALUES (2122, 211, 1979, 1021);
INSERT INTO chado.cvterm_relationship VALUES (2123, 211, 1980, 289);
INSERT INTO chado.cvterm_relationship VALUES (2124, 234, 1980, 1979);
INSERT INTO chado.cvterm_relationship VALUES (2125, 211, 1981, 289);
INSERT INTO chado.cvterm_relationship VALUES (2126, 234, 1981, 1979);
INSERT INTO chado.cvterm_relationship VALUES (2127, 211, 1982, 1029);
INSERT INTO chado.cvterm_relationship VALUES (2128, 234, 1982, 1027);
INSERT INTO chado.cvterm_relationship VALUES (2129, 211, 1983, 1029);
INSERT INTO chado.cvterm_relationship VALUES (2130, 234, 1983, 1028);
INSERT INTO chado.cvterm_relationship VALUES (2131, 211, 1984, 284);
INSERT INTO chado.cvterm_relationship VALUES (2132, 234, 1984, 1027);
INSERT INTO chado.cvterm_relationship VALUES (2133, 211, 1977, 516);
INSERT INTO chado.cvterm_relationship VALUES (2134, 211, 473, 1391);
INSERT INTO chado.cvterm_relationship VALUES (2135, 211, 1986, 1391);
INSERT INTO chado.cvterm_relationship VALUES (2136, 211, 1987, 1391);
INSERT INTO chado.cvterm_relationship VALUES (2137, 211, 1126, 262);
INSERT INTO chado.cvterm_relationship VALUES (2138, 211, 1988, 585);
INSERT INTO chado.cvterm_relationship VALUES (2139, 211, 1989, 1988);
INSERT INTO chado.cvterm_relationship VALUES (2140, 211, 1990, 1988);
INSERT INTO chado.cvterm_relationship VALUES (2141, 211, 1991, 1992);
INSERT INTO chado.cvterm_relationship VALUES (2142, 211, 1993, 1994);
INSERT INTO chado.cvterm_relationship VALUES (2143, 211, 1995, 1996);
INSERT INTO chado.cvterm_relationship VALUES (2144, 234, 1995, 1997);
INSERT INTO chado.cvterm_relationship VALUES (2145, 211, 1998, 1996);
INSERT INTO chado.cvterm_relationship VALUES (2146, 234, 1998, 1997);
INSERT INTO chado.cvterm_relationship VALUES (2147, 211, 1999, 1991);
INSERT INTO chado.cvterm_relationship VALUES (2148, 211, 1997, 1991);
INSERT INTO chado.cvterm_relationship VALUES (2149, 211, 2000, 1993);
INSERT INTO chado.cvterm_relationship VALUES (2150, 234, 2000, 1999);
INSERT INTO chado.cvterm_relationship VALUES (2151, 211, 1996, 1993);
INSERT INTO chado.cvterm_relationship VALUES (2152, 211, 2001, 1992);
INSERT INTO chado.cvterm_relationship VALUES (2153, 234, 2001, 1997);
INSERT INTO chado.cvterm_relationship VALUES (2154, 211, 2002, 319);
INSERT INTO chado.cvterm_relationship VALUES (2155, 211, 2003, 2002);
INSERT INTO chado.cvterm_relationship VALUES (2156, 215, 2003, 797);
INSERT INTO chado.cvterm_relationship VALUES (2157, 211, 2004, 426);
INSERT INTO chado.cvterm_relationship VALUES (2158, 211, 2005, 426);
INSERT INTO chado.cvterm_relationship VALUES (2159, 211, 2006, 1420);
INSERT INTO chado.cvterm_relationship VALUES (2160, 211, 2006, 671);
INSERT INTO chado.cvterm_relationship VALUES (2161, 230, 2006, 462);
INSERT INTO chado.cvterm_relationship VALUES (2162, 211, 2007, 2006);
INSERT INTO chado.cvterm_relationship VALUES (2163, 211, 2008, 2006);
INSERT INTO chado.cvterm_relationship VALUES (2164, 211, 2009, 2010);
INSERT INTO chado.cvterm_relationship VALUES (2165, 211, 2011, 2010);
INSERT INTO chado.cvterm_relationship VALUES (2166, 211, 2012, 2013);
INSERT INTO chado.cvterm_relationship VALUES (2167, 211, 2014, 2013);
INSERT INTO chado.cvterm_relationship VALUES (2168, 211, 2015, 2016);
INSERT INTO chado.cvterm_relationship VALUES (2169, 211, 2017, 2018);
INSERT INTO chado.cvterm_relationship VALUES (2170, 211, 2019, 2018);
INSERT INTO chado.cvterm_relationship VALUES (2171, 211, 2020, 2021);
INSERT INTO chado.cvterm_relationship VALUES (2172, 211, 2022, 2021);
INSERT INTO chado.cvterm_relationship VALUES (2173, 211, 2023, 2021);
INSERT INTO chado.cvterm_relationship VALUES (2174, 211, 2024, 2007);
INSERT INTO chado.cvterm_relationship VALUES (2175, 211, 2025, 2007);
INSERT INTO chado.cvterm_relationship VALUES (2176, 211, 2026, 582);
INSERT INTO chado.cvterm_relationship VALUES (2177, 211, 2027, 2006);
INSERT INTO chado.cvterm_relationship VALUES (2178, 211, 2028, 2027);
INSERT INTO chado.cvterm_relationship VALUES (2179, 211, 2029, 2010);
INSERT INTO chado.cvterm_relationship VALUES (2180, 211, 2030, 2010);
INSERT INTO chado.cvterm_relationship VALUES (2181, 211, 671, 1391);
INSERT INTO chado.cvterm_relationship VALUES (2182, 230, 671, 462);
INSERT INTO chado.cvterm_relationship VALUES (2183, 211, 2032, 2033);
INSERT INTO chado.cvterm_relationship VALUES (2184, 211, 2034, 2033);
INSERT INTO chado.cvterm_relationship VALUES (2185, 211, 2035, 2033);
INSERT INTO chado.cvterm_relationship VALUES (2186, 211, 2036, 2013);
INSERT INTO chado.cvterm_relationship VALUES (2187, 211, 2037, 2018);
INSERT INTO chado.cvterm_relationship VALUES (2188, 211, 2038, 2016);
INSERT INTO chado.cvterm_relationship VALUES (2189, 211, 2039, 2016);
INSERT INTO chado.cvterm_relationship VALUES (2190, 211, 2040, 2041);
INSERT INTO chado.cvterm_relationship VALUES (2191, 211, 2042, 2041);
INSERT INTO chado.cvterm_relationship VALUES (2192, 211, 2043, 2041);
INSERT INTO chado.cvterm_relationship VALUES (2193, 211, 2018, 2007);
INSERT INTO chado.cvterm_relationship VALUES (2194, 211, 2033, 2007);
INSERT INTO chado.cvterm_relationship VALUES (2195, 211, 2013, 2007);
INSERT INTO chado.cvterm_relationship VALUES (2196, 211, 2021, 2007);
INSERT INTO chado.cvterm_relationship VALUES (2197, 211, 2016, 2007);
INSERT INTO chado.cvterm_relationship VALUES (2198, 211, 2044, 2006);
INSERT INTO chado.cvterm_relationship VALUES (2199, 211, 2045, 2044);
INSERT INTO chado.cvterm_relationship VALUES (2200, 211, 2046, 163);
INSERT INTO chado.cvterm_relationship VALUES (2201, 215, 2046, 1090);
INSERT INTO chado.cvterm_relationship VALUES (2202, 211, 2047, 2046);
INSERT INTO chado.cvterm_relationship VALUES (2203, 211, 2048, 2049);
INSERT INTO chado.cvterm_relationship VALUES (2204, 211, 2050, 1360);
INSERT INTO chado.cvterm_relationship VALUES (2205, 211, 2051, 1360);
INSERT INTO chado.cvterm_relationship VALUES (2206, 211, 2052, 496);
INSERT INTO chado.cvterm_relationship VALUES (2207, 211, 2053, 2052);
INSERT INTO chado.cvterm_relationship VALUES (2208, 211, 2054, 2052);
INSERT INTO chado.cvterm_relationship VALUES (2209, 211, 2055, 262);
INSERT INTO chado.cvterm_relationship VALUES (2210, 211, 2056, 1119);
INSERT INTO chado.cvterm_relationship VALUES (2211, 211, 2057, 1119);
INSERT INTO chado.cvterm_relationship VALUES (2212, 211, 2058, 1119);
INSERT INTO chado.cvterm_relationship VALUES (2213, 211, 2059, 1119);
INSERT INTO chado.cvterm_relationship VALUES (2214, 211, 2060, 1119);
INSERT INTO chado.cvterm_relationship VALUES (2215, 211, 2061, 1119);
INSERT INTO chado.cvterm_relationship VALUES (2216, 211, 2062, 1119);
INSERT INTO chado.cvterm_relationship VALUES (2217, 211, 2063, 1119);
INSERT INTO chado.cvterm_relationship VALUES (2218, 211, 2064, 1119);
INSERT INTO chado.cvterm_relationship VALUES (2219, 211, 2065, 1119);
INSERT INTO chado.cvterm_relationship VALUES (2220, 211, 2066, 329);
INSERT INTO chado.cvterm_relationship VALUES (2221, 211, 2067, 329);
INSERT INTO chado.cvterm_relationship VALUES (2222, 211, 329, 327);
INSERT INTO chado.cvterm_relationship VALUES (2223, 211, 2068, 784);
INSERT INTO chado.cvterm_relationship VALUES (2224, 211, 2069, 2068);
INSERT INTO chado.cvterm_relationship VALUES (2225, 211, 2070, 2068);
INSERT INTO chado.cvterm_relationship VALUES (2226, 211, 2071, 2070);
INSERT INTO chado.cvterm_relationship VALUES (2227, 211, 2072, 2070);
INSERT INTO chado.cvterm_relationship VALUES (2228, 211, 2073, 2070);
INSERT INTO chado.cvterm_relationship VALUES (2229, 211, 2074, 2070);
INSERT INTO chado.cvterm_relationship VALUES (2230, 211, 2075, 2070);
INSERT INTO chado.cvterm_relationship VALUES (2231, 211, 2076, 2068);
INSERT INTO chado.cvterm_relationship VALUES (2232, 211, 2077, 2076);
INSERT INTO chado.cvterm_relationship VALUES (2233, 211, 2078, 2076);
INSERT INTO chado.cvterm_relationship VALUES (2234, 211, 2079, 2076);
INSERT INTO chado.cvterm_relationship VALUES (2235, 211, 2080, 1848);
INSERT INTO chado.cvterm_relationship VALUES (2236, 211, 2081, 2076);
INSERT INTO chado.cvterm_relationship VALUES (2237, 211, 2082, 2069);
INSERT INTO chado.cvterm_relationship VALUES (2238, 211, 2083, 2069);
INSERT INTO chado.cvterm_relationship VALUES (2239, 211, 2084, 2069);
INSERT INTO chado.cvterm_relationship VALUES (2240, 211, 2085, 2069);
INSERT INTO chado.cvterm_relationship VALUES (2241, 211, 2086, 2069);
INSERT INTO chado.cvterm_relationship VALUES (2242, 211, 2087, 2069);
INSERT INTO chado.cvterm_relationship VALUES (2243, 211, 2088, 2069);
INSERT INTO chado.cvterm_relationship VALUES (2244, 211, 2089, 1878);
INSERT INTO chado.cvterm_relationship VALUES (2245, 211, 2090, 549);
INSERT INTO chado.cvterm_relationship VALUES (2246, 211, 2090, 359);
INSERT INTO chado.cvterm_relationship VALUES (2247, 211, 549, 496);
INSERT INTO chado.cvterm_relationship VALUES (2248, 211, 2091, 1848);
INSERT INTO chado.cvterm_relationship VALUES (2249, 211, 2092, 1890);
INSERT INTO chado.cvterm_relationship VALUES (2250, 211, 2093, 704);
INSERT INTO chado.cvterm_relationship VALUES (2251, 234, 2093, 532);
INSERT INTO chado.cvterm_relationship VALUES (2252, 211, 2094, 524);
INSERT INTO chado.cvterm_relationship VALUES (2253, 211, 273, 476);
INSERT INTO chado.cvterm_relationship VALUES (2254, 211, 1898, 1883);
INSERT INTO chado.cvterm_relationship VALUES (2255, 211, 2095, 1938);
INSERT INTO chado.cvterm_relationship VALUES (2256, 211, 2095, 1898);
INSERT INTO chado.cvterm_relationship VALUES (2257, 211, 2096, 271);
INSERT INTO chado.cvterm_relationship VALUES (2258, 234, 2096, 322);
INSERT INTO chado.cvterm_relationship VALUES (2259, 211, 1808, 987);
INSERT INTO chado.cvterm_relationship VALUES (2260, 211, 2097, 987);
INSERT INTO chado.cvterm_relationship VALUES (2261, 211, 2098, 704);
INSERT INTO chado.cvterm_relationship VALUES (2262, 234, 2098, 2097);
INSERT INTO chado.cvterm_relationship VALUES (2263, 211, 2099, 648);
INSERT INTO chado.cvterm_relationship VALUES (2264, 211, 2100, 2099);
INSERT INTO chado.cvterm_relationship VALUES (2265, 234, 2100, 2097);
INSERT INTO chado.cvterm_relationship VALUES (2266, 234, 2100, 2098);
INSERT INTO chado.cvterm_relationship VALUES (2267, 211, 2101, 2099);
INSERT INTO chado.cvterm_relationship VALUES (2268, 234, 2101, 2097);
INSERT INTO chado.cvterm_relationship VALUES (2269, 211, 2102, 282);
INSERT INTO chado.cvterm_relationship VALUES (2270, 216, 2102, 2103);
INSERT INTO chado.cvterm_relationship VALUES (2271, 211, 2103, 280);
INSERT INTO chado.cvterm_relationship VALUES (2272, 211, 2104, 1855);
INSERT INTO chado.cvterm_relationship VALUES (2273, 211, 2105, 1855);
INSERT INTO chado.cvterm_relationship VALUES (2274, 211, 2106, 1427);
INSERT INTO chado.cvterm_relationship VALUES (2275, 211, 2107, 2108);
INSERT INTO chado.cvterm_relationship VALUES (2276, 211, 2109, 809);
INSERT INTO chado.cvterm_relationship VALUES (2277, 211, 2110, 2108);
INSERT INTO chado.cvterm_relationship VALUES (2278, 211, 2111, 809);
INSERT INTO chado.cvterm_relationship VALUES (2279, 211, 2112, 808);
INSERT INTO chado.cvterm_relationship VALUES (2280, 211, 2113, 1427);
INSERT INTO chado.cvterm_relationship VALUES (2281, 211, 2114, 1420);
INSERT INTO chado.cvterm_relationship VALUES (2282, 211, 2115, 1412);
INSERT INTO chado.cvterm_relationship VALUES (2283, 234, 2115, 1407);
INSERT INTO chado.cvterm_relationship VALUES (2284, 211, 2116, 809);
INSERT INTO chado.cvterm_relationship VALUES (2285, 211, 2117, 2068);
INSERT INTO chado.cvterm_relationship VALUES (2286, 211, 2118, 2117);
INSERT INTO chado.cvterm_relationship VALUES (2287, 211, 2119, 2117);
INSERT INTO chado.cvterm_relationship VALUES (2288, 211, 2120, 598);
INSERT INTO chado.cvterm_relationship VALUES (2289, 211, 1907, 1897);
INSERT INTO chado.cvterm_relationship VALUES (2290, 211, 1881, 1897);
INSERT INTO chado.cvterm_relationship VALUES (2291, 211, 2121, 1945);
INSERT INTO chado.cvterm_relationship VALUES (2292, 211, 2122, 2121);
INSERT INTO chado.cvterm_relationship VALUES (2293, 211, 2122, 2123);
INSERT INTO chado.cvterm_relationship VALUES (2294, 211, 2124, 2121);
INSERT INTO chado.cvterm_relationship VALUES (2295, 211, 2124, 1905);
INSERT INTO chado.cvterm_relationship VALUES (2296, 211, 2125, 2122);
INSERT INTO chado.cvterm_relationship VALUES (2297, 211, 2126, 2122);
INSERT INTO chado.cvterm_relationship VALUES (2298, 211, 2127, 2124);
INSERT INTO chado.cvterm_relationship VALUES (2299, 211, 2128, 2124);
INSERT INTO chado.cvterm_relationship VALUES (2300, 211, 2129, 271);
INSERT INTO chado.cvterm_relationship VALUES (2301, 211, 2130, 271);
INSERT INTO chado.cvterm_relationship VALUES (2302, 211, 2131, 272);
INSERT INTO chado.cvterm_relationship VALUES (2303, 211, 2132, 268);
INSERT INTO chado.cvterm_relationship VALUES (2304, 211, 2133, 724);
INSERT INTO chado.cvterm_relationship VALUES (2305, 211, 2134, 813);
INSERT INTO chado.cvterm_relationship VALUES (2306, 211, 2135, 2134);
INSERT INTO chado.cvterm_relationship VALUES (2307, 211, 2136, 2134);
INSERT INTO chado.cvterm_relationship VALUES (2308, 211, 2137, 665);
INSERT INTO chado.cvterm_relationship VALUES (2309, 211, 2138, 665);
INSERT INTO chado.cvterm_relationship VALUES (2310, 211, 2139, 1077);
INSERT INTO chado.cvterm_relationship VALUES (2311, 215, 2139, 1075);
INSERT INTO chado.cvterm_relationship VALUES (2312, 211, 2140, 1077);
INSERT INTO chado.cvterm_relationship VALUES (2313, 211, 2141, 516);
INSERT INTO chado.cvterm_relationship VALUES (2314, 211, 2142, 582);
INSERT INTO chado.cvterm_relationship VALUES (2315, 211, 2143, 327);
INSERT INTO chado.cvterm_relationship VALUES (2316, 211, 2144, 516);
INSERT INTO chado.cvterm_relationship VALUES (2317, 211, 2145, 516);
INSERT INTO chado.cvterm_relationship VALUES (2318, 211, 2146, 516);
INSERT INTO chado.cvterm_relationship VALUES (2319, 211, 2147, 516);
INSERT INTO chado.cvterm_relationship VALUES (2320, 211, 2148, 516);
INSERT INTO chado.cvterm_relationship VALUES (2321, 211, 2149, 516);
INSERT INTO chado.cvterm_relationship VALUES (2322, 211, 2150, 284);
INSERT INTO chado.cvterm_relationship VALUES (2323, 211, 2151, 516);
INSERT INTO chado.cvterm_relationship VALUES (2324, 211, 2152, 516);
INSERT INTO chado.cvterm_relationship VALUES (2325, 211, 2153, 2142);
INSERT INTO chado.cvterm_relationship VALUES (2326, 211, 2154, 516);
INSERT INTO chado.cvterm_relationship VALUES (2327, 211, 2155, 289);
INSERT INTO chado.cvterm_relationship VALUES (2328, 211, 2156, 336);
INSERT INTO chado.cvterm_relationship VALUES (2329, 211, 2157, 516);
INSERT INTO chado.cvterm_relationship VALUES (2330, 211, 2158, 516);
INSERT INTO chado.cvterm_relationship VALUES (2331, 211, 2159, 516);
INSERT INTO chado.cvterm_relationship VALUES (2332, 211, 2160, 516);
INSERT INTO chado.cvterm_relationship VALUES (2333, 211, 2161, 516);
INSERT INTO chado.cvterm_relationship VALUES (2334, 211, 2162, 289);
INSERT INTO chado.cvterm_relationship VALUES (2335, 211, 2163, 516);
INSERT INTO chado.cvterm_relationship VALUES (2336, 211, 2164, 653);
INSERT INTO chado.cvterm_relationship VALUES (2337, 211, 2165, 654);
INSERT INTO chado.cvterm_relationship VALUES (2338, 211, 2166, 289);
INSERT INTO chado.cvterm_relationship VALUES (2339, 211, 2167, 516);
INSERT INTO chado.cvterm_relationship VALUES (2340, 211, 2168, 272);
INSERT INTO chado.cvterm_relationship VALUES (2341, 229, 2168, 489);
INSERT INTO chado.cvterm_relationship VALUES (2342, 234, 2168, 489);
INSERT INTO chado.cvterm_relationship VALUES (2343, 211, 2169, 163);
INSERT INTO chado.cvterm_relationship VALUES (2344, 211, 2170, 2169);
INSERT INTO chado.cvterm_relationship VALUES (2345, 211, 2171, 2169);
INSERT INTO chado.cvterm_relationship VALUES (2346, 211, 2172, 282);
INSERT INTO chado.cvterm_relationship VALUES (2347, 254, 2172, 505);
INSERT INTO chado.cvterm_relationship VALUES (2348, 211, 2173, 516);
INSERT INTO chado.cvterm_relationship VALUES (2349, 211, 2174, 262);
INSERT INTO chado.cvterm_relationship VALUES (2350, 211, 2174, 549);
INSERT INTO chado.cvterm_relationship VALUES (2351, 211, 2175, 1362);
INSERT INTO chado.cvterm_relationship VALUES (2352, 211, 2176, 1362);
INSERT INTO chado.cvterm_relationship VALUES (2353, 211, 2177, 483);
INSERT INTO chado.cvterm_relationship VALUES (2354, 211, 484, 486);
INSERT INTO chado.cvterm_relationship VALUES (2355, 211, 1776, 282);
INSERT INTO chado.cvterm_relationship VALUES (2356, 211, 1358, 1846);
INSERT INTO chado.cvterm_relationship VALUES (2357, 211, 2178, 1846);
INSERT INTO chado.cvterm_relationship VALUES (2358, 211, 2179, 1846);
INSERT INTO chado.cvterm_relationship VALUES (2359, 211, 2180, 1846);
INSERT INTO chado.cvterm_relationship VALUES (2360, 211, 1877, 1846);
INSERT INTO chado.cvterm_relationship VALUES (2361, 211, 2181, 2180);
INSERT INTO chado.cvterm_relationship VALUES (2362, 211, 2182, 2180);
INSERT INTO chado.cvterm_relationship VALUES (2363, 211, 2183, 2182);
INSERT INTO chado.cvterm_relationship VALUES (2364, 211, 2184, 1877);
INSERT INTO chado.cvterm_relationship VALUES (2365, 211, 2185, 1877);
INSERT INTO chado.cvterm_relationship VALUES (2366, 211, 2186, 2185);
INSERT INTO chado.cvterm_relationship VALUES (2367, 211, 2187, 2179);
INSERT INTO chado.cvterm_relationship VALUES (2368, 211, 2188, 1877);
INSERT INTO chado.cvterm_relationship VALUES (2369, 211, 2189, 2179);
INSERT INTO chado.cvterm_relationship VALUES (2370, 211, 2190, 2189);
INSERT INTO chado.cvterm_relationship VALUES (2371, 211, 2191, 2178);
INSERT INTO chado.cvterm_relationship VALUES (2372, 211, 2192, 2178);
INSERT INTO chado.cvterm_relationship VALUES (2373, 211, 2193, 2192);
INSERT INTO chado.cvterm_relationship VALUES (2374, 211, 2194, 421);
INSERT INTO chado.cvterm_relationship VALUES (2375, 234, 2194, 413);
INSERT INTO chado.cvterm_relationship VALUES (2376, 211, 2195, 327);
INSERT INTO chado.cvterm_relationship VALUES (2377, 234, 2195, 413);
INSERT INTO chado.cvterm_relationship VALUES (2378, 211, 2196, 2099);
INSERT INTO chado.cvterm_relationship VALUES (2379, 234, 2196, 2101);
INSERT INTO chado.cvterm_relationship VALUES (2380, 211, 2197, 2099);
INSERT INTO chado.cvterm_relationship VALUES (2381, 234, 2197, 2101);
INSERT INTO chado.cvterm_relationship VALUES (2382, 211, 2198, 284);
INSERT INTO chado.cvterm_relationship VALUES (2383, 211, 2199, 501);
INSERT INTO chado.cvterm_relationship VALUES (2384, 234, 2199, 444);
INSERT INTO chado.cvterm_relationship VALUES (2385, 211, 2200, 767);
INSERT INTO chado.cvterm_relationship VALUES (2386, 211, 2200, 1776);
INSERT INTO chado.cvterm_relationship VALUES (2387, 211, 2201, 444);
INSERT INTO chado.cvterm_relationship VALUES (2388, 216, 2201, 2101);
INSERT INTO chado.cvterm_relationship VALUES (2389, 211, 1905, 1358);
INSERT INTO chado.cvterm_relationship VALUES (2390, 211, 1894, 1358);
INSERT INTO chado.cvterm_relationship VALUES (2391, 211, 2123, 1894);
INSERT INTO chado.cvterm_relationship VALUES (2392, 211, 2202, 1906);
INSERT INTO chado.cvterm_relationship VALUES (2393, 211, 2202, 2123);
INSERT INTO chado.cvterm_relationship VALUES (2394, 211, 2203, 1906);
INSERT INTO chado.cvterm_relationship VALUES (2395, 211, 2203, 1905);
INSERT INTO chado.cvterm_relationship VALUES (2396, 211, 2204, 1873);
INSERT INTO chado.cvterm_relationship VALUES (2397, 211, 2205, 1873);
INSERT INTO chado.cvterm_relationship VALUES (2398, 211, 520, 1021);
INSERT INTO chado.cvterm_relationship VALUES (2399, 211, 2206, 289);
INSERT INTO chado.cvterm_relationship VALUES (2400, 211, 2207, 319);
INSERT INTO chado.cvterm_relationship VALUES (2401, 211, 2208, 697);
INSERT INTO chado.cvterm_relationship VALUES (2402, 211, 2209, 2207);
INSERT INTO chado.cvterm_relationship VALUES (2403, 211, 2210, 433);
INSERT INTO chado.cvterm_relationship VALUES (2404, 211, 2211, 433);
INSERT INTO chado.cvterm_relationship VALUES (2405, 211, 2212, 498);
INSERT INTO chado.cvterm_relationship VALUES (2406, 211, 2213, 272);
INSERT INTO chado.cvterm_relationship VALUES (2407, 229, 2213, 388);
INSERT INTO chado.cvterm_relationship VALUES (2408, 211, 2214, 483);
INSERT INTO chado.cvterm_relationship VALUES (2409, 211, 2215, 2216);
INSERT INTO chado.cvterm_relationship VALUES (2410, 211, 2217, 2216);
INSERT INTO chado.cvterm_relationship VALUES (2411, 211, 2218, 2216);
INSERT INTO chado.cvterm_relationship VALUES (2412, 211, 2219, 2216);
INSERT INTO chado.cvterm_relationship VALUES (2413, 211, 2216, 282);
INSERT INTO chado.cvterm_relationship VALUES (2414, 211, 2220, 2221);
INSERT INTO chado.cvterm_relationship VALUES (2415, 211, 2222, 271);
INSERT INTO chado.cvterm_relationship VALUES (2416, 229, 2222, 1371);
INSERT INTO chado.cvterm_relationship VALUES (2417, 211, 2223, 271);
INSERT INTO chado.cvterm_relationship VALUES (2418, 229, 2223, 1372);
INSERT INTO chado.cvterm_relationship VALUES (2419, 211, 2224, 1329);
INSERT INTO chado.cvterm_relationship VALUES (2420, 211, 2225, 2001);
INSERT INTO chado.cvterm_relationship VALUES (2421, 211, 2226, 2001);
INSERT INTO chado.cvterm_relationship VALUES (2422, 211, 2227, 267);
INSERT INTO chado.cvterm_relationship VALUES (2423, 211, 2228, 2007);
INSERT INTO chado.cvterm_relationship VALUES (2424, 211, 2229, 2010);
INSERT INTO chado.cvterm_relationship VALUES (2425, 211, 2230, 2231);
INSERT INTO chado.cvterm_relationship VALUES (2426, 211, 2232, 2233);
INSERT INTO chado.cvterm_relationship VALUES (2427, 211, 2234, 2041);
INSERT INTO chado.cvterm_relationship VALUES (2428, 211, 2235, 2231);
INSERT INTO chado.cvterm_relationship VALUES (2429, 211, 2236, 2041);
INSERT INTO chado.cvterm_relationship VALUES (2430, 211, 2237, 2231);
INSERT INTO chado.cvterm_relationship VALUES (2431, 211, 2238, 2010);
INSERT INTO chado.cvterm_relationship VALUES (2432, 211, 2239, 2233);
INSERT INTO chado.cvterm_relationship VALUES (2433, 211, 2240, 2010);
INSERT INTO chado.cvterm_relationship VALUES (2434, 211, 2241, 2231);
INSERT INTO chado.cvterm_relationship VALUES (2435, 211, 2242, 2007);
INSERT INTO chado.cvterm_relationship VALUES (2436, 211, 2243, 2007);
INSERT INTO chado.cvterm_relationship VALUES (2437, 211, 2244, 2007);
INSERT INTO chado.cvterm_relationship VALUES (2438, 211, 2245, 2007);
INSERT INTO chado.cvterm_relationship VALUES (2439, 211, 2246, 2007);
INSERT INTO chado.cvterm_relationship VALUES (2440, 211, 2247, 344);
INSERT INTO chado.cvterm_relationship VALUES (2441, 211, 2248, 1992);
INSERT INTO chado.cvterm_relationship VALUES (2442, 211, 1992, 262);
INSERT INTO chado.cvterm_relationship VALUES (2443, 211, 2249, 813);
INSERT INTO chado.cvterm_relationship VALUES (2444, 211, 2250, 813);
INSERT INTO chado.cvterm_relationship VALUES (2445, 211, 2252, 534);
INSERT INTO chado.cvterm_relationship VALUES (2446, 211, 2253, 284);
INSERT INTO chado.cvterm_relationship VALUES (2447, 211, 2254, 433);
INSERT INTO chado.cvterm_relationship VALUES (2448, 211, 2255, 435);
INSERT INTO chado.cvterm_relationship VALUES (2449, 211, 499, 670);
INSERT INTO chado.cvterm_relationship VALUES (2450, 211, 435, 670);
INSERT INTO chado.cvterm_relationship VALUES (2451, 211, 2256, 670);
INSERT INTO chado.cvterm_relationship VALUES (2452, 211, 2257, 2256);
INSERT INTO chado.cvterm_relationship VALUES (2453, 211, 2258, 435);
INSERT INTO chado.cvterm_relationship VALUES (2454, 211, 2259, 499);
INSERT INTO chado.cvterm_relationship VALUES (2455, 211, 1899, 1883);
INSERT INTO chado.cvterm_relationship VALUES (2456, 211, 2260, 1946);
INSERT INTO chado.cvterm_relationship VALUES (2457, 211, 2260, 1899);
INSERT INTO chado.cvterm_relationship VALUES (2458, 211, 2261, 1938);
INSERT INTO chado.cvterm_relationship VALUES (2459, 211, 2261, 1946);
INSERT INTO chado.cvterm_relationship VALUES (2460, 211, 2262, 1742);
INSERT INTO chado.cvterm_relationship VALUES (2461, 211, 2041, 2008);
INSERT INTO chado.cvterm_relationship VALUES (2462, 211, 2010, 2008);
INSERT INTO chado.cvterm_relationship VALUES (2463, 211, 2263, 516);
INSERT INTO chado.cvterm_relationship VALUES (2464, 211, 2264, 1997);
INSERT INTO chado.cvterm_relationship VALUES (2465, 211, 2265, 1997);
INSERT INTO chado.cvterm_relationship VALUES (2466, 211, 2266, 482);
INSERT INTO chado.cvterm_relationship VALUES (2467, 211, 2267, 637);
INSERT INTO chado.cvterm_relationship VALUES (2468, 211, 2268, 293);
INSERT INTO chado.cvterm_relationship VALUES (2469, 211, 2269, 1977);
INSERT INTO chado.cvterm_relationship VALUES (2470, 211, 2270, 1977);
INSERT INTO chado.cvterm_relationship VALUES (2471, 211, 2271, 1977);
INSERT INTO chado.cvterm_relationship VALUES (2472, 211, 2272, 1942);
INSERT INTO chado.cvterm_relationship VALUES (2473, 211, 2273, 2274);
INSERT INTO chado.cvterm_relationship VALUES (2474, 211, 2275, 262);
INSERT INTO chado.cvterm_relationship VALUES (2475, 211, 2276, 1947);
INSERT INTO chado.cvterm_relationship VALUES (2476, 211, 2277, 1947);
INSERT INTO chado.cvterm_relationship VALUES (2477, 211, 2278, 2272);
INSERT INTO chado.cvterm_relationship VALUES (2478, 211, 2279, 2272);
INSERT INTO chado.cvterm_relationship VALUES (2479, 211, 2280, 2272);
INSERT INTO chado.cvterm_relationship VALUES (2480, 211, 2281, 1329);
INSERT INTO chado.cvterm_relationship VALUES (2481, 211, 1895, 1945);
INSERT INTO chado.cvterm_relationship VALUES (2482, 211, 2282, 503);
INSERT INTO chado.cvterm_relationship VALUES (2483, 211, 2283, 1354);
INSERT INTO chado.cvterm_relationship VALUES (2484, 234, 2283, 2282);
INSERT INTO chado.cvterm_relationship VALUES (2485, 211, 2284, 1882);
INSERT INTO chado.cvterm_relationship VALUES (2486, 211, 2285, 1354);
INSERT INTO chado.cvterm_relationship VALUES (2487, 211, 2286, 988);
INSERT INTO chado.cvterm_relationship VALUES (2488, 211, 2287, 305);
INSERT INTO chado.cvterm_relationship VALUES (2489, 211, 2288, 289);
INSERT INTO chado.cvterm_relationship VALUES (2490, 234, 2288, 2094);
INSERT INTO chado.cvterm_relationship VALUES (2491, 211, 2289, 2288);
INSERT INTO chado.cvterm_relationship VALUES (2492, 211, 2290, 2288);
INSERT INTO chado.cvterm_relationship VALUES (2493, 211, 2291, 2288);
INSERT INTO chado.cvterm_relationship VALUES (2494, 211, 2292, 289);
INSERT INTO chado.cvterm_relationship VALUES (2495, 234, 2292, 837);
INSERT INTO chado.cvterm_relationship VALUES (2496, 211, 2293, 289);
INSERT INTO chado.cvterm_relationship VALUES (2497, 211, 2294, 516);
INSERT INTO chado.cvterm_relationship VALUES (2498, 211, 1353, 1796);
INSERT INTO chado.cvterm_relationship VALUES (2499, 211, 2295, 1903);
INSERT INTO chado.cvterm_relationship VALUES (2500, 211, 2296, 2295);
INSERT INTO chado.cvterm_relationship VALUES (2501, 211, 2297, 2295);
INSERT INTO chado.cvterm_relationship VALUES (2502, 211, 2298, 1883);
INSERT INTO chado.cvterm_relationship VALUES (2503, 211, 2299, 1900);
INSERT INTO chado.cvterm_relationship VALUES (2504, 211, 2299, 1895);
INSERT INTO chado.cvterm_relationship VALUES (2505, 211, 2300, 1942);
INSERT INTO chado.cvterm_relationship VALUES (2506, 211, 2301, 1942);
INSERT INTO chado.cvterm_relationship VALUES (2507, 211, 2302, 1943);
INSERT INTO chado.cvterm_relationship VALUES (2508, 211, 2303, 1943);
INSERT INTO chado.cvterm_relationship VALUES (2509, 211, 2304, 1947);
INSERT INTO chado.cvterm_relationship VALUES (2510, 211, 2305, 1946);
INSERT INTO chado.cvterm_relationship VALUES (2511, 211, 2306, 1900);
INSERT INTO chado.cvterm_relationship VALUES (2512, 211, 2306, 1881);
INSERT INTO chado.cvterm_relationship VALUES (2513, 211, 2307, 1036);
INSERT INTO chado.cvterm_relationship VALUES (2514, 211, 2308, 289);
INSERT INTO chado.cvterm_relationship VALUES (2515, 211, 2309, 282);
INSERT INTO chado.cvterm_relationship VALUES (2516, 211, 2310, 697);
INSERT INTO chado.cvterm_relationship VALUES (2517, 211, 2311, 2288);
INSERT INTO chado.cvterm_relationship VALUES (2518, 211, 2312, 289);
INSERT INTO chado.cvterm_relationship VALUES (2519, 211, 2313, 508);
INSERT INTO chado.cvterm_relationship VALUES (2520, 211, 2314, 583);
INSERT INTO chado.cvterm_relationship VALUES (2521, 211, 2315, 583);
INSERT INTO chado.cvterm_relationship VALUES (2522, 211, 2316, 583);
INSERT INTO chado.cvterm_relationship VALUES (2523, 211, 2317, 2288);
INSERT INTO chado.cvterm_relationship VALUES (2524, 211, 2318, 282);
INSERT INTO chado.cvterm_relationship VALUES (2525, 211, 2319, 630);
INSERT INTO chado.cvterm_relationship VALUES (2526, 234, 2319, 631);
INSERT INTO chado.cvterm_relationship VALUES (2527, 211, 2320, 630);
INSERT INTO chado.cvterm_relationship VALUES (2528, 234, 2320, 631);
INSERT INTO chado.cvterm_relationship VALUES (2529, 211, 2321, 580);
INSERT INTO chado.cvterm_relationship VALUES (2530, 228, 2321, 631);
INSERT INTO chado.cvterm_relationship VALUES (2531, 211, 2322, 280);
INSERT INTO chado.cvterm_relationship VALUES (2532, 211, 2323, 2322);
INSERT INTO chado.cvterm_relationship VALUES (2533, 228, 2323, 631);
INSERT INTO chado.cvterm_relationship VALUES (2534, 211, 2324, 558);
INSERT INTO chado.cvterm_relationship VALUES (2535, 228, 2324, 631);
INSERT INTO chado.cvterm_relationship VALUES (2536, 211, 2325, 280);
INSERT INTO chado.cvterm_relationship VALUES (2537, 211, 2326, 2325);
INSERT INTO chado.cvterm_relationship VALUES (2538, 228, 2326, 631);
INSERT INTO chado.cvterm_relationship VALUES (2539, 211, 2327, 280);
INSERT INTO chado.cvterm_relationship VALUES (2540, 211, 2328, 2327);
INSERT INTO chado.cvterm_relationship VALUES (2541, 228, 2328, 631);
INSERT INTO chado.cvterm_relationship VALUES (2542, 211, 2329, 280);
INSERT INTO chado.cvterm_relationship VALUES (2543, 211, 2330, 2329);
INSERT INTO chado.cvterm_relationship VALUES (2544, 228, 2330, 631);
INSERT INTO chado.cvterm_relationship VALUES (2545, 211, 2331, 516);
INSERT INTO chado.cvterm_relationship VALUES (2546, 211, 2332, 582);
INSERT INTO chado.cvterm_relationship VALUES (2547, 211, 2332, 516);
INSERT INTO chado.cvterm_relationship VALUES (2548, 211, 2333, 1773);
INSERT INTO chado.cvterm_relationship VALUES (2549, 211, 2334, 344);
INSERT INTO chado.cvterm_relationship VALUES (2550, 211, 2335, 584);
INSERT INTO chado.cvterm_relationship VALUES (2551, 211, 2336, 2010);
INSERT INTO chado.cvterm_relationship VALUES (2552, 211, 2337, 290);
INSERT INTO chado.cvterm_relationship VALUES (2553, 211, 2338, 290);
INSERT INTO chado.cvterm_relationship VALUES (2554, 211, 2339, 1848);
INSERT INTO chado.cvterm_relationship VALUES (2555, 211, 2340, 1848);
INSERT INTO chado.cvterm_relationship VALUES (2556, 211, 2341, 1848);
INSERT INTO chado.cvterm_relationship VALUES (2557, 211, 2342, 1848);
INSERT INTO chado.cvterm_relationship VALUES (2558, 211, 2343, 1035);
INSERT INTO chado.cvterm_relationship VALUES (2559, 234, 2343, 534);
INSERT INTO chado.cvterm_relationship VALUES (2560, 211, 2345, 1035);
INSERT INTO chado.cvterm_relationship VALUES (2561, 211, 2345, 1224);
INSERT INTO chado.cvterm_relationship VALUES (2562, 211, 2346, 1986);
INSERT INTO chado.cvterm_relationship VALUES (2563, 211, 2347, 1096);
INSERT INTO chado.cvterm_relationship VALUES (2564, 211, 2348, 1096);
INSERT INTO chado.cvterm_relationship VALUES (2565, 211, 2349, 2090);
INSERT INTO chado.cvterm_relationship VALUES (2566, 211, 2350, 2139);
INSERT INTO chado.cvterm_relationship VALUES (2567, 211, 2351, 2139);
INSERT INTO chado.cvterm_relationship VALUES (2568, 216, 2351, 2352);
INSERT INTO chado.cvterm_relationship VALUES (2569, 211, 2353, 2139);
INSERT INTO chado.cvterm_relationship VALUES (2570, 211, 2354, 354);
INSERT INTO chado.cvterm_relationship VALUES (2571, 211, 2355, 2354);
INSERT INTO chado.cvterm_relationship VALUES (2572, 216, 2355, 2356);
INSERT INTO chado.cvterm_relationship VALUES (2573, 211, 2357, 2354);
INSERT INTO chado.cvterm_relationship VALUES (2574, 211, 2358, 2354);
INSERT INTO chado.cvterm_relationship VALUES (2575, 216, 2358, 2352);
INSERT INTO chado.cvterm_relationship VALUES (2576, 211, 2359, 2354);
INSERT INTO chado.cvterm_relationship VALUES (2577, 211, 2360, 2361);
INSERT INTO chado.cvterm_relationship VALUES (2578, 211, 1394, 162);
INSERT INTO chado.cvterm_relationship VALUES (2579, 211, 2362, 1394);
INSERT INTO chado.cvterm_relationship VALUES (2580, 211, 2363, 1947);
INSERT INTO chado.cvterm_relationship VALUES (2581, 211, 2364, 1883);
INSERT INTO chado.cvterm_relationship VALUES (2582, 211, 2365, 2364);
INSERT INTO chado.cvterm_relationship VALUES (2583, 211, 2366, 2364);
INSERT INTO chado.cvterm_relationship VALUES (2584, 211, 2367, 2364);
INSERT INTO chado.cvterm_relationship VALUES (2585, 211, 2368, 2364);
INSERT INTO chado.cvterm_relationship VALUES (2586, 211, 2369, 2364);
INSERT INTO chado.cvterm_relationship VALUES (2587, 211, 2370, 2364);
INSERT INTO chado.cvterm_relationship VALUES (2588, 211, 2371, 2368);
INSERT INTO chado.cvterm_relationship VALUES (2589, 211, 2372, 1950);
INSERT INTO chado.cvterm_relationship VALUES (2590, 211, 2373, 1948);
INSERT INTO chado.cvterm_relationship VALUES (2591, 211, 2374, 1876);
INSERT INTO chado.cvterm_relationship VALUES (2592, 211, 2375, 1876);
INSERT INTO chado.cvterm_relationship VALUES (2593, 211, 2376, 866);
INSERT INTO chado.cvterm_relationship VALUES (2594, 234, 2376, 922);
INSERT INTO chado.cvterm_relationship VALUES (2595, 211, 2377, 1938);
INSERT INTO chado.cvterm_relationship VALUES (2596, 211, 2377, 1948);
INSERT INTO chado.cvterm_relationship VALUES (2597, 211, 2378, 1943);
INSERT INTO chado.cvterm_relationship VALUES (2598, 211, 2379, 1943);
INSERT INTO chado.cvterm_relationship VALUES (2599, 211, 2379, 2260);
INSERT INTO chado.cvterm_relationship VALUES (2600, 211, 2380, 1942);
INSERT INTO chado.cvterm_relationship VALUES (2601, 211, 2380, 2260);
INSERT INTO chado.cvterm_relationship VALUES (2602, 211, 2381, 1942);
INSERT INTO chado.cvterm_relationship VALUES (2603, 211, 2382, 1916);
INSERT INTO chado.cvterm_relationship VALUES (2604, 211, 2383, 714);
INSERT INTO chado.cvterm_relationship VALUES (2605, 211, 2384, 628);
INSERT INTO chado.cvterm_relationship VALUES (2606, 211, 2385, 555);
INSERT INTO chado.cvterm_relationship VALUES (2607, 211, 2386, 327);
INSERT INTO chado.cvterm_relationship VALUES (2608, 211, 2387, 2386);
INSERT INTO chado.cvterm_relationship VALUES (2609, 211, 2388, 2386);
INSERT INTO chado.cvterm_relationship VALUES (2610, 211, 2389, 2387);
INSERT INTO chado.cvterm_relationship VALUES (2611, 211, 2390, 2387);
INSERT INTO chado.cvterm_relationship VALUES (2612, 211, 2391, 2387);
INSERT INTO chado.cvterm_relationship VALUES (2613, 211, 2392, 2388);
INSERT INTO chado.cvterm_relationship VALUES (2614, 211, 2393, 2388);
INSERT INTO chado.cvterm_relationship VALUES (2615, 211, 2394, 326);
INSERT INTO chado.cvterm_relationship VALUES (2616, 211, 2395, 329);
INSERT INTO chado.cvterm_relationship VALUES (2617, 211, 2396, 329);
INSERT INTO chado.cvterm_relationship VALUES (2618, 211, 2397, 2067);
INSERT INTO chado.cvterm_relationship VALUES (2619, 211, 2398, 326);
INSERT INTO chado.cvterm_relationship VALUES (2620, 211, 2399, 2143);
INSERT INTO chado.cvterm_relationship VALUES (2621, 211, 2400, 1816);
INSERT INTO chado.cvterm_relationship VALUES (2622, 211, 2401, 443);
INSERT INTO chado.cvterm_relationship VALUES (2623, 211, 2402, 2322);
INSERT INTO chado.cvterm_relationship VALUES (2624, 211, 2403, 443);
INSERT INTO chado.cvterm_relationship VALUES (2625, 211, 2404, 444);
INSERT INTO chado.cvterm_relationship VALUES (2626, 211, 2405, 2400);
INSERT INTO chado.cvterm_relationship VALUES (2627, 211, 2407, 2403);
INSERT INTO chado.cvterm_relationship VALUES (2628, 211, 2408, 2070);
INSERT INTO chado.cvterm_relationship VALUES (2629, 211, 2409, 282);
INSERT INTO chado.cvterm_relationship VALUES (2630, 211, 2410, 163);
INSERT INTO chado.cvterm_relationship VALUES (2631, 211, 2411, 2410);
INSERT INTO chado.cvterm_relationship VALUES (2632, 211, 2412, 2411);
INSERT INTO chado.cvterm_relationship VALUES (2633, 211, 2413, 2411);
INSERT INTO chado.cvterm_relationship VALUES (2634, 211, 2414, 2411);
INSERT INTO chado.cvterm_relationship VALUES (2635, 211, 2415, 2411);
INSERT INTO chado.cvterm_relationship VALUES (2636, 211, 1961, 1584);
INSERT INTO chado.cvterm_relationship VALUES (2637, 211, 2416, 604);
INSERT INTO chado.cvterm_relationship VALUES (2638, 211, 2417, 605);
INSERT INTO chado.cvterm_relationship VALUES (2639, 211, 2418, 164);
INSERT INTO chado.cvterm_relationship VALUES (2640, 211, 2419, 1776);
INSERT INTO chado.cvterm_relationship VALUES (2641, 211, 2420, 1776);
INSERT INTO chado.cvterm_relationship VALUES (2642, 211, 2421, 2410);
INSERT INTO chado.cvterm_relationship VALUES (2643, 211, 2422, 2421);
INSERT INTO chado.cvterm_relationship VALUES (2644, 211, 2423, 2421);
INSERT INTO chado.cvterm_relationship VALUES (2645, 211, 2424, 2421);
INSERT INTO chado.cvterm_relationship VALUES (2646, 211, 2425, 2421);
INSERT INTO chado.cvterm_relationship VALUES (2647, 211, 2426, 373);
INSERT INTO chado.cvterm_relationship VALUES (2648, 211, 2427, 2426);
INSERT INTO chado.cvterm_relationship VALUES (2649, 211, 2428, 659);
INSERT INTO chado.cvterm_relationship VALUES (2650, 211, 2429, 659);
INSERT INTO chado.cvterm_relationship VALUES (2651, 211, 2233, 2008);
INSERT INTO chado.cvterm_relationship VALUES (2652, 211, 2231, 2008);
INSERT INTO chado.cvterm_relationship VALUES (2653, 211, 2430, 2233);
INSERT INTO chado.cvterm_relationship VALUES (2654, 211, 2431, 2430);
INSERT INTO chado.cvterm_relationship VALUES (2655, 211, 2432, 2430);
INSERT INTO chado.cvterm_relationship VALUES (2656, 211, 2433, 2430);
INSERT INTO chado.cvterm_relationship VALUES (2657, 211, 2434, 2430);
INSERT INTO chado.cvterm_relationship VALUES (2658, 211, 2435, 2430);
INSERT INTO chado.cvterm_relationship VALUES (2659, 211, 2436, 2314);
INSERT INTO chado.cvterm_relationship VALUES (2660, 211, 2437, 2314);
INSERT INTO chado.cvterm_relationship VALUES (2661, 211, 2438, 1875);
INSERT INTO chado.cvterm_relationship VALUES (2662, 211, 2439, 1875);
INSERT INTO chado.cvterm_relationship VALUES (2663, 211, 2440, 661);
INSERT INTO chado.cvterm_relationship VALUES (2664, 211, 2441, 661);
INSERT INTO chado.cvterm_relationship VALUES (2665, 211, 2442, 516);
INSERT INTO chado.cvterm_relationship VALUES (2666, 211, 2443, 2273);
INSERT INTO chado.cvterm_relationship VALUES (2667, 211, 2444, 2273);
INSERT INTO chado.cvterm_relationship VALUES (2668, 211, 2445, 2108);
INSERT INTO chado.cvterm_relationship VALUES (2669, 211, 1874, 1846);
INSERT INTO chado.cvterm_relationship VALUES (2670, 211, 2446, 1874);
INSERT INTO chado.cvterm_relationship VALUES (2671, 211, 2447, 2446);
INSERT INTO chado.cvterm_relationship VALUES (2672, 211, 2448, 2446);
INSERT INTO chado.cvterm_relationship VALUES (2673, 211, 2449, 2231);
INSERT INTO chado.cvterm_relationship VALUES (2674, 211, 2450, 2447);
INSERT INTO chado.cvterm_relationship VALUES (2675, 211, 2451, 629);
INSERT INTO chado.cvterm_relationship VALUES (2676, 211, 2452, 629);
INSERT INTO chado.cvterm_relationship VALUES (2677, 211, 2453, 312);
INSERT INTO chado.cvterm_relationship VALUES (2678, 234, 2453, 164);
INSERT INTO chado.cvterm_relationship VALUES (2679, 211, 2454, 1882);
INSERT INTO chado.cvterm_relationship VALUES (2680, 211, 2455, 1948);
INSERT INTO chado.cvterm_relationship VALUES (2681, 211, 2456, 659);
INSERT INTO chado.cvterm_relationship VALUES (2682, 211, 2457, 800);
INSERT INTO chado.cvterm_relationship VALUES (2683, 211, 2458, 2457);
INSERT INTO chado.cvterm_relationship VALUES (2684, 211, 2459, 2457);
INSERT INTO chado.cvterm_relationship VALUES (2685, 211, 2460, 2457);
INSERT INTO chado.cvterm_relationship VALUES (2686, 211, 2461, 2457);
INSERT INTO chado.cvterm_relationship VALUES (2687, 211, 2462, 2460);
INSERT INTO chado.cvterm_relationship VALUES (2688, 211, 2463, 2461);
INSERT INTO chado.cvterm_relationship VALUES (2689, 211, 2464, 2461);
INSERT INTO chado.cvterm_relationship VALUES (2690, 211, 1958, 1584);
INSERT INTO chado.cvterm_relationship VALUES (2691, 211, 2465, 1958);
INSERT INTO chado.cvterm_relationship VALUES (2692, 211, 2466, 1961);
INSERT INTO chado.cvterm_relationship VALUES (2693, 211, 2467, 1961);
INSERT INTO chado.cvterm_relationship VALUES (2694, 211, 2468, 1961);
INSERT INTO chado.cvterm_relationship VALUES (2695, 211, 2469, 1961);
INSERT INTO chado.cvterm_relationship VALUES (2696, 211, 2470, 262);
INSERT INTO chado.cvterm_relationship VALUES (2697, 211, 2471, 2139);
INSERT INTO chado.cvterm_relationship VALUES (2698, 216, 2471, 2356);
INSERT INTO chado.cvterm_relationship VALUES (2699, 211, 2472, 1082);
INSERT INTO chado.cvterm_relationship VALUES (2700, 211, 2473, 2067);
INSERT INTO chado.cvterm_relationship VALUES (2701, 211, 2474, 1036);
INSERT INTO chado.cvterm_relationship VALUES (2702, 211, 2475, 671);
INSERT INTO chado.cvterm_relationship VALUES (2703, 211, 2476, 648);
INSERT INTO chado.cvterm_relationship VALUES (2704, 211, 2477, 1173);
INSERT INTO chado.cvterm_relationship VALUES (2705, 211, 2478, 1173);
INSERT INTO chado.cvterm_relationship VALUES (2706, 211, 2479, 1173);
INSERT INTO chado.cvterm_relationship VALUES (2707, 211, 2480, 1173);
INSERT INTO chado.cvterm_relationship VALUES (2708, 211, 2481, 1174);
INSERT INTO chado.cvterm_relationship VALUES (2709, 211, 2482, 1174);
INSERT INTO chado.cvterm_relationship VALUES (2710, 211, 2483, 1174);
INSERT INTO chado.cvterm_relationship VALUES (2711, 211, 2484, 1174);
INSERT INTO chado.cvterm_relationship VALUES (2712, 211, 2485, 648);
INSERT INTO chado.cvterm_relationship VALUES (2713, 211, 2486, 267);
INSERT INTO chado.cvterm_relationship VALUES (2714, 211, 2487, 659);
INSERT INTO chado.cvterm_relationship VALUES (2715, 211, 1994, 418);
INSERT INTO chado.cvterm_relationship VALUES (2716, 211, 2488, 344);
INSERT INTO chado.cvterm_relationship VALUES (2717, 211, 2489, 784);
INSERT INTO chado.cvterm_relationship VALUES (2718, 211, 2490, 2268);
INSERT INTO chado.cvterm_relationship VALUES (2719, 211, 2491, 373);
INSERT INTO chado.cvterm_relationship VALUES (2720, 211, 2492, 272);
INSERT INTO chado.cvterm_relationship VALUES (2721, 211, 2493, 1360);
INSERT INTO chado.cvterm_relationship VALUES (2722, 211, 2494, 491);
INSERT INTO chado.cvterm_relationship VALUES (2723, 211, 2495, 491);
INSERT INTO chado.cvterm_relationship VALUES (2724, 211, 2496, 1025);
INSERT INTO chado.cvterm_relationship VALUES (2725, 211, 2497, 1895);
INSERT INTO chado.cvterm_relationship VALUES (2726, 211, 2498, 289);
INSERT INTO chado.cvterm_relationship VALUES (2727, 211, 2499, 516);
INSERT INTO chado.cvterm_relationship VALUES (2728, 211, 2500, 496);
INSERT INTO chado.cvterm_relationship VALUES (2729, 211, 1848, 1845);
INSERT INTO chado.cvterm_relationship VALUES (2730, 211, 2501, 1845);
INSERT INTO chado.cvterm_relationship VALUES (2731, 211, 2502, 1845);
INSERT INTO chado.cvterm_relationship VALUES (2732, 211, 511, 290);
INSERT INTO chado.cvterm_relationship VALUES (2733, 211, 1022, 290);
INSERT INTO chado.cvterm_relationship VALUES (2734, 211, 2503, 1391);
INSERT INTO chado.cvterm_relationship VALUES (2735, 211, 2504, 813);
INSERT INTO chado.cvterm_relationship VALUES (2736, 211, 2505, 2294);
INSERT INTO chado.cvterm_relationship VALUES (2737, 211, 2506, 764);
INSERT INTO chado.cvterm_relationship VALUES (2738, 211, 2507, 421);
INSERT INTO chado.cvterm_relationship VALUES (2739, 211, 1930, 2507);
INSERT INTO chado.cvterm_relationship VALUES (2740, 211, 1928, 2507);
INSERT INTO chado.cvterm_relationship VALUES (2741, 211, 2508, 2108);
INSERT INTO chado.cvterm_relationship VALUES (2742, 211, 2509, 753);
INSERT INTO chado.cvterm_relationship VALUES (2743, 230, 2509, 2266);
INSERT INTO chado.cvterm_relationship VALUES (2744, 211, 2510, 167);
INSERT INTO chado.cvterm_relationship VALUES (2745, 211, 2511, 796);
INSERT INTO chado.cvterm_relationship VALUES (2746, 238, 2511, 423);
INSERT INTO chado.cvterm_relationship VALUES (2747, 211, 2512, 1039);
INSERT INTO chado.cvterm_relationship VALUES (2748, 234, 2512, 552);
INSERT INTO chado.cvterm_relationship VALUES (2749, 211, 2513, 1427);
INSERT INTO chado.cvterm_relationship VALUES (2750, 211, 794, 2514);
INSERT INTO chado.cvterm_relationship VALUES (2751, 211, 1336, 2514);
INSERT INTO chado.cvterm_relationship VALUES (2752, 211, 1061, 2515);
INSERT INTO chado.cvterm_relationship VALUES (2753, 211, 1063, 2515);
INSERT INTO chado.cvterm_relationship VALUES (2754, 211, 757, 2515);
INSERT INTO chado.cvterm_relationship VALUES (2755, 211, 1340, 2515);
INSERT INTO chado.cvterm_relationship VALUES (2756, 211, 1338, 2515);
INSERT INTO chado.cvterm_relationship VALUES (2757, 211, 2517, 1883);
INSERT INTO chado.cvterm_relationship VALUES (2758, 211, 2518, 2517);
INSERT INTO chado.cvterm_relationship VALUES (2759, 211, 2519, 2517);
INSERT INTO chado.cvterm_relationship VALUES (2760, 211, 606, 282);
INSERT INTO chado.cvterm_relationship VALUES (2761, 211, 2520, 319);
INSERT INTO chado.cvterm_relationship VALUES (2762, 211, 814, 696);
INSERT INTO chado.cvterm_relationship VALUES (2763, 211, 1396, 696);
INSERT INTO chado.cvterm_relationship VALUES (2764, 211, 810, 696);
INSERT INTO chado.cvterm_relationship VALUES (2765, 211, 1136, 696);
INSERT INTO chado.cvterm_relationship VALUES (2766, 211, 2521, 447);
INSERT INTO chado.cvterm_relationship VALUES (2767, 234, 2521, 679);
INSERT INTO chado.cvterm_relationship VALUES (2768, 211, 2522, 2521);
INSERT INTO chado.cvterm_relationship VALUES (2769, 211, 2523, 2521);
INSERT INTO chado.cvterm_relationship VALUES (2770, 211, 2524, 2523);
INSERT INTO chado.cvterm_relationship VALUES (2771, 211, 2525, 648);
INSERT INTO chado.cvterm_relationship VALUES (2772, 211, 2526, 289);
INSERT INTO chado.cvterm_relationship VALUES (2773, 211, 2527, 262);
INSERT INTO chado.cvterm_relationship VALUES (2774, 228, 2527, 971);
INSERT INTO chado.cvterm_relationship VALUES (2775, 234, 2527, 552);
INSERT INTO chado.cvterm_relationship VALUES (2776, 211, 2528, 532);
INSERT INTO chado.cvterm_relationship VALUES (2777, 211, 2529, 532);
INSERT INTO chado.cvterm_relationship VALUES (2778, 211, 2530, 423);
INSERT INTO chado.cvterm_relationship VALUES (2779, 211, 2531, 423);
INSERT INTO chado.cvterm_relationship VALUES (2780, 211, 2532, 532);
INSERT INTO chado.cvterm_relationship VALUES (2781, 211, 2533, 532);
INSERT INTO chado.cvterm_relationship VALUES (2782, 211, 2534, 532);
INSERT INTO chado.cvterm_relationship VALUES (2783, 211, 2535, 532);
INSERT INTO chado.cvterm_relationship VALUES (2784, 211, 2356, 532);
INSERT INTO chado.cvterm_relationship VALUES (2785, 211, 2536, 541);
INSERT INTO chado.cvterm_relationship VALUES (2786, 211, 2537, 541);
INSERT INTO chado.cvterm_relationship VALUES (2787, 211, 2538, 541);
INSERT INTO chado.cvterm_relationship VALUES (2788, 211, 2352, 541);
INSERT INTO chado.cvterm_relationship VALUES (2789, 211, 2539, 541);
INSERT INTO chado.cvterm_relationship VALUES (2790, 211, 2540, 553);
INSERT INTO chado.cvterm_relationship VALUES (2791, 211, 2541, 553);
INSERT INTO chado.cvterm_relationship VALUES (2792, 211, 2542, 553);
INSERT INTO chado.cvterm_relationship VALUES (2793, 211, 2543, 528);
INSERT INTO chado.cvterm_relationship VALUES (2794, 211, 2544, 556);
INSERT INTO chado.cvterm_relationship VALUES (2795, 211, 2545, 556);
INSERT INTO chado.cvterm_relationship VALUES (2796, 211, 2546, 556);
INSERT INTO chado.cvterm_relationship VALUES (2797, 211, 2547, 556);
INSERT INTO chado.cvterm_relationship VALUES (2798, 211, 2548, 556);
INSERT INTO chado.cvterm_relationship VALUES (2799, 211, 2549, 556);
INSERT INTO chado.cvterm_relationship VALUES (2800, 211, 2550, 556);
INSERT INTO chado.cvterm_relationship VALUES (2801, 211, 2551, 556);
INSERT INTO chado.cvterm_relationship VALUES (2802, 211, 2552, 535);
INSERT INTO chado.cvterm_relationship VALUES (2803, 211, 2553, 2552);
INSERT INTO chado.cvterm_relationship VALUES (2804, 211, 2554, 2552);
INSERT INTO chado.cvterm_relationship VALUES (2805, 211, 2555, 2552);
INSERT INTO chado.cvterm_relationship VALUES (2806, 211, 2556, 535);
INSERT INTO chado.cvterm_relationship VALUES (2807, 211, 2557, 282);
INSERT INTO chado.cvterm_relationship VALUES (2808, 211, 2558, 164);
INSERT INTO chado.cvterm_relationship VALUES (2809, 211, 2559, 659);
INSERT INTO chado.cvterm_relationship VALUES (2810, 229, 2559, 388);
INSERT INTO chado.cvterm_relationship VALUES (2811, 211, 2560, 660);
INSERT INTO chado.cvterm_relationship VALUES (2812, 211, 2560, 2559);
INSERT INTO chado.cvterm_relationship VALUES (2813, 211, 2561, 582);
INSERT INTO chado.cvterm_relationship VALUES (2814, 211, 2562, 344);
INSERT INTO chado.cvterm_relationship VALUES (2815, 228, 2562, 2561);
INSERT INTO chado.cvterm_relationship VALUES (2816, 211, 2563, 344);
INSERT INTO chado.cvterm_relationship VALUES (2817, 228, 2563, 2561);
INSERT INTO chado.cvterm_relationship VALUES (2818, 211, 2564, 523);
INSERT INTO chado.cvterm_relationship VALUES (2819, 211, 2565, 523);
INSERT INTO chado.cvterm_relationship VALUES (2820, 211, 1083, 262);
INSERT INTO chado.cvterm_relationship VALUES (2821, 211, 2566, 1083);
INSERT INTO chado.cvterm_relationship VALUES (2822, 211, 2567, 2568);
INSERT INTO chado.cvterm_relationship VALUES (2823, 211, 2569, 2568);
INSERT INTO chado.cvterm_relationship VALUES (2824, 211, 2570, 588);
INSERT INTO chado.cvterm_relationship VALUES (2825, 211, 2571, 418);
INSERT INTO chado.cvterm_relationship VALUES (2826, 234, 2571, 2570);
INSERT INTO chado.cvterm_relationship VALUES (2827, 211, 2572, 423);
INSERT INTO chado.cvterm_relationship VALUES (2828, 211, 2573, 423);
INSERT INTO chado.cvterm_relationship VALUES (2829, 241, 2573, 2570);
INSERT INTO chado.cvterm_relationship VALUES (2830, 211, 2574, 316);
INSERT INTO chado.cvterm_relationship VALUES (2831, 234, 2574, 2573);
INSERT INTO chado.cvterm_relationship VALUES (2832, 211, 682, 516);
INSERT INTO chado.cvterm_relationship VALUES (2833, 234, 682, 290);
INSERT INTO chado.cvterm_relationship VALUES (2834, 211, 2575, 290);
INSERT INTO chado.cvterm_relationship VALUES (2835, 234, 2575, 1743);
INSERT INTO chado.cvterm_relationship VALUES (2836, 211, 1535, 290);
INSERT INTO chado.cvterm_relationship VALUES (2837, 211, 2576, 682);
INSERT INTO chado.cvterm_relationship VALUES (2838, 234, 2576, 1022);
INSERT INTO chado.cvterm_relationship VALUES (2839, 211, 2577, 682);
INSERT INTO chado.cvterm_relationship VALUES (2840, 234, 2577, 1535);
INSERT INTO chado.cvterm_relationship VALUES (2841, 211, 2578, 1845);
INSERT INTO chado.cvterm_relationship VALUES (2842, 211, 2579, 2578);
INSERT INTO chado.cvterm_relationship VALUES (2843, 211, 2580, 2578);
INSERT INTO chado.cvterm_relationship VALUES (2844, 211, 2581, 2342);
INSERT INTO chado.cvterm_relationship VALUES (2845, 211, 2581, 2580);
INSERT INTO chado.cvterm_relationship VALUES (2846, 211, 2582, 1845);
INSERT INTO chado.cvterm_relationship VALUES (2847, 211, 2583, 1848);
INSERT INTO chado.cvterm_relationship VALUES (2848, 211, 2584, 1848);
INSERT INTO chado.cvterm_relationship VALUES (2849, 211, 2585, 1904);
INSERT INTO chado.cvterm_relationship VALUES (2850, 211, 2585, 2583);
INSERT INTO chado.cvterm_relationship VALUES (2851, 211, 2586, 1904);
INSERT INTO chado.cvterm_relationship VALUES (2852, 211, 2586, 2584);
INSERT INTO chado.cvterm_relationship VALUES (2853, 211, 2587, 1906);
INSERT INTO chado.cvterm_relationship VALUES (2854, 211, 2587, 2583);
INSERT INTO chado.cvterm_relationship VALUES (2855, 211, 2588, 1906);
INSERT INTO chado.cvterm_relationship VALUES (2856, 211, 2588, 2584);
INSERT INTO chado.cvterm_relationship VALUES (2857, 211, 2589, 1891);
INSERT INTO chado.cvterm_relationship VALUES (2858, 211, 2589, 2583);
INSERT INTO chado.cvterm_relationship VALUES (2859, 211, 2590, 1891);
INSERT INTO chado.cvterm_relationship VALUES (2860, 211, 2590, 2584);
INSERT INTO chado.cvterm_relationship VALUES (2861, 211, 2591, 1889);
INSERT INTO chado.cvterm_relationship VALUES (2862, 211, 2591, 2583);
INSERT INTO chado.cvterm_relationship VALUES (2863, 211, 2592, 1889);
INSERT INTO chado.cvterm_relationship VALUES (2864, 211, 2592, 2584);
INSERT INTO chado.cvterm_relationship VALUES (2865, 211, 2593, 1541);
INSERT INTO chado.cvterm_relationship VALUES (2866, 211, 2594, 1541);
INSERT INTO chado.cvterm_relationship VALUES (2867, 211, 694, 262);
INSERT INTO chado.cvterm_relationship VALUES (2868, 241, 694, 671);
INSERT INTO chado.cvterm_relationship VALUES (2869, 211, 2595, 671);
INSERT INTO chado.cvterm_relationship VALUES (2870, 230, 2595, 462);
INSERT INTO chado.cvterm_relationship VALUES (2871, 211, 2596, 686);
INSERT INTO chado.cvterm_relationship VALUES (2872, 211, 2597, 686);
INSERT INTO chado.cvterm_relationship VALUES (2873, 211, 2598, 686);
INSERT INTO chado.cvterm_relationship VALUES (2874, 211, 2599, 2515);
INSERT INTO chado.cvterm_relationship VALUES (2875, 211, 2600, 756);
INSERT INTO chado.cvterm_relationship VALUES (2876, 216, 2600, 2599);
INSERT INTO chado.cvterm_relationship VALUES (2877, 211, 2601, 627);
INSERT INTO chado.cvterm_relationship VALUES (2878, 211, 2602, 1589);
INSERT INTO chado.cvterm_relationship VALUES (2879, 211, 2603, 282);
INSERT INTO chado.cvterm_relationship VALUES (2880, 211, 2604, 1584);
INSERT INTO chado.cvterm_relationship VALUES (2881, 211, 1587, 1584);
INSERT INTO chado.cvterm_relationship VALUES (2882, 211, 1059, 604);
INSERT INTO chado.cvterm_relationship VALUES (2883, 211, 2605, 2416);
INSERT INTO chado.cvterm_relationship VALUES (2884, 211, 2606, 2416);
INSERT INTO chado.cvterm_relationship VALUES (2885, 211, 2607, 604);
INSERT INTO chado.cvterm_relationship VALUES (2886, 211, 2608, 2607);
INSERT INTO chado.cvterm_relationship VALUES (2887, 211, 2609, 2607);
INSERT INTO chado.cvterm_relationship VALUES (2888, 211, 2610, 1362);
INSERT INTO chado.cvterm_relationship VALUES (2889, 211, 2611, 2610);
INSERT INTO chado.cvterm_relationship VALUES (2890, 211, 2612, 2610);
INSERT INTO chado.cvterm_relationship VALUES (2891, 211, 2613, 282);
INSERT INTO chado.cvterm_relationship VALUES (2892, 211, 2614, 1584);
INSERT INTO chado.cvterm_relationship VALUES (2893, 211, 2615, 282);
INSERT INTO chado.cvterm_relationship VALUES (2894, 211, 2616, 1584);
INSERT INTO chado.cvterm_relationship VALUES (2895, 211, 2617, 282);
INSERT INTO chado.cvterm_relationship VALUES (2896, 211, 2618, 262);
INSERT INTO chado.cvterm_relationship VALUES (2897, 211, 2619, 1584);
INSERT INTO chado.cvterm_relationship VALUES (2898, 211, 2620, 1584);
INSERT INTO chado.cvterm_relationship VALUES (2899, 211, 2621, 1955);
INSERT INTO chado.cvterm_relationship VALUES (2900, 211, 2515, 2621);
INSERT INTO chado.cvterm_relationship VALUES (2901, 211, 2514, 2621);
INSERT INTO chado.cvterm_relationship VALUES (2902, 211, 2622, 387);
INSERT INTO chado.cvterm_relationship VALUES (2903, 211, 2622, 1955);
INSERT INTO chado.cvterm_relationship VALUES (2904, 211, 2623, 2622);
INSERT INTO chado.cvterm_relationship VALUES (2905, 211, 2624, 2622);
INSERT INTO chado.cvterm_relationship VALUES (2906, 211, 2625, 391);
INSERT INTO chado.cvterm_relationship VALUES (2907, 211, 2625, 1955);
INSERT INTO chado.cvterm_relationship VALUES (2908, 211, 2626, 2625);
INSERT INTO chado.cvterm_relationship VALUES (2909, 211, 2627, 2625);
INSERT INTO chado.cvterm_relationship VALUES (2910, 211, 2628, 2384);
INSERT INTO chado.cvterm_relationship VALUES (2911, 211, 2629, 2384);
INSERT INTO chado.cvterm_relationship VALUES (2912, 211, 2630, 2384);
INSERT INTO chado.cvterm_relationship VALUES (2913, 211, 2631, 2602);
INSERT INTO chado.cvterm_relationship VALUES (2914, 211, 2632, 2602);
INSERT INTO chado.cvterm_relationship VALUES (2915, 211, 2633, 2602);
INSERT INTO chado.cvterm_relationship VALUES (2916, 211, 2634, 1589);
INSERT INTO chado.cvterm_relationship VALUES (2917, 211, 2635, 1589);
INSERT INTO chado.cvterm_relationship VALUES (2918, 211, 2636, 2634);
INSERT INTO chado.cvterm_relationship VALUES (2919, 211, 2637, 2634);
INSERT INTO chado.cvterm_relationship VALUES (2920, 211, 2638, 2634);
INSERT INTO chado.cvterm_relationship VALUES (2921, 211, 2639, 2635);
INSERT INTO chado.cvterm_relationship VALUES (2922, 211, 2640, 1776);
INSERT INTO chado.cvterm_relationship VALUES (2923, 211, 1391, 1082);
INSERT INTO chado.cvterm_relationship VALUES (2924, 211, 788, 580);
INSERT INTO chado.cvterm_relationship VALUES (2925, 211, 2641, 787);
INSERT INTO chado.cvterm_relationship VALUES (2926, 216, 2641, 991);
INSERT INTO chado.cvterm_relationship VALUES (2927, 211, 2642, 282);
INSERT INTO chado.cvterm_relationship VALUES (2928, 216, 2642, 993);
INSERT INTO chado.cvterm_relationship VALUES (2929, 211, 2643, 481);
INSERT INTO chado.cvterm_relationship VALUES (2930, 211, 2644, 2645);
INSERT INTO chado.cvterm_relationship VALUES (2931, 211, 2645, 378);
INSERT INTO chado.cvterm_relationship VALUES (2932, 211, 2646, 378);
INSERT INTO chado.cvterm_relationship VALUES (2933, 211, 2647, 1280);
INSERT INTO chado.cvterm_relationship VALUES (2934, 234, 2647, 532);
INSERT INTO chado.cvterm_relationship VALUES (2935, 211, 2648, 524);
INSERT INTO chado.cvterm_relationship VALUES (2936, 211, 2649, 524);
INSERT INTO chado.cvterm_relationship VALUES (2937, 211, 2650, 163);
INSERT INTO chado.cvterm_relationship VALUES (2938, 211, 2274, 524);
INSERT INTO chado.cvterm_relationship VALUES (2939, 228, 2274, 2650);
INSERT INTO chado.cvterm_relationship VALUES (2940, 211, 524, 262);
INSERT INTO chado.cvterm_relationship VALUES (2941, 211, 2651, 558);
INSERT INTO chado.cvterm_relationship VALUES (2942, 211, 2652, 605);
INSERT INTO chado.cvterm_relationship VALUES (2943, 216, 2652, 2651);
INSERT INTO chado.cvterm_relationship VALUES (2944, 211, 2653, 704);
INSERT INTO chado.cvterm_relationship VALUES (2945, 230, 2653, 1232);
INSERT INTO chado.cvterm_relationship VALUES (2946, 211, 1421, 1399);
INSERT INTO chado.cvterm_relationship VALUES (2947, 211, 1426, 1421);
INSERT INTO chado.cvterm_relationship VALUES (2948, 211, 2654, 806);
INSERT INTO chado.cvterm_relationship VALUES (2949, 211, 2655, 1408);
INSERT INTO chado.cvterm_relationship VALUES (2950, 211, 2656, 1408);
INSERT INTO chado.cvterm_relationship VALUES (2951, 211, 2657, 1408);
INSERT INTO chado.cvterm_relationship VALUES (2952, 211, 2658, 1408);
INSERT INTO chado.cvterm_relationship VALUES (2953, 211, 2659, 1408);
INSERT INTO chado.cvterm_relationship VALUES (2954, 211, 2660, 1101);
INSERT INTO chado.cvterm_relationship VALUES (2955, 211, 2661, 1114);
INSERT INTO chado.cvterm_relationship VALUES (2956, 211, 1101, 813);
INSERT INTO chado.cvterm_relationship VALUES (2957, 234, 1101, 815);
INSERT INTO chado.cvterm_relationship VALUES (2958, 211, 2662, 1408);
INSERT INTO chado.cvterm_relationship VALUES (2959, 211, 2663, 813);
INSERT INTO chado.cvterm_relationship VALUES (2960, 211, 2664, 1101);
INSERT INTO chado.cvterm_relationship VALUES (2961, 234, 2664, 808);
INSERT INTO chado.cvterm_relationship VALUES (2962, 211, 2665, 1101);
INSERT INTO chado.cvterm_relationship VALUES (2963, 234, 2665, 808);
INSERT INTO chado.cvterm_relationship VALUES (2964, 211, 2666, 1101);
INSERT INTO chado.cvterm_relationship VALUES (2965, 234, 2666, 808);
INSERT INTO chado.cvterm_relationship VALUES (2966, 211, 2108, 1399);
INSERT INTO chado.cvterm_relationship VALUES (2967, 211, 2667, 1421);
INSERT INTO chado.cvterm_relationship VALUES (2968, 211, 1440, 1421);
INSERT INTO chado.cvterm_relationship VALUES (2969, 211, 2668, 1742);
INSERT INTO chado.cvterm_relationship VALUES (2970, 211, 2668, 1426);
INSERT INTO chado.cvterm_relationship VALUES (2971, 211, 807, 813);
INSERT INTO chado.cvterm_relationship VALUES (2972, 211, 1796, 496);
INSERT INTO chado.cvterm_relationship VALUES (2973, 211, 1796, 262);
INSERT INTO chado.cvterm_relationship VALUES (2974, 211, 2669, 1796);
INSERT INTO chado.cvterm_relationship VALUES (2975, 211, 2670, 1106);
INSERT INTO chado.cvterm_relationship VALUES (2976, 211, 2671, 1106);
INSERT INTO chado.cvterm_relationship VALUES (2977, 211, 2672, 2671);
INSERT INTO chado.cvterm_relationship VALUES (2978, 211, 2673, 2672);
INSERT INTO chado.cvterm_relationship VALUES (2979, 211, 2674, 2673);
INSERT INTO chado.cvterm_relationship VALUES (2980, 211, 2675, 2672);
INSERT INTO chado.cvterm_relationship VALUES (2981, 211, 2676, 2671);
INSERT INTO chado.cvterm_relationship VALUES (2982, 211, 2677, 2676);
INSERT INTO chado.cvterm_relationship VALUES (2983, 211, 2678, 2676);
INSERT INTO chado.cvterm_relationship VALUES (2984, 211, 2679, 1106);
INSERT INTO chado.cvterm_relationship VALUES (2985, 211, 2680, 2679);
INSERT INTO chado.cvterm_relationship VALUES (2986, 211, 2681, 2680);
INSERT INTO chado.cvterm_relationship VALUES (2987, 211, 2682, 2680);
INSERT INTO chado.cvterm_relationship VALUES (2988, 211, 2683, 2680);
INSERT INTO chado.cvterm_relationship VALUES (2989, 211, 2684, 2680);
INSERT INTO chado.cvterm_relationship VALUES (2990, 211, 2685, 2679);
INSERT INTO chado.cvterm_relationship VALUES (2991, 211, 2686, 2685);
INSERT INTO chado.cvterm_relationship VALUES (2992, 211, 2687, 2685);
INSERT INTO chado.cvterm_relationship VALUES (2993, 211, 2688, 2685);
INSERT INTO chado.cvterm_relationship VALUES (2994, 211, 2689, 2685);
INSERT INTO chado.cvterm_relationship VALUES (2995, 211, 2690, 359);
INSERT INTO chado.cvterm_relationship VALUES (2996, 230, 2690, 1821);
INSERT INTO chado.cvterm_relationship VALUES (2997, 211, 352, 2690);
INSERT INTO chado.cvterm_relationship VALUES (2998, 228, 352, 354);
INSERT INTO chado.cvterm_relationship VALUES (2999, 211, 841, 2690);
INSERT INTO chado.cvterm_relationship VALUES (3000, 228, 841, 752);
INSERT INTO chado.cvterm_relationship VALUES (3001, 211, 2691, 359);
INSERT INTO chado.cvterm_relationship VALUES (3002, 230, 2691, 1822);
INSERT INTO chado.cvterm_relationship VALUES (3003, 211, 2692, 496);
INSERT INTO chado.cvterm_relationship VALUES (3004, 211, 2221, 1077);
INSERT INTO chado.cvterm_relationship VALUES (3005, 211, 752, 496);
INSERT INTO chado.cvterm_relationship VALUES (3006, 211, 752, 262);
INSERT INTO chado.cvterm_relationship VALUES (3007, 211, 860, 359);
INSERT INTO chado.cvterm_relationship VALUES (3008, 211, 870, 2690);
INSERT INTO chado.cvterm_relationship VALUES (3009, 211, 870, 860);
INSERT INTO chado.cvterm_relationship VALUES (3010, 228, 870, 2221);
INSERT INTO chado.cvterm_relationship VALUES (3011, 211, 2693, 2694);
INSERT INTO chado.cvterm_relationship VALUES (3012, 211, 2695, 2694);
INSERT INTO chado.cvterm_relationship VALUES (3013, 211, 353, 854);
INSERT INTO chado.cvterm_relationship VALUES (3014, 211, 353, 870);
INSERT INTO chado.cvterm_relationship VALUES (3015, 228, 353, 548);
INSERT INTO chado.cvterm_relationship VALUES (3016, 228, 353, 2221);
INSERT INTO chado.cvterm_relationship VALUES (3017, 211, 349, 359);
INSERT INTO chado.cvterm_relationship VALUES (3018, 211, 2696, 1096);
INSERT INTO chado.cvterm_relationship VALUES (3019, 211, 1096, 548);
INSERT INTO chado.cvterm_relationship VALUES (3020, 211, 1096, 2691);
INSERT INTO chado.cvterm_relationship VALUES (3021, 211, 842, 2690);
INSERT INTO chado.cvterm_relationship VALUES (3022, 230, 842, 1301);
INSERT INTO chado.cvterm_relationship VALUES (3023, 211, 2697, 841);
INSERT INTO chado.cvterm_relationship VALUES (3024, 230, 2697, 1830);
INSERT INTO chado.cvterm_relationship VALUES (3025, 211, 2698, 841);
INSERT INTO chado.cvterm_relationship VALUES (3026, 230, 2698, 1831);
INSERT INTO chado.cvterm_relationship VALUES (3027, 211, 2699, 1096);
INSERT INTO chado.cvterm_relationship VALUES (3028, 211, 2773, 359);
INSERT INTO chado.cvterm_relationship VALUES (3029, 211, 2774, 349);
INSERT INTO chado.cvterm_relationship VALUES (3030, 211, 2775, 349);
INSERT INTO chado.cvterm_relationship VALUES (3031, 211, 2776, 2690);
INSERT INTO chado.cvterm_relationship VALUES (3032, 211, 2777, 2773);
INSERT INTO chado.cvterm_relationship VALUES (3033, 211, 2778, 2773);
INSERT INTO chado.cvterm_relationship VALUES (3034, 211, 2779, 860);
INSERT INTO chado.cvterm_relationship VALUES (3035, 211, 2780, 842);
INSERT INTO chado.cvterm_relationship VALUES (3036, 211, 2780, 2779);
INSERT INTO chado.cvterm_relationship VALUES (3037, 230, 2780, 1827);
INSERT INTO chado.cvterm_relationship VALUES (3038, 211, 2781, 352);
INSERT INTO chado.cvterm_relationship VALUES (3039, 211, 2781, 1096);
INSERT INTO chado.cvterm_relationship VALUES (3040, 228, 2781, 354);
INSERT INTO chado.cvterm_relationship VALUES (3041, 211, 2782, 841);
INSERT INTO chado.cvterm_relationship VALUES (3042, 211, 2782, 1096);
INSERT INTO chado.cvterm_relationship VALUES (3043, 228, 2782, 752);
INSERT INTO chado.cvterm_relationship VALUES (3044, 211, 2783, 2691);
INSERT INTO chado.cvterm_relationship VALUES (3045, 211, 2783, 870);
INSERT INTO chado.cvterm_relationship VALUES (3046, 211, 2784, 2347);
INSERT INTO chado.cvterm_relationship VALUES (3047, 211, 2785, 841);
INSERT INTO chado.cvterm_relationship VALUES (3048, 211, 2786, 2787);
INSERT INTO chado.cvterm_relationship VALUES (3049, 211, 2788, 2787);
INSERT INTO chado.cvterm_relationship VALUES (3050, 211, 2787, 860);
INSERT INTO chado.cvterm_relationship VALUES (3051, 211, 356, 854);
INSERT INTO chado.cvterm_relationship VALUES (3052, 211, 356, 2691);
INSERT INTO chado.cvterm_relationship VALUES (3053, 211, 2789, 356);
INSERT INTO chado.cvterm_relationship VALUES (3054, 211, 2790, 356);
INSERT INTO chado.cvterm_relationship VALUES (3055, 211, 2791, 2782);
INSERT INTO chado.cvterm_relationship VALUES (3056, 228, 2791, 752);
INSERT INTO chado.cvterm_relationship VALUES (3057, 211, 2792, 353);
INSERT INTO chado.cvterm_relationship VALUES (3058, 228, 2792, 1825);
INSERT INTO chado.cvterm_relationship VALUES (3059, 211, 2793, 2787);
INSERT INTO chado.cvterm_relationship VALUES (3060, 211, 2794, 356);
INSERT INTO chado.cvterm_relationship VALUES (3061, 211, 2795, 353);
INSERT INTO chado.cvterm_relationship VALUES (3062, 211, 2796, 359);
INSERT INTO chado.cvterm_relationship VALUES (3063, 211, 2797, 352);
INSERT INTO chado.cvterm_relationship VALUES (3064, 211, 2797, 841);
INSERT INTO chado.cvterm_relationship VALUES (3065, 228, 2797, 354);
INSERT INTO chado.cvterm_relationship VALUES (3066, 228, 2797, 752);
INSERT INTO chado.cvterm_relationship VALUES (3067, 211, 2694, 2221);
INSERT INTO chado.cvterm_relationship VALUES (3068, 211, 2798, 2796);
INSERT INTO chado.cvterm_relationship VALUES (3069, 211, 340, 589);
INSERT INTO chado.cvterm_relationship VALUES (3070, 211, 359, 589);
INSERT INTO chado.cvterm_relationship VALUES (3071, 211, 2805, 373);
INSERT INTO chado.cvterm_relationship VALUES (3072, 230, 2805, 1238);
INSERT INTO chado.cvterm_relationship VALUES (3073, 211, 2806, 867);
INSERT INTO chado.cvterm_relationship VALUES (3074, 211, 2807, 867);
INSERT INTO chado.cvterm_relationship VALUES (3075, 211, 2808, 2809);
INSERT INTO chado.cvterm_relationship VALUES (3076, 211, 2810, 2809);
INSERT INTO chado.cvterm_relationship VALUES (3077, 211, 2811, 2807);
INSERT INTO chado.cvterm_relationship VALUES (3078, 211, 2812, 2809);
INSERT INTO chado.cvterm_relationship VALUES (3079, 211, 2809, 2807);
INSERT INTO chado.cvterm_relationship VALUES (3080, 211, 2814, 1064);
INSERT INTO chado.cvterm_relationship VALUES (3081, 211, 2814, 1743);
INSERT INTO chado.cvterm_relationship VALUES (3082, 230, 2814, 1318);
INSERT INTO chado.cvterm_relationship VALUES (3083, 211, 1131, 375);
INSERT INTO chado.cvterm_relationship VALUES (3084, 211, 1131, 1040);
INSERT INTO chado.cvterm_relationship VALUES (3085, 230, 1131, 376);
INSERT INTO chado.cvterm_relationship VALUES (3086, 211, 2815, 378);
INSERT INTO chado.cvterm_relationship VALUES (3087, 211, 2817, 421);
INSERT INTO chado.cvterm_relationship VALUES (3088, 230, 2817, 1250);
INSERT INTO chado.cvterm_relationship VALUES (3089, 211, 2818, 2819);
INSERT INTO chado.cvterm_relationship VALUES (3090, 229, 2818, 1254);
INSERT INTO chado.cvterm_relationship VALUES (3091, 211, 2820, 2361);
INSERT INTO chado.cvterm_relationship VALUES (3092, 230, 2820, 1252);
INSERT INTO chado.cvterm_relationship VALUES (3093, 211, 2361, 2819);
INSERT INTO chado.cvterm_relationship VALUES (3094, 230, 2361, 1251);
INSERT INTO chado.cvterm_relationship VALUES (3095, 211, 2819, 421);
INSERT INTO chado.cvterm_relationship VALUES (3096, 230, 2819, 1142);
INSERT INTO chado.cvterm_relationship VALUES (3097, 211, 2822, 2361);
INSERT INTO chado.cvterm_relationship VALUES (3098, 230, 2822, 1253);
INSERT INTO chado.cvterm_relationship VALUES (3099, 211, 2823, 594);
INSERT INTO chado.cvterm_relationship VALUES (3100, 211, 2823, 962);
INSERT INTO chado.cvterm_relationship VALUES (3101, 211, 2824, 164);
INSERT INTO chado.cvterm_relationship VALUES (3102, 230, 2824, 1104);
INSERT INTO chado.cvterm_relationship VALUES (3103, 211, 2825, 441);
INSERT INTO chado.cvterm_relationship VALUES (3104, 211, 2826, 441);
INSERT INTO chado.cvterm_relationship VALUES (3105, 211, 2827, 2824);
INSERT INTO chado.cvterm_relationship VALUES (3106, 230, 2827, 1123);
INSERT INTO chado.cvterm_relationship VALUES (3107, 211, 2828, 2824);
INSERT INTO chado.cvterm_relationship VALUES (3108, 230, 2828, 1239);
INSERT INTO chado.cvterm_relationship VALUES (3109, 211, 962, 312);
INSERT INTO chado.cvterm_relationship VALUES (3110, 211, 2831, 1090);
INSERT INTO chado.cvterm_relationship VALUES (3111, 211, 2833, 1545);
INSERT INTO chado.cvterm_relationship VALUES (3112, 211, 2834, 1545);
INSERT INTO chado.cvterm_relationship VALUES (3113, 211, 2835, 1090);
INSERT INTO chado.cvterm_relationship VALUES (3114, 211, 2836, 962);
INSERT INTO chado.cvterm_relationship VALUES (3115, 211, 2837, 262);
INSERT INTO chado.cvterm_relationship VALUES (3116, 211, 2838, 962);
INSERT INTO chado.cvterm_relationship VALUES (3117, 211, 2839, 2838);
INSERT INTO chado.cvterm_relationship VALUES (3118, 211, 2840, 962);
INSERT INTO chado.cvterm_relationship VALUES (3119, 211, 2841, 2838);
INSERT INTO chado.cvterm_relationship VALUES (3120, 211, 2842, 2843);
INSERT INTO chado.cvterm_relationship VALUES (3121, 211, 2844, 2843);
INSERT INTO chado.cvterm_relationship VALUES (3122, 211, 2568, 524);
INSERT INTO chado.cvterm_relationship VALUES (3123, 228, 2568, 1083);
INSERT INTO chado.cvterm_relationship VALUES (3124, 211, 2845, 2843);
INSERT INTO chado.cvterm_relationship VALUES (3125, 211, 2846, 2838);
INSERT INTO chado.cvterm_relationship VALUES (3126, 211, 2847, 2838);
INSERT INTO chado.cvterm_relationship VALUES (3127, 211, 2843, 962);
INSERT INTO chado.cvterm_relationship VALUES (3128, 211, 2848, 269);
INSERT INTO chado.cvterm_relationship VALUES (3129, 211, 2049, 508);
INSERT INTO chado.cvterm_relationship VALUES (3130, 2850, 2852, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3131, 2850, 2853, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3132, 2850, 2854, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3133, 2850, 2855, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3134, 2850, 169, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3135, 2850, 170, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3136, 2850, 2856, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3137, 2850, 2857, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3138, 2850, 2858, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3139, 2850, 2859, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3140, 2850, 2860, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3141, 2850, 2861, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3142, 2850, 2862, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3143, 2850, 2863, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3144, 2850, 2864, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3145, 2850, 2865, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3146, 2850, 2866, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3147, 2850, 2867, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3148, 2850, 2868, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3149, 2850, 2869, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3150, 2850, 2870, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3151, 2850, 2871, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3152, 2850, 2872, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3153, 2850, 2873, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3154, 2850, 2874, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3155, 2850, 2875, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3156, 2850, 2876, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3157, 2850, 2877, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3158, 2850, 2878, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3159, 2850, 2879, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3160, 2850, 2880, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3161, 2850, 2881, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3162, 2850, 2882, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3163, 2850, 2883, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3164, 2850, 2884, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3165, 2850, 2885, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3166, 2850, 2886, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3167, 2850, 2887, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3168, 2850, 2888, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3169, 2850, 2889, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3170, 2850, 2890, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3171, 2850, 2891, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3172, 2850, 2892, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3173, 2850, 2893, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3174, 2850, 171, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3175, 2850, 2894, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3176, 2850, 2895, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3177, 2850, 2896, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3178, 2850, 2897, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3179, 2850, 2898, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3180, 2850, 2899, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3181, 2850, 2900, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3182, 2850, 2901, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3183, 2850, 2902, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3184, 2850, 2903, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3185, 2850, 2904, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3186, 2850, 2905, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3187, 2850, 2906, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3188, 2850, 2907, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3189, 2850, 2908, 2851);
INSERT INTO chado.cvterm_relationship VALUES (3190, 2909, 2912, 2911);
INSERT INTO chado.cvterm_relationship VALUES (3191, 2909, 2913, 2911);
INSERT INTO chado.cvterm_relationship VALUES (3192, 2909, 2914, 2911);
INSERT INTO chado.cvterm_relationship VALUES (3193, 2909, 2915, 2911);
INSERT INTO chado.cvterm_relationship VALUES (3194, 2909, 2916, 2911);
INSERT INTO chado.cvterm_relationship VALUES (3195, 2909, 2917, 2911);
INSERT INTO chado.cvterm_relationship VALUES (3196, 2909, 2918, 2911);
INSERT INTO chado.cvterm_relationship VALUES (3197, 2909, 2919, 2911);
INSERT INTO chado.cvterm_relationship VALUES (3198, 2910, 2920, 2913);
INSERT INTO chado.cvterm_relationship VALUES (3199, 2910, 2921, 2913);
INSERT INTO chado.cvterm_relationship VALUES (3200, 2910, 2922, 2913);
INSERT INTO chado.cvterm_relationship VALUES (3201, 2910, 2923, 2913);
INSERT INTO chado.cvterm_relationship VALUES (3202, 2910, 2924, 2913);
INSERT INTO chado.cvterm_relationship VALUES (3203, 2910, 2926, 2925);
INSERT INTO chado.cvterm_relationship VALUES (3204, 2910, 2927, 2925);
INSERT INTO chado.cvterm_relationship VALUES (3205, 2910, 2928, 2925);
INSERT INTO chado.cvterm_relationship VALUES (3206, 2910, 2930, 2929);
INSERT INTO chado.cvterm_relationship VALUES (3207, 2910, 2931, 2929);
INSERT INTO chado.cvterm_relationship VALUES (3208, 2910, 2932, 2929);
INSERT INTO chado.cvterm_relationship VALUES (3209, 2910, 2933, 2929);
INSERT INTO chado.cvterm_relationship VALUES (3210, 2910, 2934, 2929);
INSERT INTO chado.cvterm_relationship VALUES (3211, 2910, 2935, 2929);
INSERT INTO chado.cvterm_relationship VALUES (3212, 2910, 2936, 2929);
INSERT INTO chado.cvterm_relationship VALUES (3213, 2910, 2937, 2929);
INSERT INTO chado.cvterm_relationship VALUES (3214, 2940, 2941, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3215, 2940, 173, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3216, 2939, 2943, 174);
INSERT INTO chado.cvterm_relationship VALUES (3217, 2940, 2944, 2941);
INSERT INTO chado.cvterm_relationship VALUES (3218, 2939, 2945, 174);
INSERT INTO chado.cvterm_relationship VALUES (3219, 2940, 2945, 2946);
INSERT INTO chado.cvterm_relationship VALUES (3220, 2939, 2947, 174);
INSERT INTO chado.cvterm_relationship VALUES (3221, 2939, 2948, 174);
INSERT INTO chado.cvterm_relationship VALUES (3222, 2940, 2949, 2941);
INSERT INTO chado.cvterm_relationship VALUES (3223, 2939, 2950, 2951);
INSERT INTO chado.cvterm_relationship VALUES (3224, 2940, 2952, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3225, 2939, 2953, 174);
INSERT INTO chado.cvterm_relationship VALUES (3226, 2939, 2954, 174);
INSERT INTO chado.cvterm_relationship VALUES (3227, 2939, 2955, 174);
INSERT INTO chado.cvterm_relationship VALUES (3228, 2940, 174, 172);
INSERT INTO chado.cvterm_relationship VALUES (3229, 2940, 2946, 172);
INSERT INTO chado.cvterm_relationship VALUES (3230, 2939, 2956, 2951);
INSERT INTO chado.cvterm_relationship VALUES (3231, 2939, 2957, 2951);
INSERT INTO chado.cvterm_relationship VALUES (3232, 2940, 2942, 172);
INSERT INTO chado.cvterm_relationship VALUES (3233, 2939, 2958, 2959);
INSERT INTO chado.cvterm_relationship VALUES (3234, 2940, 2958, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3235, 2940, 2960, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3236, 2939, 2961, 174);
INSERT INTO chado.cvterm_relationship VALUES (3237, 2939, 2962, 174);
INSERT INTO chado.cvterm_relationship VALUES (3238, 2940, 2963, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3239, 2940, 2964, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3240, 2940, 2965, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3241, 2940, 2966, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3242, 2940, 2951, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3243, 2940, 2967, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3244, 2940, 2968, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3245, 2939, 2969, 2970);
INSERT INTO chado.cvterm_relationship VALUES (3246, 2940, 2971, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3247, 2940, 2972, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3248, 2940, 2973, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3249, 2940, 2974, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3250, 2940, 2975, 2951);
INSERT INTO chado.cvterm_relationship VALUES (3251, 2940, 2976, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3252, 2940, 2977, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3253, 2940, 2978, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3254, 2940, 2979, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3255, 2940, 2980, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3256, 2939, 2981, 2968);
INSERT INTO chado.cvterm_relationship VALUES (3257, 2939, 2982, 174);
INSERT INTO chado.cvterm_relationship VALUES (3258, 2939, 2983, 2968);
INSERT INTO chado.cvterm_relationship VALUES (3259, 2939, 2984, 2982);
INSERT INTO chado.cvterm_relationship VALUES (3260, 2939, 2985, 2982);
INSERT INTO chado.cvterm_relationship VALUES (3261, 2939, 2986, 2987);
INSERT INTO chado.cvterm_relationship VALUES (3262, 2940, 2986, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3263, 2939, 2988, 2982);
INSERT INTO chado.cvterm_relationship VALUES (3264, 2940, 2989, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3265, 2939, 2990, 2982);
INSERT INTO chado.cvterm_relationship VALUES (3266, 2940, 2991, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3267, 2940, 2970, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3268, 2940, 2992, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3269, 2939, 2993, 2992);
INSERT INTO chado.cvterm_relationship VALUES (3270, 2940, 2994, 2971);
INSERT INTO chado.cvterm_relationship VALUES (3271, 2940, 2995, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3272, 2940, 2996, 2946);
INSERT INTO chado.cvterm_relationship VALUES (3273, 2939, 2997, 2976);
INSERT INTO chado.cvterm_relationship VALUES (3274, 2940, 2998, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3275, 2939, 2999, 174);
INSERT INTO chado.cvterm_relationship VALUES (3276, 2939, 3000, 174);
INSERT INTO chado.cvterm_relationship VALUES (3277, 2939, 3001, 174);
INSERT INTO chado.cvterm_relationship VALUES (3278, 2939, 3002, 174);
INSERT INTO chado.cvterm_relationship VALUES (3279, 2939, 3003, 174);
INSERT INTO chado.cvterm_relationship VALUES (3280, 2939, 3004, 174);
INSERT INTO chado.cvterm_relationship VALUES (3281, 2939, 3005, 174);
INSERT INTO chado.cvterm_relationship VALUES (3282, 2939, 3006, 174);
INSERT INTO chado.cvterm_relationship VALUES (3283, 2939, 3007, 174);
INSERT INTO chado.cvterm_relationship VALUES (3284, 2939, 3008, 174);
INSERT INTO chado.cvterm_relationship VALUES (3285, 2939, 3009, 174);
INSERT INTO chado.cvterm_relationship VALUES (3286, 2939, 3010, 174);
INSERT INTO chado.cvterm_relationship VALUES (3287, 2939, 3011, 174);
INSERT INTO chado.cvterm_relationship VALUES (3288, 2939, 3012, 174);
INSERT INTO chado.cvterm_relationship VALUES (3289, 2939, 3013, 174);
INSERT INTO chado.cvterm_relationship VALUES (3290, 2939, 3014, 174);
INSERT INTO chado.cvterm_relationship VALUES (3291, 2939, 3015, 174);
INSERT INTO chado.cvterm_relationship VALUES (3292, 2939, 3016, 174);
INSERT INTO chado.cvterm_relationship VALUES (3293, 2939, 3017, 174);
INSERT INTO chado.cvterm_relationship VALUES (3294, 2939, 3018, 174);
INSERT INTO chado.cvterm_relationship VALUES (3295, 2939, 3019, 174);
INSERT INTO chado.cvterm_relationship VALUES (3296, 2939, 3020, 174);
INSERT INTO chado.cvterm_relationship VALUES (3297, 2939, 3021, 174);
INSERT INTO chado.cvterm_relationship VALUES (3298, 2939, 3022, 174);
INSERT INTO chado.cvterm_relationship VALUES (3299, 2939, 3023, 174);
INSERT INTO chado.cvterm_relationship VALUES (3300, 2939, 3024, 174);
INSERT INTO chado.cvterm_relationship VALUES (3301, 2939, 3025, 174);
INSERT INTO chado.cvterm_relationship VALUES (3302, 2939, 3026, 174);
INSERT INTO chado.cvterm_relationship VALUES (3303, 2939, 3027, 174);
INSERT INTO chado.cvterm_relationship VALUES (3304, 2939, 3028, 174);
INSERT INTO chado.cvterm_relationship VALUES (3305, 2939, 3029, 174);
INSERT INTO chado.cvterm_relationship VALUES (3306, 2939, 3030, 174);
INSERT INTO chado.cvterm_relationship VALUES (3307, 2939, 3031, 174);
INSERT INTO chado.cvterm_relationship VALUES (3308, 2939, 3032, 174);
INSERT INTO chado.cvterm_relationship VALUES (3309, 2939, 3033, 174);
INSERT INTO chado.cvterm_relationship VALUES (3310, 2939, 3034, 174);
INSERT INTO chado.cvterm_relationship VALUES (3311, 2939, 3035, 174);
INSERT INTO chado.cvterm_relationship VALUES (3312, 2939, 3036, 174);
INSERT INTO chado.cvterm_relationship VALUES (3313, 2939, 3037, 174);
INSERT INTO chado.cvterm_relationship VALUES (3314, 2939, 3038, 174);
INSERT INTO chado.cvterm_relationship VALUES (3315, 2939, 3039, 174);
INSERT INTO chado.cvterm_relationship VALUES (3316, 2939, 3040, 174);
INSERT INTO chado.cvterm_relationship VALUES (3317, 2939, 3041, 174);
INSERT INTO chado.cvterm_relationship VALUES (3318, 2939, 3042, 174);
INSERT INTO chado.cvterm_relationship VALUES (3319, 2939, 3043, 174);
INSERT INTO chado.cvterm_relationship VALUES (3320, 2939, 3044, 174);
INSERT INTO chado.cvterm_relationship VALUES (3321, 2939, 3045, 174);
INSERT INTO chado.cvterm_relationship VALUES (3322, 2939, 3046, 174);
INSERT INTO chado.cvterm_relationship VALUES (3323, 2939, 3047, 174);
INSERT INTO chado.cvterm_relationship VALUES (3324, 2939, 3048, 174);
INSERT INTO chado.cvterm_relationship VALUES (3325, 2939, 3049, 174);
INSERT INTO chado.cvterm_relationship VALUES (3326, 2939, 3050, 174);
INSERT INTO chado.cvterm_relationship VALUES (3327, 2939, 3051, 174);
INSERT INTO chado.cvterm_relationship VALUES (3328, 2939, 3052, 174);
INSERT INTO chado.cvterm_relationship VALUES (3329, 2939, 3053, 174);
INSERT INTO chado.cvterm_relationship VALUES (3330, 2939, 3054, 174);
INSERT INTO chado.cvterm_relationship VALUES (3331, 2939, 3055, 174);
INSERT INTO chado.cvterm_relationship VALUES (3332, 2939, 3056, 174);
INSERT INTO chado.cvterm_relationship VALUES (3333, 2939, 3057, 174);
INSERT INTO chado.cvterm_relationship VALUES (3334, 2939, 3058, 174);
INSERT INTO chado.cvterm_relationship VALUES (3335, 2939, 3059, 174);
INSERT INTO chado.cvterm_relationship VALUES (3336, 2939, 3060, 174);
INSERT INTO chado.cvterm_relationship VALUES (3337, 2939, 3061, 174);
INSERT INTO chado.cvterm_relationship VALUES (3338, 2939, 3062, 174);
INSERT INTO chado.cvterm_relationship VALUES (3339, 2939, 3063, 174);
INSERT INTO chado.cvterm_relationship VALUES (3340, 2939, 3064, 174);
INSERT INTO chado.cvterm_relationship VALUES (3341, 2939, 3065, 174);
INSERT INTO chado.cvterm_relationship VALUES (3342, 2939, 3066, 174);
INSERT INTO chado.cvterm_relationship VALUES (3343, 2939, 3067, 174);
INSERT INTO chado.cvterm_relationship VALUES (3344, 2939, 3068, 174);
INSERT INTO chado.cvterm_relationship VALUES (3345, 2939, 3069, 174);
INSERT INTO chado.cvterm_relationship VALUES (3346, 2939, 3070, 174);
INSERT INTO chado.cvterm_relationship VALUES (3347, 2939, 3071, 174);
INSERT INTO chado.cvterm_relationship VALUES (3348, 2939, 3072, 174);
INSERT INTO chado.cvterm_relationship VALUES (3349, 2939, 3073, 174);
INSERT INTO chado.cvterm_relationship VALUES (3350, 2939, 3074, 174);
INSERT INTO chado.cvterm_relationship VALUES (3351, 2939, 3075, 174);
INSERT INTO chado.cvterm_relationship VALUES (3352, 2939, 3076, 174);
INSERT INTO chado.cvterm_relationship VALUES (3353, 2939, 3077, 174);
INSERT INTO chado.cvterm_relationship VALUES (3354, 2939, 3078, 174);
INSERT INTO chado.cvterm_relationship VALUES (3355, 2939, 3079, 174);
INSERT INTO chado.cvterm_relationship VALUES (3356, 2939, 3080, 174);
INSERT INTO chado.cvterm_relationship VALUES (3357, 2939, 3081, 174);
INSERT INTO chado.cvterm_relationship VALUES (3358, 2939, 3082, 174);
INSERT INTO chado.cvterm_relationship VALUES (3359, 2939, 3083, 174);
INSERT INTO chado.cvterm_relationship VALUES (3360, 2939, 3084, 174);
INSERT INTO chado.cvterm_relationship VALUES (3361, 2939, 3085, 174);
INSERT INTO chado.cvterm_relationship VALUES (3362, 2939, 3086, 174);
INSERT INTO chado.cvterm_relationship VALUES (3363, 2939, 3087, 174);
INSERT INTO chado.cvterm_relationship VALUES (3364, 2939, 3088, 174);
INSERT INTO chado.cvterm_relationship VALUES (3365, 2939, 3089, 174);
INSERT INTO chado.cvterm_relationship VALUES (3366, 2939, 3090, 174);
INSERT INTO chado.cvterm_relationship VALUES (3367, 2939, 3091, 174);
INSERT INTO chado.cvterm_relationship VALUES (3368, 2939, 3092, 174);
INSERT INTO chado.cvterm_relationship VALUES (3369, 2939, 3093, 174);
INSERT INTO chado.cvterm_relationship VALUES (3370, 2939, 3094, 174);
INSERT INTO chado.cvterm_relationship VALUES (3371, 2939, 3095, 174);
INSERT INTO chado.cvterm_relationship VALUES (3372, 2939, 3096, 174);
INSERT INTO chado.cvterm_relationship VALUES (3373, 2939, 3097, 174);
INSERT INTO chado.cvterm_relationship VALUES (3374, 2939, 3098, 174);
INSERT INTO chado.cvterm_relationship VALUES (3375, 2939, 3099, 174);
INSERT INTO chado.cvterm_relationship VALUES (3376, 2939, 3100, 174);
INSERT INTO chado.cvterm_relationship VALUES (3377, 2939, 3101, 174);
INSERT INTO chado.cvterm_relationship VALUES (3378, 2939, 3102, 174);
INSERT INTO chado.cvterm_relationship VALUES (3379, 2939, 3103, 174);
INSERT INTO chado.cvterm_relationship VALUES (3380, 2939, 3104, 174);
INSERT INTO chado.cvterm_relationship VALUES (3381, 2939, 3105, 174);
INSERT INTO chado.cvterm_relationship VALUES (3382, 2939, 3106, 174);
INSERT INTO chado.cvterm_relationship VALUES (3383, 2939, 3107, 174);
INSERT INTO chado.cvterm_relationship VALUES (3384, 2939, 3108, 174);
INSERT INTO chado.cvterm_relationship VALUES (3385, 2939, 3109, 174);
INSERT INTO chado.cvterm_relationship VALUES (3386, 2939, 3110, 174);
INSERT INTO chado.cvterm_relationship VALUES (3387, 2939, 3111, 174);
INSERT INTO chado.cvterm_relationship VALUES (3388, 2939, 3112, 174);
INSERT INTO chado.cvterm_relationship VALUES (3389, 2939, 3113, 174);
INSERT INTO chado.cvterm_relationship VALUES (3390, 2939, 3114, 174);
INSERT INTO chado.cvterm_relationship VALUES (3391, 2939, 3115, 174);
INSERT INTO chado.cvterm_relationship VALUES (3392, 2939, 3116, 174);
INSERT INTO chado.cvterm_relationship VALUES (3393, 2939, 3117, 174);
INSERT INTO chado.cvterm_relationship VALUES (3394, 2939, 3118, 174);
INSERT INTO chado.cvterm_relationship VALUES (3395, 2939, 3119, 174);
INSERT INTO chado.cvterm_relationship VALUES (3396, 2939, 3120, 174);
INSERT INTO chado.cvterm_relationship VALUES (3397, 2939, 3121, 174);
INSERT INTO chado.cvterm_relationship VALUES (3398, 2939, 3122, 174);
INSERT INTO chado.cvterm_relationship VALUES (3399, 2939, 3123, 174);
INSERT INTO chado.cvterm_relationship VALUES (3400, 2939, 3124, 174);
INSERT INTO chado.cvterm_relationship VALUES (3401, 2939, 3125, 174);
INSERT INTO chado.cvterm_relationship VALUES (3402, 2939, 3126, 174);
INSERT INTO chado.cvterm_relationship VALUES (3403, 2939, 3127, 174);
INSERT INTO chado.cvterm_relationship VALUES (3404, 2939, 3128, 174);
INSERT INTO chado.cvterm_relationship VALUES (3405, 2939, 3129, 174);
INSERT INTO chado.cvterm_relationship VALUES (3406, 2939, 3130, 174);
INSERT INTO chado.cvterm_relationship VALUES (3407, 2939, 3131, 174);
INSERT INTO chado.cvterm_relationship VALUES (3408, 2939, 3132, 174);
INSERT INTO chado.cvterm_relationship VALUES (3409, 2939, 3133, 174);
INSERT INTO chado.cvterm_relationship VALUES (3410, 2939, 3134, 174);
INSERT INTO chado.cvterm_relationship VALUES (3411, 2939, 3135, 174);
INSERT INTO chado.cvterm_relationship VALUES (3412, 2939, 3136, 174);
INSERT INTO chado.cvterm_relationship VALUES (3413, 2939, 3137, 174);
INSERT INTO chado.cvterm_relationship VALUES (3414, 2939, 3138, 174);
INSERT INTO chado.cvterm_relationship VALUES (3415, 2939, 3139, 174);
INSERT INTO chado.cvterm_relationship VALUES (3416, 2940, 175, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3417, 2940, 3140, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3418, 2940, 3141, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3419, 2940, 3142, 2946);
INSERT INTO chado.cvterm_relationship VALUES (3420, 2940, 3143, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3421, 2940, 3144, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3422, 2939, 3145, 174);
INSERT INTO chado.cvterm_relationship VALUES (3423, 2940, 3146, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3424, 2940, 3147, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3425, 2940, 3148, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3426, 2940, 3149, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3427, 2940, 3150, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3428, 2940, 3151, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3429, 2940, 2987, 2942);
INSERT INTO chado.cvterm_relationship VALUES (3430, 2940, 2959, 2942);
INSERT INTO chado.cvtermprop VALUES (1, 208, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (2, 209, 159, 'This relationship is vague and up for discussion.', 0);
INSERT INTO chado.cvtermprop VALUES (3, 210, 159, 'If A is a feature with multiple regions such as a multi exon transcript, the supporting EST evidence is complete if each of the regions is supported by an equivalent region in B. Also there must be no extra regions in B that are not represented in A. This relationship was requested by jeltje on the SO term tracker. The thread for the discussion is available can be accessed via tracker ID:1917222.', 0);
INSERT INTO chado.cvtermprop VALUES (4, 213, 159, 'Example: A splice_junction connects_on exon, exon, mature_transcript.', 0);
INSERT INTO chado.cvtermprop VALUES (5, 214, 159, 'The inverse is contains. Example: intein contained_by immature_peptide_region.', 0);
INSERT INTO chado.cvtermprop VALUES (6, 215, 159, 'Example: pre_miRNA contains miRNA_loop.', 0);
INSERT INTO chado.cvtermprop VALUES (7, 216, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (8, 212, 159, 'This relationship was requested by nlw on the SO term tracker. The thread for the discussion is available can be accessed via tracker ID:1917222.', 0);
INSERT INTO chado.cvtermprop VALUES (9, 220, 159, 'Tracker id: 2594157.', 0);
INSERT INTO chado.cvtermprop VALUES (10, 221, 159, 'Example CDS finished_by stop_codon.', 0);
INSERT INTO chado.cvtermprop VALUES (11, 222, 159, 'Example: stop_codon finishes CDS.', 0);
INSERT INTO chado.cvtermprop VALUES (12, 223, 159, 'A relation with which to annotate the changes in a variant sequence with respect to a reference. For example a variant transcript may gain a stop codon not present in the reference sequence.', 0);
INSERT INTO chado.cvtermprop VALUES (13, 227, 159, 'Example: mRNA has_integral_part CDS.', 0);
INSERT INTO chado.cvtermprop VALUES (14, 228, 159, 'Example: operon has_part gene.', 0);
INSERT INTO chado.cvtermprop VALUES (15, 230, 159, 'The relationship between a feature and an attribute.', 0);
INSERT INTO chado.cvtermprop VALUES (16, 231, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (17, 233, 159, 'Example: exon integral_part_of transcript.', 0);
INSERT INTO chado.cvtermprop VALUES (18, 235, 159, 'Example: region is consecutive_sequence of base.', 0);
INSERT INTO chado.cvtermprop VALUES (19, 236, 159, 'A relation with which to annotate the changes in a variant sequence with respect to a reference. For example a variant transcript may have lost a stop codon present in the reference sequence.', 0);
INSERT INTO chado.cvtermprop VALUES (20, 237, 159, 'Example: non_coding_region_of_exon maximally_overlaps the intersections of exon and UTR.', 0);
INSERT INTO chado.cvtermprop VALUES (21, 238, 159, 'A subtype of part_of. Inverse is collection_of. Winston, M, Chaffin, R, Herrmann: A taxonomy of part-whole relations. Cognitive Science 1987, 11:417-444.', 0);
INSERT INTO chado.cvtermprop VALUES (22, 238, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (23, 239, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (24, 240, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (25, 241, 159, 'Example: coding_exon overlaps CDS.', 0);
INSERT INTO chado.cvtermprop VALUES (26, 242, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (27, 234, 159, 'Example: amino_acid part_of polypeptide.', 0);
INSERT INTO chado.cvtermprop VALUES (28, 234, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (29, 245, 159, 'Example: miRNA processed_from miRNA_primary_transcript.', 0);
INSERT INTO chado.cvtermprop VALUES (30, 246, 159, 'Example: miRNA_primary_transcript processed into miRNA.', 0);
INSERT INTO chado.cvtermprop VALUES (31, 232, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (32, 250, 159, 'Example: CDS started_by start_codon.', 0);
INSERT INTO chado.cvtermprop VALUES (33, 251, 159, 'Example: start_codon starts CDS.', 0);
INSERT INTO chado.cvtermprop VALUES (34, 254, 159, 'Example: primary_transcript transcribed_from gene.', 0);
INSERT INTO chado.cvtermprop VALUES (35, 255, 159, 'Example: gene transcribed_to primary_transcript.', 0);
INSERT INTO chado.cvtermprop VALUES (36, 256, 159, 'Example: codon translates_to amino_acid.', 0);
INSERT INTO chado.cvtermprop VALUES (37, 257, 159, 'Example: Polypeptide translation_of CDS.', 0);
INSERT INTO chado.cvtermprop VALUES (38, 258, 159, 'Added to SO during the immunology workshop, June 2007. This relationship was approved by Barry Smith.', 0);
INSERT INTO chado.cvtermprop VALUES (39, 259, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (40, 260, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (41, 264, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (42, 266, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (43, 268, 159, 'This term is mapped to MGED. This term is now located in OBI, with the following ID OBI_0000406.', 0);
INSERT INTO chado.cvtermprop VALUES (44, 268, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (45, 270, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (46, 281, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (47, 283, 159, 'Binds TAF1, TAF2.', 0);
INSERT INTO chado.cvtermprop VALUES (48, 286, 159, 'Binds TAF6, TAF9.', 0);
INSERT INTO chado.cvtermprop VALUES (49, 287, 159, 'Binds TFIIB.', 0);
INSERT INTO chado.cvtermprop VALUES (50, 315, 159, 'Definition updated Nov 10 2020, Colin Logie from GREEKC helped us realize that LCRs can also be located 3'' to a gene.', 0);
INSERT INTO chado.cvtermprop VALUES (51, 317, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (52, 318, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (53, 326, 159, 'Please not the synonym R psi M uses the spelled out form of the greek letter.', 0);
INSERT INTO chado.cvtermprop VALUES (54, 335, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (55, 338, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (56, 343, 159, 'Moved to transcriptional_cis_regulatory_region (SO:0001055) from gene_group_regulatory_region (SO:0000752) on 11 Feb 2021 when SO:0000752 was merged into SO:0001055. See GitHub Issue #529.', 0);
INSERT INTO chado.cvtermprop VALUES (57, 343, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (58, 346, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (59, 348, 159, 'FLAG - this term is should probably be a part of rather than an is_a.', 0);
INSERT INTO chado.cvtermprop VALUES (60, 350, 159, 'A region of a molecule that binds to a restriction enzyme.', 0);
INSERT INTO chado.cvtermprop VALUES (61, 357, 159, 'This classes of attributes was added by MA to allow the broad description of genes based on qualities of the transcript(s). A product of SO meeting 2004.', 0);
INSERT INTO chado.cvtermprop VALUES (62, 413, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (63, 415, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (64, 417, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (65, 420, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology. The term ''protein'' was merged with ''polypeptide''. Although ''protein'' was a sequence_attribute and therefore meant to describe the quality rather than an actual feature, it was being used erroneously. It is replaced by ''peptidyl'' as the polymer attribute.', 0);
INSERT INTO chado.cvtermprop VALUES (66, 420, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (67, 429, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (68, 162, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (69, 426, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (70, 432, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (71, 433, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (72, 443, 159, 'May contain introns.', 0);
INSERT INTO chado.cvtermprop VALUES (73, 443, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (74, 445, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (75, 448, 159, 'By:<protein_id>.', 0);
INSERT INTO chado.cvtermprop VALUES (76, 460, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (77, 466, 159, 'Examples are x-inactivation and immunoglobulin formation.', 0);
INSERT INTO chado.cvtermprop VALUES (78, 470, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (79, 472, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (80, 474, 159, 'Moved from transcription_regulatory_region (SO:0001679) to transcriptional_cis_regulatory_region (SO:0001055) by Dave Sant on Feb 11, 2021 when transcription_regulatory_region was merged into transcriptional_cis_regulatory_region to be consistent with GO and reduce redundancy as part of the GREEKC consortium. See GitHub Issue #527.', 0);
INSERT INTO chado.cvtermprop VALUES (81, 474, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (82, 476, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (83, 481, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (84, 481, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (85, 483, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (86, 272, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (87, 271, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (88, 322, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (89, 487, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (90, 489, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (91, 490, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology. Drosophila melanogaster PACs carry an average insert size of 80 kb. The library represents a 6-fold coverage of the genome.', 0);
INSERT INTO chado.cvtermprop VALUES (92, 491, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (93, 493, 159, 'Paper: vans GA et al. High efficiency vectors for cosmid microcloning and genomic analysis. Gene 1989; 79(1):9-20. This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (94, 495, 159, 'Birren BW et al. A human chromosome 22 fosmid resource: mapping and analysis of 96 clones. Genomics 1996.', 0);
INSERT INTO chado.cvtermprop VALUES (95, 354, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (96, 498, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (97, 500, 159, 'With spliceosomal introns, the splice sites bind the spliceosomal machinery.', 0);
INSERT INTO chado.cvtermprop VALUES (98, 500, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (99, 502, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (100, 504, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (101, 505, 159, 'An enhancer may participate in an enhanceosome GO:0034206. A protein-DNA complex formed by the association of a distinct set of general and specific transcription factors with a region of enhancer DNA. The cooperative assembly of an enhanceosome confers specificity of transcriptional regulation. This comment is a place holder should we start to make cross products with GO.', 0);
INSERT INTO chado.cvtermprop VALUES (102, 505, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (103, 290, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology. The region on a DNA molecule involved in RNA polymerase binding to initiate transcription. Moved from is_a: SO:0001055 transcriptional_cis_regulatory_region as per request from GREEKC initiative in August 2020. Merged with RNA_polymerase_promoter (SO:0001203) Aug 2020. Moved up one level from is_a CRM (SO:0000727) to is_a transcriptional_cis_regulatory_region (SO:0001055) as part of the GREEKC work January 2021. Pascale Gaudet from Gene Ontology pointed out that CRM can be located upstream of the promoter and therefore cannot include the promoter.', 0);
INSERT INTO chado.cvtermprop VALUES (104, 290, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (105, 510, 159, 'parent term RNA_polymerase_promoter SO:0001203 was obsoleted in Aug 2020, so term has been moved to eukaryotic_promoter SO:0002221.', 0);
INSERT INTO chado.cvtermprop VALUES (106, 512, 159, 'parent term RNA_polymerase_promoter SO:0001203 was obsoleted in Aug 2020, so term has been moved to eukaryotic_promoter SO:0002221.', 0);
INSERT INTO chado.cvtermprop VALUES (107, 513, 159, 'parent term RNA_polymerase_promoter SO:0001203 was obsoleted in Aug 2020, so term has been moved to eukaryotic_promoter SO:0002221.', 0);
INSERT INTO chado.cvtermprop VALUES (108, 517, 159, 'Binds TBP.', 0);
INSERT INTO chado.cvtermprop VALUES (109, 518, 159, 'Changed from is_a SO:0000713 DNA_motif to is_a SO:0002312 core_prokaryotic_promoter_element in response to GREEKC Initiative Dave Sant Aug 2020. Changed from is_a SO:0002312 core_prokaryotic_promoter_element back to is_a SO:0000713 DNA_motif to be consistent with minus_12_signal and minus_24_signal on 12 July 2021.', 0);
INSERT INTO chado.cvtermprop VALUES (110, 521, 159, 'Changed from is_a SO:0000713 DNA_motif to is_a SO:0002312 core_prokaryotic_promoter_element in response to GREEKC Initiative Dave Sant Aug 2020. Changed from is_a SO:0002312 core_prokaryotic_promoter_element back to is_a SO:0000713 DNA_motif to be consistent with minus_12_signal and minus_24_signal on 12 July 2021.', 0);
INSERT INTO chado.cvtermprop VALUES (111, 522, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (112, 523, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology. Definition updated with per Mejia-Almonte et.al Redefining fundamental concepts of transcription initiation in prokaryotes Aug 5 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (113, 523, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (114, 525, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (115, 527, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (116, 529, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (117, 530, 159, 'May have either GT-AG or AT-AG 5'' and 3'' boundaries.', 0);
INSERT INTO chado.cvtermprop VALUES (118, 444, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (119, 533, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (120, 534, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (121, 534, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (122, 539, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (123, 265, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (124, 542, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (125, 545, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (126, 547, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (127, 548, 154, 'DBVAR', 0);
INSERT INTO chado.cvtermprop VALUES (128, 544, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (129, 551, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (130, 471, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (131, 552, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (132, 557, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (133, 580, 159, 'This definition was broadened 26 Jan 2021 to reflect that a single transcript can encode one or more snoRNAs. Brought to our attention by FlyBase. GitHub Issue #520 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/520).', 0);
INSERT INTO chado.cvtermprop VALUES (271, 987, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (134, 581, 159, 'A processed transcript cannot contain introns.', 0);
INSERT INTO chado.cvtermprop VALUES (135, 581, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (136, 164, 159, 'An mRNA does not contain introns as it is a processed_transcript. The equivalent kind of primary_transcript is protein_coding_primary_transcript (SO:0000120) which may contain introns. This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (137, 164, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (138, 582, 159, 'Definition updated along with definitions in Mejia-Almonte et.al PMID:32665585. Added relationship part_of SO:0000727 CRM in place of previous CRM relationship has_part TF_binding_site August 2020 in response to requests from GREEKC initiative. Moved from transcription_regulatory_region (SO:0001679) to transcriptional_cis_regulatory_region (SO:0001055) by Dave Sant on Feb 11, 2021 when transcription_regulatory_region was merged into transcriptional_cis_regulatory_region to be consistent with GO and reduce redundancy as part of the GREEKC consortium. See GitHub Issue #527.', 0);
INSERT INTO chado.cvtermprop VALUES (139, 582, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (140, 583, 159, 'The definition was modified by Rama. ORF is defined by the sequence, whereas the CDS is defined according to whether a polypeptide is made. This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (141, 583, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (142, 587, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (143, 604, 159, 'Definition updated 10 June 2021 as part of restructuring rRNA terms and reforming definitions to have similar structures. Request from EBI. See GitHub Issue #493', 0);
INSERT INTO chado.cvtermprop VALUES (144, 604, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (145, 605, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (146, 605, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (147, 627, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (148, 627, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (149, 628, 159, 'Updated the definition of snoRNA (SO:0000275) from "A snoRNA (small nucleolar RNA) is any one of a class of small RNAs that are associated with the eukaryotic nucleus as components of small nucleolar ribonucleoproteins. They participate in the processing or modifications of many RNAs, mostly ribosomal RNAs (rRNAs) though snoRNAs are also known to target other classes of RNA, including spliceosomal RNAs, tRNAs, and mRNAs via a stretch of sequence that is complementary to a sequence in the targeted RNA." to "Small nucleolar RNAs (snoRNAs) are short non-coding RNAs enriched in the nucleolus as components of small nucleolar ribonucleoproteins. They guide ribose methylation and pseudouridylation of rRNAs and snRNAs, and a subgroup regulate excision of rRNAs from rRNA precursor transcripts. snoRNAs may also guide rRNA acetylation and tRNA methylation, and regulate mRNA abundance and alternative splicing." to acknowledge that some snoRNAs functionally localize to other compartments (cytoplasm or even secreted). See GitHub Issue #578.', 0);
INSERT INTO chado.cvtermprop VALUES (150, 628, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (151, 629, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (152, 507, 159, 'Formerly called transcript_by_bound_factor.', 0);
INSERT INTO chado.cvtermprop VALUES (153, 632, 159, 'Formerly called transcript_by_bound_nucleic_acid.', 0);
INSERT INTO chado.cvtermprop VALUES (154, 634, 159, 'Formerly called transcript_by_bound_protein.', 0);
INSERT INTO chado.cvtermprop VALUES (155, 652, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (156, 657, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (157, 658, 159, 'May have either GT-AC or AT-AC 5'' and 3'' boundaries.', 0);
INSERT INTO chado.cvtermprop VALUES (158, 659, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (159, 660, 159, 'Moved from is_a: SO:0000296 origin_of_replication to is_a: SO:0001411 biological_region after Terrence Murphy (INSDC) pointed out that the D loop can also refer to a loop in DNA repair, which is not an origin of replication. See GitHub Issue #417 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/417)', 0);
INSERT INTO chado.cvtermprop VALUES (160, 668, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (161, 670, 159, 'Modified base:<modified_base>.', 0);
INSERT INTO chado.cvtermprop VALUES (162, 670, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (163, 434, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (164, 672, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (165, 676, 159, 'similar to:<sequence_id>', 0);
INSERT INTO chado.cvtermprop VALUES (166, 680, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (167, 681, 159, 'Added relationship is_a SO:0002309 core_promoter_element with the creation of core_promoter_element as part of GREEKC initiative August 2020 - Dave Sant.', 0);
INSERT INTO chado.cvtermprop VALUES (168, 681, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (169, 421, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (170, 683, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (171, 685, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (172, 686, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (173, 692, 159, 'Relationship to accessible_DNA_region added 11 Feb 2021. GREEKC pointed out that this is an assay based term, but we need a biological term for the accessible DNA. See GitHub Issue #531.', 0);
INSERT INTO chado.cvtermprop VALUES (174, 697, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (175, 698, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (176, 699, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (177, 704, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (178, 705, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (179, 706, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (180, 707, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (181, 708, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (182, 327, 154, 'Alliance_of_Genome_Resources', 0);
INSERT INTO chado.cvtermprop VALUES (183, 327, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (184, 711, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (185, 715, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (186, 715, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (187, 716, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (188, 320, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (189, 688, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (190, 719, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (191, 719, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (192, 416, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (193, 724, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (194, 486, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (195, 732, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (196, 479, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (197, 742, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (198, 745, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (199, 630, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (272, 992, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (200, 748, 159, 'This was moved to be a child of transcript (SO:0000673) because some enzymatic RNA regions are part of primary transcripts and some are part of processed transcripts. Moved under ncRNA on 18 Nov 2021. See GitHub Issue #533.', 0);
INSERT INTO chado.cvtermprop VALUES (201, 748, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (202, 753, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (203, 755, 159, 'Dave Sant removed ''5_8S rRNA is also found in archaea.'' from definition due to lack of references mentioning this on 1 Feb 2021. See GitHub Issue #505. Renamed from rRNA_5_8S to cytosolic_5_8S_rRNA on 10 June 2021 with the restructuring of rRNA child terms. Updated definition to be consistent with format of other rRNA definitions. Requested by EBI. See GitHub Issue #493.', 0);
INSERT INTO chado.cvtermprop VALUES (204, 755, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (205, 762, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (206, 769, 159, 'Moved under enzymatic_RNA on 18 Nov 2021. See GitHub Issue #533.', 0);
INSERT INTO chado.cvtermprop VALUES (207, 769, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (208, 770, 159, 'Moved under enzymatic_RNA on 18 Nov 2021. See GitHub Issue #533.', 0);
INSERT INTO chado.cvtermprop VALUES (209, 770, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (210, 774, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (211, 775, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (212, 776, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (213, 777, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (214, 778, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (215, 779, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (216, 780, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (217, 781, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (218, 782, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (219, 783, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (220, 786, 159, 'An evolutionarily conserved eukaryotic low molecular weight RNA capable of intermolecular hybridization with both homologous and heterologous 18S rRNA.', 0);
INSERT INTO chado.cvtermprop VALUES (221, 786, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (222, 789, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (223, 790, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (224, 792, 159, 'Renamed to cytosolic_18S_rRNA from rRNA_18S on 10 June 2021 as per restructuring of rRNA child terms. Updated definition to be consistent with format of other rRNA definitions. Request from EBI. See GitHub Issue #493.', 0);
INSERT INTO chado.cvtermprop VALUES (225, 792, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (226, 796, 159, 'See GO:0005488 : binding.', 0);
INSERT INTO chado.cvtermprop VALUES (227, 796, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (228, 796, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (229, 797, 159, 'See GO:0042277 : peptide binding.', 0);
INSERT INTO chado.cvtermprop VALUES (230, 797, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (231, 540, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (232, 800, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (233, 805, 159, 'Range. Old definition from before biosapiens: A region of a single polypeptide chain that folds into an independent unit and exhibits biological activity. A polypeptide chain may have multiple domains.', 0);
INSERT INTO chado.cvtermprop VALUES (234, 805, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (235, 808, 159, 'Old def before biosapiens:The sequence for an N-terminal domain of a secreted protein; this domain is involved in attaching nascent polypeptide to the membrane leader sequence.', 0);
INSERT INTO chado.cvtermprop VALUES (236, 808, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (237, 808, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (238, 812, 159, 'This term mature peptide, merged with the biosapiens term mature protein region and took that to be the new name. Old def: The coding sequence for the mature or final peptide or protein product following post-translational modification.', 0);
INSERT INTO chado.cvtermprop VALUES (239, 812, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (240, 812, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (241, 837, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (242, 488, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (243, 431, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (244, 431, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (245, 712, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (246, 712, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (247, 855, 159, 'Changed parent term from ncRNA (SO:0000655) to piRNA (SO:0001035). See GitHub Issue #573.', 0);
INSERT INTO chado.cvtermprop VALUES (248, 855, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (249, 862, 159, 'I am using the term segment instead of gene here to avoid confusion with the region ''gene''.', 0);
INSERT INTO chado.cvtermprop VALUES (250, 866, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (251, 868, 159, 'Does not have to be part of a pseudogene.', 0);
INSERT INTO chado.cvtermprop VALUES (252, 868, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (253, 873, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (254, 878, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (255, 880, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (256, 280, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (257, 888, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (258, 893, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (259, 913, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (260, 916, 159, 'This concept cam about as a direct result of the SO meeting August 2004.nThe exact nature of the relationship between transcribed_region and gene is still up for discussion. We are going with ''associated_with'' for the time being.', 0);
INSERT INTO chado.cvtermprop VALUES (261, 916, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (262, 921, 159, 'This is the analog of the exon of a functional gene. The term was requested by Rama - SGD to allow the annotation of the parts of a pseudogene. Non-functional is defined as either its transcription or translation (or both) are prevented due to one or more mutations.', 0);
INSERT INTO chado.cvtermprop VALUES (263, 922, 159, 'This is the analog of the transcript of a functional gene. The term was requested by Rama - SGD to allow the annotation of the parts of a pseudogene. Non-functional is defined as either its transcription or translation (or both) are prevented due to one or more mutations.', 0);
INSERT INTO chado.cvtermprop VALUES (264, 968, 159, 'Examples are Nullo-4, Haplo-4 and triplo-4 in Drosophila.', 0);
INSERT INTO chado.cvtermprop VALUES (265, 969, 159, 'Moved from transcription_regulatory_region (SO:0001679) to transcriptional_cis_regulatory_region (SO:0001055) by Dave Sant on Feb 11, 2021 when transcription_regulatory_region was merged into transcriptional_cis_regulatory_region to be consistent with GO and reduce redundancy as part of the GREEKC consortium. See GitHub Issue #527.', 0);
INSERT INTO chado.cvtermprop VALUES (266, 969, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (267, 970, 159, 'Not found in Eukaryotic sequence.', 0);
INSERT INTO chado.cvtermprop VALUES (268, 971, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (269, 982, 159, 'Definition updated in Aug 2020 by Dave Sant.', 0);
INSERT INTO chado.cvtermprop VALUES (270, 983, 159, 'GO:0003964 RNA-directed DNA polymerase activity.', 0);
INSERT INTO chado.cvtermprop VALUES (273, 998, 159, 'GO:0000372.', 0);
INSERT INTO chado.cvtermprop VALUES (274, 998, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (275, 999, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (276, 1001, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (277, 787, 159, 'Added ''SNORD'' as a synonym of C_D_box_snoRNA (SO:0000593) and ''SNORA'' as a synonym of H_ACA_box_snoRNA (SO:0000594). See GitHub Issue #577.', 0);
INSERT INTO chado.cvtermprop VALUES (278, 787, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (279, 1004, 159, 'Added ''SNORD'' as a synonym of C_D_box_snoRNA (SO:0000593) and ''SNORA'' as a synonym of H_ACA_box_snoRNA (SO:0000594). See GitHub Issue #577.', 0);
INSERT INTO chado.cvtermprop VALUES (280, 1011, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (281, 764, 159, 'GO:0000373.', 0);
INSERT INTO chado.cvtermprop VALUES (282, 764, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (283, 1013, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (284, 1013, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (285, 1018, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (286, 1019, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (287, 1020, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (288, 1021, 159, 'former parent RNA_polymerase_promoter SO:0001203 was merged with promoter SO:0000167 in Aug 2020 as part of GREEKC.', 0);
INSERT INTO chado.cvtermprop VALUES (289, 1023, 159, 'Moved to transcriptional_cis_regulatory_region (SO:0001055) from gene_group_regulatory_region (SO:0000752) on 11 Feb 2021 when SO:0000752 was merged into SO:0001055. See GitHub Issue #529.', 0);
INSERT INTO chado.cvtermprop VALUES (290, 1026, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (291, 1029, 159, 'Binds TFIIIC.', 0);
INSERT INTO chado.cvtermprop VALUES (292, 1030, 159, 'Binds TFIIIC.', 0);
INSERT INTO chado.cvtermprop VALUES (293, 1034, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (294, 1035, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (295, 1036, 159, 'moved from is_a: SO:0001055 transcriptional_cis_regulatory_region as per request from GREEKC initiative in August 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (296, 1036, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (297, 988, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (298, 1055, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (299, 767, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (300, 1056, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (301, 1057, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (302, 793, 159, 'Renamed to cytosolic_SSU_rRNA from small_subunit_rRNA on 10 June 2021 as per restructuring of rRNA child terms. Updated definition to be consistent with format of other rRNA definitions. Request from EBI. See GitHub Issue #493.', 0);
INSERT INTO chado.cvtermprop VALUES (303, 793, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (304, 756, 159, 'Renamed to cytosolic_LSU_rRNA from large_subunit_rRNA on 10 June 2021 as per restructuring of rRNA child terms. Updated definition to be consistent with format of other rRNA definitions. Request from EBI. See GitHub Issue #493.', 0);
INSERT INTO chado.cvtermprop VALUES (305, 756, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (306, 1060, 159, 'Renamed from rRNA_5S to cytosolic_5S_rRNA on 27 May 2021 with the restructuring of rRNA child terms. Updated definition to be consistent with format of other rRNA definitions. Requested by EBI. See GitHub Issue #493.', 0);
INSERT INTO chado.cvtermprop VALUES (307, 1060, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (308, 1062, 159, 'Renamed from rRNA_28S to cytosolic_28S_rRNA on 27 May 2021 with the restructuring of rRNA child terms. Updated definition to be consistent with format of other rRNA definitions. Requested by EBI. See GitHub Issue #493.', 0);
INSERT INTO chado.cvtermprop VALUES (309, 1062, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (310, 282, 159, 'A ncRNA is a processed_transcript, so it may not contain parts such as transcribed_spacer_regions that are removed in the act of processing. For the corresponding primary_transcripts, please see term SO:0000483 nc_primary_transcript.', 0);
INSERT INTO chado.cvtermprop VALUES (311, 282, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (312, 648, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (313, 1068, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (314, 531, 159, 'GO:0000398.', 0);
INSERT INTO chado.cvtermprop VALUES (315, 531, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (316, 1077, 154, 'DBVAR', 0);
INSERT INTO chado.cvtermprop VALUES (317, 1077, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (318, 1078, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (319, 373, 159, 'Added relationship overlaps SO:0002300 unit_of_gene_expression with Mejia-Almonte et.al PMID:32665585 Aug 5, 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (320, 373, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (321, 693, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (322, 1097, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (323, 874, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (324, 1098, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (325, 1100, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (326, 1105, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (327, 269, 159, 'Requested by Lynn Crosby, jan 2006.', 0);
INSERT INTO chado.cvtermprop VALUES (328, 269, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (329, 305, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (330, 418, 159, 'A junction is a boundary between regions. A boundary has an extent of zero.', 0);
INSERT INTO chado.cvtermprop VALUES (331, 418, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (332, 801, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (333, 1112, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (334, 1113, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (335, 1114, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (336, 163, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology. A gene may be considered as a unit of inheritance.', 0);
INSERT INTO chado.cvtermprop VALUES (337, 163, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (338, 267, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (339, 1115, 159, 'This region contains a polypyridine tract and AG dinucleotide in some organisms and is UUUCAG in C. elegans.', 0);
INSERT INTO chado.cvtermprop VALUES (340, 1115, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (341, 1117, 159, 'SL RNA contains a donor site.', 0);
INSERT INTO chado.cvtermprop VALUES (342, 1125, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (343, 293, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (344, 584, 159, 'This term was added after a request by SGD. August 2004. Modified after SO meeting in Cambridge to not include start or stop.', 0);
INSERT INTO chado.cvtermprop VALUES (345, 584, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (346, 1128, 159, 'Term requested by Rama from SGD.', 0);
INSERT INTO chado.cvtermprop VALUES (347, 485, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (348, 1129, 159, 'requested by Michael on 19 Nov 2004.', 0);
INSERT INTO chado.cvtermprop VALUES (349, 1130, 159, 'Requested by Michael, 19 nov 2004.', 0);
INSERT INTO chado.cvtermprop VALUES (350, 1132, 159, 'Requested by MA nov 19 2004.', 0);
INSERT INTO chado.cvtermprop VALUES (351, 1134, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (409, 1222, 159, 'This is a manufactured term to allow the parts of RNApol_III_promoter_type_1 to have an is_a path back to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (524, 1423, 159, 'Discrete.', 0);
INSERT INTO chado.cvtermprop VALUES (352, 1135, 159, 'Added to bring SO inline with the EMBL, DDBJ, GenBank feature table. Old definition before biosapiens: The coding sequence for an N-terminal domain of a nuclear-encoded organellar protein. This domain is involved in post translational import of the protein into the organelle.', 0);
INSERT INTO chado.cvtermprop VALUES (353, 1135, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (354, 1135, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (355, 1067, 159, 'Added to comply with the feature table. A single repeat.', 0);
INSERT INTO chado.cvtermprop VALUES (356, 316, 159, 'Requested by Stephen Grossmann Dec 2004. Changed relationship from has_part SO:0000235 TF_binding site to TF_binding_site is part_of SO:0000727 CRM in response to requests from GREEKC initiative in Aug 2020. Removed 3'' from definition because 5'' UTRs are included as well, notified by Colin Logie of GREEKC. Nov 9 2020. DS Updated name from ''CRM'' to ''cis_regulatory_module'' on 08 Feb 2021. See GitHub Issue #526. DS Added final sentence to definition as part of GREEKC Feb 16, 2021. See GitHub Issue #534.', 0);
INSERT INTO chado.cvtermprop VALUES (357, 316, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (358, 1137, 159, 'Intein-mediated protein splicing occurs after mRNA has been translated into a protein.', 0);
INSERT INTO chado.cvtermprop VALUES (359, 1139, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (360, 1140, 159, 'Term added because of request by MO people.', 0);
INSERT INTO chado.cvtermprop VALUES (361, 1143, 159, 'Added for the MO people.', 0);
INSERT INTO chado.cvtermprop VALUES (362, 388, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (363, 386, 159, 'Moved from is_a SO:0000736 (organelle_sequence) when brought to our attention by GitHub issue #489.', 0);
INSERT INTO chado.cvtermprop VALUES (364, 1149, 159, 'Merged into transcriptional_cis_regulatory_region (SO:0001055) on 11 Feb 2021 as part of GREEKC reducing redundancy as we prepare to submit several terms to Ensembl. See GitHub Issue #529.', 0);
INSERT INTO chado.cvtermprop VALUES (365, 1149, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (366, 419, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (367, 1165, 159, 'Added in response to comment from Kelly Williams from Indiana. Nov 2005.', 0);
INSERT INTO chado.cvtermprop VALUES (368, 1167, 159, 'Added in response to Kelly Williams from Indiana. Date: Nov 2005.', 0);
INSERT INTO chado.cvtermprop VALUES (369, 165, 159, 'Added in respose to request by Simon Twigger November 14th 2005.', 0);
INSERT INTO chado.cvtermprop VALUES (370, 1168, 159, 'Genomic islands are transmissible elements characterized by large size (>10kb).', 0);
INSERT INTO chado.cvtermprop VALUES (371, 1169, 159, 'Nature Reviews Microbiology 2, 414-424 (2004); doi:10.1038 micro 884 GENOMIC ISLANDS IN PATHOGENIC AND ENVIRONMENTAL MICROORGANISMS Ulrich Dobrindt, Bianca Hochhut, Ute Hentschel & Jorg Hacker.', 0);
INSERT INTO chado.cvtermprop VALUES (372, 1170, 159, 'Genes for phenolic compound degradation in Pseudomonas putida are found on metabolic islands.', 0);
INSERT INTO chado.cvtermprop VALUES (373, 1171, 159, 'The iron-uptake ability of many pathogens are conveyed by adaptive islands. Nature Reviews Microbiology 2, 414-424 (2004); doi:10.1038 micro 884 GENOMIC ISLANDS IN PATHOGENIC AND ENVIRONMENTAL MICROORGANISMS Ulrich Dobrindt, Bianca Hochhut, Ute Hentschel & Jorg Hacker.', 0);
INSERT INTO chado.cvtermprop VALUES (374, 1172, 159, 'Nitrogen fixation in Rhizobiaceae species is encoded by symbiosis islands. Evolution of rhizobia by acquisition of a 500-kb symbiosis island that integrates into a phe-tRNA gene. John T. Sullivan and Clive W. Ronso PNAS 1998 Apr 28 95 (9) 5145-5149.', 0);
INSERT INTO chado.cvtermprop VALUES (375, 1173, 159, 'Added Jan 2006 to allow the annotation of the pseudogenic rRNA by flybase. Non-functional is defined as its transcription is prevented due to one or more mutatations.', 0);
INSERT INTO chado.cvtermprop VALUES (376, 1173, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (377, 1174, 159, 'Added Jan 2006 to allow the annotation of the pseudogenic tRNA by flybase. Non-functional is defined as its transcription is prevented due to one or more mutatations.', 0);
INSERT INTO chado.cvtermprop VALUES (378, 1174, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (379, 1175, 159, 'Requested by Lynn Crosby Jan 2006.', 0);
INSERT INTO chado.cvtermprop VALUES (380, 1176, 159, 'Added by KE Jan 2006 to capture the kinds of attributes of TEs', 0);
INSERT INTO chado.cvtermprop VALUES (381, 1179, 159, 'Added in response to Lynn Crosby. A clone insert may be composed of many cloned regions.', 0);
INSERT INTO chado.cvtermprop VALUES (382, 1180, 159, 'Added jan 2006 by KE.', 0);
INSERT INTO chado.cvtermprop VALUES (383, 1189, 159, 'Modified as requested by Lynn - FB. May 2007.', 0);
INSERT INTO chado.cvtermprop VALUES (384, 423, 159, 'This is a manufactured term, that serves the purpose of allow the parts of a chromosome to have an is_a path to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (385, 423, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (386, 1082, 159, 'A manufactured term used to allow the parts of a gene to have an is_a path to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (387, 1082, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (388, 1218, 159, 'This is a manufactured term to allow the parts of promoter to have an is_a path back to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (389, 482, 159, 'This term was added to provide a grouping term for the region parts of transcript, thus giving them an is_a path back to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (390, 482, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (391, 1219, 159, 'A manufactured term to collect together the parts of a mature transcript and give them an is_a path to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (392, 1219, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (393, 501, 159, 'This term was added to provide a grouping term for the region parts of primary_transcript, thus giving them an is_a path back to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (394, 501, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (395, 312, 159, 'This term was added to provide a grouping term for the region parts of mRNA, thus giving them an is_a path back to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (396, 312, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (397, 1039, 159, 'A region of UTR. This term is a grouping term to allow the parts of UTR to have an is_a path to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (398, 1039, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (399, 1050, 159, 'To allow transcribed_spacer_region to have a path to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (400, 813, 159, 'Added to allow the polypeptide regions to have is_a paths back to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (401, 813, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (402, 813, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (403, 834, 159, 'A manufactured to group the parts of repeats, to give them an is_a path back to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (404, 689, 159, 'A terms added to allow the parts of introns to have is_a paths to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (405, 689, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (406, 508, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (407, 1220, 159, 'This is a manufactured term to allow the parts of bacterial_RNApol_promoter to have an is_a path back to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (408, 1221, 159, 'This is a manufactured term to allow the parts of RNApol_II_promoter to have an is_a path back to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (523, 1422, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (410, 1223, 159, 'This is a manufactured term to allow the parts of RNApol_III_promoter_type_2 to have an is_a path back to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (411, 1166, 159, 'This term was added to provide a grouping term for the region parts of tmRNA, thus giving them an is_a path back to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (412, 696, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (413, 1224, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (414, 1227, 159, 'A term to be used in conjunction with the paralogous_to relationship.', 0);
INSERT INTO chado.cvtermprop VALUES (415, 1229, 159, 'This term should be used in conjunction with the similarity relationships defined in SO.', 0);
INSERT INTO chado.cvtermprop VALUES (416, 1141, 159, 'This term is the hypernym of attributes and should not be annotated to.', 0);
INSERT INTO chado.cvtermprop VALUES (417, 1256, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (418, 1262, 159, 'The insertion and deletion of uridine (U) residues, usually within coding regions of mRNA transcripts of cryptogenes in the mitochondrial genome of kinetoplastid protozoa.', 0);
INSERT INTO chado.cvtermprop VALUES (419, 1263, 159, 'The insertion and deletion of uridine (U) residues, usually within coding regions of mRNA transcripts of cryptogenes in the mitochondrial genome of kinetoplastid protozoa.', 0);
INSERT INTO chado.cvtermprop VALUES (420, 1269, 159, 'The type of RNA editing found in the mitochondria of Myxomycota, characterized by the insertion of mono- and dinucleotides in RNAs relative to their mtDNA template and in addition, C to U base conversion. The most common mononucleotide insertion is cytidine, although a number of uridine mononucleotides are inserted at specific sites. Adenine and guanine have not been observed in mononucleotide insertions. Five different dinucleotide insertions have been observed, GC, GU, CU, AU and AA. Both mono- and dinucleotide insertions create open reading frames in mRNA and contribute to highly conserved structural features of rRNAs and tRNAs.', 0);
INSERT INTO chado.cvtermprop VALUES (421, 1270, 159, 'The type of RNA editing found in the mitochondria of Myxomycota, characterized by the insertion of mono- and dinucleotides in RNAs relative to their mtDNA template and in addition, C to U base conversion. The most common mononucleotide insertion is cytidine, although a number of uridine mononucleotides are inserted at specific sites. Adenine and guanine have not been observed in mononucleotide insertions. Five different dinucleotide insertions have been observed, GC, GU, CU, AU and AA. Both mono- and dinucleotide insertions create open reading frames in mRNA and contribute to highly conserved structural features of rRNAs and tRNAs.', 0);
INSERT INTO chado.cvtermprop VALUES (422, 1271, 159, 'The type of RNA editing found in the mitochondria of Myxomycota, characterized by the insertion of mono- and dinucleotides in RNAs relative to their mtDNA template and in addition, C to U base conversion. The most common mononucleotide insertion is cytidine, although a number of uridine mononucleotides are inserted at specific sites. Adenine and guanine have not been observed in mononucleotide insertions. Five different dinucleotide insertions have been observed, GC, GU, CU, AU and AA. Both mono- and dinucleotide insertions create open reading frames in mRNA and contribute to highly conserved structural features of rRNAs and tRNAs.', 0);
INSERT INTO chado.cvtermprop VALUES (423, 1272, 159, 'The type of RNA editing found in the mitochondria of Myxomycota, characterized by the insertion of mono- and dinucleotides in RNAs relative to their mtDNA template and in addition, C to U base conversion. The most common mononucleotide insertion is cytidine, although a number of uridine mononucleotides are inserted at specific sites. Adenine and guanine have not been observed in mononucleotide insertions. Five different dinucleotide insertions have been observed, GC, GU, CU, AU and AA. Both mono- and dinucleotide insertions create open reading frames in mRNA and contribute to highly conserved structural features of rRNAs and tRNAs.', 0);
INSERT INTO chado.cvtermprop VALUES (424, 1273, 159, 'The type of RNA editing found in the mitochondria of Myxomycota, characterized by the insertion of mono- and dinucleotides in RNAs relative to their mtDNA template and in addition, C to U base conversion. The most common mononucleotide insertion is cytidine, although a number of uridine mononucleotides are inserted at specific sites. Adenine and guanine have not been observed in mononucleotide insertions. Five different dinucleotide insertions have been observed, GC, GU, CU, AU and AA. Both mono- and dinucleotide insertions create open reading frames in mRNA and contribute to highly conserved structural features of rRNAs and tRNAs.', 0);
INSERT INTO chado.cvtermprop VALUES (425, 726, 159, 'A target region for site-specific inversion of a DNA region and which carries binding sites for a site-specific recombinase and accessory proteins as well as the site for specific cleavage by the recombinase.', 0);
INSERT INTO chado.cvtermprop VALUES (426, 1311, 159, 'This has been obsoleted as it represents a process. replaced_by: GO:0034961.', 0);
INSERT INTO chado.cvtermprop VALUES (427, 1312, 159, 'This has been obsoleted as it represents a process. replaced_by: GO:0070581.', 0);
INSERT INTO chado.cvtermprop VALUES (428, 1313, 159, 'This has been obsoleted as it represents a process. replaced_by: GO:0070582', 0);
INSERT INTO chado.cvtermprop VALUES (429, 1314, 159, 'This has been obsoleted as it represents a process. replaced_by: GO:0006260.', 0);
INSERT INTO chado.cvtermprop VALUES (430, 1315, 159, 'This has been obsoleted as it represents a process. replaced_by: GO:0034961.', 0);
INSERT INTO chado.cvtermprop VALUES (431, 1236, 159, 'Part of an edited transcript only.', 0);
INSERT INTO chado.cvtermprop VALUES (432, 1323, 159, 'Attributes added to describe the different kinds of replicon. SO workshop, September 2006.', 0);
INSERT INTO chado.cvtermprop VALUES (433, 1297, 159, 'Attributes added to describe the different kinds of replicon. SO workshop, September 2006.', 0);
INSERT INTO chado.cvtermprop VALUES (434, 1295, 159, 'Attributes added to describe the different kinds of replicon. SO workshop, September 2006.', 0);
INSERT INTO chado.cvtermprop VALUES (435, 1324, 159, 'Attributes added to describe the different kinds of replicon. SO workshop, September 2006.', 0);
INSERT INTO chado.cvtermprop VALUES (436, 1299, 159, 'Attributes added to describe the different kinds of replicon. SO workshop, September 2006.', 0);
INSERT INTO chado.cvtermprop VALUES (437, 1301, 159, 'Attributes added to describe the different kinds of replicon. SO workshop, September 2006.', 0);
INSERT INTO chado.cvtermprop VALUES (438, 1326, 159, 'Requested by Karen Pilcher - Dictybase. song-Term Tracker-1574577.', 0);
INSERT INTO chado.cvtermprop VALUES (439, 323, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (440, 1327, 159, 'Requested by Andy Schroder - Flybase Harvard, Nov 2006.', 0);
INSERT INTO chado.cvtermprop VALUES (441, 1328, 159, 'Term added Dec 06 to comply with mapping to MGED terms. It should be used to generate consensus regions. The specific cross product terms they require are consensus_region and consensus_mRNA.', 0);
INSERT INTO chado.cvtermprop VALUES (442, 1329, 159, 'DO not obsolete without considering MGED mapping.', 0);
INSERT INTO chado.cvtermprop VALUES (443, 1330, 159, 'DO not obsolete without considering MGED mapping.', 0);
INSERT INTO chado.cvtermprop VALUES (444, 1331, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (445, 1332, 159, 'This term is mapped to MGED. Do not obsolete without consulting MGED ontology.', 0);
INSERT INTO chado.cvtermprop VALUES (446, 1334, 159, 'Requested by Keith Boroevich December, 2006.', 0);
INSERT INTO chado.cvtermprop VALUES (447, 1335, 159, 'Renamed to cytosolic_16S_rRNA from rRNA_16S on 10 June 2021 as per restructuring of rRNA child terms. Updated definition to be consistent with format of other rRNA definitions. Request from EBI. See GitHub Issue #493.', 0);
INSERT INTO chado.cvtermprop VALUES (448, 1335, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (449, 1337, 159, 'Renamed from rRNA_23S to cytosolic_23S_rRNA on 27 May 2021 with the restructuring of rRNA child terms. Updated definition to be consistent with format of other rRNA definitions. Requested by EBI. See GitHub Issue #493.', 0);
INSERT INTO chado.cvtermprop VALUES (450, 1337, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (451, 1339, 159, 'Renamed from rRNA_5S to cytosolic_5S_rRNA on 27 May 2021 with the restructuring of rRNA child terms. Updated definition to be consistent with format of other rRNA definitions. Requested by EBI. See GitHub Issue #493.', 0);
INSERT INTO chado.cvtermprop VALUES (452, 1339, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (453, 1341, 159, 'Requested by Hadi Quesneville January 2007.', 0);
INSERT INTO chado.cvtermprop VALUES (454, 1345, 159, 'This is not cryptic in the same sense as a cryptic gene or cryptic splice site.', 0);
INSERT INTO chado.cvtermprop VALUES (455, 1351, 159, 'Added by request from Colin Batchelor.', 0);
INSERT INTO chado.cvtermprop VALUES (456, 1354, 159, 'Requested by Colin Batchelor, Feb 2007.', 0);
INSERT INTO chado.cvtermprop VALUES (457, 1357, 159, 'Added in March 2007 in after meeting with PharmGKB. Although this term is in common usage, it is better to annotate with the most specific term possible, such as synonymous codon, intron variant etc.', 0);
INSERT INTO chado.cvtermprop VALUES (458, 1359, 159, 'Requested by Trish Whetzel.', 0);
INSERT INTO chado.cvtermprop VALUES (459, 1360, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (460, 1361, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (461, 1371, 159, 'This terms is used by MO.', 0);
INSERT INTO chado.cvtermprop VALUES (462, 1372, 159, 'This term is used by MO.', 0);
INSERT INTO chado.cvtermprop VALUES (463, 1373, 159, 'Ruby et al. Nature 448:83 describe a new class of miRNAs that are derived from de-branched introns.', 0);
INSERT INTO chado.cvtermprop VALUES (464, 1075, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (465, 414, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (466, 1376, 159, 'The definitions of the children of this term were revised Decemeber 2007 after discussion on song-devel. The resulting definitions are slightly unweildy but hopefully more logically correct.', 0);
INSERT INTO chado.cvtermprop VALUES (467, 1378, 159, 'Definition change requested by Val, 3172757.', 0);
INSERT INTO chado.cvtermprop VALUES (468, 1381, 159, 'A term created to allow the parts of an inversion site have an is_a path back to the root.', 0);
INSERT INTO chado.cvtermprop VALUES (469, 1384, 159, 'Requested by Chris Smith, and others at Flybase to help annotate nested repeats.', 0);
INSERT INTO chado.cvtermprop VALUES (470, 344, 159, 'Previous parent term transcription_regulatory_region (SO:0001067) has been merged with this term on 11 Feb 2021 as part of the GREEKC consortium. See GitHub Issue #527.', 0);
INSERT INTO chado.cvtermprop VALUES (471, 344, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (472, 718, 159, 'Moved from transcription_regulatory_region (SO:0001679) to transcriptional_cis_regulatory_region (SO:0001055) by Dave Sant on Feb 11, 2021 when transcription_regulatory_region was merged into transcriptional_cis_regulatory_region to be consistent with GO and reduce redundancy as part of the GREEKC consortium. See GitHub Issue #527.', 0);
INSERT INTO chado.cvtermprop VALUES (473, 718, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (474, 1393, 159, 'Obsoleted Jan 21, 2021 by Dave Sant. GREEKC consortium individuals pointed out that this did not fit with the other child terms of transcriptional_cis_regulatory_region (SO:0001055), which are currently promoter, CRM and promoter flanking region. No comments about when this term was created exist, no references are listed. GREEKC members assume that this was previously under enhansosome (SO:0001057), which was probably created along with this term but has since been obsoleted. This term can be resurrected as non-obsolete if we can find a reference publication and/or change the name to a term that is commonly used in the field.', 0);
INSERT INTO chado.cvtermprop VALUES (475, 496, 159, 'Merged with partially characterized change in nucleotide sequence.', 0);
INSERT INTO chado.cvtermprop VALUES (476, 496, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (477, 1395, 159, 'Discrete.', 0);
INSERT INTO chado.cvtermprop VALUES (478, 1395, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (479, 811, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (480, 811, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (481, 815, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (482, 815, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (483, 815, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (484, 1397, 159, 'Hormones, neuropeptides, antimicrobial peptides, are active peptides. They are typically short (<40 amino acids) in length.', 0);
INSERT INTO chado.cvtermprop VALUES (485, 1397, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (486, 1398, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (487, 1398, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (488, 1399, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (489, 1399, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (490, 1400, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (491, 1400, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (492, 806, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (493, 806, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (494, 1401, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (495, 1401, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (496, 1402, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (497, 1402, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (498, 1403, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (499, 1404, 159, 'This could be inside an organelle within the cell.', 0);
INSERT INTO chado.cvtermprop VALUES (500, 1404, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (501, 1405, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (502, 1406, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (503, 1407, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (504, 1408, 159, 'Biosapien term was secondary_structure.', 0);
INSERT INTO chado.cvtermprop VALUES (505, 1408, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (506, 1409, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (507, 1410, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (508, 1410, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (509, 1411, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (510, 1413, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (511, 1413, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (512, 1414, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (513, 1415, 159, 'Discrete.', 0);
INSERT INTO chado.cvtermprop VALUES (514, 1415, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (515, 1416, 159, 'Discrete.', 0);
INSERT INTO chado.cvtermprop VALUES (516, 1416, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (517, 1417, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (518, 1418, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (519, 1419, 159, '2 discreet & joined.', 0);
INSERT INTO chado.cvtermprop VALUES (520, 1419, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (521, 1420, 159, 'Discrete.', 0);
INSERT INTO chado.cvtermprop VALUES (522, 1420, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (525, 1423, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (526, 1424, 159, 'Residue is part of a binding site for a metal ion.', 0);
INSERT INTO chado.cvtermprop VALUES (527, 1424, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (528, 1427, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (529, 1428, 159, 'Residue involved in contact with calcium.', 0);
INSERT INTO chado.cvtermprop VALUES (530, 1428, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (531, 1429, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (532, 1430, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (533, 1431, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (534, 1432, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (535, 1433, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (536, 1434, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (537, 1435, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (538, 1436, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (539, 1437, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (540, 1438, 159, 'Discrete.', 0);
INSERT INTO chado.cvtermprop VALUES (541, 1438, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (542, 1441, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (543, 1443, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (544, 1444, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (545, 1445, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (546, 1446, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (547, 1447, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (548, 1448, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (549, 1448, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (550, 1449, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (551, 1449, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (552, 1450, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (553, 1450, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (554, 1412, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (555, 1412, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (556, 1451, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (557, 1452, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (558, 1453, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (559, 1453, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (560, 1454, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (561, 1454, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (562, 1455, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (563, 1455, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (564, 1456, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (565, 1457, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (566, 1458, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (567, 1459, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (568, 1460, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (569, 1461, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (570, 1462, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (571, 1463, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (572, 1257, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (573, 1257, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (574, 1464, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (575, 1465, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (576, 1466, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (577, 1467, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (578, 1468, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (579, 1469, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (580, 1470, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (581, 1471, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (582, 1472, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (583, 1473, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (584, 1474, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (585, 1475, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (586, 1476, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (587, 1477, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (588, 1478, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (589, 1479, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (590, 1480, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (591, 1481, 159, 'For example, was a substitution natural or mutated as part of an experiment? This term is added to merge the biosapiens term sequence_variations.', 0);
INSERT INTO chado.cvtermprop VALUES (592, 1481, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (593, 1482, 159, 'Discrete.', 0);
INSERT INTO chado.cvtermprop VALUES (594, 1482, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (595, 1483, 159, 'Discrete.', 0);
INSERT INTO chado.cvtermprop VALUES (596, 1483, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (597, 1484, 159, 'Discrete.', 0);
INSERT INTO chado.cvtermprop VALUES (598, 1484, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (599, 1485, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (600, 1486, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (601, 1487, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (602, 1488, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (603, 1489, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (604, 1490, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (605, 1491, 159, 'This consensus sequence was identified computationally using the MEME algorithm within core promoter sequences from -60 to +40, with an E value of 1.7e-183. Tends to co-occur with Motif 7. Tends to not occur with DPE motif (SO:0000015) or motif 10.', 0);
INSERT INTO chado.cvtermprop VALUES (606, 1506, 159, 'This term has been merged into mt_LSU_rRNA (SO:0002345) as part of reorganization of rRNA child terms 10 June 2021. Requested by EBI. See GitHub Issue #493.', 0);
INSERT INTO chado.cvtermprop VALUES (607, 1513, 159, 'The definition is most of the old definition for snoRNA (SO:0000275).', 0);
INSERT INTO chado.cvtermprop VALUES (608, 1515, 159, 'Not to be confused with BRE_motif (SO:0000016), which binds transcription factor II B.', 0);
INSERT INTO chado.cvtermprop VALUES (609, 310, 159, 'Do not use this for feature annotation. Use morpholino_oligo (SO:0000034) instead.', 0);
INSERT INTO chado.cvtermprop VALUES (610, 1350, 159, 'Do not use this term for feature annotation. Use PNA_oligo (SO:0001011) instead.', 0);
INSERT INTO chado.cvtermprop VALUES (611, 749, 159, 'Do not use this for feature annotation. Use enzymatic_RNA (SO:0000372) instead.', 0);
INSERT INTO chado.cvtermprop VALUES (612, 754, 159, 'Do not use this for feature annotation. Use ribozyme (SO:0000374) instead.', 0);
INSERT INTO chado.cvtermprop VALUES (613, 1517, 159, 'Has RNA pseudouridylation guide activity (GO:0030558).', 0);
INSERT INTO chado.cvtermprop VALUES (614, 1518, 159, 'Do not use this term for feature annotation. Use LNA_oligo (SO:0001189) instead.', 0);
INSERT INTO chado.cvtermprop VALUES (615, 1520, 159, 'Do not use this term for feature annotation. Use TNA_oligo (SO:0001191) instead.', 0);
INSERT INTO chado.cvtermprop VALUES (616, 1522, 159, 'Do not use this term for feature annotation. Use GNA_oligo (SO:0001192) instead.', 0);
INSERT INTO chado.cvtermprop VALUES (617, 1524, 159, 'Do not use this term for feature annotation. Use R_GNA_oligo (SO:0001195) instead.', 0);
INSERT INTO chado.cvtermprop VALUES (618, 1526, 159, 'Do not use this term for feature annotation. Use S_GNA_oligo (SO:0001197) instead.', 0);
INSERT INTO chado.cvtermprop VALUES (619, 1533, 159, 'Term merged with promoter SO:0000167 in August 2020 as part of GREEKC initiative. See GitHub Issue 492 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/492)', 0);
INSERT INTO chado.cvtermprop VALUES (1233, 3031, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (620, 1534, 159, 'former parent RNA_polymerase_promoter SO:0001203 was merged with promoter SO:0000167 in Aug 2020 as part of GREEKC.', 0);
INSERT INTO chado.cvtermprop VALUES (621, 1541, 159, 'Added synonym ''ribosomal_slippage'' on Feb 1, 2021, a term in INSDC and GenBank. See GitHub Issue #522.', 0);
INSERT INTO chado.cvtermprop VALUES (622, 1544, 159, 'GO:0000374.', 0);
INSERT INTO chado.cvtermprop VALUES (623, 889, 159, 'An exon either containing but not starting with a start codon or containing but not ending with a stop codon will be partially coding and partially non coding.', 0);
INSERT INTO chado.cvtermprop VALUES (624, 889, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (625, 543, 159, 'An exon containing either a start or stop codon will be partially coding and partially non coding.', 0);
INSERT INTO chado.cvtermprop VALUES (626, 543, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (627, 851, 154, 'Alliance_of_Genome_Resources', 0);
INSERT INTO chado.cvtermprop VALUES (628, 1548, 159, 'RNA interference is GO:0016246.', 0);
INSERT INTO chado.cvtermprop VALUES (629, 1549, 159, 'Histone modification is GO:0016570.', 0);
INSERT INTO chado.cvtermprop VALUES (630, 1550, 159, 'Histone methylation is GO:0016571.', 0);
INSERT INTO chado.cvtermprop VALUES (631, 1551, 159, 'Histone deacetylation is GO:0016573.', 0);
INSERT INTO chado.cvtermprop VALUES (632, 1558, 159, 'The free molecule is CHEBI:17802.', 0);
INSERT INTO chado.cvtermprop VALUES (633, 1559, 159, 'The free molecule is CHEBI:17596.', 0);
INSERT INTO chado.cvtermprop VALUES (634, 1560, 159, 'The free molecule is CHEBI:2274.', 0);
INSERT INTO chado.cvtermprop VALUES (635, 1561, 159, 'The free molecule is CHEBI:30832.', 0);
INSERT INTO chado.cvtermprop VALUES (636, 492, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (637, 602, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (638, 1439, 159, 'Probably in the future this will cross reference to Chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (639, 1566, 159, 'Merged into promoter (SO:0000167) on 11 Feb 2021 by Dave Sant. GREEKC had asked us to merge these terms to reduce redundancy. See GitHub Issue #528', 0);
INSERT INTO chado.cvtermprop VALUES (640, 729, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (641, 1580, 159, 'Nature. 1986 Oct 16-22;323(6089):640-3.', 0);
INSERT INTO chado.cvtermprop VALUES (642, 1582, 159, 'This feature was requested by Nicole, tracker id 1911479. It is required to gather evidence together for annotation. An example would be overlapping ESTs that support an mRNA.', 0);
INSERT INTO chado.cvtermprop VALUES (643, 1584, 154, 'Alliance_of_Genome_Resources', 0);
INSERT INTO chado.cvtermprop VALUES (644, 1586, 159, 'Moved from ncRNA_gene to sncRNA_gene 27 April 2021 to be more consistent with the organization of the ncRNA branch of SO. Requested by FlyBase, moved by Dave Sant. See GitHub Issue #514.', 0);
INSERT INTO chado.cvtermprop VALUES (645, 1589, 159, 'Moved from ncRNA_gene to sncRNA_gene 27 April 2021 to be more consistent with the organization of the ncRNA branch of SO. Requested by FlyBase, moved by Dave Sant. See GitHub Issue #514. Added additional children of snoRNA on 18 Nov 2021 at the request of Steven Marygold. See GitHub Issue #519.', 0);
INSERT INTO chado.cvtermprop VALUES (646, 1590, 159, 'Moved from ncRNA_gene to sncRNA_gene 27 April 2021 to be more consistent with the organization of the ncRNA branch of SO. Requested by FlyBase, moved by Dave Sant. See GitHub Issue #514.', 0);
INSERT INTO chado.cvtermprop VALUES (647, 1592, 159, 'Moved from ncRNA_gene to sncRNA_gene 27 April 2021 to be more consistent with the organization of the ncRNA branch of SO. Requested by FlyBase, moved by Dave Sant. See GitHub Issue #514.', 0);
INSERT INTO chado.cvtermprop VALUES (648, 1593, 159, 'Moved from ncRNA_gene to sncRNA_gene 27 April 2021 to be more consistent with the organization of the ncRNA branch of SO. Requested by FlyBase, moved by Dave Sant. See GitHub Issue #514.', 0);
INSERT INTO chado.cvtermprop VALUES (649, 1107, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (650, 319, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (651, 262, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (652, 588, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (653, 1733, 159, 'Term requested by the MODencode group.', 0);
INSERT INTO chado.cvtermprop VALUES (654, 503, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (655, 1116, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (656, 1735, 159, 'MM Young, K Kirshenbaum, KA Dill & S Highsmith. Predicting conformational switches in proteins. Protein Science, 1999, 8, 1752-64. K. Kirshenbaum, M.M. Young and S. Highsmith. Predicting Allosteric Switches in Myosins. Protein Science 8(9):1806-1815. 1999.', 0);
INSERT INTO chado.cvtermprop VALUES (657, 1737, 159, 'An example is a read produced by Roche 454 technology.', 0);
INSERT INTO chado.cvtermprop VALUES (658, 1738, 159, 'An example of this kind of read is one produced by ABI SOLiD.', 0);
INSERT INTO chado.cvtermprop VALUES (659, 1739, 159, 'An example is a read produced by Illumina technology.', 0);
INSERT INTO chado.cvtermprop VALUES (660, 1740, 159, 'Moved from transcription_regulatory_region (SO:0001679) to transcriptional_cis_regulatory_region (SO:0001055) by Dave Sant on Feb 11, 2021 when transcription_regulatory_region was merged into transcriptional_cis_regulatory_region to be consistent with GO and reduce redundancy as part of the GREEKC consortium. See GitHub Issue #527.', 0);
INSERT INTO chado.cvtermprop VALUES (661, 1741, 159, 'From tracker [ 2372385 ] expressed_sequence_assembly.', 0);
INSERT INTO chado.cvtermprop VALUES (662, 1744, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (663, 1746, 159, 'Requested by the Trypanosome community.', 0);
INSERT INTO chado.cvtermprop VALUES (664, 1747, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (665, 1748, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (666, 1749, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (667, 1750, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (668, 1751, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (669, 1752, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (670, 1753, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (671, 1754, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (672, 1755, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (673, 1756, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (674, 1757, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (675, 1758, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (676, 1759, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (677, 1760, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (678, 1761, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (679, 1762, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (680, 1763, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (681, 1764, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (682, 1765, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (683, 1766, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (684, 1767, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (685, 1768, 159, 'A place holder for a cross product with chebi.', 0);
INSERT INTO chado.cvtermprop VALUES (686, 1769, 159, 'This term was requested by Jeff Bowes, using the tracker, ID = 2594157.', 0);
INSERT INTO chado.cvtermprop VALUES (687, 1770, 159, 'This term was requested by Jeff Bowes, using the tracker, ID = 2594157.', 0);
INSERT INTO chado.cvtermprop VALUES (688, 1772, 159, 'See tracker ID 2060908.', 0);
INSERT INTO chado.cvtermprop VALUES (689, 1774, 159, 'See tracker ID: 2138359.', 0);
INSERT INTO chado.cvtermprop VALUES (690, 1106, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (691, 1797, 159, 'X element combinatorial repeats contain Tbf1p binding sites, and possible functions include a role in telomerase-independent telomere maintenance via recombination or as a barrier against transcriptional silencing. These are usually present as a combination of one or more of several types of smaller elements (designated A, B, C, or D). This term was requested 2009-10-16 by Michel Dumontier, tracker id 2880747.', 0);
INSERT INTO chado.cvtermprop VALUES (692, 1798, 159, 'This term was requested 2009-10-16 by Michel Dumontier, tracker id 2880747.', 0);
INSERT INTO chado.cvtermprop VALUES (693, 1806, 159, 'Moved from transcription_regulatory_region (SO:0001679) to transcriptional_cis_regulatory_region (SO:0001055) by Dave Sant on Feb 11, 2021 when transcription_regulatory_region was merged into transcriptional_cis_regulatory_region to be consistent with GO and reduce redundancy as part of the GREEKC consortium. See GitHub Issue #527.', 0);
INSERT INTO chado.cvtermprop VALUES (694, 1807, 159, 'This term was requested 2009-10-16 by Michel Dumontier, tracker id 2880699.', 0);
INSERT INTO chado.cvtermprop VALUES (695, 1809, 159, 'This term was requested 2009-10-16 by Michel Dumontier, tracker id 2880699.', 0);
INSERT INTO chado.cvtermprop VALUES (696, 1810, 159, 'This term was requested 2009-10-16 by Michel Dumontier, tracker id 2880699.', 0);
INSERT INTO chado.cvtermprop VALUES (697, 1811, 159, 'The repeats are maintained by telomerase and there is generally 300 (+/-) 75 bp of TG(1-3) at a given end. Telomeric repeats function in completing chromosome replication and protecting the ends from degradation and end-to-end fusions. This term was requested 2009-10-16 by Michel Dumontier, tracker id 2880739.', 0);
INSERT INTO chado.cvtermprop VALUES (698, 1812, 159, 'Possible functions include roles in chromosomal segregation, maintenance of chromosome stability, recombinational sequestering, or as a barrier to transcriptional silencing. This term was requested 2009-10-16 by Michel Dumontier, tracker id 2880747.  From Janos Demeter: The only region shared by all chromosome ends, the X element core sequence is a small conserved element (~475 bp) that contains an ARS sequence and in most cases an Abf1p binding site. Between these is a GC-rich region nearly identical to the meiosis-specific regulatory sequence URS1.', 0);
INSERT INTO chado.cvtermprop VALUES (699, 1800, 159, 'This terms and children were added to SO in response to tracker request by Patrick Chain. The paper Genome Project Standards in a New Era of Sequencing. Science October 9th 2009, addresses these terms.', 0);
INSERT INTO chado.cvtermprop VALUES (700, 1814, 159, 'Term requested via tracker ID: 2910829.', 0);
INSERT INTO chado.cvtermprop VALUES (701, 1815, 159, 'Requested by tracker ID: 2902685.', 0);
INSERT INTO chado.cvtermprop VALUES (702, 1816, 159, 'Ensembl and Vega also use this term name. Requested by Howard Deen of MGI.', 0);
INSERT INTO chado.cvtermprop VALUES (703, 809, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (704, 1844, 159, 'Moved from under DNA_transposon (SO:0000182) by Dave Sant as per request from GitHub issue #488 on June 25, 2020', 0);
INSERT INTO chado.cvtermprop VALUES (705, 1845, 159, 'Updated after request from Lea Starita, lea.starita@gmail.com from the NCBI.', 0);
INSERT INTO chado.cvtermprop VALUES (706, 1878, 159, 'EBI term: Regulatory region variations - In regulatory region annotated by Ensembl.', 0);
INSERT INTO chado.cvtermprop VALUES (707, 1892, 159, 'EBI term: Complex InDel - Insertion or deletion that spans an exon/intron border or a coding sequence/UTR border.', 0);
INSERT INTO chado.cvtermprop VALUES (708, 1893, 159, 'EBI term: Stop lost - In coding sequence, resulting in the loss of a stop codon.', 0);
INSERT INTO chado.cvtermprop VALUES (709, 1900, 159, 'This is being used to annotate changes to the first codon of a transcript, when the first annotated codon is not to methionine. A variant is predicted to change the first amino acid of a translation irrespective of the fact that the underlying codon is an AUG. As such for transcripts with an incomplete CDS (sequence does not start with an AUG), it is still called.', 0);
INSERT INTO chado.cvtermprop VALUES (710, 1901, 159, 'EBI term: Non-synonymous SNPs. SNPs that are located in the coding sequence and result in an amino acid change in the encoded peptide sequence. A change that causes a non_synonymous_codon can be more than 3 bases - for example 4 base substitution.', 0);
INSERT INTO chado.cvtermprop VALUES (711, 1904, 159, 'EBI term: Stop gained - In coding sequence, resulting in the gain of a stop codon (i.e. leading to a shortened peptide sequence).', 0);
INSERT INTO chado.cvtermprop VALUES (712, 1906, 159, 'EBI term:Frameshift variations - In coding sequence, resulting in a frameshift.', 0);
INSERT INTO chado.cvtermprop VALUES (713, 1880, 159, 'The terminal codon may be the terminator, or in an incomplete transcript the last available codon.', 0);
INSERT INTO chado.cvtermprop VALUES (714, 1938, 159, 'Within non-coding gene - Located within a gene that does not code for a protein.', 0);
INSERT INTO chado.cvtermprop VALUES (715, 1939, 159, 'EBI term: Within mature miRNA - Located within a microRNA.', 0);
INSERT INTO chado.cvtermprop VALUES (716, 1942, 159, 'EBI term: 5prime UTR variations - In 5prime UTR (untranslated region).', 0);
INSERT INTO chado.cvtermprop VALUES (717, 1943, 159, 'EBI term 3prime UTR variations - In 3prime UTR.', 0);
INSERT INTO chado.cvtermprop VALUES (718, 1944, 159, 'EBI term: Partial codon - Located within the final, incomplete codon of a transcript with a shortened coding sequence where the end is unknown.', 0);
INSERT INTO chado.cvtermprop VALUES (719, 1946, 159, 'EBI term: Intronic variations - In intron.', 0);
INSERT INTO chado.cvtermprop VALUES (720, 1947, 159, 'EBI term Intergenic variations - More than 5 kb either upstream or downstream of a transcript.', 0);
INSERT INTO chado.cvtermprop VALUES (721, 1890, 159, 'EBI term - essential splice site - In the first 2 or the last 2 base pairs of an intron. The 5th base is on the donor (5'') side of the intron. Updated to b in line with Cancer Genome Project at the Sanger.', 0);
INSERT INTO chado.cvtermprop VALUES (722, 1948, 159, 'EBI term: splice site - 1-3 bps into an exon or 3-8 bps into an intron.', 0);
INSERT INTO chado.cvtermprop VALUES (723, 1949, 159, 'Different groups annotate up and downstream to different lengths. The subtypes are specific and are backed up with cross references.', 0);
INSERT INTO chado.cvtermprop VALUES (724, 1950, 159, 'Different groups annotate up and downstream to different lengths. The subtypes are specific and are backed up with cross references.', 0);
INSERT INTO chado.cvtermprop VALUES (725, 1951, 159, 'EBI term Downstream variations - Within 5 kb downstream of the 3prime end of a transcript.', 0);
INSERT INTO chado.cvtermprop VALUES (726, 1953, 159, 'EBI term Upstream variations - Within 5 kb upstream of the 5prime end of a transcript.', 0);
INSERT INTO chado.cvtermprop VALUES (727, 1955, 159, 'Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (728, 1956, 159, 'Moved from ncRNA_gene to sncRNA_gene 27 April 2021 to be more consistent with the organization of the ncRNA branch of SO. Requested by FlyBase, moved by Dave Sant. See GitHub Issue #514.', 0);
INSERT INTO chado.cvtermprop VALUES (729, 1957, 159, 'Moved under enzymatic_RNA_gene on 18 Nov 2021. See GitHub Issue #533.', 0);
INSERT INTO chado.cvtermprop VALUES (730, 1959, 159, 'Moved under enzymatic_RNA_gene on 18 Nov 2021. See GitHub Issue #533.', 0);
INSERT INTO chado.cvtermprop VALUES (731, 1962, 159, 'Mathematically defined repeat regions are determined without regard to the biological origin of the repetitive region. The repeat units of a MDR are the overlapping oligomers of size k that were used to for the query. Tools that can annotate mathematically defined repeats include Tallymer (Kurtz et al 2008, BMC Genomics: 517) and RePS (Wang et al, Genome Res 12(5): 824-831.).', 0);
INSERT INTO chado.cvtermprop VALUES (732, 1966, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (733, 347, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (734, 1280, 159, 'See GO:0000166 : nucleotide binding.', 0);
INSERT INTO chado.cvtermprop VALUES (735, 1425, 159, 'See GO:0046872 : metal ion binding.', 0);
INSERT INTO chado.cvtermprop VALUES (736, 1968, 159, 'Tracker ID: 3052459.', 0);
INSERT INTO chado.cvtermprop VALUES (737, 516, 159, 'Mmoved from is_a: SO:0001055 transcriptional_cis_regulatory_region as per request from GREEKC initiative in August 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (738, 1982, 159, 'The A box can be found in the promoters of type 1 and type 2 (pol III) so sub-typing here allows the part of relationship of the subtypes to remain true.', 0);
INSERT INTO chado.cvtermprop VALUES (739, 1983, 159, 'The A box can be found in the promoters of type 1 and type 2 (pol III) so sub-typing here allows the part of relationship of the subtypes to remain true.', 0);
INSERT INTO chado.cvtermprop VALUES (740, 1985, 159, 'Obsoleted by David Sant on 11 Feb 2021 when it was merged with transcriptional_cis_regulatory_region (SO:0001055) to reduce redundancy and be consistent with Gene Ontology. See GitHub Issue #527.', 0);
INSERT INTO chado.cvtermprop VALUES (741, 1985, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (742, 1126, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (743, 2026, 159, 'Term requested via tracker (2981725) by Alan Ruttenberg, April 2010. It has been described as both an enhancer and a promoter, so the parent is the more general term. Moved from is_a SO:0001055 transcriptional_cis_regulatory_region to SO:0000235 TF_binding_site after Colin Logie pointed out that this is a consensus sequence where transcription factors bind, GREEKC Jan 21, 2021.', 0);
INSERT INTO chado.cvtermprop VALUES (744, 671, 159, 'Moved from is_a biological_region (SO:0001411) to is_a regulatory_region (SO:0005836) on 11 Feb 2021. GREEKC members pointed out that this would be a more appropriate location. See GitHub Issue #530. 11 Feb 2021 updated definition along with addition of epigenomically_modified_region (SO:0002332). Epigenetically modified region is now not inherited while epigenomically modified region is not annotated as inherited. See GitHub Issue #532 and issue #534.', 0);
INSERT INTO chado.cvtermprop VALUES (745, 671, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (746, 2046, 159, 'Requested by flybase, Dec 2010.', 0);
INSERT INTO chado.cvtermprop VALUES (747, 2047, 159, 'Requested by flybase, Dec 2010.', 0);
INSERT INTO chado.cvtermprop VALUES (748, 2050, 154, 'DBVAR', 0);
INSERT INTO chado.cvtermprop VALUES (749, 2051, 154, 'DBVAR', 0);
INSERT INTO chado.cvtermprop VALUES (750, 2052, 154, 'DBVAR', 0);
INSERT INTO chado.cvtermprop VALUES (751, 2055, 159, 'Requested by John Calley 3125900.', 0);
INSERT INTO chado.cvtermprop VALUES (752, 2067, 159, 'This is different from a non processed pseudogene because the gene was not duplicated. An example is the L-gulono-lactone oxidase pseudogene in primates.', 0);
INSERT INTO chado.cvtermprop VALUES (753, 2090, 154, 'DBVAR', 0);
INSERT INTO chado.cvtermprop VALUES (754, 549, 154, 'DBVAR', 0);
INSERT INTO chado.cvtermprop VALUES (755, 2091, 154, 'DBVAR', 0);
INSERT INTO chado.cvtermprop VALUES (756, 273, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (757, 2104, 159, 'Term requested by M. Dumontier, June 1 2011.', 0);
INSERT INTO chado.cvtermprop VALUES (758, 2105, 159, 'Term requested by M. Dumontier, June 1 2011.', 0);
INSERT INTO chado.cvtermprop VALUES (759, 2106, 159, 'Note: PMID:18794354 describes the DDB box, and has lots of alignments, but doesn''t actually come out with a consensus sequence.', 0);
INSERT INTO chado.cvtermprop VALUES (760, 1881, 159, 'EBI term: Synonymous SNPs - In coding sequence, not resulting in an amino acid change (i.e. silent mutation). This term is sometimes used synonomously with the more general term ''silent mutation'', although a silent mutation may occur in non coding sequence. The best practice is to annotate to the most specific term.', 0);
INSERT INTO chado.cvtermprop VALUES (761, 2129, 159, 'Requested by Bayer Cropscience June, 2011.', 0);
INSERT INTO chado.cvtermprop VALUES (762, 2131, 159, 'Requested by Bayer Cropscience June, 2011.', 0);
INSERT INTO chado.cvtermprop VALUES (763, 2132, 159, 'Requested by Bayer Cropscience June, 2011.', 0);
INSERT INTO chado.cvtermprop VALUES (764, 2139, 159, 'Requested by the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (765, 2140, 159, 'Requested by the NCBI.', 0);
INSERT INTO chado.cvtermprop VALUES (766, 2142, 159, 'Changed to is_a SO:0001055 transcriptional_cis_regulatory_region from core_eukaryotic_promoter_element SO:0001660 after Ruth Lovering from GREEKC initiative pointed out that GATA boxes are frequently in enhancer regions, Dave Sant Aug 2020. Moved from is_a SO:0001055 transcriptional_cis_regulatory_region to SO:0000235 TF_binding_site after Colin Logie pointed out that this is a consensus sequence where transcription factors bind, GREEKC Jan 21, 2021.', 0);
INSERT INTO chado.cvtermprop VALUES (767, 2143, 159, 'This terms is used by Ensembl and Vega. Pseudogene owing to a SNP/DIP but in other individuals/haplotypes/strains the gene is translated.', 0);
INSERT INTO chado.cvtermprop VALUES (768, 2145, 159, 'New synonym Atf1/Pcr1 recognition motif added in response to Antonia Lock GitHub Issue Request #437, PMID:15716492', 0);
INSERT INTO chado.cvtermprop VALUES (769, 2153, 159, 'The synonym IDP (GATA) is found in an annotation but un-traced as far as literature goes.', 0);
INSERT INTO chado.cvtermprop VALUES (770, 2154, 159, 'Note that this should not be confused with the M-box that has consensus sequence CATGTG and is bound by bHLH transcription factors such as MITF.', 0);
INSERT INTO chado.cvtermprop VALUES (771, 2162, 159, 'Page 208 of ISBN:978-0199638901', 0);
INSERT INTO chado.cvtermprop VALUES (772, 2164, 159, 'paper:PMID:16043634.', 0);
INSERT INTO chado.cvtermprop VALUES (773, 2168, 159, 'Requested by Bayer Cropscience December, 2011.', 0);
INSERT INTO chado.cvtermprop VALUES (774, 2169, 159, 'Requested by Bayer Cropscience December, 2011.', 0);
INSERT INTO chado.cvtermprop VALUES (775, 2170, 159, 'Requested by Bayer Cropscience December, 2011.', 0);
INSERT INTO chado.cvtermprop VALUES (776, 2171, 159, 'Requested by Bayer Cropscience December, 2011.', 0);
INSERT INTO chado.cvtermprop VALUES (777, 2174, 159, 'NCBI definition: An orphan rearrangement between chromosomal location observed in isolation.', 0);
INSERT INTO chado.cvtermprop VALUES (778, 2177, 159, 'Requested by Bayer Cropscience January, 2012.', 0);
INSERT INTO chado.cvtermprop VALUES (779, 484, 159, 'Requested by Bayer Cropscience January, 2012.', 0);
INSERT INTO chado.cvtermprop VALUES (839, 2307, 159, 'Requested by Antonia Lock. Insulator is included as a related synonym since this is used to refer to insulator in the literature (NCBI:cf).', 0);
INSERT INTO chado.cvtermprop VALUES (840, 2308, 159, 'Requested by Midori Harris.', 0);
INSERT INTO chado.cvtermprop VALUES (780, 1776, 159, 'Updated the definition of lncRNA (SO:0001877) from "A non-coding RNA over 200nucleotides in length." to "A non-coding RNA generally longer than 200 nucleotides that cannot be classified as any other ncRNA subtype. Similar to mRNAs, lncRNAs are mainly transcribed by RNA polymerase II, are often capped by 7-methyl guanosine at their 5'' ends, polyadenylated at their 3'' ends and may be spliced." See GitHub Issue #575', 0);
INSERT INTO chado.cvtermprop VALUES (781, 1358, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (782, 2178, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (783, 2179, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (784, 2180, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (785, 1877, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (786, 2181, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (787, 2182, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (788, 2183, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (789, 2184, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (790, 2185, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (791, 2186, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (792, 2187, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (793, 2188, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (794, 2189, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (795, 2190, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (796, 2191, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (797, 2192, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (798, 2193, 159, 'Created in conjunction with the EBI.', 0);
INSERT INTO chado.cvtermprop VALUES (799, 2196, 159, 'For the S. pombe project - requested by Val Wood.', 0);
INSERT INTO chado.cvtermprop VALUES (800, 2197, 159, 'For the S. pombe project - requested by Val Wood.', 0);
INSERT INTO chado.cvtermprop VALUES (801, 2200, 159, 'Relationship is_a SO:0000644 antisense_RNA added 23 April 2021. See GitHub Issue #443', 0);
INSERT INTO chado.cvtermprop VALUES (802, 520, 159, 'Requested by Kevin Clancy - invitrogen -May 2012.', 0);
INSERT INTO chado.cvtermprop VALUES (803, 2206, 159, 'Requested by Midori - June 2012.', 0);
INSERT INTO chado.cvtermprop VALUES (804, 2213, 159, 'Requested by Bayer Cropscience, October, 2012.', 0);
INSERT INTO chado.cvtermprop VALUES (805, 2215, 159, 'Telomeric transcription has been documented in mammals, birds, fish, plants and yeast. Requested by Antonia Lock, October 2012.', 0);
INSERT INTO chado.cvtermprop VALUES (806, 2217, 159, 'Telomeric transcription has been documented in mammals, birds, fish, plants and yeast. Requested by Antonia Lock, October 2012.', 0);
INSERT INTO chado.cvtermprop VALUES (807, 2218, 159, 'Telomeric transcription has been documented in mammals, birds, fish, plants and yeast. Requested by Antonia Lock, October 2012.', 0);
INSERT INTO chado.cvtermprop VALUES (808, 2219, 159, 'Telomeric transcription has been documented in mammals, birds, fish, plants and yeast. Requested by Antonia Lock, October 2012.', 0);
INSERT INTO chado.cvtermprop VALUES (809, 2220, 159, 'This term is used by Complete Genomics in the structural variant analysis files.', 0);
INSERT INTO chado.cvtermprop VALUES (810, 2222, 159, 'Requested by Bayer Cropscience, October, 2012.', 0);
INSERT INTO chado.cvtermprop VALUES (811, 2223, 159, 'Requested by Bayer Cropscience, October, 2012.', 0);
INSERT INTO chado.cvtermprop VALUES (812, 2224, 159, 'Requested by Bayer Cropscience November, 2012.', 0);
INSERT INTO chado.cvtermprop VALUES (813, 1992, 159, 'Not a great term for annotation, but used to classify the various regions related to restriction enzymes.', 0);
INSERT INTO chado.cvtermprop VALUES (814, 2252, 159, 'Requested by PomBase 3604508.', 0);
INSERT INTO chado.cvtermprop VALUES (815, 2264, 159, 'Requested by Jackie Quinn. The sticky restriction sites are different from junctions because they include the sequence that is cut, inclusive of the five prime junction and the three prime junction.', 0);
INSERT INTO chado.cvtermprop VALUES (816, 2265, 159, 'Requested by Jackie Quinn. The sticky restriction sites are different from junctions because they include the sequence that is cut, inclusive of the five prime junction and the three prime junction.', 0);
INSERT INTO chado.cvtermprop VALUES (817, 2267, 159, 'Requested by Jackie Quinn for use in synthetic biology.', 0);
INSERT INTO chado.cvtermprop VALUES (818, 2269, 159, 'A plant specific region.', 0);
INSERT INTO chado.cvtermprop VALUES (819, 2272, 159, 'Requested by Andy Menzies at the Sanger. This isn''t necessarily a protein coding change. A premature start codon can effect the production of a mature protein product by providing a competing translation start point. Some genes balance their expression this way, eg THPO requires the presence of a premature start to limit expression, its loss leads to Familial thrombocythemia.', 0);
INSERT INTO chado.cvtermprop VALUES (820, 2275, 159, 'Requested by Midori Harris, 2013.', 0);
INSERT INTO chado.cvtermprop VALUES (821, 2276, 159, 'Requested by Graham Ritchie, EBI/Sanger.', 0);
INSERT INTO chado.cvtermprop VALUES (822, 2277, 159, 'Requested by Graham Ritchie, EBI/Sanger.', 0);
INSERT INTO chado.cvtermprop VALUES (823, 2281, 159, 'Requested by Bayer Cropscience September, 2013.', 0);
INSERT INTO chado.cvtermprop VALUES (824, 2282, 159, 'Added by Andy Menzies (Sanger).', 0);
INSERT INTO chado.cvtermprop VALUES (825, 2284, 159, 'Added by Andy Menzies (Sanger).', 0);
INSERT INTO chado.cvtermprop VALUES (826, 2289, 159, 'Requested by Janos Demeter, SGD.', 0);
INSERT INTO chado.cvtermprop VALUES (827, 2290, 159, 'Requested by Janos Demeter, SGD.', 0);
INSERT INTO chado.cvtermprop VALUES (828, 2291, 159, 'Requested by Janos Demeter, SGD.', 0);
INSERT INTO chado.cvtermprop VALUES (829, 2293, 159, 'Requested by Antonia Locke, (Pombe).', 0);
INSERT INTO chado.cvtermprop VALUES (830, 2294, 159, 'This element is bound by Loz1 in S. pombe. The paper does not name the element. This term was requested by Midoris Harris, for Pombe.', 0);
INSERT INTO chado.cvtermprop VALUES (831, 2295, 159, 'Request from Uma Devi Paila, UVA. Variants in the sites of rare amino acids e.g. Selenocysteine. These are important impact terms since a loss of such rare amino acids may lead to a loss of function.', 0);
INSERT INTO chado.cvtermprop VALUES (832, 2296, 159, 'Request from Uma Devi Paila, UVA. Variants in the sites of rare amino acids e.g. Selenocysteine. These are important impact terms since a loss of such rare amino acids may lead to a loss of function.', 0);
INSERT INTO chado.cvtermprop VALUES (833, 2297, 159, 'Request from Uma Devi Paila, UVA. Variants in the sites of rare amino acids e.g. Selenocysteine. These are important impact terms since a loss of such rare amino acids may lead to a loss of function.', 0);
INSERT INTO chado.cvtermprop VALUES (834, 2298, 159, 'Requested by Pablo Cingolani, for use in SnpEff.', 0);
INSERT INTO chado.cvtermprop VALUES (835, 2299, 159, 'Request from Uma Devi Paila, UVA. This term should not be applied to incomplete transcripts.', 0);
INSERT INTO chado.cvtermprop VALUES (836, 2304, 159, 'Requested by Uma Paila (UVA) for snpEff.', 0);
INSERT INTO chado.cvtermprop VALUES (837, 2305, 159, 'Requested by Uma Paila (UVA) for snpEff.', 0);
INSERT INTO chado.cvtermprop VALUES (838, 2306, 159, 'Requested by Uma Paila as this term is annotated by snpEff. This would be used for non_AUG start codon annotation.', 0);
INSERT INTO chado.cvtermprop VALUES (841, 2311, 159, 'MERGED COMMENT: TARGET COMMENT: Requested by Janos Demeter, SGD.', 0);
INSERT INTO chado.cvtermprop VALUES (842, 2312, 159, 'Comment: An example of this is the Sme2 locus in fission yeast S. pombe, where is coincident with an ribonuclear complex termed the "Mei2 dot". This term was Requested by Val Wood, PomBase.', 0);
INSERT INTO chado.cvtermprop VALUES (843, 2313, 159, 'Requested by Janos Demeter 2014.', 0);
INSERT INTO chado.cvtermprop VALUES (844, 2319, 159, 'MoRs are generated from miR hairpins that are longer and can produce two functional miR per strand. They are called moRs because they are not located next to the loop and thus their biogenesis process is a little different, but functionally, they are supposed to act like miRs. It is the same for loRs that are the loop fragments, they are generated differently than miRs or moRs but if loaded into the risc they are supposed to act the same way miRs do. Requested by Thomas Desvignes, Jan 2015.', 0);
INSERT INTO chado.cvtermprop VALUES (845, 2320, 159, 'MoRs are generated from miR hairpins that are longer and can produce two functional miR per strand. They are called moRs because they are not located next to the loop and thus their biogenesis process is a little different, but functionally, they are supposed to act like miRs. It is the same for loRs that are the loop fragments, they are generated differently than miRs or moRs but if loaded into the risc they are supposed to act the same way miRs do. Requested by Thomas Desvignes, Jan 2015.', 0);
INSERT INTO chado.cvtermprop VALUES (846, 2331, 159, 'Requested by Rama - SGD.', 0);
INSERT INTO chado.cvtermprop VALUES (847, 2332, 159, 'Requested by Rama, SGD.', 0);
INSERT INTO chado.cvtermprop VALUES (848, 2333, 159, 'Requested by Rama, SGD.', 0);
INSERT INTO chado.cvtermprop VALUES (849, 2334, 159, 'Moved from transcription_regulatory_region (SO:0001679) to transcriptional_cis_regulatory_region (SO:0001055) by Dave Sant on Feb 11, 2021 when transcription_regulatory_region was merged into transcriptional_cis_regulatory_region to be consistent with GO and reduce redundancy as part of the GREEKC consortium. See GitHub Issue #527.', 0);
INSERT INTO chado.cvtermprop VALUES (850, 2336, 159, 'Requested by: Sagar Jain, Richard Scheuermann.', 0);
INSERT INTO chado.cvtermprop VALUES (851, 2339, 159, 'Requested by Deanna Church.', 0);
INSERT INTO chado.cvtermprop VALUES (852, 2343, 159, 'Requested by Javier Diez Perez.', 0);
INSERT INTO chado.cvtermprop VALUES (853, 2345, 159, 'Requested by Javier Diez Perez.', 0);
INSERT INTO chado.cvtermprop VALUES (854, 2362, 159, 'This term is requested by the ClinVar data model group for use in the allele registry and such. A sequence at a defined location that is defined to match the reference assembly.', 0);
INSERT INTO chado.cvtermprop VALUES (855, 2363, 159, 'This term is added to map to the Annovar annotation ''upstream,downstream'' .', 0);
INSERT INTO chado.cvtermprop VALUES (856, 2364, 159, 'This term is to map to the ANNOVAR term ''ncRNA'' http://annovar.openbioinformatics.org/en/latest/user-guide/gene/ . The description in the documentation (11/23/15) ''variant overlaps a transcript without coding annotation in the gene definition''. and this is further clarified in the document: ncRNA above refers to RNA without coding annotation. It does not mean that this is a RNA that will never be translated; it merely means that the user-selected gene annotation system was not able to give a coding sequence annotation. It could still code protein products and may have such annotations in future versions of gene annotation or in another gene annotation system. For example, BC039000 is regarded as ncRNA by ANNOVAR when using UCSC Known Gene annotation, but it is regarded as a protein-coding gene by ANNOVAR when using ENSEMBL annotation.  It is further clarified in the comments section as: ncRNA does NOT mean conventional non-coding RNA. It means a RNA without complete coding sequence, and it can be a coding RNA that is annotated incorrectly by RefSeq or other gene definition systems.', 0);
INSERT INTO chado.cvtermprop VALUES (857, 2374, 159, 'Requested by SNPEFF team. Feb 2016.', 0);
INSERT INTO chado.cvtermprop VALUES (858, 2375, 159, 'Requested by SNPEFF team. Feb 2016.', 0);
INSERT INTO chado.cvtermprop VALUES (859, 2378, 159, 'Requested by visze github tracker ID 346.', 0);
INSERT INTO chado.cvtermprop VALUES (860, 2379, 159, 'Requested by visze github tracker ID 346.', 0);
INSERT INTO chado.cvtermprop VALUES (861, 2380, 159, 'Requested by visze github tracker ID 346.', 0);
INSERT INTO chado.cvtermprop VALUES (862, 2381, 159, 'Requested by visze github tracker ID 346.', 0);
INSERT INTO chado.cvtermprop VALUES (863, 2382, 159, 'Requested by Pablo Cingolani. The way I calculate this is simply by looking at the PDB entry of one protein and then marking those AA that are within 3 Angstrom of each other (and far away in the AA sequence, e.g. over 20 AA distance). The assumption is that, since they are very close in distance, they must be "interacting" and thus important for protein structure.', 0);
INSERT INTO chado.cvtermprop VALUES (864, 2384, 159, 'Moved from is_a ncRNA (SO:0000655) to is_a snoRNA (SO:0000275) as per request from FlyBase by Dave Sant 24 April 2021. See GitHub Issue #509.', 0);
INSERT INTO chado.cvtermprop VALUES (865, 2386, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (866, 2387, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (867, 2388, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (868, 2389, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (869, 2390, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (870, 2391, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (871, 2392, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (872, 2393, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (873, 2394, 159, 'Term added as part of collaboration with Gencode, adding biotypes used in annotation.', 0);
INSERT INTO chado.cvtermprop VALUES (874, 2395, 159, 'Term added as part of collaboration with Gencode, adding biotypes used in annotation.', 0);
INSERT INTO chado.cvtermprop VALUES (875, 2396, 159, 'Term added as part of collaboration with Gencode, adding biotypes used in annotation.', 0);
INSERT INTO chado.cvtermprop VALUES (876, 2397, 159, 'Term added as part of collaboration with Gencode, adding biotypes used in annotation.', 0);
INSERT INTO chado.cvtermprop VALUES (877, 2398, 159, 'Term added as part of collaboration with Gencode, adding biotypes used in annotation.', 0);
INSERT INTO chado.cvtermprop VALUES (878, 2399, 159, 'Term added as part of collaboration with Gencode, adding biotypes used in annotation.', 0);
INSERT INTO chado.cvtermprop VALUES (879, 2400, 159, 'Term added as part of collaboration with Gencode, adding biotypes used in annotation.', 0);
INSERT INTO chado.cvtermprop VALUES (880, 2401, 159, 'Term added as part of collaboration with Gencode, adding biotypes used in annotation.', 0);
INSERT INTO chado.cvtermprop VALUES (881, 2402, 159, 'Term added as part of collaboration with Gencode, adding biotypes used in annotation.', 0);
INSERT INTO chado.cvtermprop VALUES (882, 2403, 159, 'Term added as part of collaboration with Gencode, adding biotypes used in annotation.', 0);
INSERT INTO chado.cvtermprop VALUES (883, 2404, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes.', 0);
INSERT INTO chado.cvtermprop VALUES (884, 2405, 159, 'Term added as part of collaboration with Gencode, adding biotypes used in annotation.', 0);
INSERT INTO chado.cvtermprop VALUES (885, 2407, 159, 'Term added as part of collaboration with Gencode, adding biotypes used in annotation.', 0);
INSERT INTO chado.cvtermprop VALUES (886, 2408, 159, 'Requested by HL7 clinical genomics group.', 0);
INSERT INTO chado.cvtermprop VALUES (887, 2409, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes.', 0);
INSERT INTO chado.cvtermprop VALUES (888, 2410, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (889, 2411, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (890, 2412, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (891, 2413, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (892, 2414, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (893, 2415, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (894, 1961, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes.', 0);
INSERT INTO chado.cvtermprop VALUES (895, 2416, 159, 'Updated definition to be consistent with format of other rRNA definitions on 10 June 2021. Requested by EBI. See GitHub Issue #493.', 0);
INSERT INTO chado.cvtermprop VALUES (896, 2419, 159, 'Updating the names of sense_intronic_ncRNA (SO:0002131), sense_overlap_ncRNA (SO:0002132), sense_overlap_ncRNA_gene (SO:0002183), and sense_intronic_ncRNA_gene (SO:0002184) to _lncRNA. See GitHub Issue #579.', 0);
INSERT INTO chado.cvtermprop VALUES (897, 2420, 159, 'Updating the names of sense_intronic_ncRNA (SO:0002131), sense_overlap_ncRNA (SO:0002132), sense_overlap_ncRNA_gene (SO:0002183), and sense_intronic_ncRNA_gene (SO:0002184) to _lncRNA. See GitHub Issue #579.', 0);
INSERT INTO chado.cvtermprop VALUES (898, 2421, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (899, 2422, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (900, 2423, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (901, 2424, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (902, 2425, 159, 'These terms have been requested by Adam Frankish to support Gencode and Vega biotypes. The terms are defined according to IGMT.', 0);
INSERT INTO chado.cvtermprop VALUES (903, 2442, 159, 'Requested by Antonia Lock', 0);
INSERT INTO chado.cvtermprop VALUES (904, 2456, 159, 'This definition is from GO:0061820 telomeric D-loop disassembly.', 0);
INSERT INTO chado.cvtermprop VALUES (905, 2467, 159, 'Updating the names of sense_intronic_ncRNA (SO:0002131), sense_overlap_ncRNA (SO:0002132), sense_overlap_ncRNA_gene (SO:0002183), and sense_intronic_ncRNA_gene (SO:0002184) to _lncRNA. See GitHub Issue #579.', 0);
INSERT INTO chado.cvtermprop VALUES (906, 2468, 159, 'Updating the names of sense_intronic_ncRNA (SO:0002131), sense_overlap_ncRNA (SO:0002132), sense_overlap_ncRNA_gene (SO:0002183), and sense_intronic_ncRNA_gene (SO:0002184) to _lncRNA. See GitHub Issue #579.', 0);
INSERT INTO chado.cvtermprop VALUES (907, 2469, 159, 'This is a gencode term. See GitHub Issue #408. Synonyms "bidirectional promoter lncRNA gene" and "bidirectional_promoter_lncRNA_gene" added 23 April 2021 by David Sant. See GitHub Issue #506.', 0);
INSERT INTO chado.cvtermprop VALUES (908, 2472, 159, 'A functional_gene_region is a sequence feature that resides within a gene. But it is typically the corresponding region of translated/transcribed sequence in a gene product, that performs the molecular function qualifying it as a functional_gene_region. Here, a functional_gene_region must contribute directly to the molecular function of the gene product - regions that code for purely structural elements in a gene product that connect such directly functional elements together are not considered functional_gene_regions. Examples of regions considered ''functional'' include those encoding enzymatic activity, binding activity, regions required for localization or membrane association, channel-forming regions, and signal peptides or other elements critical for processing of a gene product. In addition, regions that function at the genomic/DNA level are also included - e.g. regions of sequence known to be critical for binding transcription or splicing factors.', 0);
INSERT INTO chado.cvtermprop VALUES (909, 2474, 159, 'Insulator is included as a related synonym since this is used to refer to insulator in the literature (NCBI:cf).', 0);
INSERT INTO chado.cvtermprop VALUES (910, 2475, 159, 'Moved from is_a regulatory_region (SO:0005836) to is_a epigenetically_modified_region (SO:0001720) on 11 Feb 2021. GREEKC members pointed out that this would be a more appropriate location. See GitHub Issue #530.', 0);
INSERT INTO chado.cvtermprop VALUES (911, 2488, 159, 'Moved from transcription_regulatory_region (SO:0001679) to transcriptional_cis_regulatory_region (SO:0001055) by Dave Sant on Feb 11, 2021 when transcription_regulatory_region was merged into transcriptional_cis_regulatory_region to be consistent with GO and reduce redundancy as part of the GREEKC consortium. See GitHub Issue #527.', 0);
INSERT INTO chado.cvtermprop VALUES (912, 2489, 159, 'Terms such as genomic_DNA or mRNA can be used to describe a sequence source.', 0);
INSERT INTO chado.cvtermprop VALUES (913, 2492, 159, 'Requested by Bayer Crop Science, March 2018', 0);
INSERT INTO chado.cvtermprop VALUES (914, 2493, 159, 'Requested by Bayer Crop Science, March 2018', 0);
INSERT INTO chado.cvtermprop VALUES (915, 2500, 159, 'This term is used when there is a change that is either an insertion or a deletion but it is unknown which event occurred.', 0);
INSERT INTO chado.cvtermprop VALUES (916, 1848, 159, 'Added after request from Lea Starita, lea.starita@gmail.com from the NCBI Feb 2019.', 0);
INSERT INTO chado.cvtermprop VALUES (917, 2501, 159, 'Added after request from Lea Starita, lea.starita@gmail.com from the NCBI Feb 2019.', 0);
INSERT INTO chado.cvtermprop VALUES (918, 2502, 159, 'Added after request from Lea Starita, lea.starita@gmail.com from the NCBI Feb 2019.', 0);
INSERT INTO chado.cvtermprop VALUES (919, 2503, 159, 'Updated by Evan Christensen on May 27, 2021 per github request https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/494', 0);
INSERT INTO chado.cvtermprop VALUES (920, 2504, 159, 'Added by Dave Sant on October 21, 2019 per github request https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/475', 0);
INSERT INTO chado.cvtermprop VALUES (921, 2505, 159, 'Added on October 30, 2019 as per request of Val Wood request on GitHub Issue# 476 https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/476', 0);
INSERT INTO chado.cvtermprop VALUES (922, 2507, 159, 'Added as per request by Edward Wallace GitHub issue #480 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/480)', 0);
INSERT INTO chado.cvtermprop VALUES (923, 1930, 159, 'Added as per request by Edward Wallace GitHub issue #480 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/480)', 0);
INSERT INTO chado.cvtermprop VALUES (924, 1928, 159, 'Added as per request by Edward Wallace GitHub issue #480 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/480)', 0);
INSERT INTO chado.cvtermprop VALUES (925, 2508, 159, 'Added as per request by Val Wood GitHub issue #479 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/479)', 0);
INSERT INTO chado.cvtermprop VALUES (926, 2509, 159, 'Added as per request by John T. Sexton GitHub issue #470 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/470)', 0);
INSERT INTO chado.cvtermprop VALUES (927, 2510, 159, 'Added as per request by Bryan Bartley GitHub issue #468 and #402 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/468)', 0);
INSERT INTO chado.cvtermprop VALUES (928, 2511, 159, 'Added as per request by Val Wood GitHub issue #483 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/483)', 0);
INSERT INTO chado.cvtermprop VALUES (929, 2512, 159, 'Added as per request by Val Wood GitHub issue #455 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/455)', 0);
INSERT INTO chado.cvtermprop VALUES (930, 2513, 159, 'Added as per request GitHub issue #434 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/434)', 0);
INSERT INTO chado.cvtermprop VALUES (931, 794, 159, 'Added as per request by Antonia Lock GitHub issue #472 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/472). Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (932, 1336, 159, 'Added as per request by Antonia Lock GitHub issue #472 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/472). Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (933, 1061, 159, 'Added as per request by Antonia Lock GitHub issue #472 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/472). Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (934, 1063, 159, 'Added as per request by Antonia Lock GitHub issue #472 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/472). Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (935, 757, 159, 'Added as per request by Antonia Lock GitHub issue #472 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/472). Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (936, 2516, 159, 'Added as per request by Antonia Lock GitHub issue #472 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/472) Removed relationship derives_from SO:0001171 on 10 June 2021 when SO:0001171 rRNA_21S was obsoleted into SO:0002345 mt_LSU_rRNA. See GitHub Issue #493. OBSOLETED on 12 September 2022, merged into SO:0002364 mt_LSU_rRNA_gene see GitHub Issue #513.', 0);
INSERT INTO chado.cvtermprop VALUES (937, 1340, 159, 'Added as per request by Antonia Lock GitHub issue #472 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/472). Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (938, 1338, 159, 'Added as per request by Antonia Lock GitHub issue #472 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/472). Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (939, 2517, 159, 'Added as per request from the Illumina group', 0);
INSERT INTO chado.cvtermprop VALUES (940, 2518, 159, 'Added as per request from the Illumina group', 0);
INSERT INTO chado.cvtermprop VALUES (941, 2519, 159, 'Added as per request from the Illumina group', 0);
INSERT INTO chado.cvtermprop VALUES (942, 606, 159, 'Added as per request from GitHub Issue #485 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/485)', 0);
INSERT INTO chado.cvtermprop VALUES (943, 2520, 159, 'Added as per request from GitHub Issue #478 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/478)', 0);
INSERT INTO chado.cvtermprop VALUES (944, 814, 159, 'Added as per request from GitHub Issue #484 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/484)', 0);
INSERT INTO chado.cvtermprop VALUES (945, 1396, 159, 'Added as per request from GitHub Issue #484 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/484)', 0);
INSERT INTO chado.cvtermprop VALUES (946, 810, 159, 'Added as per request from GitHub Issue #484 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/484)', 0);
INSERT INTO chado.cvtermprop VALUES (947, 1136, 159, 'Added as per request from GitHub Issue #484 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/484)', 0);
INSERT INTO chado.cvtermprop VALUES (948, 2521, 159, 'Added as per request from GitHub Issue #451 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/451)', 0);
INSERT INTO chado.cvtermprop VALUES (949, 2522, 159, 'Added as per request from GitHub Issue #451 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/451)', 0);
INSERT INTO chado.cvtermprop VALUES (950, 2523, 159, 'Added as per request from GitHub Issue #451 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/451)', 0);
INSERT INTO chado.cvtermprop VALUES (951, 2524, 159, 'Added as per request from GitHub Issue #451 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/451)', 0);
INSERT INTO chado.cvtermprop VALUES (952, 2525, 159, 'Added as per request from GitHub Issue #487 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/487)', 0);
INSERT INTO chado.cvtermprop VALUES (953, 2526, 159, 'Requested by Antonia Locke, (Pombe) as per GitHub Issue Request #439 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/439)', 0);
INSERT INTO chado.cvtermprop VALUES (954, 2527, 159, 'Added as per GitHub Issue Request #450 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/450)', 0);
INSERT INTO chado.cvtermprop VALUES (955, 2528, 159, 'Added as per GitHub Issue Request #429 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/429)', 0);
INSERT INTO chado.cvtermprop VALUES (956, 2529, 159, 'Added as per GitHub Issue Request #429 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/429)', 0);
INSERT INTO chado.cvtermprop VALUES (957, 2530, 159, 'Added as per GitHub Issue Request #419 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/419)', 0);
INSERT INTO chado.cvtermprop VALUES (958, 2531, 159, 'Added as per GitHub Issue Request #419 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/419)', 0);
INSERT INTO chado.cvtermprop VALUES (1229, 3027, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (959, 2532, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (960, 2533, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (961, 2534, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (962, 2535, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (963, 2356, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (964, 2536, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (965, 2537, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (966, 2538, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (967, 2352, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (968, 2539, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (969, 2540, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (970, 2541, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (971, 2542, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (972, 2543, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (973, 2544, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (974, 2545, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (975, 2546, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (976, 2547, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (977, 2548, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (978, 2549, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (979, 2550, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (980, 2551, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (981, 2552, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (982, 2553, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (983, 2554, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (984, 2555, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (985, 2556, 159, 'Added as per GitHub Issue Request #488 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/488)', 0);
INSERT INTO chado.cvtermprop VALUES (986, 2557, 159, 'Added as per GitHub Issue Request #490 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/490) and GitHub Issue Request #391 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/391)', 0);
INSERT INTO chado.cvtermprop VALUES (987, 2558, 159, 'Added as per GitHub Issue Request #490 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/490) and GitHub Issue Request #391 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/391)', 0);
INSERT INTO chado.cvtermprop VALUES (988, 2559, 159, 'Added as per GitHub Issue Request #417 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/417) from INSDC', 0);
INSERT INTO chado.cvtermprop VALUES (989, 2560, 159, 'Added as per request by Terence Murphy (INSDC) for GitHub Issue #417 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/417)', 0);
INSERT INTO chado.cvtermprop VALUES (990, 2561, 159, 'Added as per Mejia-Almonte et.al PMID:32665585', 0);
INSERT INTO chado.cvtermprop VALUES (991, 2562, 159, 'Added as per Mejia-Almonte et.al PMID:32665585. Moved from transcription_regulatory_region (SO:0001679) to transcriptional_cis_regulatory_region (SO:0001055) by Dave Sant on Feb 11, 2021 when transcription_regulatory_region was merged into transcriptional_cis_regulatory_region to be consistent with GO and reduce redundancy as part of the GREEKC consortium. See GitHub Issue #527.', 0);
INSERT INTO chado.cvtermprop VALUES (992, 2563, 159, 'Added as per Mejia-Almonte et.al PMID:32665585. Moved from transcription_regulatory_region (SO:0001679) to transcriptional_cis_regulatory_region (SO:0001055) by Dave Sant on Feb 11, 2021 when transcription_regulatory_region was merged into transcriptional_cis_regulatory_region to be consistent with GO and reduce redundancy as part of the GREEKC consortium. See GitHub Issue #527.', 0);
INSERT INTO chado.cvtermprop VALUES (993, 2564, 159, 'Added as per Mejia-Almonte et.al PMID:32665585', 0);
INSERT INTO chado.cvtermprop VALUES (994, 2565, 159, 'Added as per Mejia-Almonte et.al PMID:32665585', 0);
INSERT INTO chado.cvtermprop VALUES (995, 1083, 159, 'Added as per Mejia-Almonte et.al PMID:32665585', 0);
INSERT INTO chado.cvtermprop VALUES (996, 2566, 159, 'Added as per Mejia-Almonte et.al PMID:32665585', 0);
INSERT INTO chado.cvtermprop VALUES (997, 2567, 159, 'Added as per Mejia-Almonte et.al PMID:32665585', 0);
INSERT INTO chado.cvtermprop VALUES (998, 2569, 159, 'Added as per Mejia-Almonte et.al PMID:32665585', 0);
INSERT INTO chado.cvtermprop VALUES (999, 2570, 159, 'Added by Dave to be consistent with other ontologies updated with GREEKC initiative.', 0);
INSERT INTO chado.cvtermprop VALUES (1000, 2571, 159, 'Added by Dave to be consistent with other ontologies updated with GREEKC initiative.', 0);
INSERT INTO chado.cvtermprop VALUES (1001, 2572, 159, 'Added by Dave to be consistent with other ontologies updated with GREEKC initiative.', 0);
INSERT INTO chado.cvtermprop VALUES (1002, 2573, 159, 'Added by Dave to be consistent with other ontologies updated with GREEKC initiative. DS updated defintion Feb 16, 2021. See GitHub Issue #534.', 0);
INSERT INTO chado.cvtermprop VALUES (1003, 2574, 159, 'Added by Dave to be consistent with other ontologies updated with GREEKC initiative. DS updated defintion Feb 16, 2021. See GitHub Issue #534.', 0);
INSERT INTO chado.cvtermprop VALUES (1004, 682, 159, 'Added by Dave to be consistent with other ontologies updated with GREEKC initiative.', 0);
INSERT INTO chado.cvtermprop VALUES (1005, 2575, 159, 'Added by Dave to be consistent with other ontologies updated with GREEKC initiative.', 0);
INSERT INTO chado.cvtermprop VALUES (1006, 2578, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020. See Issue Request #501 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/501). Updated definition 17 Feb 2023 along with updates from GenCC. See Issue Request #612.', 0);
INSERT INTO chado.cvtermprop VALUES (1007, 2579, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020. See Issue Request #501 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/501). Updated definition 17 Feb 2023 along with updates from GenCC. See Issue Request #612.', 0);
INSERT INTO chado.cvtermprop VALUES (1008, 2580, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020. See Issue Request #501 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/501). Updated definition 17 Feb 2023 along with updates from GenCC. See Issue Request #612.', 0);
INSERT INTO chado.cvtermprop VALUES (1009, 2581, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020. See Issue Request #501 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/501). Updated definition 17 Feb 2023 along with updates from GenCC. See Issue Request #612.', 0);
INSERT INTO chado.cvtermprop VALUES (1010, 2582, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020. See Issue Request #501 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/501)', 0);
INSERT INTO chado.cvtermprop VALUES (1011, 2583, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (1012, 2584, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (1013, 2585, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (1014, 2586, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (1015, 2587, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (1016, 2588, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (1017, 2589, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (1018, 2590, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (1019, 2591, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (1020, 2592, 159, 'Added as per request from Ang Roberts as part of GenCC November 2020.', 0);
INSERT INTO chado.cvtermprop VALUES (1021, 2593, 159, 'Added along with the update to the definition of transaltional_frameshift SO:0001210 Feb 2021, brought to our attention by Terrence Murphy of INSDC. See GitHub Issue #522.', 0);
INSERT INTO chado.cvtermprop VALUES (1022, 2594, 159, 'Added along with the update to the definition of transaltional_frameshift SO:0001210 Feb 2021, brought to our attention by Terrence Murphy of INSDC. See GitHub Issue #522.', 0);
INSERT INTO chado.cvtermprop VALUES (1023, 694, 159, 'Added as part of GREEKC terms. See GitHub Issues #531 & #534.', 0);
INSERT INTO chado.cvtermprop VALUES (1024, 2595, 159, 'Added as part of GREEKC terms to differentiate between inherited and not inherited epigenetic changes. See GitHub Issue #532.', 0);
INSERT INTO chado.cvtermprop VALUES (1025, 2596, 159, 'Added as per GitHub request #537.', 0);
INSERT INTO chado.cvtermprop VALUES (1026, 2597, 159, 'Added as per GitHub request #537.', 0);
INSERT INTO chado.cvtermprop VALUES (1027, 2598, 159, 'Added as per GitHub request #537.', 0);
INSERT INTO chado.cvtermprop VALUES (1028, 2599, 159, 'Added as a request from FlyBase. See GitHub Issue #507. Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (1029, 2600, 159, 'Added as a request from FlyBase. See GitHub Issue #507. Renamed from rRNA_2S to cytosolic_2S_rRNA on 27 May 2021 with the restructuring of rRNA child terms. Updated definition to be consistent with format of other rRNA definitions. Requested by EBI. See GitHub Issue #493.', 0);
INSERT INTO chado.cvtermprop VALUES (1030, 2601, 159, 'Added as a request from FlyBase. See GitHub Issue #508', 0);
INSERT INTO chado.cvtermprop VALUES (1031, 2602, 159, 'Added as a request from FlyBase. See GitHub Issue #510', 0);
INSERT INTO chado.cvtermprop VALUES (1032, 2603, 159, 'Added as a request from FlyBase. See GitHub Issue #512', 0);
INSERT INTO chado.cvtermprop VALUES (1033, 2604, 159, 'Added as a request from FlyBase. See GitHub Issue #512', 0);
INSERT INTO chado.cvtermprop VALUES (1034, 1587, 159, 'Added as a request from FlyBase to make the ncRNA_gene branch in SO mirror the ncRNA branch. See GitHub Issue #514', 0);
INSERT INTO chado.cvtermprop VALUES (1035, 1059, 159, 'Added as a request from EBI. See GitHub Issue #493', 0);
INSERT INTO chado.cvtermprop VALUES (1036, 2605, 159, 'Added as a request from EMBL. See GitHub Issue #493', 0);
INSERT INTO chado.cvtermprop VALUES (1037, 2606, 159, 'Added as a request from EMBL. See GitHub Issue #493', 0);
INSERT INTO chado.cvtermprop VALUES (1038, 2607, 159, 'Added as a request from EMBL. See GitHub Issue #493', 0);
INSERT INTO chado.cvtermprop VALUES (1039, 2608, 159, 'Added as a request from EMBL. See GitHub Issue #493', 0);
INSERT INTO chado.cvtermprop VALUES (1040, 2609, 159, 'Added as a request from EMBL. See GitHub Issue #493', 0);
INSERT INTO chado.cvtermprop VALUES (1041, 2610, 159, 'See GitHub Issue #301.', 0);
INSERT INTO chado.cvtermprop VALUES (1042, 2611, 159, 'See GitHub Issue #301.', 0);
INSERT INTO chado.cvtermprop VALUES (1043, 2612, 159, 'See GitHub Issue #301.', 0);
INSERT INTO chado.cvtermprop VALUES (1044, 2613, 159, 'See GitHub Issue #515.', 0);
INSERT INTO chado.cvtermprop VALUES (1045, 2614, 159, 'See GitHub Issue #516.', 0);
INSERT INTO chado.cvtermprop VALUES (1046, 2615, 159, 'See GitHub Issue #516.', 0);
INSERT INTO chado.cvtermprop VALUES (1047, 2616, 159, 'See GitHub Issue #518.', 0);
INSERT INTO chado.cvtermprop VALUES (1048, 2617, 159, 'See GitHub Issue #518.', 0);
INSERT INTO chado.cvtermprop VALUES (1049, 2618, 159, 'See GitHub Issue #558.', 0);
INSERT INTO chado.cvtermprop VALUES (1050, 2619, 159, 'As of 11 November 2021 the HNGC lists 4 genes as RNA, vault. These are HGNC IDs: 12654, 12655, 12656, 37054.', 0);
INSERT INTO chado.cvtermprop VALUES (1051, 2620, 159, 'There are four genes from HGNC that are annotated this way. HGNC IDs: 10242, 10243, 10244, and 10248.', 0);
INSERT INTO chado.cvtermprop VALUES (1052, 2621, 159, 'Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (1053, 2515, 159, 'Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (1054, 2514, 159, 'Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (1055, 2622, 159, 'Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (1056, 2623, 159, 'Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513). Obsoleted term rRNA_21S_gene (SO:0002241) merged into this term on 12 Sept 2022, see GitHub Issue #513.', 0);
INSERT INTO chado.cvtermprop VALUES (1230, 3028, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1057, 2624, 159, 'Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (1058, 2625, 159, 'Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (1059, 2626, 159, 'Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (1060, 2627, 159, 'Adjusted heirarchy and names of rRNA_gene terms at the request of Steven Marygold GitHub Issue #513 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/513).', 0);
INSERT INTO chado.cvtermprop VALUES (1061, 2628, 159, 'Added at the request of Steven Marygold. See GitHub Issue #519 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/519).', 0);
INSERT INTO chado.cvtermprop VALUES (1062, 2629, 159, 'Added at the request of Steven Marygold. See GitHub Issue #519 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/519).', 0);
INSERT INTO chado.cvtermprop VALUES (1063, 2630, 159, 'Added at the request of Steven Marygold. See GitHub Issue #519 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/519).', 0);
INSERT INTO chado.cvtermprop VALUES (1064, 2631, 159, 'Added at the request of Steven Marygold. See GitHub Issue #519 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/519).', 0);
INSERT INTO chado.cvtermprop VALUES (1065, 2632, 159, 'Added at the request of Steven Marygold. See GitHub Issue #519 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/519).', 0);
INSERT INTO chado.cvtermprop VALUES (1066, 2633, 159, 'Added at the request of Steven Marygold. See GitHub Issue #519 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/519).', 0);
INSERT INTO chado.cvtermprop VALUES (1067, 2634, 159, 'Added at the request of Steven Marygold. See GitHub Issue #519 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/519). Added citations. See GitHub Issue #565.', 0);
INSERT INTO chado.cvtermprop VALUES (1068, 2635, 159, 'Added at the request of Steven Marygold. See GitHub Issue #519 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/519). Added citations. See GitHub Issue #565.', 0);
INSERT INTO chado.cvtermprop VALUES (1069, 2636, 159, 'Added at the request of Steven Marygold. See GitHub Issue #519 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/519).', 0);
INSERT INTO chado.cvtermprop VALUES (1070, 2637, 159, 'Added at the request of Steven Marygold. See GitHub Issue #519 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/519).', 0);
INSERT INTO chado.cvtermprop VALUES (1071, 2638, 159, 'Added at the request of Steven Marygold. See GitHub Issue #519 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/519).', 0);
INSERT INTO chado.cvtermprop VALUES (1072, 2639, 159, 'Added at the request of Steven Marygold. See GitHub Issue #519 (https://github.com/The-Sequence-Ontology/SO-Ontologies/issues/519).', 0);
INSERT INTO chado.cvtermprop VALUES (1073, 2640, 159, 'Created new term "bidirectional_promoter_lncRNA" (SO:0002381). See GitHub Issue #579.', 0);
INSERT INTO chado.cvtermprop VALUES (1074, 1391, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (1075, 2641, 159, 'Has RNA 2''-O-ribose methylation guide activity (GO:0030561).', 0);
INSERT INTO chado.cvtermprop VALUES (1076, 2648, 159, 'This would include, for example, a cluster of genes each encoding the major ribosomal RNAs and a cluster of histone gene subarrays.', 0);
INSERT INTO chado.cvtermprop VALUES (1077, 2649, 159, 'This would include, for example, a cluster of genes encoding different histones.', 0);
INSERT INTO chado.cvtermprop VALUES (1078, 2650, 159, 'This would include, for example, the mating type gene cassettes of S. cerevisiae. Gene cassettes usually exist as linear sequences as part of a larger DNA molecule, such as a chromosome or plasmid.', 0);
INSERT INTO chado.cvtermprop VALUES (1079, 2274, 159, 'This would include, for example, the arrays of non-functional VSG genes of Trypanosomes.', 0);
INSERT INTO chado.cvtermprop VALUES (1080, 524, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (1081, 1421, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (1082, 1421, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1083, 1426, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (1084, 1426, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1085, 2654, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1086, 2655, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1087, 2656, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1088, 2657, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1089, 2658, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1090, 2659, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1091, 2660, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1092, 2661, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1093, 1101, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (1094, 1101, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1095, 1101, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (1096, 2662, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1097, 2663, 159, 'Range.', 0);
INSERT INTO chado.cvtermprop VALUES (1098, 2663, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1099, 2664, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1100, 2665, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1101, 2666, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1102, 2108, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1103, 2667, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1104, 1440, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1105, 2668, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1106, 807, 154, 'biosapiens', 0);
INSERT INTO chado.cvtermprop VALUES (1107, 1796, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (1108, 2669, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (1109, 2670, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (1110, 2692, 159, 'Indels can have a different number of bases than the corresponding reference sequence. The term name was changed from indel to delins on 2/24/2019 to align with the HGVS nomenclature term for a deletion-insertion. Indel was causing confusion in the annotation community (github issue 445). The HGVS nomenclature definition of deletion-insertion (delins) is a sequence change where, compared to a reference sequence, one or more nucleotides are replaced by one or more other nucleotides and which is not a substitution, inversion or conversion.', 0);
INSERT INTO chado.cvtermprop VALUES (1111, 752, 154, 'DBVAR', 0);
INSERT INTO chado.cvtermprop VALUES (1112, 752, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (1113, 2700, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1114, 2701, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect. Also as there is not change, it is not a good ontological term.', 0);
INSERT INTO chado.cvtermprop VALUES (1115, 2702, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1116, 2703, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1117, 2704, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1118, 2705, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1119, 2706, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1120, 2707, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1121, 2708, 159, 'The exact rules need to be stated, a common set of rules can be derived from e.g. BLOSUM62 amino acid distance matrix.', 0);
INSERT INTO chado.cvtermprop VALUES (1122, 2709, 159, 'The exact rules need to be stated, a common set of rules can be derived from e.g. BLOSUM62 amino acid distance matrix.', 0);
INSERT INTO chado.cvtermprop VALUES (1123, 2710, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1124, 2711, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1125, 2712, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1126, 2714, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1127, 2715, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1128, 2716, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1129, 2717, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1130, 2718, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1131, 2719, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1132, 2720, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1133, 2721, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1134, 2722, 159, 'A cryptic splice site is only used when the natural splice site has been disrupted by a sequence alteration.', 0);
INSERT INTO chado.cvtermprop VALUES (1135, 2723, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1136, 2724, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1137, 2725, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1138, 2726, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1139, 2727, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1140, 2728, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1141, 2729, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1142, 2730, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1143, 2731, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1144, 2732, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1145, 2733, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1146, 2734, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1147, 2735, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1148, 2736, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect. Also, as there is no change, this is not a good ontological term.', 0);
INSERT INTO chado.cvtermprop VALUES (1149, 2737, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1150, 2738, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1151, 2739, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1152, 2740, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1153, 2741, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1154, 2742, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1155, 2743, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1156, 2744, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1157, 2745, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1158, 2746, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1159, 2747, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1160, 2748, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1161, 2749, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1162, 2750, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1163, 2751, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1231, 3029, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1232, 3030, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1164, 2752, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1165, 2754, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1166, 2756, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1167, 2757, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect. Also as there is no effect, it is not a good term.', 0);
INSERT INTO chado.cvtermprop VALUES (1168, 2758, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1169, 2759, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1170, 2760, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1171, 2761, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1172, 2762, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1173, 2763, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1174, 2764, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1175, 2765, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1176, 2767, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1177, 2768, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1178, 2769, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1179, 2770, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1180, 2771, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect. Updated after discussion with Peter Taschner - Feb 09.', 0);
INSERT INTO chado.cvtermprop VALUES (1181, 2772, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1182, 2777, 159, 'Corrected spelling from dexstrosynaptic_chromosome to dextrosynaptic_chromosome on April 14, 2020 in response to GitHub request #447', 0);
INSERT INTO chado.cvtermprop VALUES (1183, 2793, 159, 'Flag - unknown in the definition.', 0);
INSERT INTO chado.cvtermprop VALUES (1184, 2794, 159, 'FLAG - term describes an unknown.', 0);
INSERT INTO chado.cvtermprop VALUES (1185, 2795, 159, 'FLAG - definition describes an unknown.', 0);
INSERT INTO chado.cvtermprop VALUES (1186, 2694, 154, 'DBVAR', 0);
INSERT INTO chado.cvtermprop VALUES (1187, 2799, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1188, 2800, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1189, 2801, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1190, 2802, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1191, 2803, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1192, 2804, 159, 'OBSOLETE: This term was deleted as it conflated more than one term. The alteration is separate from the effect.', 0);
INSERT INTO chado.cvtermprop VALUES (1193, 2833, 159, 'Intron characteristic of tRNA genes; splices by an endonuclease-ligase mediated mechanism.', 0);
INSERT INTO chado.cvtermprop VALUES (1194, 2834, 159, 'Could be a cross product with Gene ontology, GO:0006388.', 0);
INSERT INTO chado.cvtermprop VALUES (1195, 2568, 159, 'Definition updated with Mejia-Almonte et.al PMID:32665585 on Aug 5, 2020. Added relationship has_part SO:0002300', 0);
INSERT INTO chado.cvtermprop VALUES (1196, 2568, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (1197, 2843, 159, 'This term does not include the stop codons that are redefined. An example would be a stop codon that partially overlapped a frame shifting site would be an example stimulatory signal.', 0);
INSERT INTO chado.cvtermprop VALUES (1198, 2848, 154, 'SOFA', 0);
INSERT INTO chado.cvtermprop VALUES (1199, 2049, 159, 'Requested by tracker 2021594, July 2008, by Alex.', 0);
INSERT INTO chado.cvtermprop VALUES (1200, 2962, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1201, 2999, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1202, 3000, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1203, 3001, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1204, 3002, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1205, 3003, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1206, 3004, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1207, 3005, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1208, 3006, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1209, 3007, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1210, 3008, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1211, 3009, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1212, 3010, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1213, 3011, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1214, 3012, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1215, 3013, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1216, 3014, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1217, 3015, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1218, 3016, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1219, 3017, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1220, 3018, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1221, 3019, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1222, 3020, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1223, 3021, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1224, 3022, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1225, 3023, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1226, 3024, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1227, 3025, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1228, 3026, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1234, 3032, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1235, 3033, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1236, 3034, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1237, 3035, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1238, 3036, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1239, 3037, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1240, 3038, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1241, 3039, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1242, 3040, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1243, 3041, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1244, 3042, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1245, 3043, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1246, 3044, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1247, 3045, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1248, 3046, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1249, 3047, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1250, 3048, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1251, 3049, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1252, 3050, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1253, 3051, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1254, 3052, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1255, 3053, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1256, 3054, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1257, 3055, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1258, 3056, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1259, 3057, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1260, 3058, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1261, 3059, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1262, 3060, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1263, 3061, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1264, 3062, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1265, 3063, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1266, 3064, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1267, 3065, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1268, 3066, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1269, 3067, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1270, 3068, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1271, 3069, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1272, 3070, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1273, 3071, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1274, 3072, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1275, 3073, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1276, 3074, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1277, 3075, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1278, 3076, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1279, 3077, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1280, 3078, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1281, 3079, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1282, 3080, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1283, 3081, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1284, 3082, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1285, 3083, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1286, 3084, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1287, 3085, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1288, 3086, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1289, 3087, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1290, 3088, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1291, 3089, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1292, 3090, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1293, 3091, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1294, 3092, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1295, 3093, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1296, 3094, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1297, 3095, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1298, 3096, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1299, 3097, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1300, 3098, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1301, 3099, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1302, 3100, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1303, 3101, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1304, 3102, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1305, 3103, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1306, 3104, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1307, 3105, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1308, 3106, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1309, 3107, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1310, 3108, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1311, 3109, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1312, 3110, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1313, 3111, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1314, 3112, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1315, 3113, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1316, 3114, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1317, 3115, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1318, 3116, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1319, 3117, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1320, 3118, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1321, 3119, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1322, 3120, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1323, 3121, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1324, 3122, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1325, 3123, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1326, 3124, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1327, 3125, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1328, 3126, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1329, 3127, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1330, 3128, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1331, 3129, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1332, 3130, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1333, 3131, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1334, 3132, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1335, 3133, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1336, 3134, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1337, 3135, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1338, 3136, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1339, 3137, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1340, 3138, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermprop VALUES (1341, 3139, 154, 'MeSH_Publication_Type', 0);
INSERT INTO chado.cvtermsynonym VALUES (1, 260, 'sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2, 261, 'INSDC_feature:misc_structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3, 261, 'sequence secondary structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4, 263, 'G quartet', NULL);
INSERT INTO chado.cvtermsynonym VALUES (5, 263, 'G tetrad', NULL);
INSERT INTO chado.cvtermsynonym VALUES (6, 263, 'G-quadruplex', NULL);
INSERT INTO chado.cvtermsynonym VALUES (7, 263, 'G-quartet', NULL);
INSERT INTO chado.cvtermsynonym VALUES (8, 263, 'G-tetrad', NULL);
INSERT INTO chado.cvtermsynonym VALUES (9, 263, 'G_quadruplex', NULL);
INSERT INTO chado.cvtermsynonym VALUES (10, 263, 'guanine tetrad', NULL);
INSERT INTO chado.cvtermsynonym VALUES (11, 264, 'interior coding exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (12, 266, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (13, 266, 'INSDC_qualifier:satellite', NULL);
INSERT INTO chado.cvtermsynonym VALUES (14, 266, 'satellite DNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (15, 268, 'amplicon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (16, 268, 'PCR product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (17, 270, 'mate pair', NULL);
INSERT INTO chado.cvtermsynonym VALUES (18, 270, 'read-pair', NULL);
INSERT INTO chado.cvtermsynonym VALUES (19, 276, 'protein-coding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (20, 278, 'non protein-coding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (21, 279, 'scRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (22, 279, 'scRNA transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (23, 279, 'small cytoplasmic RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (24, 279, 'small cytoplasmic RNA transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (25, 279, 'small_cytoplasmic_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (26, 281, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (27, 281, 'INSDC_qualifier:scRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (28, 281, 'small cytoplasmic RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (29, 283, 'DMp2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (30, 283, 'initiator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (31, 283, 'initiator motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (32, 283, 'INR motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (33, 286, 'CRWMGCGWKCGCTTS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (34, 286, 'downstream core promoter element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (35, 286, 'DPE motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (36, 287, 'B-recognition element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (37, 287, 'BRE motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (38, 287, 'BREu', NULL);
INSERT INTO chado.cvtermsynonym VALUES (39, 287, 'BREu motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (40, 287, 'TFIIB recognition element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (41, 287, 'transcription factor B-recognition element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (42, 288, 'proximal sequence element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (43, 288, 'PSE motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (44, 291, 'linkage group', NULL);
INSERT INTO chado.cvtermsynonym VALUES (45, 292, 'RNA internal loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (46, 294, 'asymmetric RNA internal loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (47, 295, 'A minor RNA motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (48, 296, 'K turn RNA motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (49, 296, 'K-turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (50, 296, 'kink turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (51, 296, 'kink-turn motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (52, 297, 'sarcin like RNA motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (53, 297, 'sarcin/ricin domain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (54, 297, 'sarcin/ricin loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (55, 297, 'sarcin/ricin RNA domain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (56, 298, 'A-minor RNA motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (57, 299, 'RNA junction loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (58, 300, 'hook turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (59, 300, 'hook-turn motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (60, 300, 'RNA hook turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (61, 301, 'base pair', NULL);
INSERT INTO chado.cvtermsynonym VALUES (62, 302, 'canonical base pair', NULL);
INSERT INTO chado.cvtermsynonym VALUES (63, 302, 'Watson Crick base pair', NULL);
INSERT INTO chado.cvtermsynonym VALUES (64, 302, 'Watson-Crick base pair', NULL);
INSERT INTO chado.cvtermsynonym VALUES (65, 302, 'Watson-Crick pair', NULL);
INSERT INTO chado.cvtermsynonym VALUES (66, 302, 'WC base pair', NULL);
INSERT INTO chado.cvtermsynonym VALUES (67, 303, 'sugar edge base pair', NULL);
INSERT INTO chado.cvtermsynonym VALUES (68, 306, 'DNA aptamer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (69, 307, 'RNA aptamer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (70, 308, 'morphant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (71, 308, 'morpholino', NULL);
INSERT INTO chado.cvtermsynonym VALUES (72, 308, 'morpholino oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (73, 311, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (74, 311, 'INSDC_qualifier:riboswitch', NULL);
INSERT INTO chado.cvtermsynonym VALUES (75, 311, 'riboswitch RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (76, 313, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (77, 313, 'INSDC_qualifier:matrix_attachment_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (78, 313, 'MAR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (79, 313, 'matrix association region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (80, 313, 'matrix attachment region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (81, 313, 'matrix attachment site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (82, 313, 'nuclear matrix association region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (83, 313, 'nuclear matrix attachment site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (84, 313, 'S/MAR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (85, 313, 'S/MAR element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (86, 313, 'scaffold attachment site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (87, 313, 'scaffold matrix attachment region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (88, 313, 'SMAR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (89, 315, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (90, 315, 'INSDC_qualifier:locus_control_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (91, 315, 'LCR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (92, 315, 'locus control element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (93, 315, 'locus control region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (94, 318, 'match part', NULL);
INSERT INTO chado.cvtermsynonym VALUES (95, 321, 'genomic clone', NULL);
INSERT INTO chado.cvtermsynonym VALUES (96, 324, 'sequence operation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (97, 325, 'pseudogene attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (98, 326, 'INSDC_feature:gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (99, 326, 'INSDC_qualifier:processed', NULL);
INSERT INTO chado.cvtermsynonym VALUES (100, 326, 'processed pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (101, 326, 'pseudogene by reverse transcription', NULL);
INSERT INTO chado.cvtermsynonym VALUES (102, 326, 'R psi G', NULL);
INSERT INTO chado.cvtermsynonym VALUES (103, 326, 'retropseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (104, 328, 'pseudogene by unequal crossing over', NULL);
INSERT INTO chado.cvtermsynonym VALUES (105, 337, 'assortment-derived_deficiency', NULL);
INSERT INTO chado.cvtermsynonym VALUES (106, 338, 'mutation affecting regulatory region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (107, 338, 'sequence variant affecting regulatory region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (108, 343, 'operator segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (109, 345, 'assortment-derived_aneuploid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (110, 346, 'nuclease binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (111, 348, 'compound chromosome arm', NULL);
INSERT INTO chado.cvtermsynonym VALUES (112, 350, 'restriction endonuclease binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (113, 350, 'restriction enzyme binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (114, 351, 'deficient intrachromosomal transposition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (115, 355, 'deficient interchromosomal transposition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (116, 358, 'free chromosome arm', NULL);
INSERT INTO chado.cvtermsynonym VALUES (117, 361, 'gene to gene feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (118, 363, 'inside intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (119, 364, 'inside intron antiparallel', NULL);
INSERT INTO chado.cvtermsynonym VALUES (120, 365, 'inside intron parallel', NULL);
INSERT INTO chado.cvtermsynonym VALUES (121, 367, 'five prime-three prime overlap', NULL);
INSERT INTO chado.cvtermsynonym VALUES (122, 368, 'five prime-five prime overlap', NULL);
INSERT INTO chado.cvtermsynonym VALUES (123, 369, 'three prime-three prime overlap', NULL);
INSERT INTO chado.cvtermsynonym VALUES (124, 370, '5'' 3'' overlap', NULL);
INSERT INTO chado.cvtermsynonym VALUES (125, 370, 'three prime five prime overlap', NULL);
INSERT INTO chado.cvtermsynonym VALUES (126, 372, 'polycistronic transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (127, 375, 'dicistronic transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (128, 377, 'operon member', NULL);
INSERT INTO chado.cvtermsynonym VALUES (129, 378, 'gene array member', NULL);
INSERT INTO chado.cvtermsynonym VALUES (130, 380, 'macronuclear sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (131, 382, 'micronuclear sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (132, 385, 'nuclear gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (133, 387, 'mitochondrial gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (134, 387, 'mt gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (135, 389, 'kinetoplast gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (136, 391, 'plastid gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (137, 393, 'apicoplast gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (138, 395, 'chloroplast gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (139, 395, 'ct gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (140, 397, 'chromoplast gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (141, 399, 'cyanelle gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (142, 401, 'leucoplast gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (143, 403, 'proplastid gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (144, 405, 'nucleomorph gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (145, 407, 'plasmid gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (146, 409, 'proviral gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (147, 411, 'endogenous retroviral gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (148, 413, 'transposable element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (149, 413, 'transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (150, 415, 'expressed sequence match', NULL);
INSERT INTO chado.cvtermsynonym VALUES (151, 417, 'clone insert end', NULL);
INSERT INTO chado.cvtermsynonym VALUES (152, 420, 'protein', NULL);
INSERT INTO chado.cvtermsynonym VALUES (153, 422, 'chromosome arm', NULL);
INSERT INTO chado.cvtermsynonym VALUES (154, 425, 'sequencing primer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (155, 427, 'frameshifted mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (156, 427, 'mRNA with frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (157, 429, 'mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (158, 162, 'INSDC_feature:misc_feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (159, 162, 'INSDC_note:other', NULL);
INSERT INTO chado.cvtermsynonym VALUES (160, 162, 'INSDC_note:sequence_feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (161, 162, 'located sequence feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (162, 162, 'located_sequence_feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (163, 162, 'sequence feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (164, 430, 'transposable element gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (165, 426, 'DNA primer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (166, 426, 'primer oligonucleotide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (167, 426, 'primer polynucleotide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (168, 426, 'primer sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (169, 432, 'proviral region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (170, 432, 'proviral sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (171, 433, 'methylated C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (172, 433, 'methylated cytosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (173, 433, 'methylated cytosine base', NULL);
INSERT INTO chado.cvtermsynonym VALUES (174, 433, 'methylated cytosine residue', NULL);
INSERT INTO chado.cvtermsynonym VALUES (175, 433, 'methylated_C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (176, 440, 'transcript with translational frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (177, 443, 'pre mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (178, 443, 'protein coding primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (179, 445, 'DNA forward primer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (180, 445, 'forward DNA primer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (181, 445, 'forward primer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (182, 445, 'forward primer oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (183, 445, 'forward primer oligonucleotide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (184, 445, 'forward primer polynucleotide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (185, 445, 'forward primer sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (186, 447, 'RNA sequence secondary structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (187, 448, 'transcriptionally regulated', NULL);
INSERT INTO chado.cvtermsynonym VALUES (188, 449, 'transcriptionally constitutive', NULL);
INSERT INTO chado.cvtermsynonym VALUES (189, 450, 'transcriptionally induced', NULL);
INSERT INTO chado.cvtermsynonym VALUES (190, 451, 'transcriptionally repressed', NULL);
INSERT INTO chado.cvtermsynonym VALUES (191, 452, 'silenced gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (192, 454, 'gene silenced by DNA modification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (193, 456, 'gene silenced by DNA methylation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (194, 456, 'methylation-silenced gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (195, 458, 'post translationally regulated', NULL);
INSERT INTO chado.cvtermsynonym VALUES (196, 458, 'post-translationally regulated', NULL);
INSERT INTO chado.cvtermsynonym VALUES (197, 459, 'translationally regulated', NULL);
INSERT INTO chado.cvtermsynonym VALUES (198, 460, 'DNA reverse primer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (199, 460, 'reverse DNA primer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (200, 460, 'reverse primer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (201, 460, 'reverse primer oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (202, 460, 'reverse primer oligonucleotide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (203, 460, 'reverse primer sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (204, 462, 'epigenetically modified', NULL);
INSERT INTO chado.cvtermsynonym VALUES (205, 463, 'genomically imprinted', NULL);
INSERT INTO chado.cvtermsynonym VALUES (206, 463, 'imprinted', NULL);
INSERT INTO chado.cvtermsynonym VALUES (207, 464, 'maternally imprinted', NULL);
INSERT INTO chado.cvtermsynonym VALUES (208, 465, 'paternally imprinted', NULL);
INSERT INTO chado.cvtermsynonym VALUES (209, 466, 'allelically excluded', NULL);
INSERT INTO chado.cvtermsynonym VALUES (210, 467, 'gene rearranged at DNA level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (211, 470, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (212, 470, 'INSDC_qualifier:ribosome_binding_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (213, 470, 'ribosome entry site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (214, 472, 'attenuator sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (215, 472, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (216, 472, 'INSDC_qualifier:attenuator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (217, 474, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (218, 474, 'INSDC_qualifier:terminator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (219, 474, 'terminator sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (220, 475, 'DNA sequence secondary structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (221, 476, 'assembly component', NULL);
INSERT INTO chado.cvtermsynonym VALUES (222, 478, 'recoded codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (223, 481, 'INSDC_feature:exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (224, 483, 'scaffold', NULL);
INSERT INTO chado.cvtermsynonym VALUES (225, 487, 'yeast artificial chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (226, 489, 'bacterial artificial chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (227, 490, 'P1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (228, 490, 'P1 artificial chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (229, 491, 'plasmid sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (230, 493, 'cosmid vector', NULL);
INSERT INTO chado.cvtermsynonym VALUES (231, 494, 'phagemid vector', NULL);
INSERT INTO chado.cvtermsynonym VALUES (232, 495, 'fosmid vector', NULL);
INSERT INTO chado.cvtermsynonym VALUES (233, 354, 'deleted_sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (234, 354, 'nucleotide deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (235, 354, 'nucleotide_deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (236, 498, 'methylated A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (237, 498, 'methylated adenine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (238, 498, 'methylated adenine base', NULL);
INSERT INTO chado.cvtermsynonym VALUES (239, 498, 'methylated adenine residue', NULL);
INSERT INTO chado.cvtermsynonym VALUES (240, 498, 'methylated_A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (241, 500, 'splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (242, 502, '5'' splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (243, 502, 'donor', NULL);
INSERT INTO chado.cvtermsynonym VALUES (244, 502, 'donor splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (245, 502, 'five prime splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (246, 502, 'splice donor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (247, 504, '3'' splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (248, 504, 'acceptor', NULL);
INSERT INTO chado.cvtermsynonym VALUES (249, 504, 'acceptor splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (250, 504, 'splice acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (251, 504, 'three prime splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (252, 505, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (253, 505, 'INSDC_qualifier:enhancer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (254, 506, 'enhancer bound by factor', NULL);
INSERT INTO chado.cvtermsynonym VALUES (255, 290, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (256, 290, 'INSDC_qualifier:promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (257, 290, 'promoter sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (258, 510, 'pol I promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (259, 510, 'polymerase I promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (260, 510, 'RNA polymerase A promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (261, 510, 'RNApol I promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (262, 512, 'pol II promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (263, 512, 'polymerase II promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (264, 512, 'RNA polymerase B promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (265, 512, 'RNApol II promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (266, 513, 'pol III promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (267, 513, 'polymerase III promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (268, 513, 'RNA polymerase C promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (269, 513, 'RNApol III promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (270, 514, 'CAAT box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (271, 514, 'CAAT signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (272, 514, 'CAAT-box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (273, 514, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (274, 514, 'INSDC_qualifier:CAAT_signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (275, 515, 'GC rich promoter region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (276, 515, 'GC-rich region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (277, 515, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (278, 515, 'INSDC_qualifier:GC_rich_promoter_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (279, 517, 'Goldstein-Hogness box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (280, 517, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (281, 517, 'INSDC_qualifier:TATA_box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (282, 517, 'TATA box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (283, 518, '-10 signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (284, 518, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (285, 518, 'INSDC_qualifier:minus_10_signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (286, 518, 'minus 10 signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (287, 518, 'Pribnow box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (288, 518, 'Pribnow Schaller box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (289, 518, 'Pribnow-Schaller box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (290, 521, '-35 signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (291, 521, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (292, 521, 'INSDC_qualifier:minus_35_signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (293, 521, 'minus 35 signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (294, 522, 'cross genome match', NULL);
INSERT INTO chado.cvtermsynonym VALUES (295, 523, 'INSDC_feature:operon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (296, 525, 'clone insert start', NULL);
INSERT INTO chado.cvtermsynonym VALUES (297, 526, 'class I', NULL);
INSERT INTO chado.cvtermsynonym VALUES (298, 526, 'class I transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (299, 526, 'retrotransposon element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (300, 527, 'translated nucleotide match', NULL);
INSERT INTO chado.cvtermsynonym VALUES (301, 528, 'class II', NULL);
INSERT INTO chado.cvtermsynonym VALUES (302, 528, 'class II transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (303, 528, 'DNA transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (304, 529, 'non transcribed region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (305, 529, 'non-transcribed sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (306, 529, 'nontranscribed region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (307, 529, 'nontranscribed sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (308, 530, 'U2 intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (309, 444, 'INSDC_feature:precursor_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (310, 444, 'INSDC_feature:prim_transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (311, 444, 'precursor RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (312, 444, 'primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (313, 532, 'long terminal repeat retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (314, 532, 'LTR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (315, 534, 'INSDC_feature:intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (316, 535, 'non LTR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (317, 536, '5'' intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (318, 536, '5'' intron sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (319, 536, 'five prime intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (320, 537, 'interior intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (321, 538, '3'' intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (322, 538, '3'' intron sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (323, 538, 'three prime intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (324, 539, 'restriction fragment length polymorphism', NULL);
INSERT INTO chado.cvtermsynonym VALUES (325, 539, 'RFLP', NULL);
INSERT INTO chado.cvtermsynonym VALUES (326, 539, 'RFLP fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (327, 541, 'LINE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (328, 541, 'LINE element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (329, 541, 'Long interspersed element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (330, 541, 'Long interspersed nuclear element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (331, 265, 'coding exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (332, 542, 'five prime exon coding region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (333, 545, 'three prime exon coding region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (334, 547, 'noncoding exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (335, 548, 'transchr', NULL);
INSERT INTO chado.cvtermsynonym VALUES (336, 548, 'translocated sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (337, 544, '5'' coding exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (338, 544, 'five prime coding exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (339, 550, 'interior exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (340, 546, '3'' coding exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (341, 546, 'three prime coding exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (342, 551, 'untranslated region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (343, 471, '5'' UTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (344, 471, 'five prime UTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (345, 471, 'five_prime_untranslated_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (346, 471, 'INSDC_feature:5''UTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (347, 552, 'INSDC_feature:3''UTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (348, 552, 'three prime untranslated region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (349, 552, 'three prime UTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (350, 553, 'Short interspersed element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (351, 553, 'Short interspersed nuclear element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (352, 553, 'SINE element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (353, 554, 'simple sequence length polymorphism', NULL);
INSERT INTO chado.cvtermsynonym VALUES (354, 554, 'simple sequence length variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (355, 554, 'SSLP', NULL);
INSERT INTO chado.cvtermsynonym VALUES (356, 556, 'terminal inverted repeat element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (357, 556, 'TIR element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (358, 557, 'ribosomal RNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (359, 557, 'rRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (360, 558, 'tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (361, 559, 'alanine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (362, 560, 'arginine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (363, 561, 'asparagine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (364, 562, 'aspartic acid tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (365, 563, 'cysteine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (366, 564, 'glutamic acid tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (367, 565, 'glutamine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (368, 566, 'glycine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (369, 567, 'histidine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (370, 568, 'isoleucine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (371, 569, 'leucine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (372, 570, 'lysine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (373, 571, 'methionine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (374, 572, 'phenylalanine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (375, 573, 'proline tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (376, 574, 'serine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (377, 575, 'threonine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (378, 576, 'tryptophan tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (379, 577, 'tyrosine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (380, 578, 'valine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (381, 579, 'snRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (382, 580, 'snoRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (383, 581, 'mature transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (384, 164, 'INSDC_feature:mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (385, 164, 'messenger RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (386, 164, 'protein_coding_transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (387, 582, 'TF binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (388, 582, 'transcription factor binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (389, 583, 'open reading frame', NULL);
INSERT INTO chado.cvtermsynonym VALUES (390, 438, 'transcript attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (391, 586, 'foldback element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (392, 586, 'long inverted repeat element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (393, 586, 'LVR element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (394, 587, 'flanking region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (395, 589, 'chromosome variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (396, 592, 'internal UTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (397, 593, 'untranslated region polycistronic mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (398, 594, 'internal ribosomal entry sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (399, 594, 'internal ribosomal entry site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (400, 594, 'internal ribosome entry sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (401, 594, 'internal ribosome entry site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (402, 594, 'IRES', NULL);
INSERT INTO chado.cvtermsynonym VALUES (403, 595, '4-cutter_restriction_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (404, 595, 'four-cutter_restriction_sit', NULL);
INSERT INTO chado.cvtermsynonym VALUES (405, 555, 'sequence length alteration', NULL);
INSERT INTO chado.cvtermsynonym VALUES (406, 600, '6-cutter_restriction_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (407, 600, 'six-cutter_restriction_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (408, 601, 'modified RNA base feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (409, 603, '8-cutter_restriction_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (410, 603, 'eight-cutter_restriction_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (411, 604, 'INSDC_feature:rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (412, 604, 'INSDC_qualifier:unknown', NULL);
INSERT INTO chado.cvtermsynonym VALUES (413, 604, 'ribosomal ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (414, 604, 'ribosomal RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (415, 605, 'INSDC_feature:tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (416, 605, 'INSDC_qualifier:unknown', NULL);
INSERT INTO chado.cvtermsynonym VALUES (417, 605, 'transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (418, 605, 'transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (419, 607, 'alanyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (420, 607, 'alanyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (421, 607, 'alanyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (422, 608, 'rRNA small subunit primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (423, 609, 'asparaginyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (424, 609, 'asparaginyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (425, 609, 'asparaginyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (426, 610, 'aspartyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (427, 610, 'aspartyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (428, 610, 'aspartyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (429, 611, 'cysteinyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (430, 611, 'cysteinyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (431, 611, 'cysteinyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (432, 612, 'glutaminyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (433, 612, 'glutaminyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (434, 612, 'glutaminyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (435, 613, 'glutamyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (436, 613, 'glutamyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (437, 613, 'glutamyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (438, 614, 'glycyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (439, 614, 'glycyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (440, 614, 'glycyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (441, 615, 'histidyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (442, 615, 'histidyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (443, 615, 'histidyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (444, 616, 'isoleucyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (445, 616, 'isoleucyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (446, 616, 'isoleucyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (447, 617, 'leucyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (448, 617, 'leucyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (449, 617, 'leucyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (450, 618, 'lysyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (451, 618, 'lysyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (452, 618, 'lysyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (453, 619, 'methionyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (454, 619, 'methionyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (455, 619, 'methionyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (456, 620, 'phenylalanyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (457, 620, 'phenylalanyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (458, 620, 'phenylalanyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (459, 621, 'prolyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (460, 621, 'prolyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (461, 621, 'prolyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (462, 622, 'seryl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (463, 622, 'seryl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (464, 622, 'seryl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (465, 623, 'threonyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (466, 623, 'threonyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (467, 623, 'threonyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (468, 624, 'tryptophanyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (469, 624, 'tryptophanyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (470, 624, 'tryptophanyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (471, 625, 'tyrosyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (472, 625, 'tyrosyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (473, 625, 'tyrosyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (474, 626, 'valyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (475, 626, 'valyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (476, 626, 'valyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (477, 627, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (478, 627, 'INSDC_qualifier:snRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (479, 627, 'small nuclear RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (480, 628, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (481, 628, 'INSDC_qualifier:snoRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (482, 628, 'small nucleolar RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (483, 629, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (484, 629, 'INSDC_qualifier:miRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (485, 629, 'micro RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (486, 629, 'microRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (487, 629, 'small temporal RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (488, 629, 'stRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (489, 507, 'bound by factor', NULL);
INSERT INTO chado.cvtermsynonym VALUES (490, 632, 'transcript bound by nucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (491, 634, 'transcript bound by protein', NULL);
INSERT INTO chado.cvtermsynonym VALUES (492, 636, 'engineered gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (493, 639, 'engineered foreign gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (494, 643, 'mRNA with minus 1 frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (495, 645, 'engineered foreign transposable element gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (496, 640, 'foreign gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (497, 647, 'direct terminal repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (498, 647, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (499, 647, 'INSDC_qualifier:long_terminal_repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (500, 647, 'long terminal repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (501, 647, 'LTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (502, 649, 'fusion gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (503, 651, 'engineered fusion gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (504, 652, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (505, 652, 'INSDC_qualifier:microsatellite', NULL);
INSERT INTO chado.cvtermsynonym VALUES (506, 652, 'microsatellite locus', NULL);
INSERT INTO chado.cvtermsynonym VALUES (507, 652, 'microsatellite marker', NULL);
INSERT INTO chado.cvtermsynonym VALUES (508, 652, 'short tandem repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (509, 652, 'STR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (510, 653, 'dinucleotide repeat microsatellite', NULL);
INSERT INTO chado.cvtermsynonym VALUES (511, 653, 'dinucleotide repeat microsatellite feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (512, 653, 'dinucleotide repeat microsatellite locus', NULL);
INSERT INTO chado.cvtermsynonym VALUES (513, 653, 'dinucleotide repeat microsatellite marker', NULL);
INSERT INTO chado.cvtermsynonym VALUES (514, 654, 'dinucleotide repeat microsatellite marker', NULL);
INSERT INTO chado.cvtermsynonym VALUES (515, 654, 'rinucleotide repeat microsatellite', NULL);
INSERT INTO chado.cvtermsynonym VALUES (516, 654, 'trinucleotide repeat microsatellite feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (517, 654, 'trinucleotide repeat microsatellite locus', NULL);
INSERT INTO chado.cvtermsynonym VALUES (518, 656, 'engineered foreign repetitive element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (519, 657, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (520, 657, 'INSDC_qualifier:inverted', NULL);
INSERT INTO chado.cvtermsynonym VALUES (521, 657, 'inverted repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (522, 657, 'inverted repeat sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (523, 658, 'U12 intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (524, 658, 'U12-dependent intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (525, 659, 'INSDC_feature:rep_origin', NULL);
INSERT INTO chado.cvtermsynonym VALUES (526, 659, 'ori', NULL);
INSERT INTO chado.cvtermsynonym VALUES (527, 659, 'origin of replication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (528, 660, 'D-loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (529, 660, 'displacement loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (530, 660, 'INSDC_feature:D-loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (531, 661, 'INSDC_feature:misc_recomb', NULL);
INSERT INTO chado.cvtermsynonym VALUES (532, 661, 'INSDC_qualifier:other', NULL);
INSERT INTO chado.cvtermsynonym VALUES (533, 661, 'recombination feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (534, 662, 'specific recombination site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (535, 664, 'recombination feature of rearranged gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (536, 665, 'vertebrate immune system gene recombination feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (537, 666, 'J gene recombination feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (538, 666, 'J-RS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (539, 670, 'INSDC_feature:modified_base', NULL);
INSERT INTO chado.cvtermsynonym VALUES (540, 670, 'modified base site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (541, 434, 'methylated base feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (542, 672, 'CG island', NULL);
INSERT INTO chado.cvtermsynonym VALUES (543, 672, 'CpG island', NULL);
INSERT INTO chado.cvtermsynonym VALUES (544, 677, 'experimentally determined', NULL);
INSERT INTO chado.cvtermsynonym VALUES (545, 679, 'INSDC_feature:stem_loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (546, 679, 'RNA_hairpin_loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (547, 679, 'stem loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (548, 679, 'stem-loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (549, 680, 'direct repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (550, 680, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (551, 680, 'INSDC_qualifier:direct', NULL);
INSERT INTO chado.cvtermsynonym VALUES (552, 681, 'INSDC_feature:misc_feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (553, 681, 'INSDC_note:transcription_start_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (554, 681, 'transcription start site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (555, 681, 'transcription_start_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (556, 421, 'coding sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (557, 421, 'coding_sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (558, 421, 'INSDC_feature:CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (559, 683, 'cDNA clone', NULL);
INSERT INTO chado.cvtermsynonym VALUES (560, 685, 'initiation codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (561, 685, 'start codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (562, 686, 'stop codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (563, 687, 'intronic splice enhancer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (564, 690, 'mRNA with plus 1 frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (565, 692, 'nuclease hypersensitive site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (566, 695, 'coding start', NULL);
INSERT INTO chado.cvtermsynonym VALUES (567, 695, 'translation initiation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (568, 695, 'translation start', NULL);
INSERT INTO chado.cvtermsynonym VALUES (569, 698, '35S rRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (570, 698, 'rRNA large subunit primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (571, 699, 'SAGE tag', NULL);
INSERT INTO chado.cvtermsynonym VALUES (572, 700, 'coding end', NULL);
INSERT INTO chado.cvtermsynonym VALUES (573, 700, 'translation termination site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (574, 700, 'translation_end', NULL);
INSERT INTO chado.cvtermsynonym VALUES (575, 701, 'microarray oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (576, 701, 'microarray oligonucleotide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (577, 702, 'mRNA with plus 2 frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (578, 704, 'conserved region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (579, 704, 'INSDC_feature:misc_feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (580, 704, 'INSDC_note:conserved_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (581, 705, 'INSDC_feature:STS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (582, 705, 'sequence tag site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (583, 706, 'coding conserved region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (584, 707, 'exon junction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (585, 708, 'conserved non-coding element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (586, 708, 'conserved non-coding sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (587, 708, 'nc conserved region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (588, 708, 'noncoding conserved region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (589, 709, 'mRNA with minus 2 frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (590, 327, 'INSDC_feature:gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (591, 327, 'INSDC_qualifier:pseudo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (592, 327, 'INSDC_qualifier:unknown', NULL);
INSERT INTO chado.cvtermsynonym VALUES (593, 711, 'RNAi reagent', NULL);
INSERT INTO chado.cvtermsynonym VALUES (594, 713, 'miniature inverted repeat transposable element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (595, 714, 'recombination hotspot', NULL);
INSERT INTO chado.cvtermsynonym VALUES (596, 716, 'chromosome band', NULL);
INSERT INTO chado.cvtermsynonym VALUES (597, 716, 'cytoband', NULL);
INSERT INTO chado.cvtermsynonym VALUES (598, 716, 'cytological band', NULL);
INSERT INTO chado.cvtermsynonym VALUES (599, 717, 'site specific recombination target region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (600, 688, 'splice enhancer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (601, 719, 'expressed sequence tag', NULL);
INSERT INTO chado.cvtermsynonym VALUES (602, 720, 'Cre-recombination target region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (603, 720, 'loxP site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (604, 416, 'nucleotide match', NULL);
INSERT INTO chado.cvtermsynonym VALUES (605, 722, 'nucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (606, 724, 'protein match', NULL);
INSERT INTO chado.cvtermsynonym VALUES (607, 725, 'FLP recombination target region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (608, 725, 'FRT site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (609, 727, 'synthetic sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (610, 486, 'sequence assembly', NULL);
INSERT INTO chado.cvtermsynonym VALUES (611, 730, 'group 1 intron homing endonuclease target region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (612, 731, 'haplotype block', NULL);
INSERT INTO chado.cvtermsynonym VALUES (613, 735, 'FRT flanked', NULL);
INSERT INTO chado.cvtermsynonym VALUES (614, 736, 'invalidated by chimeric cDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (615, 738, 'floxed gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (616, 740, 'transposable element flanking region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (617, 742, 'insertion site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (618, 743, 'attI site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (619, 745, 'transposable element insertion site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (620, 630, 'small regulatory ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (621, 747, 'conjugative transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (622, 748, 'enzymatic RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (623, 750, 'recombinationally inverted gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (624, 753, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (625, 753, 'INSDC_qualifier:ribozyme', NULL);
INSERT INTO chado.cvtermsynonym VALUES (626, 755, 'cytosolic 5.8S LSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (627, 755, 'cytosolic 5.8S ribosomal RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (628, 755, 'cytosolic 5.8S rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (629, 755, 'cytosolic rRNA 5 8S', NULL);
INSERT INTO chado.cvtermsynonym VALUES (630, 758, '6S RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (631, 758, 'RNA 6S', NULL);
INSERT INTO chado.cvtermsynonym VALUES (632, 759, 'CsrB RsmB RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (633, 759, 'CsrB-RsmB RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (634, 760, 'DsrA RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (635, 761, 'GcvB RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (636, 762, 'hammerhead ribozyme', NULL);
INSERT INTO chado.cvtermsynonym VALUES (637, 762, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (638, 762, 'INSDC_qualifier:hammerhead_ribozyme', NULL);
INSERT INTO chado.cvtermsynonym VALUES (639, 763, 'group IIA intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (640, 765, 'group IIB intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (641, 766, 'MicF RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (642, 768, 'OxyS RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (643, 769, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (644, 769, 'INSDC_qualifier:RNase_MRP_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (645, 769, 'RNase MRP RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (646, 770, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (647, 770, 'INSDC_qualifier:RNase_P_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (648, 770, 'RNase P RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (649, 771, 'RprA RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (650, 772, 'RRE RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (651, 773, 'spot-42 RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (652, 774, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (653, 774, 'INSDC_qualifier:telomerase_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (654, 774, 'telomerase RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (655, 775, 'small nuclear RNA U1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (656, 775, 'snRNA U1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (657, 775, 'U1 small nuclear RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (658, 775, 'U1 snRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (659, 776, 'small nuclear RNA U2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (660, 776, 'snRNA U2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (661, 776, 'U2 small nuclear RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (662, 776, 'U2 snRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (663, 777, 'small nuclear RNA U4', NULL);
INSERT INTO chado.cvtermsynonym VALUES (664, 777, 'snRNA U4', NULL);
INSERT INTO chado.cvtermsynonym VALUES (665, 777, 'U4 small nuclear RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (666, 777, 'U4 snRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (667, 778, 'small nuclear RNA U4atac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (668, 778, 'snRNA U4atac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (669, 778, 'U4atac small nuclear RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (670, 778, 'U4atac snRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (671, 779, 'small nuclear RNA U5', NULL);
INSERT INTO chado.cvtermsynonym VALUES (672, 779, 'snRNA U5', NULL);
INSERT INTO chado.cvtermsynonym VALUES (673, 779, 'U5 small nuclear RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (674, 779, 'U5 snRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (675, 780, 'small nuclear RNA U6', NULL);
INSERT INTO chado.cvtermsynonym VALUES (676, 780, 'snRNA U6', NULL);
INSERT INTO chado.cvtermsynonym VALUES (677, 780, 'U6 small nuclear RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (678, 780, 'U6 snRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (679, 781, 'snRNA U6atac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (680, 781, 'U6atac small nuclear RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (681, 781, 'U6atac snRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (682, 782, 'small nuclear RNA U11', NULL);
INSERT INTO chado.cvtermsynonym VALUES (683, 782, 'snRNA U11', NULL);
INSERT INTO chado.cvtermsynonym VALUES (684, 782, 'U11 small nuclear RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (685, 782, 'U11 snRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (686, 783, 'small nuclear RNA U12', NULL);
INSERT INTO chado.cvtermsynonym VALUES (687, 783, 'snRNA U12', NULL);
INSERT INTO chado.cvtermsynonym VALUES (688, 783, 'U12 small nuclear RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (689, 783, 'U12 snRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (690, 784, 'sequence attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (691, 277, 'gene attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (692, 786, 'small nucleolar RNA U14', NULL);
INSERT INTO chado.cvtermsynonym VALUES (693, 786, 'snoRNA U14', NULL);
INSERT INTO chado.cvtermsynonym VALUES (694, 786, 'U14 small nucleolar RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (695, 786, 'U14 snoRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (696, 789, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (697, 789, 'INSDC_qualifier:vault_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (698, 789, 'vault RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (699, 790, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (700, 790, 'INSDC_qualifier:Y_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (701, 790, 'Y RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (702, 792, 'cytosolic 18S ribosomal RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (703, 792, 'cytosolic 18S rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (704, 792, 'cytosolic rRNA 18S', NULL);
INSERT INTO chado.cvtermsynonym VALUES (705, 796, 'binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (706, 796, 'binding_or_interaction_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (707, 796, 'INSDC_feature:misc_binding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (708, 796, 'site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (709, 797, 'INSDC_feature:protein_bind', NULL);
INSERT INTO chado.cvtermsynonym VALUES (710, 797, 'protein binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (711, 798, 'rescue fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (712, 798, 'rescue region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (713, 798, 'rescue segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (714, 540, 'restriction fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (715, 800, 'INSDC_feature:misc_difference', NULL);
INSERT INTO chado.cvtermsynonym VALUES (716, 800, 'sequence difference', NULL);
INSERT INTO chado.cvtermsynonym VALUES (717, 802, 'invalidated by genomic contamination', NULL);
INSERT INTO chado.cvtermsynonym VALUES (718, 803, 'invalidated by genomic polyA primed cDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (719, 804, 'invalidated by partial processing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (720, 805, 'domain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (721, 805, 'polypeptide domain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (722, 805, 'polypeptide_structural_domain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (723, 805, 'structural domain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (724, 808, 'INSDC_feature:sig_peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (725, 808, 'signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (726, 808, 'signal peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (727, 808, 'signal peptide coding sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (728, 812, 'chain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (729, 812, 'INSDC_feature:mat_peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (730, 812, 'mature peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (731, 812, 'mature protein region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (732, 816, '5'' TIR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (733, 816, 'five prime terminal inverted repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (734, 818, '3'' TIR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (735, 818, 'three prime terminal inverted repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (736, 819, 'U5 long terminal repeat region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (737, 819, 'U5 LTR region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (738, 821, 'R long terminal repeat region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (739, 821, 'R LTR region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (740, 822, 'U3 long terminal repeat region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (741, 822, 'U3 LTR region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (742, 823, '5'' long terminal repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (743, 823, '5'' LTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (744, 823, 'five prime LTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (745, 824, '3'' long terminal repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (746, 824, '3'' LTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (747, 824, 'three prime LTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (748, 825, 'R 5'' long term repeat region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (749, 825, 'R five prime LTR region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (750, 827, 'U5 5'' long terminal repeat region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (751, 827, 'U5 five prime LTR region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (752, 828, 'U3 5'' long term repeat region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (753, 828, 'U3 five prime LTR region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (754, 829, 'R 3'' long terminal repeat region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (755, 829, 'R three prime LTR region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (756, 831, 'U3 3'' long terminal repeat region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (757, 831, 'U3 three prime LTR region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (758, 832, 'U5 3'' long terminal repeat region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (759, 832, 'U5 three prime LTR region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (760, 833, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (761, 833, 'INSDC_qualifier:non_ltr_retrotransposon_polymeric_tract', NULL);
INSERT INTO chado.cvtermsynonym VALUES (762, 833, 'non LTR retrotransposon polymeric tract', NULL);
INSERT INTO chado.cvtermsynonym VALUES (763, 835, 'target site duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (764, 836, 'LTR retrotransposon poly purine tract', NULL);
INSERT INTO chado.cvtermsynonym VALUES (765, 836, 'RR tract', NULL);
INSERT INTO chado.cvtermsynonym VALUES (766, 837, 'autonomously replicating sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (767, 840, 'inverted ring chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (768, 488, 'vector', NULL);
INSERT INTO chado.cvtermsynonym VALUES (769, 488, 'vector replicon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (770, 431, 'single strand oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (771, 431, 'single strand oligonucleotide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (772, 431, 'single stranded oligonucleotide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (773, 431, 'ss oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (774, 431, 'ss oligonucleotide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (775, 712, 'double stranded oligonucleotide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (776, 712, 'ds oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (777, 712, 'ds-oligonucleotide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (778, 723, 'polymer attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (779, 843, 'three prime noncoding exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (780, 844, '5'' nc exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (781, 844, '5'' non coding exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (782, 844, 'five prime noncoding exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (783, 845, 'UTR intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (784, 846, 'five prime UTR intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (785, 847, 'three prime UTR intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (786, 848, 'random sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (787, 849, 'chromosome interband', NULL);
INSERT INTO chado.cvtermsynonym VALUES (788, 850, 'gene with polyadenylated mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (789, 854, 'chromosomal transposition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (790, 854, 'transposition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (791, 855, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (792, 855, 'INSDC_qualifier:rasiRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (793, 855, 'repeat associated small interfering RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (794, 857, 'gene with mRNA with frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (795, 751, 'recombinationally rearranged gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (796, 859, 'interchromosomal duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (797, 861, 'D gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (798, 861, 'D-GENE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (799, 861, 'INSDC_feature:D_segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (800, 863, 'gene with trans spliced transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (801, 862, 'vertebrate immunoglobulin T cell receptor segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (802, 862, 'vertebrate_immunoglobulin/T-cell receptor gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (803, 865, 'inversion derived bipartite deficiency', NULL);
INSERT INTO chado.cvtermsynonym VALUES (804, 866, 'pseudogenic region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (805, 867, 'encodes alternately spliced transcripts', NULL);
INSERT INTO chado.cvtermsynonym VALUES (806, 868, 'decayed exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (807, 869, 'inversion derived deficiency plus duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (808, 871, 'INSDC_feature:V_segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (809, 871, 'V gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (810, 871, 'V gene segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (811, 871, 'V-GENE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (812, 871, 'variable_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (813, 872, 'post translationally regulated by protein stability', NULL);
INSERT INTO chado.cvtermsynonym VALUES (814, 872, 'post-translationally regulated by protein stability', NULL);
INSERT INTO chado.cvtermsynonym VALUES (815, 873, 'golden path fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (816, 875, 'post translationally regulated by protein modification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (817, 875, 'post-translationally regulated by protein modification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (818, 876, 'INSDC_feature:J_segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (819, 876, 'J gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (820, 876, 'J-GENE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (821, 878, 'tiling path', NULL);
INSERT INTO chado.cvtermsynonym VALUES (822, 879, 'negatively autoregulated', NULL);
INSERT INTO chado.cvtermsynonym VALUES (823, 880, 'tiling path fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (824, 881, 'positively autoregulated', NULL);
INSERT INTO chado.cvtermsynonym VALUES (825, 882, 'contig read', NULL);
INSERT INTO chado.cvtermsynonym VALUES (826, 884, 'C gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (827, 884, 'C_GENE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (828, 884, 'constant gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (829, 884, 'INSDC_feature:C_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (830, 864, 'INSDC_feature:tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (831, 864, 'INSDC_qualifier:trans_splicing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (832, 864, 'trans spliced transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (833, 864, 'trans-spliced transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (834, 886, 'tiling path clone', NULL);
INSERT INTO chado.cvtermsynonym VALUES (835, 817, 'terminal inverted repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (836, 817, 'TIR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (837, 887, 'vertebrate immunoglobulin T cell receptor gene cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (838, 887, 'vertebrate_immunoglobulin/T-cell receptor gene cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (839, 280, 'nc primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (840, 280, 'noncoding primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (841, 888, 'three prime coding exon noncoding region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (842, 888, 'three_prime_exon_noncoding_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (843, 890, '(DJ)-J-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (844, 890, 'DJ J cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (845, 893, 'five prime coding exon noncoding region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (846, 893, 'five_prime_exon_noncoding_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (847, 894, '(VDJ)-J-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (848, 894, 'VDJ J C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (849, 896, '(VDJ)-J-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (850, 896, 'VDJ J cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (851, 897, '(VJ)-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (852, 897, 'VJ C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (853, 899, '(VJ)-J-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (854, 899, 'VJ J C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (855, 900, '(VJ)-J-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (856, 900, 'VJ J cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (857, 901, 'D gene recombination feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (858, 902, '3''D-HEPTAMER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (859, 902, 'three prime D heptamer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (860, 905, '3''D-NOMAMER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (861, 905, 'three prime D nonamer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (862, 907, '3''D-SPACER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (863, 907, 'three prime D spacer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (864, 909, '5''D-HEPTAMER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (865, 909, 'five prime D heptamer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (866, 911, '5''D-NONAMER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (867, 911, 'five prime D nonamer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (868, 912, '5''-SPACER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (869, 912, 'five prime D spacer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (870, 912, 'five prime D-spacer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (871, 913, 'virtual sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (872, 914, 'Hoogsteen base pair', NULL);
INSERT INTO chado.cvtermsynonym VALUES (873, 915, 'reverse Hoogsteen base pair', NULL);
INSERT INTO chado.cvtermsynonym VALUES (874, 918, 'D DJ C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (875, 918, 'D-(DJ)-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (876, 919, 'D DJ cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (877, 919, 'D-(DJ)-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (878, 920, 'D DJ J C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (879, 920, 'D-(DJ)-J-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (880, 921, 'pseudogenic exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (881, 923, 'D DJ J cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (882, 923, 'D-(DJ)-J-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (883, 924, 'D J C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (884, 924, 'D-J-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (885, 925, 'V_D_GENE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (886, 925, 'VD gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (887, 927, 'J C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (888, 927, 'J-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (889, 928, 'inversion derived deficiency plus aneuploid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (890, 929, 'J cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (891, 929, 'J-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (892, 930, 'J nonamer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (893, 930, 'J-NONAMER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (894, 931, 'J heptamer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (895, 931, 'J-HEPTAMER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (896, 922, 'INSDC_feature:misc_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (897, 922, 'INSDC_qualifier:pseudo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (898, 922, 'pseudogenic transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (899, 932, 'J spacer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (900, 932, 'J-SPACER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (901, 933, 'V DJ cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (902, 933, 'V-(DJ)-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (903, 934, 'V DJ J cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (904, 934, 'V-(DJ)-J-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (905, 935, 'V VDJ C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (906, 935, 'V-(VDJ)-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (907, 936, 'V VDJ cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (908, 936, 'V-(VDJ)-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (909, 937, 'V VDJ J cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (910, 937, 'V-(VDJ)-J-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (911, 938, 'V VJ C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (912, 938, 'V-(VJ)-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (913, 939, 'V VJ cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (914, 939, 'V-(VJ)-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (915, 940, 'V VJ J cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (916, 940, 'V-(VJ)-J-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (917, 941, 'V cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (918, 941, 'V-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (919, 942, 'V D DJ C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (920, 942, 'V-D-(DJ)-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (921, 943, 'V D DJ cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (922, 943, 'V-D-(DJ)-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (923, 944, 'V D DJ J C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (924, 944, 'V-D-(DJ)-J-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (925, 945, 'V D DJ J cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (926, 945, 'V-D-(DJ)-J-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (927, 946, 'V D J C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (928, 946, 'V-D-J-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (929, 947, 'V D J cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (930, 947, 'V-D-J-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (931, 948, 'V heptamer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (932, 948, 'V-HEPTAMER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (933, 950, 'V J cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (934, 950, 'V-J-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (935, 951, 'V J C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (936, 951, 'V-J-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (937, 952, 'V nonamer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (938, 952, 'V-NONAMER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (939, 953, 'V spacer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (940, 953, 'V-SPACER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (941, 949, 'V gene recombination feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (942, 949, 'V-RS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (943, 954, '(DJ)-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (944, 954, 'DJ C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (945, 955, '(DJ)-J-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (946, 955, 'DJ J C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (947, 956, '(VDJ)-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (948, 956, 'VDJ C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (949, 957, 'V DJ C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (950, 957, 'V-(DJ)-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (951, 959, 'ISCR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (952, 960, 'recoding pseudoknot', NULL);
INSERT INTO chado.cvtermsynonym VALUES (953, 963, 'designed sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (954, 964, 'inversion derived bipartite duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (955, 965, 'gene with edited transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (956, 967, 'inversion derived duplication plus aneuploid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (957, 968, 'aneuploid chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (958, 969, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (959, 969, 'INSDC_qualifier:polyA_signal_sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (960, 969, 'poly(A) signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (961, 969, 'polyA signal sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (962, 969, 'polyadenylation termination signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (963, 970, 'five prime ribosome binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (964, 970, 'RBS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (965, 970, 'Shine Dalgarno sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (966, 970, 'Shine-Dalgarno sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (967, 971, 'INSDC_feature:polyA_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (968, 971, 'polyA cleavage site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (969, 971, 'polyA junction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (970, 971, 'polyA site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (971, 971, 'polyA_junction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (972, 971, 'polyadenylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (973, 973, '5'' clip', NULL);
INSERT INTO chado.cvtermsynonym VALUES (974, 973, 'five prime clip', NULL);
INSERT INTO chado.cvtermsynonym VALUES (975, 910, '5''RS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (976, 910, 'five prime D recombination signal sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (977, 910, 'five prime D-recombination signal sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (978, 974, '3''-clip', NULL);
INSERT INTO chado.cvtermsynonym VALUES (979, 974, 'three prime clip', NULL);
INSERT INTO chado.cvtermsynonym VALUES (980, 975, 'C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (981, 975, 'C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (982, 976, 'D cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (983, 976, 'D-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (984, 977, 'D J cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (985, 977, 'D-J-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (986, 903, 'HEPTAMER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (987, 903, 'heptamer of recombination feature of vertebrate immune system gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (988, 906, 'nonamer of recombination feature of vertebrate immune system gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (989, 908, 'vertebrate immune system gene recombination spacer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (990, 978, 'V DJ J C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (991, 978, 'V-(DJ)-J-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (992, 979, 'V VDJ J C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (993, 979, 'V-(VDJ)-J-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (994, 980, 'V VJ J C cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (995, 980, 'V-(VJ)-J-C-CLUSTER', NULL);
INSERT INTO chado.cvtermsynonym VALUES (996, 981, 'inversion derived aneuploid chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (997, 982, 'bidirectional promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (998, 904, '3''D-RS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (999, 904, 'three prime D recombination signal sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1000, 904, 'three_prime_D-recombination_signal_sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1001, 984, 'miRNA encoding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1002, 892, 'D-J-GENE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1003, 892, 'DJ gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1004, 985, 'rRNA encoding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1005, 895, 'V-D-J-GENE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1006, 895, 'VDJ gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1007, 986, 'scRNA encoding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1008, 898, 'V-J-GENE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1009, 898, 'VJ gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1010, 987, 'INSDC_feature:centromere', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1011, 989, 'snoRNA encoding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1012, 990, 'edited transcript feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1013, 991, 'methylation guide snoRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1014, 993, 'rRNA cleavage snoRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1015, 994, 'pre edited region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1016, 994, 'pre-edited region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1017, 995, '10Sa RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1018, 995, 'INSDC_feature:tmRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1019, 995, 'ssrA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1020, 996, 'C/D box snoRNA encoding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1021, 997, '10Sa RNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1022, 997, 'ssrA RNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1023, 997, 'tmRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1024, 998, 'group I intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1025, 999, 'autocatalytically spliced intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1026, 999, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1027, 999, 'INSDC_qualifier:autocatalytically_spliced_intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1028, 1000, 'SRP RNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1029, 1001, '7S RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1030, 1001, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1031, 1001, 'INSDC_qualifier:SRP_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1032, 1001, 'signal recognition particle RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1033, 1001, 'SRP RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1034, 1002, 'classical pseudoknot', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1035, 1002, 'H pseudoknot', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1036, 1002, 'H-pseudoknot', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1037, 1002, 'H-type pseudoknot', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1038, 1002, 'hairpin-type pseudoknot', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1039, 787, 'box C/D snoRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1040, 787, 'C D box snoRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1041, 787, 'C/D box snoRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1042, 787, 'SNORD', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1043, 1004, 'box H/ACA snoRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1044, 1004, 'H ACA box snoRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1045, 1004, 'H/ACA box snoRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1046, 1004, 'SNORA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1047, 1003, 'C/D box snoRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1048, 1005, 'H ACA box snoRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1049, 1007, 'transcript_edited_by_C-insertion_and_dinucleotide_insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1050, 1011, 'gRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1051, 1011, 'guide RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1052, 1011, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1053, 1011, 'INSDC_qualifier:guide_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1054, 764, 'group II intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1055, 1012, 'editing block', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1056, 1013, 'intergenic region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1057, 1014, 'editing domain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1058, 1015, 'unedited region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1059, 1016, 'H ACA box snoRNA encoding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1060, 1017, 'oligo U tail', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1061, 1018, 'polyA sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1062, 1019, 'branch point', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1063, 1019, 'branch site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1064, 1019, 'branch_point', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1065, 1020, 'polypyrimidine tract', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1066, 1021, 'bacterial RNApol promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1067, 1023, 'bacterial terminator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1068, 1024, 'terminator of type 2 RNApol III promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1069, 1026, 'transcription end site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1070, 1027, 'RNApol III promoter type 1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1071, 1028, 'RNApol III promoter type 2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1072, 1028, 'tRNA promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1073, 1029, 'A-box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1074, 1030, 'B-box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1075, 1031, 'RNApol III promoter type 3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1076, 1032, 'C-box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1077, 1033, 'snRNA encoding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1078, 1034, 'INSDC_feature:telomere', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1079, 1034, 'telomeric DNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1080, 1034, 'telomeric sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1081, 1035, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1082, 1035, 'INSDC_qualifier:silencer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1083, 314, 'chromosomal regulatory element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1084, 1036, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1085, 1036, 'INSDC_qualifier:insulator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1086, 1036, 'insulator element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1087, 988, 'chromosomal structural element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1088, 1037, 'five prime open reading frame', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1089, 1038, 'upstream AUG codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1090, 1040, 'polycistronic primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1091, 1041, 'monocistronic primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1092, 1044, 'monocistronic mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1093, 1044, 'monocistronic processed transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1094, 1045, 'polycistronic mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1095, 1045, 'polycistronic processed transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1096, 1046, 'mini exon donor RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1097, 1046, 'mini-exon donor RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1098, 1047, 'mini-exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1099, 1047, 'spliced leader RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1100, 1048, 'engineered plasmid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1101, 1048, 'engineered plasmid gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1102, 1049, 'transcribed spacer region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1103, 1051, 'internal transcribed spacer region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1104, 1052, 'external transcribed spacer region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1105, 1053, 'tetranucleotide repeat microsatellite feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1106, 1054, 'SRP RNA encoding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1107, 1055, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1108, 1055, 'INSDC_qualifier:minisatellite', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1109, 1055, 'VNTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1110, 767, 'antisense RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1111, 767, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1112, 767, 'INSDC_qualifier:antisense_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1113, 1056, 'antisense primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1114, 1057, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1115, 1057, 'INSDC_qualifier:siRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1116, 1057, 'small interfering RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1117, 1058, 'micro RNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1118, 1058, 'miRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1119, 1058, 'small temporal RNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1120, 1058, 'stRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1121, 1058, 'stRNA_primary_transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1122, 793, 'cytosolic small subunit rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1123, 793, 'cytosolic SSU ribosomal RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1124, 793, 'cytosolic SSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1125, 756, 'cytosolic large subunit rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1126, 756, 'cytosolic LSU RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1127, 756, 'cytosolic LSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1128, 1060, 'cytosolic 5S LSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1129, 1060, 'cytosolic 5S ribosomal RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1130, 1060, 'cytosolic 5S rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1131, 1060, 'cytosolic rRNA 5S', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1132, 1062, 'cytosolic 28S LSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1133, 1062, 'cytosolic 28S ribosomal RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1134, 1062, 'cytosolic 28S rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1135, 1062, 'cytosolic rRNA 28S', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1136, 1064, 'maxi-circle gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1137, 1064, 'maxicircle gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1138, 282, 'INSDC_qualifier:other', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1139, 282, 'known_ncrna', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1140, 282, 'noncoding RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1141, 1066, 'stRNA encoding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1142, 648, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1143, 648, 'INSDC_qualifier:other', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1144, 648, 'repeat region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1145, 1068, 'dispersed repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1146, 1068, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1147, 1068, 'INSDC_qualifier:dispersed', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1148, 1068, 'interspersed repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1149, 1069, 'tmRNA encoding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1150, 531, 'spliceosomal intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1151, 1072, 'tRNA encoding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1152, 1073, 'introgressed chromosome region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1153, 1042, 'monocistronic transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1154, 1074, 'mobile intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1155, 1077, 'insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1156, 1077, 'nucleotide insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1157, 1077, 'nucleotide_insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1158, 1078, 'EST match', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1159, 663, 'sequence rearrangement feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1160, 1079, 'chromosome breakage sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1161, 1080, 'internal eliminated sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1162, 1081, 'macronucleus destined segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1163, 373, 'INSDC_feature:misc_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1164, 1084, 'non canonical splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1165, 1084, 'non-canonical splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1166, 1085, 'canonical splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1167, 1086, 'canonical 3'' splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1168, 1086, 'canonical three prime splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1169, 1087, 'canonical 5'' splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1170, 1087, 'canonical five prime splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1171, 1088, 'non canonical 3'' splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1172, 1088, 'non canonical three prime splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1173, 1088, 'non-canonical three prime splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1174, 1089, 'non canonical 5'' splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1175, 1089, 'non canonical five prime splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1176, 1089, 'non-canonical five prime splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1177, 1090, 'non ATG start codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1178, 1090, 'non canonical start codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1179, 1090, 'non-canonical start codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1180, 1091, 'aberrant processed transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1181, 1093, 'exonic splice enhancer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1182, 693, 'nuclease sensitive site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1183, 1094, 'DHS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1184, 1094, 'DNaseI hypersensitive site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1185, 1094, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1186, 1094, 'INSDC_qualifier:DNase_I_hypersensitive_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1187, 1095, 'translocation element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1188, 1097, 'deletion junction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1189, 874, 'golden path', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1190, 1098, 'cDNA match', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1191, 1099, 'gene with polycistronic transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1192, 1100, 'cleaved initiator methionine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1193, 1100, 'init_met', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1194, 1100, 'initiator methionine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1195, 1102, 'gene with dicistronic transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1196, 1103, 'gene with recoded mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1197, 1105, 'single nucleotide polymorphism', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1198, 305, 'oligonucleotide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1199, 1108, 'gene with stop codon read through', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1200, 1110, 'gene with stop codon redefined as pyrrolysine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1201, 418, 'boundary', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1202, 418, 'breakpoint', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1203, 1112, 'possible base call error', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1204, 1113, 'possible assembly error', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1205, 1114, 'experimental result region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1206, 163, 'INSDC_feature:gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1207, 267, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1208, 267, 'INSDC_qualifier:tandem', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1209, 267, 'tandem repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1210, 1115, '3'' trans splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1211, 1115, 'trans splice acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1212, 1117, '5 prime trans splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1213, 1117, 'trans splice donor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1214, 1117, 'trans-splice donor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1215, 1118, 'SL1 acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1216, 1119, 'SL2 acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1217, 1120, 'gene with stop codon redefined as selenocysteine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1218, 1122, 'gene with mRNA recoded by translational bypass', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1219, 1124, 'gene with transcript with translational frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1220, 289, 'DNA motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1221, 1125, 'INSDC_feature:misc_feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1222, 1125, 'INSDC_note:nucleotide_motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1223, 1125, 'nucleotide motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1224, 293, 'RNA motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1225, 1127, 'dicistronic mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1226, 1127, 'dicistronic processed transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1227, 584, 'reading frame', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1228, 1128, 'blocked reading frame', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1229, 485, 'pseudochromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1230, 485, 'superscaffold', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1231, 1129, 'foreign transposable element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1232, 1130, 'gene with dicistronic primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1233, 1132, 'gene with dicistronic mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1234, 1132, 'gene with dicistronic processed transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1235, 1133, 'INSDC_feature:iDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1236, 1133, 'intervening DNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1237, 1134, 'INSDC_feature:oriT', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1238, 1134, 'origin of transfer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1239, 1135, 'INSDC_feature:transit_peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1240, 1135, 'signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1241, 1135, 'transit', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1242, 1135, 'transit peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1243, 1067, 'repeat unit', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1244, 316, 'cis regulatory module', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1245, 316, 'CRM', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1246, 316, 'TF module', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1247, 316, 'transcription factor module', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1248, 1137, 'protein intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1249, 1138, 'intein containing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1250, 1139, 'INSDC_feature:assembly_gap', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1251, 1139, 'INSDC_feature:gap', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1252, 1140, 'fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1253, 585, 'feature attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1254, 1143, 'exemplar mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1255, 1145, 'sequence location', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1256, 381, 'organelle sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1257, 388, 'mitochondrial sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1258, 386, 'nuclear sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1259, 406, 'nucleomorphic sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1260, 392, 'plastid sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1261, 390, 'kinetoplast_chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1262, 1065, 'maxicircle_chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1263, 394, 'apicoplast sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1264, 398, 'chromoplast sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1265, 396, 'chloroplast sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1266, 400, 'cyanelle sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1267, 402, 'leucoplast sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1268, 404, 'proplastid sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1269, 408, 'plasmid location', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1270, 1148, 'amplification origin', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1271, 410, 'proviral location', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1272, 1149, 'gene group regulatory region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1273, 419, 'clone insert', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1274, 1150, 'lambda vector', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1275, 1151, 'plasmid vector', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1276, 684, 'complementary DNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1277, 1152, 'single strand cDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1278, 1152, 'single stranded cDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1279, 1152, 'single-strand cDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1280, 1153, 'double strand cDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1281, 1153, 'double stranded cDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1282, 1153, 'double-strand cDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1283, 1157, 'P1_clone', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1284, 1161, 'pyrrolysyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1285, 1161, 'pyrrolysyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1286, 1161, 'pyrrolysyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1287, 1165, 'tmRNA coding piece', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1288, 1167, 'tmRNA acceptor piece', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1289, 165, 'quantitative trait locus', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1290, 1168, 'genomic island', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1291, 1169, 'pathogenic island', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1292, 1170, 'metabolic island', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1293, 1171, 'adaptive island', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1294, 1172, 'symbiosis island', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1295, 1173, 'INSDC_feature:rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1296, 1173, 'INSDC_qualifier:pseudo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1297, 1173, 'pseudogenic rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1298, 1174, 'INSDC_feature:tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1299, 1174, 'INSDC_qualifier:pseudo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1300, 1174, 'pseudogenic tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1301, 1175, 'engineered episome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1302, 1179, 'cloned region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1303, 1179, 'cloned segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1304, 1180, 'reagent attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1305, 1186, 'engineered rescue fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1306, 1186, 'engineered rescue region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1307, 1186, 'engineered rescue segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1308, 1187, 'rescue mini gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1309, 1187, 'rescue mini-gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1310, 1189, 'transgenic transposable element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1311, 1190, 'natural transposable element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1312, 1192, 'engineered transposable element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1313, 1193, 'engineered foreign transposable element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1314, 1194, 'assortment derived duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1315, 1196, 'assortment derived deficiency plus duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1316, 1197, 'assortment-derived deficiency', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1317, 1198, 'assortment derived aneuploid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1318, 637, 'construct', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1319, 637, 'engineered region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1320, 637, 'engineered sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1321, 641, 'engineered foreign region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1322, 1199, 'engineered tag', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1323, 1200, 'validated cDNA clone', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1324, 1201, 'invalidated cDNA clone', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1325, 1202, 'chimeric cDNA clone', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1326, 1203, 'genomically contaminated cDNA clone', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1327, 1204, 'polyA primed cDNA clone', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1328, 1205, 'partially processed cDNA clone', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1329, 1188, 'mini gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1330, 1206, 'rescue gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1331, 1207, 'wild type', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1332, 1208, 'wild type rescue gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1333, 1209, 'mitochondrial chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1334, 1210, 'chloroplast chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1335, 1211, 'chromoplast chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1336, 1212, 'cyanelle chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1337, 1213, 'leucoplast chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1338, 1214, 'macronuclear chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1339, 1215, 'micronuclear chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1340, 1216, 'nuclear chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1341, 1217, 'nucleomorphic chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1342, 423, 'chromosomal region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1343, 423, 'chromosomal_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1344, 423, 'chromosome part', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1345, 1082, 'gene member region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1346, 482, 'transcript region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1347, 1219, 'mature transcript region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1348, 501, 'primary transcript region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1349, 312, 'mRNA region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1350, 1039, 'UTR region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1351, 1050, 'rRNA primary transcript region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1352, 813, 'positional', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1353, 813, 'positional polypeptide feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1354, 813, 'region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1355, 813, 'region or site annotation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1356, 813, 'site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1357, 834, 'repeat component', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1358, 689, 'spliceosomal intron region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1359, 508, 'gene component region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1360, 1166, 'tmRNA region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1361, 820, 'long term repeat component', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1362, 820, 'LTR component', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1363, 830, '3'' long terminal repeat component', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1364, 830, 'three prime LTR component', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1365, 826, '5'' long term repeat component', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1366, 826, 'five prime LTR component', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1367, 696, 'CDS region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1368, 1224, 'exon region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1369, 1225, 'homolog', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1370, 1225, 'homologous region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1371, 1225, 'homologue', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1372, 1227, 'paralog', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1373, 1227, 'paralogous region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1374, 1227, 'paralogue', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1375, 1229, 'ortholog', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1376, 1229, 'orthologous region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1377, 1229, 'orthologue', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1378, 1233, 'capped primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1379, 1234, 'capped mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1380, 598, 'mRNA attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1381, 644, 'minus 1 frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1382, 710, 'minus 2 frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1383, 691, 'plus 1 frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1384, 703, 'plus 2 framshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1385, 885, 'trans-spliced', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1386, 852, 'polyadenylated mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1387, 1235, 'trans-spliced mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1388, 966, 'edited transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1389, 1237, 'edited transcript by A to I substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1390, 635, 'bound by protein', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1391, 633, 'bound by nucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1392, 1238, 'alternatively spliced', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1393, 1239, 'codon redefined', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1394, 1109, 'stop codon read through', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1395, 1109, 'stop codon readthrough', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1396, 1111, 'stop codon redefined as pyrrolysine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1397, 1121, 'stop codon redefined as selenocysteine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1398, 1123, 'recoded by translational bypass', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1399, 441, 'translationally frameshifted', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1400, 1240, 'maternally imprinted gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1401, 1241, 'paternally imprinted gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1402, 1242, 'post translationally regulated gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1403, 1243, 'negatively autoregulated gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1404, 1244, 'positively autoregulated gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1405, 455, 'silenced by DNA modification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1406, 457, 'silenced by DNA methylation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1407, 1245, 'translationally regulated gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1408, 1246, 'allelically excluded gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1409, 468, 'epigenetically modified gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1410, 1247, 'nuclear mitochondrial', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1411, 1249, 'unequally crossed over', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1412, 412, 'endogenous retroviral sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1413, 469, 'rearranged at DNA level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1414, 1250, 'independently known', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1415, 1251, 'supported by sequence similarity', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1416, 1252, 'supported by domain match', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1417, 1253, 'supported by EST or cDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1418, 1255, 'predicted by ab initio computation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1419, 1256, 'asx turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1420, 1258, 'cloned cDNA insert', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1421, 1259, 'cloned genomic insert', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1422, 1260, 'engineered insert', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1423, 1261, 'edit operation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1424, 1262, 'insert U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1425, 1263, 'delete U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1426, 1264, 'substitute A to I', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1427, 1265, 'insert C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1428, 1266, 'insert dinucleotide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1429, 1267, 'substitute C to U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1430, 1268, 'insert G', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1431, 1269, 'insert GC', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1432, 1270, 'insert GU', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1433, 1271, 'insert CU', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1434, 1272, 'insert AU', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1435, 1273, 'insert AA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1436, 1274, 'edited mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1437, 1275, 'guide RNA region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1438, 1276, 'anchor region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1439, 1277, 'pre-edited mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1440, 1279, 'miRNA target site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1441, 1281, 'edited CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1442, 926, 'vertebrate immunoglobulin T cell receptor rearranged segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1443, 891, 'vertebrate immunoglobulin T cell receptor rearranged gene cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1444, 667, 'vertebrate immune system gene recombination signal feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1445, 858, 'recombinationally rearranged', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1446, 1283, 'recombinationally rearranged vertebrate immune system gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1447, 1284, 'attP site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1448, 1286, 'attB site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1449, 1287, 'attBP''', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1450, 1287, 'attL site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1451, 1288, 'attPB''', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1452, 1288, 'attR site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1453, 744, 'attachment site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1454, 744, 'integration excision site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1455, 721, 'res site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1456, 721, 'resolution site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1457, 726, 'inversion site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1458, 1289, 'dif site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1459, 1290, 'attC site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1460, 1025, 'eukaryotic terminator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1461, 1291, 'origin of vegetative replication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1462, 1292, 'origin of bacterial chromosome replication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1463, 1293, 'DNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1464, 1294, 'double stranded DNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1465, 1296, 'single stranded DNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1466, 1298, 'linear double stranded DNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1467, 1300, 'circular double stranded DNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1468, 1302, 'linear single stranded DNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1469, 1303, 'circular single stranded DNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1470, 1304, 'RNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1471, 1305, 'single stranded RNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1472, 1306, 'linear single stranded RNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1473, 1307, 'linear double stranded RNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1474, 1308, 'double stranded RNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1475, 1309, 'circular single stranded RNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1476, 1310, 'circular double stranded RNA chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1477, 1311, 'sequence replication mode', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1478, 1312, 'rolling circle', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1479, 1313, 'theta replication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1480, 1314, 'DNA replication mode', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1481, 1315, 'RNA replication mode', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1482, 1316, 'insertion sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1483, 1316, 'IS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1484, 1317, 'minicircle gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1485, 1236, 'anchor binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1486, 1319, 'information region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1487, 1319, 'template region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1488, 1320, 'gRNA encoding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1489, 1147, 'minicircle_chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1490, 1321, 'rho dependent bacterial terminator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1491, 1322, 'rho independent bacterial terminator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1492, 1323, 'strand attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1493, 1324, 'topology attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1494, 1299, 'two-ended', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1495, 1301, 'zero-ended', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1496, 1325, 'class II RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1497, 1326, 'class I RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1498, 323, 'gDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1499, 323, 'genomic DNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1500, 1327, 'BAC cloned genomic insert', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1501, 1329, 'consensus region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1502, 1330, 'consensus mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1503, 1331, 'predicted gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1504, 1332, 'gene fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1505, 1333, 'recursive splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1506, 1334, 'BAC end', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1507, 1334, 'BAC end sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1508, 1334, 'BES', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1509, 1335, 'cytosolic 16S ribosomal RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1510, 1335, 'cytosolic 16S rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1511, 1335, 'cytosolic 16S SSU RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1512, 1335, 'cytosolic rRNA 16S', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1513, 1337, 'cytosolic 23S LSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1514, 1337, 'cytosolic 23S ribosomal RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1515, 1337, 'cytosolic 23S rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1516, 1337, 'cytosolic rRNA 23S', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1517, 1339, 'cytosolic 25S LSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1518, 1339, 'cytosolic 25S ribosomal RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1519, 1339, 'cytosolic 25S rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1520, 1339, 'cytosolic rRNA 25S', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1521, 1341, 'solo LTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1522, 1342, 'low complexity', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1523, 1343, 'low complexity region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1524, 1345, 'cryptic prophage', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1525, 1347, 'DNA constraint', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1526, 1347, 'DNA constraint sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1527, 1348, 'i motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1528, 1348, 'short intercalated motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1529, 1349, 'peptide nucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1530, 1349, 'PNA oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1531, 1351, 'catalytic DNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1532, 1351, 'deoxyribozyme', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1533, 1351, 'DNA enzyme', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1534, 1352, 'multiple nucleotide polymorphism', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1535, 1354, 'intron domain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1536, 1355, 'wobble base pair', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1537, 1355, 'wobble pair', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1538, 1356, 'IGS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1539, 1356, 'internal guide sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1540, 1357, 'silent mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1541, 1360, 'CNP', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1542, 1360, 'CNV', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1543, 1360, 'copy number polymorphism', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1544, 1360, 'copy number variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1545, 1361, 'mutation affecting copy number', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1546, 1361, 'sequence variant affecting copy number', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1547, 1362, 'aberration breakpoint', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1548, 1362, 'aberration_junction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1549, 1362, 'chromosome breakpoint', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1550, 1362, 'INSDC_feature:misc_recomb', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1551, 1362, 'INSDC_qualifier:chromosome_breakpoint', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1552, 1363, 'inversion breakpoint', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1553, 1364, 'allelomorph', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1554, 1366, 'polymorphic sequence variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1555, 1370, 'direction attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1556, 1371, 'mitochondrial DNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1557, 1371, 'mtDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1558, 1372, 'chloroplast DNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1559, 856, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1560, 856, 'INSDC_qualifier:piRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1561, 856, 'piwi-associated RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1562, 1374, 'arginyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1563, 1075, 'INSDC_feature:mobile_element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1564, 1075, 'MGE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1565, 1075, 'mobile genetic element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1566, 1191, 'extrachromosomal mobile genetic element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1567, 414, 'integrated mobile genetic element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1568, 1375, 'integrated plasmid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1569, 1376, 'viral sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1570, 1376, 'virus sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1571, 1285, 'bacteriophage', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1572, 1285, 'phage', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1573, 1285, 'phage sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1574, 1377, 'attCtn site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1575, 1378, 'nuclear mitochondrial pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1576, 1378, 'nuclear mt pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1577, 1378, 'NUMT', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1578, 1379, 'cointegrated plasmid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1579, 1379, 'cointegrated replicon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1580, 1380, 'IRLinv site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1581, 1382, 'IRRinv site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1582, 1381, 'inversion site part', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1583, 1383, 'defective conjugative transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1584, 1384, 'repeat fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1585, 1389, 'transposon fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1586, 344, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1587, 344, 'INSDC_qualifier:transcriptional_cis_regulatory_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1588, 344, 'transcription-control region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1589, 344, 'transcriptional cis regulatory region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1590, 718, 'splicing regulatory region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1591, 1393, 'promoter targeting sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1592, 496, 'INSDC_feature:misc_feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1593, 496, 'INSDC_feature:variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1594, 496, 'INSDC_note:sequence_alteration', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1595, 496, 'partially characterised change in DNA sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1596, 496, 'partially_characterised_change_in_DNA_sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1597, 496, 'sequence alteration', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1598, 496, 'sequence variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1599, 496, 'uncharacterised_change_in_nucleotide_sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1600, 166, 'ANNOVAR:unknown', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1601, 166, 'Jannovar:sequence_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1602, 166, 'sequence variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1603, 166, 'VAAST:sequence_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1604, 1395, 'propeptide cleavage site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1605, 811, 'INSDC_feature:propeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1606, 811, 'propep', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1607, 815, 'immature peptide region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1608, 1397, 'active peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1609, 1397, 'peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1610, 1398, 'compbias', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1611, 1398, 'compositional bias', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1612, 1398, 'compositionally biased', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1613, 1398, 'compositionally biased region of peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1614, 1398, 'compositionally_biased_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1615, 1399, 'motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1616, 1399, 'polypeptide motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1617, 1400, 'polypeptide repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1618, 1400, 'repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1619, 806, 'polypeptide structural region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1620, 806, 'structural_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1621, 1401, 'membrane structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1622, 1402, 'extramembrane', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1623, 1402, 'extramembrane polypeptide region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1624, 1402, 'extramembrane_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1625, 1402, 'topo_dom', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1626, 1403, 'cytoplasm_location', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1627, 1403, 'cytoplasmic polypeptide region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1628, 1403, 'inside', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1629, 1404, 'non cytoplasmic polypeptide region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1630, 1404, 'non_cytoplasm_location', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1631, 1404, 'outside', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1632, 1405, 'intramembrane', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1633, 1405, 'intramembrane polypeptide region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1634, 1406, 'membrane peptide loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1635, 1406, 'membrane_loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1636, 1407, 'transmem', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1637, 1407, 'transmembrane', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1638, 1407, 'transmembrane polypeptide region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1639, 1408, '2nary structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1640, 1408, 'polypeptide secondary structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1641, 1408, 'secondary structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1642, 1408, 'secondary structure region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1643, 1408, 'secondary_structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1644, 1409, 'polypeptide structural motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1645, 1409, 'structural_motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1646, 1410, 'coiled', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1647, 1410, 'coiled coil', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1648, 1411, 'helix turn helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1649, 1411, 'helix-turn-helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1650, 1411, 'HTH', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1651, 1413, 'sequencing_information', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1652, 1414, 'non consecutive', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1653, 1414, 'non_cons', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1654, 1415, 'non terminal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1655, 1415, 'non_ter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1656, 1416, 'conflict', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1657, 1417, 'INSDC_feature:unsure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1658, 1417, 'unsure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1659, 1418, 'cross link', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1660, 1418, 'crosslink', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1661, 1419, 'disulfid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1662, 1419, 'disulfide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1663, 1419, 'disulfide bond', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1664, 1419, 'disulphide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1665, 1419, 'disulphide bond', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1666, 1420, 'mod_res', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1667, 1420, 'modified residue', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1668, 1420, 'post_translational_modification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1669, 1422, 'covalent binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1670, 1423, 'binding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1671, 1423, 'binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1672, 1423, 'non covalent binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1673, 1424, 'metal_binding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1674, 1427, 'protein protein contact', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1675, 1427, 'protein protein contact site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1676, 1427, 'protein_protein_interaction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1677, 1428, 'ca bind', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1678, 1428, 'ca_bind', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1679, 1428, 'Ca_contact_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1680, 1428, 'polypeptide calcium ion contact site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1681, 1429, 'Co_contact_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1682, 1429, 'polypeptide cobalt ion contact site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1683, 1430, 'Cu_contact_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1684, 1430, 'polypeptide copper ion contact site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1685, 1431, 'Fe_contact_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1686, 1431, 'polypeptide iron ion contact site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1687, 1432, 'Mg_contact_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1688, 1432, 'polypeptide magnesium ion contact site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1689, 1433, 'Mn_contact_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1690, 1433, 'polypeptide manganese ion contact site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1691, 1434, 'Mo_contact_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1692, 1434, 'polypeptide molybdenum ion contact site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1693, 1435, 'Ni_contact_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1694, 1435, 'polypeptide nickel ion contact site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1695, 1436, 'polypeptide tungsten ion contact site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1696, 1436, 'W_contact_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1697, 1437, 'polypeptide zinc ion contact site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1698, 1437, 'Zn_contact_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1699, 1438, 'act_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1700, 1438, 'active site residue', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1701, 1438, 'catalytic residue', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1702, 1441, 'polypeptide ligand contact', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1703, 1441, 'protein-ligand interaction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1704, 1443, 'asx motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1705, 1444, 'beta bulge', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1706, 1445, 'beta bulge loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1707, 1446, 'beta bulge loop five', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1708, 1447, 'beta bulge loop six', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1709, 1448, 'strand', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1710, 1449, 'antiparallel beta strand', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1711, 1450, 'parallel beta strand', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1712, 1412, 'helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1713, 1451, 'helix-l', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1714, 1451, 'left handed helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1715, 1452, 'helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1716, 1452, 'right handed helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1717, 1453, 'a-helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1718, 1453, 'helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1719, 1454, 'pi helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1720, 1455, '3(10) helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1721, 1455, '3-10 helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1722, 1455, '310 helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1723, 1455, 'three ten helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1724, 1456, 'nest', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1725, 1456, 'nest_motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1726, 1456, 'polypeptide nest motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1727, 1457, 'nest_left_right', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1728, 1457, 'nest_lr', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1729, 1457, 'polypeptide nest left right motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1730, 1458, 'nest_right_left', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1731, 1458, 'nest_rl', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1732, 1458, 'polypeptide nest right left motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1733, 1459, 'paperclip', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1734, 1459, 'paperclip loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1735, 1459, 'schellmann loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1736, 1460, 'schellmann loop seven', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1737, 1460, 'seven-residue schellmann loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1738, 1461, 'schellmann loop six', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1739, 1461, 'six-residue schellmann loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1740, 1462, 'serine/threonine motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1741, 1462, 'st motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1742, 1462, 'st_motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1743, 1463, 'serine threonine staple motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1744, 1463, 'st_staple', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1745, 1257, 'turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1746, 1464, 'asx turn left handed type one', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1747, 1464, 'asx_turn_il', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1748, 1465, 'asx turn left handed type two', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1749, 1465, 'asx_turn_iil', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1750, 1466, 'asx turn right handed type two', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1751, 1466, 'asx_turn_iir', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1752, 1467, 'asx turn type right handed type one', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1753, 1467, 'asx_turn_ir', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1754, 1468, 'beta turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1755, 1469, 'beta turn left handed type one', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1756, 1469, 'beta_turn_il', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1757, 1469, 'type I'' beta turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1758, 1469, 'type I'' turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1759, 1470, 'beta turn left handed type two', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1760, 1470, 'beta_turn_iil', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1761, 1470, 'type II'' beta turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1762, 1470, 'type II'' turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1763, 1471, 'beta turn right handed type one', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1764, 1471, 'beta_turn_ir', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1765, 1471, 'type I beta turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1766, 1471, 'type I turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1767, 1472, 'beta turn right handed type two', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1768, 1472, 'beta_turn_iir', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1769, 1472, 'type II beta turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1770, 1472, 'type II turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1771, 1473, 'gamma turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1772, 1474, 'classic gamma turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1773, 1474, 'gamma turn classic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1774, 1475, 'gamma turn inverse', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1775, 1476, 'serine/threonine turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1776, 1476, 'st_turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1777, 1477, 'st turn left handed type one', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1778, 1477, 'st_turn_il', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1779, 1478, 'st turn left handed type two', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1780, 1478, 'st_turn_iil', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1781, 1479, 'st turn right handed type one', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1782, 1479, 'st_turn_ir', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1783, 1480, 'st turn right handed type two', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1784, 1480, 'st_turn_iir', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1785, 1481, 'sequence_variations', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1786, 1482, 'natural_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1787, 1482, 'sequence variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1788, 1482, 'variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1789, 1483, 'mutagen', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1790, 1483, 'mutagenesis', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1791, 1483, 'mutated_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1792, 1484, 'alternative_sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1793, 1484, 'isoform', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1794, 1484, 'sequence variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1795, 1484, 'var_seq', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1796, 1484, 'varsplic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1797, 1485, 'beta turn type six', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1798, 1485, 'cis-proline loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1799, 1485, 'type VI beta turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1800, 1485, 'type VI turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1801, 1486, 'beta turn type six a', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1802, 1486, 'type VIa beta turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1803, 1486, 'type VIa turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1804, 1487, 'beta turn type six a one', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1805, 1487, 'type VIa1 beta turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1806, 1487, 'type VIa1 turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1807, 1488, 'beta turn type six a two', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1808, 1488, 'type VIa2 beta turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1809, 1488, 'type VIa2 turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1810, 1489, 'beta turn type six b', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1811, 1489, 'type VIb beta turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1812, 1489, 'type VIb turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1813, 1490, 'beta turn type eight', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1814, 1490, 'type VIII beta turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1815, 1490, 'type VIII turn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1816, 1491, 'DRE motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1817, 1491, 'NDM4', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1818, 1491, 'WATCGATW_motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1819, 1492, 'directional motif v4', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1820, 1492, 'DMv4', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1821, 1492, 'DMv4 motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1822, 1492, 'motif 1 element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1823, 1492, 'promoter motif 1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1824, 1492, 'YGGTCACATR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1825, 1493, 'AWCAGCTGWT', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1826, 1493, 'E box motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1827, 1493, 'generic E box motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1828, 1493, 'NDM5', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1829, 1494, 'directional motif v5', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1830, 1494, 'DMv5', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1831, 1494, 'DMv5 motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1832, 1494, 'KTYRGTATWTTT', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1833, 1494, 'promoter motif 6', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1834, 1495, 'directional motif v3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1835, 1495, 'DMv3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1836, 1495, 'DMv3 motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1837, 1495, 'KNNCAKCNCTRNY', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1838, 1495, 'promoter motif 7', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1839, 1496, 'directional motif v2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1840, 1496, 'DMv2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1841, 1496, 'DMv2 motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1842, 1496, 'MKSYGGCARCGSYSS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1843, 1496, 'promoter motif 8', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1844, 1497, 'CSARCSSAACGS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1845, 1497, 'motif ten element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1846, 1497, 'motif_ten_element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1847, 1498, 'directional motif p3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1848, 1498, 'directional promoter motif 3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1849, 1498, 'DMp3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1850, 1498, 'INR1 motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1851, 1499, 'directional motif 5', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1852, 1499, 'directional promoter motif 5', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1853, 1499, 'DMp5', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1854, 1499, 'DPE1 motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1855, 1500, 'directional promoter motif v1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1856, 1500, 'DMv1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1857, 1500, 'DMv1 motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1858, 1501, 'GAGA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1859, 1501, 'GAGA motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1860, 1501, 'NDM1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1861, 1502, 'NDM2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1862, 1502, 'NDM2 motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1863, 1502, 'non directional promoter motif 2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1864, 1503, 'NDM3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1865, 1503, 'NDM3 motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1866, 1503, 'non directional motif 3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1867, 1504, 'double stranded RNA virus sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1868, 1504, 'ds RNA viral sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1869, 1505, 'maverick element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1870, 1506, '21S LSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1871, 1506, '21S ribosomal RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1872, 1506, '21S rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1873, 1506, 'rRNA 21S', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1874, 1507, 'tRNA region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1875, 1508, 'anti-codon loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1876, 1508, 'anticodon loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1877, 1509, 'anti-codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1878, 1510, 'CCA sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1879, 1510, 'CCA tail', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1880, 1511, 'D loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1881, 1511, 'DHU loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1882, 1512, 'T loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1883, 1512, 'TpsiC loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1884, 1162, 'pyrrolysine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1885, 1513, 'small nucleolar RNA U3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1886, 1513, 'snoRNA U3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1887, 1513, 'U3 small nucleolar RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1888, 1513, 'U3 snoRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1889, 1514, 'ARE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1890, 1514, 'AU rich element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1891, 1514, 'AU-rich element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1892, 1515, 'BRE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1893, 1515, 'Bruno response element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1894, 1516, 'IRE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1895, 1516, 'iron responsive element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1896, 310, 'morpholino backbone', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1897, 1350, 'peptide nucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1898, 1517, 'pseudouridylation guide snoRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1899, 1519, 'LNA oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1900, 1519, 'locked nucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1901, 1521, 'threose nucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1902, 1521, 'TNA oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1903, 1523, 'glycerol nucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1904, 1523, 'glycol nucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1905, 1523, 'GNA oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1906, 1524, 'R GNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1907, 1525, '(R)-glycerol nucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1908, 1525, '(R)-glycol nucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1909, 1525, 'R GNA oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1910, 1526, 'S GNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1911, 1527, '(S)-glycerol nucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1912, 1527, '(S)-glycol nucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1913, 1527, 'S GNA oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1914, 1528, 'double stranded DNA virus', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1915, 1528, 'ds DNA viral sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1916, 1529, 'single strand RNA virus', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1917, 1529, 'ss RNA viral sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1918, 1530, 'negative sense single stranded RNA virus', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1919, 1530, 'negative sense ssRNA viral sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1920, 1531, 'positive sense single stranded RNA virus', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1921, 1531, 'positive sense ssRNA viral sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1922, 1532, 'ambisense single stranded RNA virus', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1923, 1532, 'ambisense ssRNA viral sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1924, 1533, 'RNA polymerase promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1925, 1534, 'Phage RNA Polymerase Promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1926, 1536, 'SP6 RNA Polymerase Promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1927, 1537, 'T3 RNA Polymerase Promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1928, 1538, 'T7 RNA Polymerase Promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1929, 1539, '5'' EST', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1930, 1539, 'five prime EST', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1931, 1540, '3'' EST', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1932, 1540, 'three prime EST', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1933, 1541, 'INSDC_qualifier:ribosomal_slippage', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1934, 1541, 'ribosomal frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1935, 1541, 'ribosomal slippage', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1936, 1541, 'translational frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1937, 1542, 'plus 1 ribosomal frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1938, 1542, 'plus 1 translational frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1939, 1543, 'plus 2 ribosomal frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1940, 1543, 'plus 2 translational frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1941, 1544, 'group III intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1942, 889, 'noncoding region of exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1943, 543, 'coding region of exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1944, 1545, 'endonuclease spliced intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1945, 851, 'protein coding gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1946, 1546, 'transgenic insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1947, 1548, 'silenced by RNA interference', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1948, 1549, 'silenced by histone modification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1949, 1550, 'silenced by histone methylation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1950, 1551, 'silenced by histone deacetylation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1951, 1552, 'gene silenced by RNA interference', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1952, 1552, 'RNA interference silenced gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1953, 1552, 'RNAi silenced gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1954, 1553, 'gene silenced by histone modification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1955, 1554, 'gene silenced by histone methylation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1956, 1555, 'gene silenced by histone deacetylation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1957, 1556, ' D', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1958, 1558, ' Y', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1959, 1559, 'I', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1960, 1559, 'RNAMOD:017', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1961, 1560, '7-methylguanine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1962, 1560, 'seven methylguanine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1963, 1439, 'amino acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1964, 1564, 'major transcription start site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1965, 1564, 'major TSS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1966, 1565, 'minor TSS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1967, 1566, 'TSS region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1968, 1567, 'encodes alternate transcription start sites', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1969, 1568, 'miRNA primary transcript region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1970, 631, 'pre-miRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1971, 1569, 'miRNA stem', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1972, 1570, 'miRNA loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1973, 309, 'synthetic oligo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1974, 1571, 'fragment assembly', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1975, 1571, 'physical map', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1976, 1572, 'BACmap', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1977, 1572, 'fingerprint map', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1978, 1572, 'FPC', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1979, 1572, 'FPCmap', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1980, 1572, 'restriction map', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1981, 1573, 'STS map', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1982, 1574, 'radiation hybrid map', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1983, 1574, 'RH map', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1984, 1575, 'sonicate fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1985, 1579, 'homing endonuclease binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1986, 1580, 'octamer motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1987, 1581, 'apicoplast chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1988, 1367, 'sequence collection', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1989, 1582, 'overlapping feature set', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1990, 1583, 'overlapping EST set', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1991, 1584, 'ncRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1992, 1584, 'non-coding RNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1993, 1585, 'gRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1994, 1586, 'miRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1995, 1586, 'stRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1996, 1586, 'stRNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1997, 1588, 'scRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1998, 1589, 'snoRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (1999, 1590, 'small nuclear RNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2000, 1590, 'snRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2001, 1591, 'SRP RNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2002, 1592, 'tmRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2003, 1593, 'tRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2004, 1594, 'modified adenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2005, 1563, 'modified inosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2006, 1595, 'modified cytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2007, 1596, 'modified guanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2008, 1557, 'modified uridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2009, 1597, '1-methylinosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2010, 1597, 'm1I', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2011, 1597, 'one methylinosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2012, 1598, '1,2''-O-dimethylinosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2013, 1598, 'm''Im', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2014, 1598, 'one two prime O dimethylinosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2015, 1599, '2''-O-methylinosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2016, 1599, 'Im', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2017, 1599, 'two prime O methylinosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2018, 1600, '3-methylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2019, 1600, 'm3C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2020, 1600, 'three methylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2021, 1601, '5-methylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2022, 1601, 'five methylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2023, 1601, 'm5C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2024, 1602, '2''-O-methylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2025, 1602, 'Cm', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2026, 1602, 'two prime O methylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2027, 1603, '2-thiocytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2028, 1603, 's2C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2029, 1603, 'two thiocytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2030, 1604, 'ac4C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2031, 1604, 'N4 acetylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2032, 1604, 'N4-acetylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2033, 1605, '5-formylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2034, 1605, 'f5C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2035, 1605, 'five formylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2036, 1606, '5,2''-O-dimethylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2037, 1606, 'five two prime O dimethylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2038, 1606, 'm5Cm', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2039, 1607, 'ac4Cm', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2040, 1607, 'N4 acetyl 2 prime O methylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2041, 1607, 'N4-acetyl-2''-O-methylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2042, 1608, 'k2C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2043, 1609, 'm4C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2044, 1609, 'N4 methylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2045, 1609, 'N4-methylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2046, 1610, 'm4Cm', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2047, 1610, 'N4 2 prime O dimethylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2048, 1610, 'N4,2''-O-dimethylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2049, 1611, '5-hydroxymethylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2050, 1611, 'five hydroxymethylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2051, 1611, 'hm5C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2052, 1612, '5-formyl-2''-O-methylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2053, 1612, 'f5Cm', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2054, 1612, 'five formyl two prime O methylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2055, 1613, 'm42Cm', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2056, 1613, 'N4,N4,2''-O-trimethylcytidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2057, 1614, '1-methyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2058, 1614, 'm1A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2059, 1614, 'one methyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2060, 1615, '2-methyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2061, 1615, 'm2A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2062, 1615, 'two methyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2063, 1616, 'm6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2064, 1616, 'N6 methyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2065, 1616, 'N6-methyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2066, 1617, '2''-O-methyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2067, 1617, 'Am', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2068, 1617, 'two prime O methyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2069, 1618, '2-methylthio-N6-methyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2070, 1618, 'ms2m6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2071, 1618, 'two methylthio N6 methyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2072, 1619, 'i6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2073, 1619, 'N6 isopentenyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2074, 1619, 'N6-isopentenyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2075, 1620, '2-methylthio-N6-isopentenyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2076, 1620, 'ms2i6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2077, 1620, 'two methylthio N6 isopentenyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2078, 1621, 'io6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2079, 1621, 'N6 cis hydroxyisopentenyl adenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2080, 1621, 'N6-(cis-hydroxyisopentenyl)adenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2081, 1622, '2-methylthio-N6-(cis-hydroxyisopentenyl) adenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2082, 1622, 'ms2io6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2083, 1622, 'two methylthio N6 cis hydroxyisopentenyl adenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2084, 1623, 'g6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2085, 1623, 'N6 glycinylcarbamoyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2086, 1623, 'N6-glycinylcarbamoyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2087, 1624, 'N6 threonylcarbamoyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2088, 1624, 'N6-threonylcarbamoyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2089, 1624, 't6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2090, 1625, '2-methylthio-N6-threonyl carbamoyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2091, 1625, 'ms2t6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2092, 1625, 'two methylthio N6 threonyl carbamoyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2093, 1626, 'm6t6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2094, 1626, 'N6 methyl N6 threonylcarbamoyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2095, 1626, 'N6-methyl-N6-threonylcarbamoyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2096, 1627, 'hn6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2097, 1627, 'N6 hydroxynorvalylcarbamoyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2098, 1627, 'N6-hydroxynorvalylcarbamoyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2099, 1628, '2-methylthio-N6-hydroxynorvalyl carbamoyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2100, 1628, 'ms2hn6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2101, 1628, 'two methylthio N6 hydroxynorvalyl carbamoyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2102, 1629, '2''-O-ribosyladenosine (phosphate)', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2103, 1629, 'Ar(p)', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2104, 1629, 'two prime O ribosyladenosine phosphate', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2105, 1630, 'm62A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2106, 1630, 'N6,N6-dimethyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2107, 1631, 'm6Am', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2108, 1631, 'N6 2 prime O dimethyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2109, 1631, 'N6,2''-O-dimethyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2110, 1632, 'm62Am', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2111, 1632, 'N6,N6,2''-O-trimethyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2112, 1633, '1,2''-O-dimethyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2113, 1633, 'm1Am', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2114, 1633, 'one two prime O dimethyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2115, 1634, 'ac6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2116, 1634, 'N6 acetyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2117, 1634, 'N6-acetyladenosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2118, 1635, '7-deazaguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2119, 1635, 'seven deazaguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2120, 1636, ' Q', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2121, 1637, 'eQ', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2122, 1638, 'galactosyl queuosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2123, 1638, 'galactosyl-queuosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2124, 1638, 'galQ', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2125, 1639, 'mannosyl queuosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2126, 1639, 'mannosyl-queuosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2127, 1639, 'manQ', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2128, 1640, '7-cyano-7-deazaguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2129, 1640, 'preQ0', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2130, 1640, 'seven cyano seven deazaguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2131, 1641, '7-aminomethyl-7-deazaguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2132, 1641, 'preQ1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2133, 1641, 'seven aminomethyl seven deazaguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2134, 1642, 'G+', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2135, 1643, '1-methylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2136, 1643, 'm1G', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2137, 1643, 'one methylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2138, 1644, 'm2G', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2139, 1644, 'N2 methylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2140, 1644, 'N2-methylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2141, 1645, '7-methylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2142, 1645, 'm7G', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2143, 1645, 'seven methylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2144, 1646, '2''-O-methylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2145, 1646, 'Gm', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2146, 1646, 'two prime O methylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2147, 1647, 'm22G', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2148, 1647, 'N2,N2-dimethylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2149, 1648, 'm2Gm', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2150, 1648, 'N2 2 prime O dimethylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2151, 1648, 'N2,2''-O-dimethylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2152, 1649, 'm22Gmv', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2153, 1649, 'N2,N2,2''-O-trimethylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2154, 1650, '2''-O-ribosylguanosine (phosphate)', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2155, 1650, 'Gr(p)', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2156, 1650, 'two prime O ribosylguanosine phosphate', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2157, 1651, 'yW', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2158, 1652, 'o2yW', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2159, 1653, 'OHyW', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2160, 1654, 'OHyW*', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2161, 1654, 'undermodified hydroxywybutosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2162, 1655, 'IMG', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2163, 1656, 'mimG', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2164, 1657, 'm2,7G', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2165, 1657, 'N2 7 dimethylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2166, 1657, 'N2,7-dimethylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2167, 1658, 'm2,2,7G', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2168, 1658, 'N2,N2,7-trimethylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2169, 1659, '1,2''-O-dimethylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2170, 1659, 'm1Gm', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2171, 1659, 'one two prime O dimethylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2172, 1660, '4-demethylwyosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2173, 1660, 'four demethylwyosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2174, 1660, 'imG-14', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2175, 1661, 'imG2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2176, 1662, 'm2,7Gm', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2177, 1662, 'N2 7 2prirme O trimethylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2178, 1662, 'N2,7,2''-O-trimethylguanosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2179, 1663, '5-methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2180, 1663, 'five methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2181, 1663, 'm5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2182, 1664, '2''-O-methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2183, 1664, 'two prime O methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2184, 1664, 'Um', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2185, 1665, '5,2''-O-dimethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2186, 1665, 'five two prime O dimethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2187, 1665, 'm5Um', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2188, 1666, '1-methylpseudouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2189, 1666, 'm1Y', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2190, 1666, 'one methylpseudouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2191, 1667, '2''-O-methylpseudouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2192, 1667, 'two prime O methylpseudouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2193, 1667, 'Ym', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2194, 1668, '2-thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2195, 1668, 's2U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2196, 1668, 'two thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2197, 1669, '4-thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2198, 1669, 'four thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2199, 1669, 's4U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2200, 1670, '5-methyl-2-thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2201, 1670, 'five methyl 2 thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2202, 1670, 'm5s2U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2203, 1671, '2-thio-2''-O-methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2204, 1671, 's2Um', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2205, 1671, 'two thio two prime O methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2206, 1672, '3-(3-amino-3-carboxypropyl)uridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2207, 1672, 'acp3U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2208, 1673, '5-hydroxyuridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2209, 1673, 'five hydroxyuridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2210, 1673, 'ho5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2211, 1674, '5-methoxyuridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2212, 1674, 'five methoxyuridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2213, 1674, 'mo5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2214, 1675, 'cmo5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2215, 1675, 'uridine 5-oxyacetic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2216, 1675, 'uridine five oxyacetic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2217, 1676, 'mcmo5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2218, 1676, 'uridine 5-oxyacetic acid methyl ester', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2219, 1676, 'uridine five oxyacetic acid methyl ester', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2220, 1677, '5-(carboxyhydroxymethyl)uridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2221, 1677, 'chm5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2222, 1677, 'five carboxyhydroxymethyl uridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2223, 1678, '5-(carboxyhydroxymethyl)uridine methyl ester', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2224, 1678, 'five carboxyhydroxymethyl uridine methyl ester', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2225, 1678, 'mchm5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2226, 1679, '5-methoxycarbonylmethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2227, 1679, 'five methoxycarbonylmethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2228, 1679, 'mcm5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2229, 1680, '5-methoxycarbonylmethyl-2''-O-methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2230, 1680, 'five methoxycarbonylmethyl two prime O methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2231, 1680, 'mcm5Um', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2232, 1681, '5-methoxycarbonylmethyl-2-thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2233, 1681, 'five methoxycarbonylmethyl two thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2234, 1681, 'mcm5s2U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2235, 1682, '5-aminomethyl-2-thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2236, 1682, 'five aminomethyl two thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2237, 1682, 'nm5s2U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2238, 1683, '5-methylaminomethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2239, 1683, 'five methylaminomethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2240, 1683, 'mnm5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2241, 1684, '5-methylaminomethyl-2-thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2242, 1684, 'five methylaminomethyl two thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2243, 1684, 'mnm5s2U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2244, 1685, '5-methylaminomethyl-2-selenouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2245, 1685, 'five methylaminomethyl two selenouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2246, 1685, 'mnm5se2U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2247, 1686, '5-carbamoylmethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2248, 1686, 'five carbamoylmethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2249, 1686, 'ncm5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2250, 1687, '5-carbamoylmethyl-2''-O-methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2251, 1687, 'five carbamoylmethyl two prime O methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2252, 1687, 'ncm5Um', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2253, 1688, '5-carboxymethylaminomethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2254, 1688, 'cmnm5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2255, 1688, 'five carboxymethylaminomethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2256, 1689, '5-carboxymethylaminomethyl- 2''-O-methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2257, 1689, 'cmnm5Um', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2258, 1689, 'five carboxymethylaminomethyl two prime O methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2259, 1690, '5-carboxymethylaminomethyl-2-thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2260, 1690, 'cmnm5s2U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2261, 1690, 'five carboxymethylaminomethyl two thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2262, 1691, '3-methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2263, 1691, 'm3U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2264, 1691, 'three methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2265, 1692, '1-methyl-3-(3-amino-3-carboxypropyl) pseudouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2266, 1692, 'm1acp3Y', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2267, 1693, '5-carboxymethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2268, 1693, 'cm5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2269, 1693, 'five carboxymethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2270, 1694, '3,2''-O-dimethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2271, 1694, 'm3Um', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2272, 1694, 'three two prime O dimethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2273, 1695, '5-methyldihydrouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2274, 1695, 'five methyldihydrouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2275, 1695, 'm5D', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2276, 1696, '3-methylpseudouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2277, 1696, 'm3Y', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2278, 1696, 'three methylpseudouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2279, 1697, '5-taurinomethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2280, 1697, 'five taurinomethyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2281, 1697, 'tm5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2282, 1698, '5-taurinomethyl-2-thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2283, 1698, 'five taurinomethyl two thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2284, 1698, 'tm5s2U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2285, 1699, '5-(isopentenylaminomethyl)uridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2286, 1699, 'five isopentenylaminomethyl uridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2287, 1699, 'inm5U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2288, 1700, '5-(isopentenylaminomethyl)- 2-thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2289, 1700, 'five isopentenylaminomethyl two thiouridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2290, 1700, 'inm5s2U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2291, 1701, '5-(isopentenylaminomethyl)- 2''-O-methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2292, 1701, 'five isopentenylaminomethyl two prime O methyluridine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2293, 1701, 'inm5Um', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2294, 1702, 'histone binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2295, 1703, 'CDS fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2296, 1703, 'incomplete CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2297, 1704, 'modified amino acid feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2298, 1705, 'ModGly', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2299, 1705, 'modified glycine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2300, 1706, 'ModAla', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2301, 1706, 'modified L alanine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2302, 1706, 'modified L-alanine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2303, 1707, 'ModAsn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2304, 1707, 'modified L asparagine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2305, 1707, 'modified L-asparagine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2306, 1708, 'ModAsp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2307, 1708, 'modified L aspartic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2308, 1708, 'modified L-aspartic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2309, 1709, 'ModCys', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2310, 1709, 'modified L cysteine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2311, 1709, 'modified L-cysteine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2312, 1710, 'ModGlu', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2313, 1710, 'modified L glutamic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2314, 1710, 'modified L-glutamic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2315, 1711, 'modified L threonine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2316, 1711, 'modified L-threonine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2317, 1711, 'ModThr', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2318, 1712, 'modified L tryptophan', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2319, 1712, 'modified L-tryptophan', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2320, 1712, 'ModTrp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2321, 1713, 'ModGln', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2322, 1713, 'modified L glutamine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2323, 1713, 'modified L-glutamine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2324, 1714, 'modified L methionine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2325, 1714, 'modified L-methionine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2326, 1714, 'ModMet', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2327, 1715, 'modified L isoleucine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2328, 1715, 'modified L-isoleucine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2329, 1715, 'ModIle', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2330, 1716, 'modified L phenylalanine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2331, 1716, 'modified L-phenylalanine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2332, 1716, 'ModPhe', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2333, 1717, 'ModHis', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2334, 1717, 'modified L histidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2335, 1717, 'modified L-histidine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2336, 1718, 'modified L serine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2337, 1718, 'modified L-serine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2338, 1718, 'MosSer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2339, 1719, 'modified L lysine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2340, 1719, 'modified L-lysine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2341, 1719, 'ModLys', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2342, 1720, 'modified L leucine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2343, 1720, 'modified L-leucine ', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2344, 1720, 'ModLeu', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2345, 1721, 'modified L selenocysteine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2346, 1721, 'modified L-selenocysteine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2347, 1722, 'modified L valine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2348, 1722, 'modified L-valine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2349, 1722, 'ModVal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2350, 1723, 'modified L proline', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2351, 1723, 'modified L-proline ', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2352, 1723, 'ModPro', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2353, 1724, 'modified L tyrosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2354, 1724, 'modified L-tyrosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2355, 1724, 'ModTry', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2356, 1725, 'ModArg', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2357, 1725, 'modified L arginine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2358, 1725, 'modified L-arginine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2359, 1727, 'cleaved for gpi anchor region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2360, 1107, 'biomaterial region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2361, 319, 'analysis feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2362, 319, 'experimental output artefact', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2363, 319, 'experimental_output_artefact', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2364, 262, 'biological region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2365, 262, 'INSDC_misc_feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2366, 262, 'INSDC_note:biological_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2367, 588, 'topologically defined region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2368, 1728, 'translocation breakpoint', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2369, 1729, 'insertion breakpoint', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2370, 1730, 'deletion breakpoint', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2371, 1731, '5'' flanking region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2372, 1731, 'five prime flanking region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2373, 1732, '3'' flanking region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2374, 1732, 'three prime flanking region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2375, 1733, 'transcribed fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2376, 1733, 'transfrag', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2377, 503, 'cis splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2378, 1116, 'trans splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2379, 1734, 'splice boundary', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2380, 1734, 'splice junction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2381, 1735, 'polypeptide conformational switch', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2382, 1736, 'dye terminator read', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2383, 1737, 'pyorsequenced read', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2384, 1738, 'ligation based read', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2385, 1739, 'polymerase synthesis read', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2386, 1740, 'cis regulatory frameshift element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2387, 1741, 'expressed sequence assembly', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2388, 1742, 'DNA binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2389, 1743, 'cryptic gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2390, 1744, 'mutation affecting polyadenylation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2391, 1744, 'sequence variant affecting polyadenylation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2392, 1745, '3'' RACE clone', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2393, 1746, 'cassette pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2394, 1746, 'cassette type psedogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2395, 1747, 'A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2396, 1747, 'Ala', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2397, 1748, 'V', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2398, 1748, 'Val', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2399, 1749, 'L', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2400, 1749, 'Leu', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2401, 1750, 'I', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2402, 1750, 'Ile', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2403, 1751, 'P', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2404, 1751, 'Pro', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2405, 1752, 'Trp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2406, 1752, 'W', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2407, 1753, 'F', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2408, 1753, 'Phe', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2409, 1754, 'M', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2410, 1754, 'Met', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2411, 1755, 'G', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2412, 1755, 'Gly', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2413, 1756, 'S', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2414, 1756, 'Ser', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2415, 1757, 'T', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2416, 1757, 'Thr', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2417, 1758, 'Tyr', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2418, 1758, 'Y', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2419, 1759, 'C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2420, 1759, 'Cys', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2421, 1760, 'Gln', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2422, 1760, 'Q', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2423, 1761, 'Asn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2424, 1761, 'N', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2425, 1762, 'K', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2426, 1762, 'Lys', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2427, 1763, 'Arg', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2428, 1763, 'R', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2429, 1764, 'H', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2430, 1764, 'His', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2431, 1765, 'Asp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2432, 1765, 'aspartic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2433, 1765, 'D', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2434, 1766, 'E', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2435, 1766, 'Glu', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2436, 1766, 'glutamic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2437, 1767, 'Sec', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2438, 1767, 'U', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2439, 1768, 'O', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2440, 1768, 'Pyl', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2441, 1769, 'transcribed cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2442, 1769, 'unigene cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2443, 1770, 'unigene cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2444, 1771, 'Clustered_Regularly_Interspaced_Short_Palindromic_Repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2445, 1771, 'CRISPR element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2446, 1772, 'insulator binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2447, 1773, 'enhancer binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2448, 1774, 'contig collection', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2449, 1775, 'large intervening non-coding RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2450, 1775, 'long intergenic non-coding RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2451, 1775, 'long intervening non-coding RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2452, 1777, 'UTR sequence tag', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2453, 1778, '3'' UST', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2454, 1779, '5'' UST', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2455, 1780, 'RACE sequence tag', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2456, 1781, '3'' RST', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2457, 1782, '5'' RST', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2458, 1783, 'UST match', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2459, 1784, 'RST match', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2460, 1785, 'primer match', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2461, 1786, 'miRNA antiguide ', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2462, 1786, 'miRNA passenger strand', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2463, 1786, 'miRNA star', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2464, 1787, 'trans-splice junction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2465, 1789, 'natural plasmid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2466, 1790, 'gene trap construct', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2467, 1791, 'promoter trap construct', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2468, 1792, 'enhancer trap construct', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2469, 1793, 'PAC end', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2470, 1794, 'Random Amplification Polymorphic DNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2471, 1795, 'shadow enhancer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2472, 1106, 'single nucleotide variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2473, 1797, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2474, 1797, 'INSDC_qualifier:x_element_combinatorial_repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2475, 1797, 'X element combinatorial repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2476, 1798, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2477, 1798, 'INSDC_qualifier:Y_prime_element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2478, 1798, 'Y prime element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2479, 1798, 'Y'' element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2480, 1799, 'standard draft', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2481, 1801, 'high quality draft', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2482, 1802, 'improved high quality draft', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2483, 1803, 'annotation directed improvement', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2484, 1804, 'non contiguous finished', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2485, 1805, 'finished', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2486, 1805, 'finished genome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2487, 1806, 'intronic regulatory region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2488, 1807, 'CDEI', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2489, 1807, 'Centromere DNA Element I', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2490, 1809, 'CDEII', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2491, 1809, 'centromere DNA Element II', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2492, 1810, 'CDEIII', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2493, 1810, 'centromere DNA Element III', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2494, 1811, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2495, 1811, 'INSDC_qualifier:telomeric_repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2496, 1811, 'telomeric repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2497, 1812, 'X element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2498, 1812, 'X element core sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2499, 1813, 'YAC end', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2500, 1800, 'whole genome sequence status', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2501, 168, 'heritable phenotypic marker', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2502, 168, 'phenotypic marker', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2503, 1814, 'peptide collection', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2504, 1814, 'peptide set', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2505, 1815, 'high identity region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2506, 1816, 'processed transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2507, 1195, 'assortment derived variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2508, 1817, 'reference genome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2509, 1818, 'variant genome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2510, 590, 'variant collection', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2511, 1819, 'alteration attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2512, 1820, 'chromosomal variation attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2513, 1823, 'insertion attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2514, 1829, 'inversion attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2515, 1832, 'translocation attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2516, 1828, 'duplication attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2517, 591, 'chromosomally aberrant genome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2518, 1835, 'assembly error correction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2519, 1836, 'base call error correction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2520, 809, 'localization signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2521, 809, 'peptide localization signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2522, 1837, 'NLS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2523, 1838, 'endosomal localization signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2524, 1839, 'lysosomal localization signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2525, 1840, 'NES', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2526, 1840, 'nuclear export signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2527, 1841, 'recombination signal sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2528, 1842, 'cryptic splice signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2529, 1842, 'cryptic splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2530, 1843, 'nuclear rim localization signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2531, 1844, 'DTP transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2532, 1844, 'P element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2533, 1844, 'P TIR transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2534, 1844, 'P transposable element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2535, 1844, 'P-element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2536, 1845, 'functional effect variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2537, 1845, 'functional variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2538, 1846, 'Jannovar:structural_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2539, 1846, 'structural variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2540, 1846, 'VAT:svOverlap', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2541, 1847, 'transcript function variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2542, 1849, 'translational product variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2543, 1850, 'level of transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2544, 1851, 'decreased transcript level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2545, 1852, 'increased transcript level variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2546, 1853, 'transcript processing variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2547, 1854, 'editing variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2548, 1855, 'polyadenylation variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2549, 1856, 'transcript stability variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2550, 1857, 'decrease transcript stability variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2551, 1858, 'increased transcript stability variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2552, 1859, 'transcription variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2553, 1860, 'rate of transcription variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2554, 1861, 'increased transcription rate variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2555, 1862, 'decreased transcription rate variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2556, 1863, 'translational product level variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2557, 1864, 'polypeptide function variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2558, 1865, 'decrease translational product level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2559, 1866, 'increase translational product level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2560, 1867, 'polypeptide gain of function variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2561, 1868, 'polypeptide localization variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2562, 1869, 'polypeptide loss of function variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2563, 1870, 'inactive ligand binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2564, 1871, 'polypeptide partial loss of function', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2565, 1872, 'polypeptide post translational processing variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2566, 1873, 'copy number change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2567, 1875, 'gene structure variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2568, 1875, 'Jannovar:gene_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2569, 1875, 'snpEff:GENE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2570, 1875, 'VAAST:gene_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2571, 1876, 'gene fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2572, 1878, 'Jannovar:regulatory_region_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2573, 1878, 'regulatory region variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2574, 1878, 'regulatory_region_', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2575, 1878, 'snpEff:REGULATION', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2576, 1878, 'VEP:regulatory_region_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2577, 1879, 'Jannovar:stop_retained_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2578, 1879, 'snpEff:NON_SYNONYMOUS_STOP', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2579, 1879, 'snpEff:SYNONYMOUS_STOP', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2580, 1879, 'stop retained variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2581, 1879, 'VAAST:stop_retained', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2582, 1879, 'VAAST:stop_retained_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2583, 1879, 'VEP:stop_retained_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2584, 1882, 'Jannovar:splicing_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2585, 1882, 'splicing variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2586, 1884, 'cryptic splice site activation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2587, 1885, 'cryptic splice acceptor', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2588, 1886, 'cryptic splice donor', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2589, 1887, 'exon loss', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2590, 1887, 'Jannovar:exon_loss_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2591, 1887, 'snpEff:EXON_DELETED', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2592, 1888, 'intron gain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2593, 1888, 'intron gain variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2594, 1889, 'Jannovar:splice_acceptor_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2595, 1889, 'Seattleseq:splice-acceptor', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2596, 1889, 'snpEff:SPLICE_SITE_ACCEPTOR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2597, 1889, 'splice acceptor variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2598, 1889, 'VAAST:splice_acceptor_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2599, 1889, 'VEP:splice_acceptor_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2600, 1891, 'Jannovar:splice_donor_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2601, 1891, 'Seattleseq:splice-donor', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2602, 1891, 'snpEff:SPLICE_SITE_DONOR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2603, 1891, 'splice donor variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2604, 1891, 'VAAST:splice_donor_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2605, 1891, 'VEP:splice_donor_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2606, 1883, 'Jannovar:transcript_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2607, 1883, 'snpEff:TRANSCRIPT', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2608, 1883, 'transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2609, 1883, 'VAAST:transcript_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2610, 1892, 'complex change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2611, 1892, 'complex transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2612, 1892, 'complex_indel', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2613, 1892, 'Seattleseq:codingComplex', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2614, 1892, 'Seattleseq:codingComplex-near-splice', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2615, 1893, 'ANNOVAR:stoploss', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2616, 1893, 'Jannovar:stop_lost', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2617, 1893, 'Seattleseq:stop-lost', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2618, 1893, 'Seattleseq:stop-lost-near-splice', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2619, 1893, 'snpEff:STOP_LOST', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2620, 1893, 'stop codon lost', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2621, 1893, 'stop lost', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2622, 1893, 'VAAST:stop_lost', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2623, 1893, 'VAT:removedStop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2624, 1893, 'VEP:stop_lost', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2625, 1896, 'transcript sequence variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2626, 1897, 'coding sequence variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2627, 1897, 'coding variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2628, 1897, 'codon variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2629, 1897, 'codon_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2630, 1897, 'Jannovar:coding_sequence_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2631, 1897, 'Seattleseq:coding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2632, 1897, 'snpEff:CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2633, 1897, 'snpEff:CODON_CHANGE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2634, 1897, 'VAAST:coding_sequence_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2635, 1897, 'VEP:coding_sequence_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2636, 1900, 'initiatior codon variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2637, 1900, 'initiator codon change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2638, 1900, 'Jannovar:initiator_codon_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2639, 1900, 'snpEff:NON_SYNONYMOUS_START', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2640, 1900, 'VAT:startOverlap', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2641, 1901, 'ANNOVAR:nonsynonymous SNV', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2642, 1901, 'Jannovar:missense_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2643, 1901, 'missense', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2644, 1901, 'missense codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2645, 1901, 'Seattleseq:missense', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2646, 1901, 'Seattleseq:missense-near-splice', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2647, 1901, 'snpEff:NON_SYNONYMOUS_CODING', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2648, 1901, 'VAAST:missense_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2649, 1901, 'VAAST:non_synonymous_codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2650, 1901, 'VAT:nonsynonymous', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2651, 1901, 'VEP:missense_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2652, 1902, 'conservative missense codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2653, 1902, 'conservative missense variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2654, 1902, 'neutral missense codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2655, 1902, 'quiet missense codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2656, 1903, 'non conservative missense codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2657, 1903, 'non conservative missense variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2658, 1904, 'ANNOVAR:stopgain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2659, 1904, 'Jannovar:stop_gained', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2660, 1904, 'nonsense', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2661, 1904, 'nonsense codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2662, 1904, 'Seattleseq:stop-gained', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2663, 1904, 'Seattleseq:stop-gained-near-splice', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2664, 1904, 'snpEff:STOP_GAINED', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2665, 1904, 'stop codon gained', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2666, 1904, 'stop gained', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2667, 1904, 'VAAST:stop_gained', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2668, 1904, 'VAT:prematureStop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2669, 1904, 'VEP:stop_gained', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2670, 1906, 'ANNOVAR:frameshift block substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2671, 1906, 'ANNOVAR:frameshift substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2672, 1906, 'frameshift variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2673, 1906, 'frameshift_', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2674, 1906, 'frameshift_coding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2675, 1906, 'Jannovar:frameshift_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2676, 1906, 'Seattleseq:frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2677, 1906, 'Seattleseq:frameshift-near-splice', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2678, 1906, 'snpEff:FRAME_SHIFT', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2679, 1906, 'VAAST:frameshift_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2680, 1906, 'VAT:deletionFS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2681, 1906, 'VAT:insertionFS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2682, 1906, 'VEP:frameshift_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2683, 1880, 'terminal codon variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2684, 1880, 'terminal_codon_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2685, 1880, 'terminator codon variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2686, 1880, 'VAT:endOverlap', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2687, 1908, 'frame restoring variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2688, 1909, '-1 frameshift variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2689, 1909, 'minus 1 frameshift variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2690, 1910, '-2 frameshift variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2691, 1910, 'minus 2 frameshift variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2692, 1911, '+1 frameshift variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2693, 1911, 'plus 1 frameshift variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2694, 1912, '+2 frameshift variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2695, 1912, 'plus 2 frameshift variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2696, 1913, 'transcript secondary structure variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2697, 1914, 'compensatory transcript secondary structure variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2698, 1915, 'translational product structure variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2699, 1916, '3D polypeptide structure variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2700, 1917, 'complex 3D structural variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2701, 1918, 'conformational change variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2702, 1919, 'complex change of translational product variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2703, 1920, 'polypeptide sequence variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2704, 1921, 'amino acid deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2705, 1922, 'amino acid insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2706, 1923, 'amino acid substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2707, 1923, 'VAAST:amino_acid_substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2708, 1924, 'conservative amino acid substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2709, 1925, 'non conservative amino acid substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2710, 1926, 'elongated polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2711, 1927, 'elongated polypeptide C terminal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2712, 1929, 'elongated polypeptide N terminal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2713, 1931, 'elongated in frame polypeptide C terminal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2714, 1932, 'elongated polypeptide out of frame C terminal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2715, 1933, 'elongated in frame polypeptide N terminal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2716, 1934, 'elongated out of frame N terminal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2717, 1935, 'polypeptide fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2718, 1936, 'polypeptide truncation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2719, 1937, 'inactive catalytic site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2720, 1938, 'ANNOVAR:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2721, 1938, 'Jannovar:non_coding_transcript_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2722, 1938, 'nc transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2723, 1938, 'non coding transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2724, 1938, 'VEP:non_coding_transcript_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2725, 1938, 'within_non_coding_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2726, 1939, 'mature miRNA variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2727, 1939, 'snpEff:MICRO_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2728, 1939, 'VEP:mature_miRNA_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2729, 1939, 'within_mature_miRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2730, 1940, 'NMD transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2731, 1940, 'NMD_transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2732, 1940, 'Nonsense mediated decay transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2733, 1940, 'VEP:NMD_transcript_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2734, 1941, 'UTR variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2735, 1941, 'UTR_', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2736, 1942, '5''UTR variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2737, 1942, '5PRIME_UTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2738, 1942, 'ANNOVAR:UTR5', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2739, 1942, 'five prime UTR variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2740, 1942, 'Jannovar:5_prime_utr_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2741, 1942, 'Seattleseq:5-prime-UTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2742, 1942, 'snpEff:UTR_5_PRIME', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2743, 1942, 'untranslated-5', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2744, 1942, 'VAAST:5_prime_UTR_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2745, 1942, 'VAAST:five_prime_UTR_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2746, 1942, 'VEP:5_prime_UTR_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2747, 1943, '3''UTR variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2748, 1943, '3PRIME_UTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2749, 1943, 'ANNOVAR:UTR3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2750, 1943, 'Jannovar:3_prime_utr_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2751, 1943, 'Seattleseq:3-prime-UTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2752, 1943, 'snpEff:UTR_3_PRIME', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2753, 1943, 'three prime UTR variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2754, 1943, 'untranslated-3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2755, 1943, 'VAAST:3_prime_UTR_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2756, 1943, 'VAAST:three_prime_UTR_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2757, 1943, 'VEP:3_prime_UTR_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2758, 1944, 'incomplete terminal codon variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2759, 1944, 'partial_codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2760, 1944, 'VEP:incomplete_terminal_codon_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2761, 1946, 'ANNOVAR:intronic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2762, 1946, 'intron variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2763, 1946, 'intron_', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2764, 1946, 'intronic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2765, 1946, 'Jannovar:intron_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2766, 1946, 'Seattleseq:intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2767, 1946, 'Seattleseq:intron-near-splice', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2768, 1946, 'snpEff:INTRON', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2769, 1946, 'VAAST:intron_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2770, 1946, 'VEP:intron_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2771, 1947, 'ANNOVAR:intergenic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2772, 1947, 'intergenic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2773, 1947, 'intergenic variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2774, 1947, 'Jannovar:intergenic_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2775, 1947, 'Seattleseq:intergenic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2776, 1947, 'snpEff:INTERGENIC', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2777, 1947, 'VEP:intergenic_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2778, 1890, 'essential_splice_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2779, 1890, 'splice site variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2780, 1890, 'VAT:spliceOverlap', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2781, 1948, 'ANNOVAR:splicing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2782, 1948, 'Jannovar:splice_region_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2783, 1948, 'snpEff:SPLICE_SITE_BRANCH', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2784, 1948, 'snpEff:SPLICE_SITE_BRANCH_U12', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2785, 1948, 'snpEff:SPLICE_SITE_REGION', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2786, 1948, 'splice region variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2787, 1948, 'VAAST:splice_region_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2788, 1948, 'VEP:splice_region_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2789, 1949, 'ANNOVAR:upstream', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2790, 1949, 'Jannovar:upstream_gene_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2791, 1949, 'snpEff:UPSTREAM', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2792, 1949, 'upstream gene variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2793, 1949, 'VEP:upstream_gene_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2794, 1950, 'ANNOVAR:downstream', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2795, 1950, 'downstream gene variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2796, 1950, 'Jannovar:downstream_gene_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2797, 1950, 'snpEff:DOWNSTREAM', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2798, 1950, 'VEP:downstream_gene_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2799, 1951, '5KB downstream variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2800, 1951, 'downstream', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2801, 1951, 'Seattleseq:downstream-gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2802, 1951, 'within 5KB downstream', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2803, 1952, '500B downstream variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2804, 1952, 'near-gene-3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2805, 1953, '5kb upstream variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2806, 1953, 'Seattleseq:upstream-gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2807, 1953, 'upstream', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2808, 1954, '2KB upstream variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2809, 1954, 'near-gene-5', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2810, 1955, 'rDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2811, 1955, 'rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2812, 1956, 'piRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2813, 1957, 'RNase P RNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2814, 1959, 'RNase MRP RNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2815, 1960, 'lincRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2816, 1962, 'mathematically defined repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2817, 1963, 'Telomerase RNA component', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2818, 1963, 'telomerase RNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2819, 1963, 'TERC', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2820, 1964, 'targeting vector', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2821, 167, 'genetic marker', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2822, 1965, 'DArT marker', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2823, 1966, 'kozak consensus', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2824, 1966, 'kozak consensus sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2825, 1966, 'kozak sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2826, 1390, 'nested transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2827, 1385, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2828, 1385, 'INSDC_qualifier:nested', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2829, 1385, 'nested repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2830, 1945, 'ANNOVAR:nonframeshift block substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2831, 1945, 'ANNOVAR:nonframeshift substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2832, 1945, 'cds-indel', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2833, 1945, 'inframe variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2834, 1945, 'VAAST:inframe_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2835, 1967, 'RARE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2836, 1967, 'retinoic acid responsive element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2837, 347, 'nucleotide to protein binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2838, 1280, 'np_bind', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2839, 1280, 'nucleotide binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2840, 1425, 'metal binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2841, 1442, 'ligand binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2842, 1968, 'nested tandem repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2843, 1968, 'NTR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2844, 516, 'promoter element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2845, 284, 'core eukaryotic promoter element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2846, 284, 'general transcription factor binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2847, 1969, 'RNA polymerase II TATA box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2848, 1970, 'RNA polymerase III TATA box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2849, 1971, 'BREd', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2850, 1971, 'BREd motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2851, 1972, 'downstream core element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2852, 1973, 'DCE SI', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2853, 1974, 'DCE SII', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2854, 1975, 'DCE SIII', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2855, 1976, 'proximal promoter element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2856, 1976, 'specific transcription factor binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2857, 285, 'RNApol II core promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2858, 1978, 'distal promoter element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2859, 519, 'bacterial RNA polymerase promoter sigma 70', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2860, 1979, '<new synonym>', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2861, 1979, 'bacterial RNA polymerase promoter sigma54', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2862, 1980, 'minus 12 signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2863, 1981, 'minus 24 signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2864, 1982, 'A box type 1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2865, 1983, 'A box type 2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2866, 1984, 'IE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2867, 1984, 'intermediate element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2868, 1977, 'regulatory promoter element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2869, 1985, 'transcription regulatory region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2870, 473, 'translation regulatory region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2871, 1986, 'recombination regulatory region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2872, 1987, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2873, 1987, 'INSDC_qualifier:replication_regulatory_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2874, 1987, 'replication regulatory region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2875, 1126, 'sequence motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2876, 1988, 'experimental feature attribute', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2877, 1990, 'quality value', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2878, 1991, 'restriction endonuclease recognition site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2879, 1991, 'restriction enzyme recognition site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2880, 1993, 'restriction enzyme cleavage junction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2881, 1995, '5'' restriction enzyme junction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2882, 1998, '3'' restriction enzyme junction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2883, 1999, 'blunt end restriction enzyme cleavage site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2884, 1997, 'sticky end restriction enzyme cleavage site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2885, 2000, 'blunt end restriction enzyme cleavage site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2886, 1996, 'single strand restriction enzyme cleavage site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2887, 2001, 'single strand overhang', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2888, 2001, 'sticky end', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2889, 2002, 'experimentally defined binding region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2890, 2003, 'ChIP seq region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2891, 2004, 'allele specific primer extension primer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2892, 2004, 'ASPE primer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2893, 2005, 'dCAPS primer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2894, 2005, 'derived cleaved amplified polymorphic primer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2895, 2006, 'histone modification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2896, 2006, 'histone modification site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2897, 2007, 'histone methylation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2898, 2007, 'histone methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2899, 2008, 'histone acetylation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2900, 2008, 'histone acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2901, 2009, 'H3K9 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2902, 2009, 'H3K9ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2903, 2011, 'H3K14 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2904, 2011, 'H3K14ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2905, 2012, 'H3K4 mono-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2906, 2012, 'H3K4me1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2907, 2014, 'H3K4 tri-methylation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2908, 2014, 'H3K4me3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2909, 2015, 'H3K9 tri-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2910, 2015, 'H3K9Me3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2911, 2017, 'H2K27 mono-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2912, 2017, 'H2K27Me1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2913, 2019, 'H3K27 tri-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2914, 2019, 'H3K27Me3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2915, 2020, 'H3K79 mono-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2916, 2020, 'H3K79me1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2917, 2022, 'H3K79 di-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2918, 2022, 'H3K79Me2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2919, 2023, 'H3K79 tri-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2920, 2023, 'H3K79Me3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2921, 2024, 'H4K20 mono-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2922, 2024, 'H4K20Me1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2923, 2025, 'H2BK5 mono-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2924, 2026, 'interferon stimulated response element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2925, 2027, 'histone ubiquitination site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2926, 2028, 'H2BUbiq', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2927, 2029, 'H3K18 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2928, 2029, 'H3K18ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2929, 2030, 'H3K23 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2930, 2030, 'H3K23ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2931, 671, 'epigenetically modified region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2932, 2031, 'H3K27 acylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2933, 2031, 'H3K27Ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2934, 2032, 'H3K36 mono-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2935, 2032, 'H3K36Me1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2936, 2034, 'H3K36 di-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2937, 2034, 'H3K36Me2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2938, 2035, 'H3K36 tri-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2939, 2035, 'H3K36Me3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2940, 2036, 'H3K4 di-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2941, 2036, 'H3K4Me2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2942, 2037, 'H3K27 di-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2943, 2037, 'H3K27Me2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2944, 2038, 'H3K9 mono-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2945, 2038, 'H3K9Me1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2946, 2039, 'H3K9 di-methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2947, 2039, 'H3K9Me2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2948, 2040, 'H4K16 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2949, 2040, 'H4K16ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2950, 2042, 'H4K5 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2951, 2042, 'H4K5ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2952, 2043, 'H4K8 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2953, 2043, 'H4K8ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2954, 2018, 'H3K27 methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2955, 2033, 'H3K36 methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2956, 2013, 'H3K4 methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2957, 2021, 'H3K79 methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2958, 2016, 'H3K9 methylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2959, 2044, 'histone acylation region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2960, 2045, 'H4K acylation region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2961, 2045, 'H4KAc', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2962, 2046, 'gene with non canonical start codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2963, 2047, 'gene with start codon CUG', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2964, 2048, 'pseudogenic gene segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2965, 2050, 'copy number gain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2966, 2050, 'gain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2967, 2051, 'copy number loss', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2968, 2051, 'loss', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2969, 2052, 'uniparental disomy', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2970, 2052, 'UPD', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2971, 2053, 'maternal uniparental disomy', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2972, 2054, 'paternal uniparental disomy', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2973, 2055, 'open chromatin region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2974, 2056, 'SL3 acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2975, 2057, 'SL4 acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2976, 2058, 'SL5 acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2977, 2059, 'SL6 acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2978, 2060, 'SL37 acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2979, 2061, 'SL8 acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2980, 2062, 'SL9 acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2981, 2063, 'SL10 acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2982, 2064, 'SL11 acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2983, 2065, 'SL12 acceptor site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2984, 2066, 'duplicated pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2985, 2067, 'disabled gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2986, 2067, 'INSDC_feature:gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2987, 2067, 'INSDC_qualifier:unitary', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2988, 2067, 'unitary pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2989, 329, 'INSDC_feature:gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2990, 329, 'INSDC_qualifier:unprocessed', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2991, 329, 'non processed pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2992, 329, 'unprocessed pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2993, 329, 'unprocessed_pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2994, 2068, 'variant quality', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2995, 2069, 'variant origin', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2996, 2070, 'variant frequency', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2997, 2071, 'unique variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2998, 2072, 'rare variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (2999, 2073, 'polymorphic variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3000, 2074, 'common variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3001, 2075, 'fixed variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3002, 2076, 'variant phenotype', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3003, 2077, 'benign variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3004, 2078, 'disease associated variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3005, 2079, 'disease causing variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3006, 2080, 'lethal variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3007, 2081, 'quantitative variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3008, 2082, 'maternal variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3009, 2083, 'paternal variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3010, 2084, 'somatic variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3011, 2085, 'germline variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3012, 2086, 'pedigree specific variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3013, 2087, 'population specific variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3014, 2088, 'de novo variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3015, 2089, 'Jannovar:tf_binding_site_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3016, 2089, 'TF binding site variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3017, 2089, 'VEP:TF_binding_site_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3018, 2090, 'complex', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3019, 2090, 'complex chromosomal mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3020, 2090, 'complex_chromosomal_mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3021, 549, 'structural alteration', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3022, 2091, 'LOH', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3023, 2091, 'loss of heterozygosity', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3024, 2092, 'splice donor 5th base variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3025, 2093, 'U-box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3026, 2094, 'mating type region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3027, 273, 'paired end fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3028, 1898, 'ANNOVAR:exonic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3029, 1898, 'exon variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3030, 1898, 'Jannovar:exon_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3031, 1898, 'snpEff:EXON', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3032, 1898, 'VAAST:exon_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3033, 2095, 'ANNOVAR:ncRNA_exonic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3034, 2095, 'Jannovar:non_coding_transcript_exon_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3035, 2095, 'non coding transcript exon variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3036, 2095, 'non_coding_transcript_exon_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3037, 2095, 'Seattleseq:non-coding-exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3038, 2095, 'Seattleseq:non-coding-exon-near-splice', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3039, 2095, 'snpEff:non_coding_exon_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3040, 2095, 'VEP:non_coding_transcript_exon_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3041, 2096, 'clone end', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3042, 1808, 'point centromere', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3043, 2097, 'regional centromere', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3044, 2098, 'regional centromere central core', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3045, 2099, 'centromeric repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3046, 2099, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3047, 2099, 'INSDC_qualifier:centromeric_repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3048, 2100, 'lmr repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3049, 2100, 'lmr1L', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3050, 2100, 'lmr1R', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3051, 2100, 'regional centromere inner repeat region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3052, 2101, 'regional centromere outer repeat region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3053, 2102, 'trans acting small interfering RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3054, 2103, 'tasiRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3055, 2104, 'increased polyadenylation variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3056, 2105, 'decreased polyadenylation variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3057, 2106, 'DDB box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3058, 2106, 'DDB-box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3059, 2107, 'D-box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3060, 2107, 'destruction box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3061, 2109, 'endoplasmic reticulum retention signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3062, 2109, 'ER retention signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3063, 2110, 'KEN box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3064, 2111, 'mitochondrial signal sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3065, 2111, 'mitochondrial targeting signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3066, 2111, 'MTS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3067, 2112, 'signal anchor', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3068, 2112, 'uncleaved signal peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3069, 2113, 'PIP box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3070, 2114, 'phosphorylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3071, 2115, 'transmembrane helix', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3072, 2116, 'vacuolar sorting signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3073, 2117, 'coding variant quality', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3074, 2119, 'non synonymous', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3075, 1907, 'protein altering variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3076, 1907, 'VEP:protein_altering_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3077, 1881, 'ANNOVAR:synonymous SNV', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3078, 1881, 'coding-synon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3079, 1881, 'Jannovar:synonymous_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3080, 1881, 'Seattleseq:synonymous', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3081, 1881, 'Seattleseq:synonymous-near-splice', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3082, 1881, 'silent mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3083, 1881, 'silent substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3084, 1881, 'silent_mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3085, 1881, 'snpEff:SYNONYMOUS_CODING', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3086, 1881, 'synonymous codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3087, 1881, 'synonymous_coding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3088, 1881, 'synonymous_codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3089, 1881, 'VAAST:synonymous_codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3090, 1881, 'VAAST:synonymous_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3091, 1881, 'VAT:synonymous', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3092, 1881, 'VEP:synonymous_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3093, 2121, 'inframe change in CDS length', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3094, 2121, 'inframe indel', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3095, 2122, 'ANNOVAR:nonframeshift insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3096, 2122, 'inframe codon gain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3097, 2122, 'inframe increase in CDS length', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3098, 2122, 'inframe insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3099, 2122, 'inframe_codon_gain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3454, 2319, 'microRNA-offset RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3100, 2122, 'Jannovar:inframe_insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3101, 2122, 'snpEFF:CODON_INSERTION', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3102, 2122, 'VAT:insertionNFS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3103, 2122, 'VEP:inframe_insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3104, 2124, 'ANNOVAR:nonframeshift deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3105, 2124, 'inframe codon loss', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3106, 2124, 'inframe decrease in CDS length', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3107, 2124, 'inframe deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3108, 2124, 'inframe_codon_loss', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3109, 2124, 'Jannovar:inframe_deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3110, 2124, 'snpEff:CODON_DELETION', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3111, 2124, 'VAT:deletionNFS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3112, 2124, 'VEP:inframe_deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3113, 2125, 'conservative increase in CDS length', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3114, 2125, 'conservative inframe insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3115, 2126, 'disruptive increase in CDS length', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3116, 2126, 'disruptive inframe insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3117, 2126, 'Jannovar:disruptive_inframe_insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3118, 2126, 'snpEff:CODON_CHANGE_PLUS_CODON_INSERTION', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3119, 2127, 'conservative decrease in CDS length', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3120, 2127, 'conservative inframe deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3121, 2128, 'disruptive decrease in CDS length', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3122, 2128, 'disruptive inframe deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3123, 2128, 'Jannovar:disruptive_inframe_deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3124, 2128, 'snpEff:CODON_CHANGE_PLUS_CODON_DELETION', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3125, 2129, 'mRNA read', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3126, 2130, 'gDNA read', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3127, 2130, 'gDNA_read', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3128, 2130, 'genomic DNA read', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3129, 2131, 'mRNA contig', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3130, 2132, 'AFLP', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3131, 2132, 'AFLP fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3132, 2132, 'AFLP-PCR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3133, 2132, 'amplified fragment length polymorphism', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3134, 2132, 'amplified fragment length polymorphism PCR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3135, 2133, 'protein hmm match', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3136, 2134, 'immunoglobulin region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3137, 2135, 'INSDC_feature:V_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3138, 2135, 'V region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3139, 2136, 'C region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3140, 2137, 'INSDC_feature:N_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3141, 2137, 'N-region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3142, 2138, 'INSDC_feature:S_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3143, 2138, 'S region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3144, 2139, 'mobile element insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3145, 2140, 'novel sequence insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3146, 2141, 'CSL response element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3147, 2142, 'GATA box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3148, 2142, 'GATA element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3149, 2143, 'polymorphic psuedogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3150, 2144, 'AP-1 binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3151, 2145, 'ATF/CRE site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3152, 2145, 'Atf1/Pcr1 recognition motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3153, 2145, 'cyclic AMP response element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3154, 2145, 'M26 binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3155, 2145, 'm26 site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3156, 2145, 'M26_binding_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3157, 2146, 'copper-response element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3158, 2147, 'DNA damage response element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3159, 2148, 'FLEX element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3160, 2149, 'forkhead motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3161, 2150, 'homoID', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3162, 2150, 'homol D box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3163, 2151, 'homol E box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3164, 2152, 'heat shock element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3165, 2153, 'IDP (GATA)', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3166, 2153, 'iron repressed GATA element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3167, 2154, 'mating type M-box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3168, 2155, 'androgen response element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3169, 2155, 'ARE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3170, 2156, 'single molecule fish probe', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3171, 2156, 'smFISH probe', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3172, 2157, 'MluI cell cycle box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3173, 2158, 'CCAAT motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3174, 2159, 'Ace2 upstream activating sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3175, 2160, 'TR box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3176, 2161, 'STREP motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3177, 2161, 'stress-starvation response element of Schizosaccharomyces pombe', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3178, 2162, 'rDIS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3179, 2163, 'SRE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3180, 2164, 'd(GT)n', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3181, 2165, 'd(GTT)', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3182, 2166, 'Sap1 recognitions site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3183, 2167, 'calcineurin-dependent response element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3184, 2167, 'CDRE motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3185, 2168, 'BAC read contig', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3186, 2169, 'candidate gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3187, 2169, 'target gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3188, 2170, 'positional candidate gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3189, 2170, 'positional target gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3190, 2171, 'functional candidate gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3191, 2171, 'functional target gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3192, 2172, 'eRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3193, 2174, 'rearrangement region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3194, 2175, 'interchromosomal breakpoint', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3195, 2176, 'intrachromosomal breakpoint', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3196, 2177, 'unassigned scaffold', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3197, 2177, 'unassigned supercontig', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3198, 484, 'partial genomic sequence assembly', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3199, 484, 'pseudomolecule', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3200, 484, 'sequence assembly with N-gaps', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3201, 1776, 'INSDC_feature:ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3202, 1776, 'INSDC_qualifier:lncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3203, 1776, 'lncRNA_transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3204, 1776, 'long non-coding RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3205, 1358, 'feature alteration', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3206, 2178, 'feature ablation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3207, 2179, 'feature amplification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3208, 2180, 'feature translocation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3209, 1877, 'feature fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3210, 2181, 'transcript translocation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3211, 2182, 'regulatory region translocation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3212, 2183, 'TFBS binding site translocation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3213, 2183, 'transcription factor binding site translocation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3214, 2184, 'transcript fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3215, 2185, 'regulatory region fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3216, 2186, 'TFBS fusion ', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3217, 2186, 'transcription factor binding site fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3218, 2187, 'transcript amplification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3219, 2187, 'VEP:transcript_amplification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3220, 2188, 'transcript regulatory region fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3221, 2189, 'regulatory region amplification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3222, 2189, 'VEP:regulatory_region_amplification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3223, 2190, 'TFBS amplification ', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3224, 2190, 'transcription factor binding site amplification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3225, 2190, 'VEP:TFBS_amplification', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3226, 2191, 'Jannovar:transcript_ablation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3227, 2191, 'transcript ablation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3228, 2191, 'VEP:transcript_ablation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3229, 2192, 'regulatory region ablation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3230, 2192, 'VEP:regulatory_region_ablation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3231, 2193, 'TFBS ablation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3232, 2193, 'transcription factor binding site ablation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3233, 2193, 'VEP:TFBS_ablation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3234, 2194, 'transposable element CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3235, 2195, 'transposable element pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3236, 2196, 'dg repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3237, 2197, 'dh repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3238, 2198, 'AACCCT box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3239, 2199, 'splice region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3240, 2200, 'antisense lncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3241, 2200, 'natural antisense transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3242, 2201, 'centromere outer repeat transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3243, 2201, 'regional centromere outer repeat region transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3244, 2201, 'regional_centromere_outer_repeat_region_transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3245, 1905, 'feature truncation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3246, 1905, 'Jannovar:feature_truncation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3247, 1905, 'VEP:feature_truncation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3248, 1894, 'feature elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3249, 1894, 'VEP:feature_elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3250, 2123, 'internal feature elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3251, 2123, 'Jannovar:internal_feature_elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3252, 2202, 'ANNOVAR:frameshift insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3253, 2202, 'frameshift elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3254, 2202, 'Jannovar:frameshift_elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3255, 2203, 'ANNOVAR:frameshift deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3256, 2203, 'frameshift truncation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3257, 2203, 'Jannovar:frameshift_truncation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3258, 2204, 'copy number increase', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3259, 2205, 'copy number decrease', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3260, 520, 'bacterial RNApol promoter sigma ecf ', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3261, 2206, 'DNA spacer replication fork barrier', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3262, 2206, 'rDNA replication fork barrier', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3263, 2206, 'RFB', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3264, 2206, 'RTS1 barrier', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3265, 2206, 'RTS1 element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3266, 2207, 'transcriptional initiation cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3267, 2207, 'transcriptional start site cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3268, 2207, 'TSC', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3269, 2207, 'TSS cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3270, 2208, 'CAGE tag', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3271, 2209, 'CAGE cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3272, 2209, 'CAGE peak', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3273, 2209, 'CAGE_peak', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3274, 2209, 'INSDC_feature:misc_feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3275, 2209, 'INSDC_note:CAGE_cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3276, 2210, '5 methylcytosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3277, 2210, '5-mC', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3278, 2210, 'm-5C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3279, 2210, 'm5c', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3280, 2211, '4-mC', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3281, 2211, '4-methylcytosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3282, 2211, 'm-4C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3283, 2211, 'm4c', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3284, 2211, 'N4 methylcytosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3285, 2211, 'N4-methylcytosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3286, 2211, 'N4_methylcytosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3287, 2212, '6-mA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3288, 2212, '6-methyladenine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3289, 2212, '6mA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3290, 2212, 'm-6A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3291, 2212, 'm6a', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3292, 2212, 'N6-methyladenine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3293, 2213, 'mitochondrial contig', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3294, 2214, 'mitochondrial scaffold', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3295, 2214, 'mitochondrial supercontig', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3296, 2214, 'mitochondrial_scaffold', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3297, 2215, 'telomeric repeat containing RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3298, 2219, 'anti-ARRET', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3299, 2216, 'telomeric transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3300, 2220, 'distal duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3301, 2222, 'mitochondrial DNA read', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3302, 2223, 'chloroplast DNA read', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3303, 2224, 'consensus gDNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3304, 2224, 'consensus genomic DNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3305, 2225, 'restriction enzyme five prime single strand overhang', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3306, 2226, 'restriction enzyme three prime single strand overhang', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3307, 2227, 'monomeric repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3308, 2228, 'H3K20 trimethylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3309, 2229, 'H3K36 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3310, 2229, 'H3K36ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3311, 2230, 'H2BK12 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3312, 2230, 'H2BK12ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3313, 2232, 'H2AK5 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3314, 2232, 'H2AK5ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3315, 2234, 'H4K12 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3316, 2234, 'H4K12ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3317, 2235, 'H2BK120 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3318, 2235, 'H2BK120ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3319, 2236, 'H4K91 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3320, 2236, 'H4K91ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3321, 2237, 'H2BK20 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3322, 2237, 'H2BK20ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3323, 2238, 'H3K4 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3324, 2238, 'H3K4ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3325, 2239, 'H2AK9 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3326, 2239, 'H2AK9ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3327, 2240, 'H3K56 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3328, 2240, 'H3K56ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3329, 2241, 'H2BK15 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3330, 2241, 'H2BK15ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3331, 2242, ' H3R2me1', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3332, 2242, 'H3R2 monomethylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3333, 2243, 'H3R2 dimethylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3334, 2243, 'H3R2me2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3335, 2244, 'H4R3 dimethylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3336, 2244, 'H4R3me2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3337, 2245, ' H4K4me3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3338, 2245, 'H4K4 trimethylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3339, 2246, 'H3K23 dimethylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3340, 2246, 'H3K23me2', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3341, 2247, 'promoter flanking region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3342, 1992, 'restriction enzyme region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3343, 2249, 'protein stability element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3344, 2250, 'protease site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3345, 2251, 'rna stability element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3346, 2252, 'lariat intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3347, 2253, 'polypyrimidine initiator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3348, 2253, 'TCT element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3349, 2254, '5-hmC', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3350, 2254, '5-hydroxymethylcytosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3351, 2255, '5-fC', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3352, 2255, '5-formylcytosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3353, 2257, '8-oxoG', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3354, 2257, '8-oxoguanine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3355, 2258, '5-caC', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3356, 2258, '5-carboxycytosine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3357, 2259, '8-oxoA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3358, 2259, '8-oxoadenine', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3359, 1899, 'coding transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3360, 1899, 'Jannovar:coding_transcript_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3361, 2260, 'coding sequence intron variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3362, 2260, 'Jannovar:coding_transcript_intron_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3363, 2261, 'ANNOVAR:ncRNA_intronic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3364, 2261, 'Jannovar:non_coding_transcript_intron_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3365, 2261, 'non coding transcript intron variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3366, 2262, 'zinc finger binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3367, 2262, 'zinc_fing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3368, 2041, 'H4ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3369, 2041, 'histone 4 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3370, 2010, 'H3ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3371, 2010, 'histone 3 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3372, 2263, 'CCCTF binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3373, 2263, 'CTCF binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3374, 2264, 'five prime sticky end restriction enzyme cleavage site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3375, 2265, 'three prime sticky end restriction enzyme cleavage site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3376, 2266, 'ribonuclease site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3377, 2267, 'DNA signature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3378, 2268, 'RNA stability element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3379, 2269, 'G-box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3380, 2269, 'GBF binding sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3381, 2270, 'L-box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3382, 2270, 'L-box promoter element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3383, 2271, 'I-box promoter motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3384, 2272, '5'' UTR premature start codon variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3385, 2273, 'silent mating-type cassette', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3386, 2275, 'Okazaki fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3387, 2276, 'upstream transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3388, 2277, 'downstream transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3389, 2278, '5 prime UTR premature start codon gain variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3390, 2278, 'Jannovar:5_prime_UTR_premature_start_codon_gain_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3391, 2278, 'snpEff:START_GAINED', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3392, 2281, 'consensus AFLP fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3393, 2281, 'consensus amplified fragment length polymorphism fragment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3394, 1895, 'non_synonymous_coding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3395, 1895, 'nonsynonymous variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3396, 2282, 'extended cis splice site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3397, 2283, 'intron base 5', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3398, 2284, 'extended intronic splice region variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3399, 2285, 'extended intronic splice region ', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3400, 2287, 'gRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3401, 2287, 'guide RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3402, 2287, 'small guide RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3403, 2288, 'mating type region motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3404, 2289, 'Y-region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3405, 2290, 'Z1-region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3406, 2291, 'Z2-segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3407, 2292, 'ACS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3408, 2292, 'ARS consensus sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3409, 2293, 'DSR motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3410, 2294, 'zinc repressed element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3411, 1353, 'multiple nucleotide substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3412, 1353, 'multiple nucleotide variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3413, 2295, 'Jannovar:rare_amino_acid_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3414, 2295, 'rare amino acid variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3415, 2295, 'snpEff:RARE_AMINO_ACID', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3416, 2296, 'selenocysteine loss', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3417, 2297, 'pyrrolysine loss', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3418, 2298, 'intragenic variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3419, 2298, 'Jannovar:intragenic_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3420, 2298, 'snpEff:INTRAGENIC', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3421, 2299, 'Jannovar:start_lost', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3422, 2299, 'snpEff:START_LOST', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3423, 2299, 'VEP:start_lost', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3424, 2300, '5 prime UTR truncation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3425, 2300, 'Jannovar:5_prime_utr_truncation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3426, 2300, 'snpEff:UTR_5_DELETED', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3427, 2301, '5 prime UTR elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3428, 2302, '3 prime UTR truncation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3429, 2302, 'Jannovar:3_prime_utr_truncation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3430, 2302, 'snpEff:UTR_3_DELETED', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3431, 2303, '3 prime UTR elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3432, 2304, 'conserved intergenic variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3433, 2304, 'Jannovar:conserved_intergenic_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3434, 2304, 'snpEff:INTERGENIC_CONSERVED', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3435, 2305, 'conserved intron variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3436, 2305, 'Jannovar:conserved_intron_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3437, 2305, 'snpEff:INTRON_CONSERVED', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3438, 2306, 'snpEff:SYNONYMOUS_START', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3439, 2307, 'boundary element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3440, 2307, 'insulator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3441, 2308, 'mating type region replication fork barrier', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3442, 2309, 'primal small RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3443, 2310, 'multiplexing sequence identifier', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3444, 2311, 'W-region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3445, 2312, 'cis-acting homologous chromosome pairing region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3446, 2314, 'regulatory uORF', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3447, 2314, 'upstream ORF', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3448, 2315, 'small ORF', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3449, 2315, 'smORF', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3450, 2316, 'translated nested antisense gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3451, 2317, 'x-region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3452, 2318, 'short hairpin RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3453, 2318, 'small hairpin RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3455, 2320, 'loop-origin miRs', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3456, 2321, 'miR encoding snoRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3457, 2322, 'lncRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3458, 2323, 'miR encoding lncRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3459, 2324, 'miR encoding tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3460, 2325, 'shRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3461, 2326, 'miR encoding shRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3462, 2327, 'vaultRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3463, 2328, 'miR encoding vaultRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3464, 2329, 'Y-RNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3465, 2330, 'miR encoding Y-RNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3466, 2331, 'TCS element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3467, 2331, 'TEA Consensus Sequence ', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3468, 2332, 'pheromone response element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3469, 2332, 'PRE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3470, 2333, 'filamentation and invasion response element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3471, 2334, 'transcription pause site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3472, 2335, 'disabled ORF', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3473, 2335, 'disabled_reading frame', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3474, 2335, 'dORF', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3475, 2336, 'H3K27 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3476, 2336, 'H3K27ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3477, 2337, 'constitutive promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3478, 2338, 'inducible promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3479, 2339, 'dominant negative', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3480, 2339, 'dominant negative variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3481, 2340, 'gain of function variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3482, 2341, 'loss of function variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3483, 2342, 'null mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3484, 2343, 'intronic splicing silencer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3485, 2343, 'ISS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3486, 2344, 'ISE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3487, 2345, 'ESS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3488, 2345, 'exonic splicing silencer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3489, 2346, 'recombination enhancer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3490, 2349, 'complex chromosomal rearrangement', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3491, 2350, 'Alu insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3492, 2351, 'line1 insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3493, 2354, 'mobile element deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3494, 2355, 'HERV deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3495, 2357, 'SVA deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3496, 2358, 'LINE1 deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3497, 1394, 'INSDC_feature:misc_feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3498, 1394, 'INSDC_note:sequence_comparison', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3499, 1394, 'sequence comparison', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3500, 2362, 'no sequence alteration', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3501, 2363, 'ANNOVAR:upstream;downstream', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3502, 2364, 'incomplete transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3503, 2365, 'ANNOVAR:ncRNA_UTR3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3504, 2365, 'incomplete transcript 3UTR variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3505, 2366, 'ANNOVAR:ncRNA_UTR5', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3506, 2366, 'incomplete transcript 5UTR variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3507, 2367, 'incomplete transcript intronic variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3508, 2368, 'incomplete transcript splice region variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3509, 2369, 'incomplete transcript exonic variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3510, 2370, 'Seattleseq:coding-notMod3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3511, 2370, 'Seattleseq:coding-unknown', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3512, 2371, 'incomplete transcript coding splice variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3513, 2371, 'Seattleseq:coding-notMod3-near-splice', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3514, 2371, 'Seattleseq:coding-unknown-near-splice', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3515, 2372, 'Seattleseq:near-gene-3', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3516, 2373, 'ANNOVAR:exonic;splicing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3517, 2373, 'exonic splice region variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3518, 2373, 'Seattleseq:coding-near-splice', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3519, 2374, 'unidirectional gene fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3520, 2375, 'bidirectional gene fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3521, 2376, 'INSDC_feature:CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3522, 2376, 'INSDC_qualifier:pseudo', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3523, 2376, 'pseudogenic CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3524, 2377, 'ANNOVAR:ncRNA_splicing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3525, 2378, '3 prime UTR exon variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3526, 2379, '3 prime UTR intron variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3527, 2380, '5 prime UTR intron variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3528, 2381, '5 prime UTR exon variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3529, 2382, 'structural interaction variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3530, 2383, 'INSDC_feature:misc_recomb', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3531, 2383, 'INSDC_qualifier:non_allelic_homologous', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3532, 2383, 'INSDC_qualifier:non_allelic_homologous_recombination', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3533, 2383, 'NAHRR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3534, 2383, 'non allelic homologous recombination region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3535, 2384, 'small Cajal body specific RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3536, 2384, 'small Cajal body-specific RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3537, 2385, 'short tandem repeat variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3538, 2385, 'str variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3539, 2386, 'vertebrate immune system pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3540, 2387, 'immunoglobulin pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3541, 2389, 'IG C pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3542, 2390, 'IG J pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3543, 2390, 'IG joining pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3544, 2390, 'IG_joining_pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3545, 2390, 'Immunoglobulin Joining Pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3546, 2390, 'Immunoglobulin_Joining_Pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3547, 2391, 'IG V pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3548, 2391, 'IG variable pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3549, 2391, 'IG_variable_pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3550, 2391, 'Immunoglobulin variable pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3551, 2391, 'Immunoglobulin_variable_pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3552, 2392, 'T cell receptor V pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3553, 2392, 'T cell receptor Variable pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3554, 2392, 'T_cell_receptor_V_pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3555, 2392, 'T_cell_receptor_Variable_pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3556, 2392, 'TR V pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3557, 2393, 'T cell receptor J pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3558, 2393, 'T cell receptor Joining pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3559, 2393, 'T_cell_receptor_J_pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3560, 2393, 'T_cell_receptor_Joining_pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3561, 2393, 'TR J pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3562, 2394, 'translated processed pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3563, 2395, 'translated unprocessed pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3564, 2395, 'translated_nonprocessed_pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3565, 2396, 'transcribed unprocessed pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3566, 2396, 'transcribed_non_processed_pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3567, 2397, 'transcribed unitary pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3568, 2398, 'transcribed processed pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3569, 2399, 'polymorphic pseudogene with retained intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3570, 2400, 'pseudogene processed transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3571, 2401, 'mRNA with retained intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3572, 2402, 'lncRNA with retained intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3573, 2402, 'lncRNA_retained_intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3574, 2403, 'NMD transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3575, 2403, 'nonsense mediated decay transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3576, 2403, 'protein_coding_NMD', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3577, 2404, 'pseudogene retained intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3578, 2405, 'polymorphic pseudogene processed transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3579, 2407, 'NMD polymorphic pseudogene transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3580, 2407, 'nonsense_mediated_decay_polymorphic_pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3581, 2409, '3''_overlapping_ncrna', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3582, 2409, '3prime_overlapping_ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3583, 2409, 'three prime overlapping noncoding rna', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3584, 2410, 'immune_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3585, 2411, 'All_IG_genes', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3586, 2411, 'IG_genes', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3587, 2412, 'IGC_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3588, 2412, 'immunoglobulin_C_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3589, 2412, 'Immunoglobulin_Constant_germline_Gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3590, 2413, 'IGD_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3591, 2413, 'immunoglobulin_D_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3592, 2413, 'Immunoglobulin_Diversity_ gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3593, 2414, 'IG_joining_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3594, 2414, 'immunoglobulin_J_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3595, 2414, 'Immunoglobulin_Joining_Gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3596, 2415, 'IG_variable_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3597, 2415, 'IGV_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3598, 2415, 'Immunoglobulin_variable_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3599, 1961, 'lnc RNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3600, 1961, 'lnc_RNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3601, 1961, 'long_non_coding_RNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3602, 2416, 'mitochondrial rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3603, 2416, 'mitochondrial_rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3604, 2416, 'Mt rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3605, 2416, 'Mt_rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3606, 2417, 'mitochondrial_tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3607, 2417, 'Mt_tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3608, 2418, 'non_stop_decay_transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3609, 2419, 'sense intronic lncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3610, 2419, 'sense_intronic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3611, 2419, 'sense_intronic_lncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3612, 2419, 'sense_intronic_non-coding_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3613, 2420, 'sense overlap lncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3614, 2420, 'sense_overlap_lncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3615, 2420, 'sense_overlapping', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3616, 2421, 'TR_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3617, 2422, 'T_cell_receptor_C_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3618, 2423, 'T_cell_receptor_D_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3619, 2424, 'T_cell_receptor_J_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3620, 2425, 'T_cell_receptor_V_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3621, 2426, 'predicted transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3622, 2427, 'TEC', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3623, 2427, 'to_be_experimentally_confirmed_transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3624, 2428, 'early origin', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3625, 2428, 'early origin of replication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3626, 2428, 'early replication origin', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3627, 2429, 'late origin', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3628, 2429, 'late origin of replication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3629, 2429, 'late replication origin', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3630, 2233, 'H2Aac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3631, 2233, 'histone 2A acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3632, 2231, 'H2Bac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3633, 2231, 'histone 2B acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3634, 2430, 'H2A.Zac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3635, 2430, 'H2AZac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3636, 2430, 'histone 2AZ acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3637, 2431, 'H2A.ZK4ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3638, 2431, 'H2AZK4 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3639, 2431, 'H2AZK4ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3640, 2432, 'H2A.ZK7ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3641, 2432, 'H2AZK7 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3642, 2432, 'H2AZK7ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3643, 2433, 'H2A.ZK11ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3644, 2433, 'H2AZK11 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3645, 2433, 'H2AZK11ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3646, 2434, 'H2A.ZK13ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3647, 2434, 'H2AZK13 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3648, 2434, 'H2AZK13ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3649, 2435, 'H2A.ZK15ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3650, 2435, 'H2AZK15 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3651, 2435, 'H2AZK15ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3652, 2436, 'AUG initiated uORF', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3653, 2437, 'non AUG initiated uORF', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3654, 2438, 'genic 3 prime transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3655, 2438, 'genic 3'' transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3656, 2438, 'genic downstream transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3657, 2439, 'genic 5 prime transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3658, 2439, 'genic 5'' transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3659, 2439, 'genic upstream transcript variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3660, 2440, 'INSDC_feature:misc_recomb', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3661, 2440, 'INSDC_qualifier:mitotic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3662, 2440, 'INSDC_qualifier:mitotic_recombination', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3663, 2440, 'mitotic recombination region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3664, 2441, 'INSDC_feature:misc_recomb', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3665, 2441, 'INSDC_qualifier:meiotic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3666, 2441, 'INSDC_qualifier:meiotic_recombination', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3667, 2441, 'meiotic recombination region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3668, 2442, 'CArG box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3669, 2445, 'SHP box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3670, 1874, 'sequence length variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3671, 2446, 'short tandem repeat change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3672, 2446, 'str change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3673, 2447, 'short tandem repeat expansion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3674, 2447, 'str expansion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3675, 2448, 'short tandem repeat contraction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3676, 2448, 'str contraction', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3677, 2449, 'H2BK5 acetylation site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3678, 2449, 'H2BK5ac', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3679, 2450, 'trinucleotide repeat expansion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3680, 2451, 'ref miRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3681, 2451, 'RefSeq miRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3682, 2451, 'RefSeq-miRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3683, 2453, 'RNA thermometer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3684, 2453, 'RNA thermoregulator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3685, 2453, 'RNAT', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3686, 2453, 'thermoregulator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3687, 2454, 'splice polypyrimidine tract variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3688, 2455, 'splice donor region variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3689, 2456, 'telomeric D loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3690, 2457, 'sequence alteration artifact', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3691, 2458, 'indel artifact', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3692, 2459, 'deletion artifact', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3693, 2460, 'insertion artifact', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3694, 2461, 'substitution artifact', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3695, 2462, 'duplication artifact', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3696, 2463, 'SNV artifact', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3697, 2464, 'MNV artifact', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3698, 1958, 'enzymatic RNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3699, 2465, 'ribozyme gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3700, 2466, 'antisense lncRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3701, 2467, 'sense overlap lncRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3702, 2467, 'sense overlap ncRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3703, 2467, 'sense_overlap_lncRNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3704, 2468, 'sense intronic lncRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3705, 2468, 'sense intronic ncRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3706, 2468, 'sense_intronic_lncRNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3707, 2469, 'bidirectional promoter lncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3708, 2469, 'bidirectional promoter lncRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3709, 2469, 'bidirectional_promoter_lncRNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3710, 2470, 'mutational hotspot', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3711, 2471, 'HERV insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3712, 2472, 'functional gene region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3713, 2473, 'allelic pseudogene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3714, 2473, 'INSDC_feature:gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3715, 2473, 'INSDC_qualifier:allelic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3716, 2474, 'enhancer blocking element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3717, 2474, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3718, 2474, 'INSDC_qualifier:enhancer_blocking_element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3719, 2474, 'insulator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3720, 2475, 'imprinting control region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3721, 2475, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3722, 2475, 'INSDC_qualifier:imprinting_control_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3723, 2476, 'flanking repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3724, 2476, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3725, 2476, 'INSDC_qualifier:flanking', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3726, 2477, 'INSDC_feature:rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3727, 2477, 'INSDC_qualifier:processed', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3728, 2477, 'processed pseudogenic rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3729, 2478, 'INSDC_feature:rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3730, 2478, 'INSDC_qualifier:unprocessed', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3731, 2478, 'unprocessed pseudogenic rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3732, 2479, 'INSDC_feature:rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3733, 2479, 'INSDC_qualifier:unitary', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3734, 2479, 'unitary pseudogenic rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3735, 2480, 'allelic pseudogenic rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3736, 2480, 'INSDC_feature:rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3737, 2480, 'INSDC_qualifier:allelic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3738, 2481, 'INSDC_feature:tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3739, 2481, 'INSDC_qualifier:processed', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3740, 2481, 'processed pseudogenic tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3741, 2482, 'INSDC_feature:tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3742, 2482, 'INSDC_qualifier:unprocessed', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3743, 2482, 'unprocessed pseudogenic tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3744, 2483, 'INSDC_feature:tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3745, 2483, 'INSDC_qualifier:unitary', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3746, 2483, 'unitary pseudogenic tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3747, 2484, 'allelic pseudogenic tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3748, 2484, 'INSDC_feature:tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3749, 2484, 'INSDC_qualifier:allelic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3750, 2485, 'INSDC_feature:repeat_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3751, 2485, 'INSDC_qualifier:terminal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3752, 2485, 'terminal repeat', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3753, 2486, 'INSDC_feature:misc_feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3754, 2486, 'INSDC_note:repeat_instability_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3755, 2486, 'repeat instability region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3756, 2487, 'INSDC_feature:misc_feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3757, 2487, 'INSDC_note:replication_start_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3758, 2487, 'replication start site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3759, 1994, 'INSDC_feature:misc_feature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3760, 1994, 'INSDC_note:nucleotide_cleavage_site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3761, 1994, 'nucleotide cleavage site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3762, 2488, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3763, 2488, 'INSDC_qualifier:response_element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3764, 2488, 'response element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3765, 2489, 'INSDC_feature:source', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3766, 2489, 'sequence source', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3767, 2490, 'UNAAAC motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3768, 2491, 'long terminal repeat transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3769, 2491, 'LTR transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3770, 2492, 'gDNA contig', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3771, 2492, 'gDNA_contig', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3772, 2492, 'genomic DNA contig', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3773, 2493, 'PAV', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3774, 2493, 'presence absence variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3775, 2493, 'presence-absence variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3776, 2493, 'presence-absence_variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3777, 2493, 'presence/absence variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3778, 2493, 'presence/absence_variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3779, 2494, 'circular plasmid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3780, 2495, 'linear plasmid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3781, 2496, '(A(U)GUA) motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3782, 2496, 'Nrd1 binding motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3783, 2496, 'Nrd1-dependent terminator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3784, 2496, 'polyA site associated transcription termination signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3785, 2496, 'polyA site downstream element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3786, 2496, 'transcription termination signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3787, 2496, 'UCUUG motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3788, 2496, 'UGUAA/G motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3789, 2497, 'redundant inserted stop gained', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3790, 2498, 'Zas1 recognition motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3791, 2499, 'Pho7 binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3792, 2500, 'insertion or deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3793, 2500, 'unspecified indel', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3794, 1848, 'function modified variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3795, 1848, 'function_modified_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3796, 1848, 'functionally abnormal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3797, 2501, 'function retained variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3798, 2501, 'function_retained_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3799, 2501, 'functionally normal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3800, 2502, 'function uncertain variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3801, 2502, 'function_uncertain_variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3802, 511, 'Eukaryotic promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3803, 1022, 'Prokaryotic promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3804, 2503, 'Inert DNA Spacer', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3805, 2504, '2A polypeptide region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3806, 2504, '2A self-cleaving polypeptide region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3807, 2505, 'Loz1 response element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3808, 2505, 'LRE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3809, 2505, 'LRE element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3810, 2506, 'group IIB intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3811, 2507, 'CDS Extension', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3812, 2507, 'elongated CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3813, 2507, 'elongated_CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3814, 1930, 'CDS Extension 5 prime', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3815, 1930, 'CDS Extension five prime', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3816, 1930, 'elongated CDS five prime', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3817, 1930, 'elongated_CDS_five_prime', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3818, 1928, 'CDS Extension 3 prime', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3819, 1928, 'CDS Extension three prime', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3820, 1928, 'elongated CDS three prime', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3821, 1928, 'elongated_CDS_three_prime', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3822, 2508, 'CAAX box', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3823, 2509, 'self cleaving ribozyme', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3824, 2510, 'selectable marker', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3825, 2510, 'selectable_marker', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3826, 2510, 'selection marker', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3827, 2511, 'homologous chromosome recognition and pairing locus', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3828, 2512, 'PRE binding RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3829, 2512, 'pumilio response element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3830, 2513, 'SBM', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3831, 2513, 'SIM', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3832, 2513, 'SUMO binding motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3833, 2513, 'SUMO interaction motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3834, 794, '18S rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3835, 794, '18S_rRNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3836, 1336, '16S rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3837, 1336, '16S_rRNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3838, 1061, '5S rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3839, 1061, '5S_rRNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3840, 1063, '28S rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3841, 1063, '28S_rRNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3842, 757, '5.8S rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3843, 757, '5_8S rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3844, 757, '5_8S_rRNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3845, 2516, '21S rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3846, 2516, '21S_rRNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3847, 1340, '25S rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3848, 1340, '25S_rRNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3849, 1338, '23S rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3850, 1338, '23S_rRNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3851, 2517, 'partially duplicated transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3852, 2518, '5'' duplicated transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3853, 2518, 'five prime duplicated transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3854, 2518, 'five prime partially duplicated transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3855, 2519, '3'' duplicated transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3856, 2519, 'three prime duplicated transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3857, 2519, 'three prime partially duplicated transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3858, 606, 'Small noncoding RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3859, 2520, 'spurious protein', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3860, 814, 'INSDC_feature:mat_peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3861, 814, 'mature protein region of CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3862, 1396, 'INSDC_feature:propeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3863, 1396, 'propeptide region of CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3864, 810, 'INSDC_feature:sig_peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3865, 810, 'Signal peptide region of CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3866, 1136, 'INSDC_feature:transit_peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3867, 1136, 'transit peptide region of CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3868, 2521, 'stem loop region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3869, 2522, 'loop portion of stem loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3870, 2523, 'stem portion of stem loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3871, 2524, 'non-complimentary stem', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3872, 2524, 'noncomplimentary stem', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3873, 2525, 'Heterochromatin Knob', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3874, 2526, 'teb1 recognition motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3875, 2527, 'polyA cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3876, 2527, 'polyA site cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3877, 2527, 'polyA_cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3878, 2528, 'Large Retrotransposon Derivative', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3879, 2528, 'large_retrotransposon_derivative', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3880, 2529, 'terminal-repeat retrotransposons in miniature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3881, 2529, 'terminal-repeat_retrotransposons_in_miniature', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3882, 2530, 'Forward strand', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3883, 2530, 'Plus strand', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3884, 2530, 'Top strand', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3885, 2530, 'Watson strand', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3886, 2531, 'Bottom strand', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3887, 2531, 'Crick strand', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3888, 2531, 'Minus strand', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3889, 2531, 'Reverse strand', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3890, 2532, 'Copia LTR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3891, 2532, 'RLC retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3892, 2532, 'Ty1 retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3893, 2533, 'Gypsy LTR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3894, 2533, 'RLG retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3895, 2533, 'Ty3 retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3896, 2534, 'Bel Pao LTR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3897, 2534, 'Bel-Pao LTR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3898, 2534, 'RLB retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3899, 2535, 'Retrovirus LTR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3900, 2535, 'RLR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3901, 2356, 'Endogenous Retrovirus LTR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3902, 2356, 'HERV', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3903, 2356, 'RLE retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3904, 2536, 'R2 LINE retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3905, 2536, 'R2 retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3906, 2536, 'RIR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3907, 2537, 'RIT retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3908, 2537, 'RTE LINE retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3909, 2537, 'RTE retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3910, 2538, 'Jockey LINE retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3911, 2538, 'LINE Jockey element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3912, 2538, 'RIJ retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3913, 2352, 'L1 element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3914, 2352, 'L1 LINE retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3915, 2352, 'LINE 1 element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3916, 2352, 'LINE-1 element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3917, 2539, 'I LINE retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3918, 2539, 'LINE I element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3919, 2539, 'RII retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3920, 2540, 'RST retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3921, 2540, 'tRNA SINE element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3922, 2540, 'tRNA SINE retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3923, 2541, '7SL SINE element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3924, 2541, '7SL SINE retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3925, 2541, 'RSL retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3926, 2542, '5S SINE element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3927, 2542, '5S SINE retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3928, 2542, 'RSS retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3929, 2543, 'Crypton transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3930, 2543, 'Crypton YR transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3931, 2543, 'DYC transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3932, 2544, 'DTT transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3933, 2544, 'Mariner', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3934, 2544, 'Stowaway', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3935, 2544, 'Tc1 Mariner TIR transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3936, 2544, 'Tc1 transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3937, 2544, 'TcMar-Stowaway transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3938, 2545, 'Ac transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3939, 2545, 'Ac/Ds transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3940, 2545, 'Ds transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3941, 2545, 'DTA transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3942, 2545, 'hAT TIR transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3943, 2545, 'hAT transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3944, 2545, 'hAT-Ac transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3945, 2546, 'DTM transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3946, 2546, 'MLE transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3947, 2546, 'Mu transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3948, 2546, 'MuDR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3949, 2546, 'MULE', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3950, 2546, 'Mutator TIR transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3951, 2546, 'Mutator transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3952, 2547, 'DTE transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3953, 2547, 'Merlin TIR transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3954, 2547, 'Merlin transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3955, 2548, 'DTR transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3956, 2548, 'Transib TIR transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3957, 2548, 'transib transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3958, 2549, 'DTB transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3959, 2549, 'piggyBac TIR transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3960, 2549, 'PiggyBac transposable element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3961, 2550, 'DTH transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3962, 2550, 'Harbinger transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3963, 2550, 'PIF Harbinger TIR transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3964, 2550, 'PIF transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3965, 2550, 'Tourist transposon element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3966, 2551, 'CACTA TIR transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3967, 2551, 'CACTA transposon element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3968, 2551, 'CACTC transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3969, 2551, 'CMC-EnSpm transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3970, 2551, 'dSpm transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3971, 2551, 'DTC transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3972, 2551, 'En transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3973, 2551, 'En-Spm transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3974, 2551, 'EnSpm transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3975, 2551, 'Spm transposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3976, 2552, 'tyrosine kinase retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3977, 2552, 'YR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3978, 2553, 'DIRS retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3979, 2553, 'DIRS YR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3980, 2553, 'RYD retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3981, 2554, 'Ngaro retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3982, 2554, 'Ngaro YR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3983, 2554, 'RYN retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3984, 2555, 'RYV retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3985, 2555, 'Viper retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3986, 2555, 'Viper YR retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3987, 2556, 'Penelope retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3988, 2556, 'RPP retrotransposon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3989, 2557, 'circRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3990, 2557, 'circular ncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3991, 2557, 'noncoding circRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3992, 2558, 'circular mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3993, 2558, 'coding circRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3994, 2559, 'Mitochondrial A+T region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3995, 2559, 'Mitochondrial DNA control region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3996, 2559, 'Mitochondrial NCR', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3997, 2559, 'Mitochondrial noncoding region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3998, 2559, 'MtDNA control region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (3999, 2559, 'MtDNA_control_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4000, 2560, 'Mitochondrial D loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4001, 2560, 'Mitochondrial displacement loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4002, 2561, 'TFRS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4003, 2561, 'transcription factor regulatory site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4004, 2562, 'TFRS module', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4005, 2562, 'TFRS phrase', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4006, 2562, 'transcription factor regulatory site module', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4007, 2562, 'transcription factor regulatory site phrase', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4008, 2563, 'TFRS collection', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4009, 2563, 'transcription factor regulatory site collection', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4010, 2564, 'simple operon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4011, 2565, 'complex operon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4012, 1083, 'unit of gene expression', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4013, 2566, 'transcription unit', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4014, 2567, 'simple regulon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4015, 2569, 'simple regulon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4016, 2570, 'TAD', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4017, 2570, 'topologically associated domain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4018, 2571, 'TAD boundary', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4019, 2571, 'TAD_boundary', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4020, 2571, 'topologically associated domain boundary', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4021, 2572, 'chromatin regulatory region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4022, 2573, 'DNA loop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4023, 2574, 'DNA loop anchor', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4024, 682, 'core promoter element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4025, 2575, 'cryptic promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4026, 1535, 'viral promoter', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4027, 2576, 'core prokaryotic promoter element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4028, 2576, 'general transcription factor binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4029, 2577, 'core viral promoter element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4030, 2577, 'general transcription factor binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4031, 2578, 'altered gene product level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4032, 2578, 'altered transcription level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4033, 2578, 'altered_transcription_level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4034, 2579, 'increased gene product level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4035, 2579, 'increased transcription level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4036, 2579, 'increased_transcription_level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4037, 2580, 'decreased gene product level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4038, 2580, 'decreased transcription level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4039, 2580, 'decreased_transcription_level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4040, 2580, 'reduced gene product level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4041, 2580, 'reduced transcription level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4042, 2580, 'reduced_gene_product_level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4043, 2580, 'reduced_transcription_level', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4044, 2581, 'absent gene product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4045, 2582, 'altered gene product structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4046, 2583, 'NMD triggering variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4047, 2583, 'nonsense-mediated decay triggering variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4048, 2584, 'NMD escaping variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4049, 2584, 'nonsense-mediated decay escaping variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4050, 2585, 'stop gained variant-nonsense-mediated decay triggering', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4051, 2585, 'stop gained-NMD triggering', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4052, 2586, 'stop gained variant-nonsense-mediated decay escaping', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4053, 2586, 'stop gained-NMD escaping', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4054, 2587, 'frameshift variant-NMD triggering', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4055, 2587, 'frameshift variant-nonsense-mediated decay triggering', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4056, 2588, 'frameshift variant-NMD escaping', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4057, 2588, 'frameshift variant-nonsense-mediated decay escaping', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4058, 2589, 'splice donor variant-NMD triggering', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4059, 2589, 'splice donor variant-nonsense-mediated decay triggering', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4060, 2590, 'splice donor variant-NMD escaping', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4061, 2590, 'splice donor variant-nonsense-mediated decay escaping', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4062, 2591, 'splice acceptor variant-NMD triggering', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4063, 2591, 'splice acceptor variant-nonsense-mediated decay triggering', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4064, 2592, 'splice acceptor variant-NMD escaping', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4065, 2592, 'splice acceptor variant-nonsense-mediated decay escaping', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4066, 2593, 'minus 1 ribosomal frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4067, 2593, 'minus 1 ribosomal slippage', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4068, 2593, 'minus 1 translational frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4069, 2594, 'minus 2 ribosomal frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4070, 2594, 'minus 2 ribosomal slippage', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4071, 2594, 'minus 2 translational frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4072, 694, 'accessible DNA region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4073, 2595, 'epigenomically modified region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4074, 2596, 'Amber stop codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4075, 2597, 'Ochre stop codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4076, 2598, 'Opal stop codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4077, 2599, '2S rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4078, 2599, 'rRNA 2S gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4079, 2600, 'cytosolic 2S rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4080, 2600, 'cytosolic rRNA 2S', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4081, 2601, 'small nuclear RNA U7', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4082, 2601, 'snRNA U7', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4083, 2601, 'U7 small nuclear RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4084, 2601, 'U7 snRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4085, 2602, 'scaRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4086, 2602, 'Small Cajal body-specific RNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4087, 2603, '7SK RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4088, 2603, 'RNA 7SK', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4089, 2604, '7SK RNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4090, 2604, 'RNA 7SK gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4091, 1587, 'small non-coding RNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4092, 1587, 'sncRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4093, 1059, 'cytosolic ribosomal RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4094, 1059, 'cytosolic rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4095, 2605, 'mitochondrial small subunit rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4096, 2605, 'mitochondrial SSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4097, 2605, 'MT SSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4098, 2606, 'mitochondrial large subunit rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4099, 2606, 'mitochondrial LSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4100, 2606, 'MT LSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4101, 2607, 'plastid rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4102, 2608, 'plastid small subunit rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4103, 2608, 'plastid SSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4104, 2609, 'plastid large subunit rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4105, 2609, 'plastid LSU rRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4106, 2613, 'Stable intronic sequence RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4107, 2613, 'stable_intronic_sequence_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4108, 2614, 'Stem-bulge RNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4109, 2614, 'stem_bulge_RNA_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4110, 2615, 'Stem-bulge RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4111, 2615, 'stem_bulge_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4112, 2616, 'Hairpin RNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4113, 2617, 'Hairpin RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4114, 2618, 'Metabolic gene cluster', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4115, 2515, 'cytosolic large subunit rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4116, 2514, 'cytosolic small subunit rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4117, 2622, 'mitochondrial rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4118, 2623, 'mitochondrial large subunit rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4119, 2623, 'rRNA 21S gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4120, 2623, 'rRNA_21S_gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4121, 2624, 'mitochondrial small subunit rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4122, 2626, 'plastid large subunit rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4123, 2627, 'plastid small subunit rRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4124, 2628, 'C/D scaRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4125, 2629, 'H/ACA scaRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4126, 2630, 'C/D-H/ACA scaRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4127, 2631, 'C/D scaRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4128, 2632, 'H/ACA scaRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4129, 2633, 'C/D-H/ACA scaRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4130, 2634, 'box C/D snoRNA gene, C D box snoRNA gene, C/D box snoRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4131, 2635, 'box H/ACA snoRNA gene, H ACA box snoRNA gene, H/ACA box snoRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4132, 2636, 'small nucleolar RNA U14 gene, snoRNA U14 gene, U14 small nucleolar RNA gene, U14 snoRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4133, 2637, 'small nucleolar RNA U3 gene, snoRNA U3 gene, U3 small nucleolar RNA gene, U3 snoRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4134, 2638, 'methylation guide snoRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4135, 2639, 'pseudouridylation guide snoRNA gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4136, 2640, 'bidirectional lncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4137, 2640, 'bidirectional promoter lncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4138, 2640, 'bidirectional promoter long non-coding RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4139, 2640, 'bidirectional_lncRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4140, 2640, 'bidirectional_promoter_long_non-coding_RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4141, 1391, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4142, 1391, 'INSDC_qualifier:other', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4143, 1391, 'regulatory region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4144, 788, '4.5S snRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4145, 788, 'U14 snoRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4146, 2641, 'methylation guide snoRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4147, 2642, 'rRNA cleavage RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4148, 2643, 'exon of single exon gene', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4149, 2643, 'single_exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4150, 2643, 'singleton exon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4151, 2644, 'cassette array member', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4152, 2645, 'gene cassette member', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4153, 2646, 'gene subarray member', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4154, 2647, 'INSDC_feature:primer_bind', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4155, 2647, 'primer binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4156, 2648, 'gene array', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4157, 2649, 'gene subarray', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4158, 2650, 'gene cassette', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4159, 2274, 'gene cassette array', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4160, 524, 'gene group', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4161, 2651, 'selenocysteine tRNA primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4162, 2652, 'selenocysteinyl tRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4163, 2652, 'selenocysteinyl-transfer ribonucleic acid', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4164, 2652, 'selenocysteinyl-transfer RNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4165, 2653, 'syntenic region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4166, 1421, 'biochemical motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4167, 1421, 'biochemical region of peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4168, 1421, 'biochemical_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4169, 1426, 'molecular contact region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4170, 2654, 'disordered region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4171, 2654, 'intrinsically unstructured polypeptide region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4172, 2655, 'catmat-3l', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4173, 2656, 'catmat-4l', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4174, 2657, 'catmat-3r', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4175, 2658, 'catmat-4r', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4176, 2659, 'alpha beta motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4177, 2660, 'lipoprotein signal peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4178, 2660, 'prokaryotic membrane lipoprotein lipid attachment site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4179, 2661, 'no output', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4180, 1101, 'cleaved peptide region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4181, 2662, 'coil', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4182, 2662, 'peptide coil', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4183, 2662, 'random coil', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4184, 2663, 'hydropathic', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4185, 2663, 'hydrophobic region of peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4186, 2663, 'hydrophobic_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4187, 2663, 'hydrophobicity', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4188, 2664, 'N-region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4189, 2665, 'C-region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4190, 2666, 'central hydrophobic region of signal peptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4191, 2666, 'central_hydrophobic_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4192, 2666, 'H-region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4193, 2108, 'motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4194, 2667, 'binding', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4195, 2667, 'polypeptide binding motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4196, 1440, 'catalytic_motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4197, 1440, 'polypeptide catalytic motif', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4198, 2668, 'DNA_bind', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4199, 2668, 'polypeptide DNA contact', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4200, 807, 'polypeptide conserved region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4201, 2669, 'complex substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4202, 2670, 'point mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4203, 2672, 'pyrimidine transition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4204, 2673, 'C to T transition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4205, 2674, 'C to T transition at pCpG site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4206, 2675, 'T to C transition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4207, 2676, 'purine transition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4208, 2677, 'A to G transition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4209, 2678, 'G to A transition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4210, 2680, 'pyrimidine to purine transversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4211, 2681, 'C to A transversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4212, 2682, 'C to G transversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4213, 2683, 'T to A transversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4214, 2684, 'T to G transversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4215, 2685, 'purine to pyrimidine transversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4216, 2686, 'A to C transversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4217, 2687, 'A to T transversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4218, 2688, 'G to C transversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4219, 2689, 'G to T transversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4220, 2690, 'intrachromosomal mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4221, 352, '(bacteria)&ampDgr;', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4222, 352, '(Drosophila)Df', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4223, 352, '(fungi)D', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4224, 352, 'chromosomal deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4225, 352, 'deficiency', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4226, 841, '(bacteria)IN', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4227, 841, '(Drosophila)In', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4228, 841, '(fungi)In', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4229, 841, 'chromosomal inversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4230, 2691, 'interchromosomal mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4231, 2692, 'deletion-insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4232, 2692, 'indel', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4233, 2221, 'nucleotide duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4234, 2221, 'nucleotide_duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4235, 752, 'inversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4236, 860, '(Drosophila)Dp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4237, 860, '(fungi)Dp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4238, 860, 'chromosomal duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4239, 870, 'intrachromosomal duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4240, 2693, 'direct tandem duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4241, 2695, 'inverted tandem duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4242, 2695, 'mirror duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4243, 353, '(Drosophila)Tp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4244, 353, 'intrachromosomal transposition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4245, 349, 'compound chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4246, 2696, 'centric-fusion translocations', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4247, 2696, 'Robertsonian fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4248, 2696, 'whole-arm translocations', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4249, 1096, '(Drosophila)T', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4250, 1096, '(fungi)T', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4251, 1096, 'chromosomal translocation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4252, 842, '(Drosophila)R', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4253, 842, '(fungi)C', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4254, 842, 'ring chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4255, 2697, 'pericentric inversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4256, 2698, 'paracentric inversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4257, 2699, 'reciprocal chromosomal translocation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4258, 2700, 'mutation affecting transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4259, 2700, 'mutation causing partially characterised change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4260, 2700, 'mutation causing uncharacterised change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4261, 2700, 'sequence variant causing partially characterised change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4262, 2700, 'sequence variant causing uncharacterised change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4263, 2700, 'sequence variation affecting transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4264, 2700, 'sequence_variant_causing_partially_characterised_change_in_transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4265, 2700, 'sequence_variant_causing_uncharacterised_change_in_transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4266, 2701, 'mutation causing no change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4267, 2701, 'sequence variant causing no change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4268, 2702, 'mutation affecting coding sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4269, 2702, 'sequence variation affecting coding sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4270, 2703, 'mutation causing initiator codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4271, 2703, 'sequence variant causing initiator codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4272, 2704, 'mutaton causing amino acid coding codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4273, 2704, 'sequence variant causing amino acid coding codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4274, 2705, 'mutation causing synonymous codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4275, 2705, 'sequence variant causing synonymous codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4276, 2706, 'mutation causing non synonymous codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4277, 2706, 'non-synonymous codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4278, 2706, 'sequence variant causing non synonymous codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4279, 2707, 'mutation causing missense codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4280, 2707, 'sequence variant causing missense codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4281, 2708, 'mutation causing conservative missense codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4282, 2708, 'sequence variant causing conservative missense codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4283, 2709, 'mutation causing nonconservative missense codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4284, 2709, 'sequence variant causing nonconservative missense codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4285, 2710, 'mutation causing nonsense codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4286, 2710, 'sequence variant causing nonsense codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4287, 2711, 'mutation causing terminator codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4288, 2711, 'sequence variant causing terminator codon change in transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4289, 2712, 'mutation affecting reading frame', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4290, 2712, 'sequence variation affecting reading frame', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4291, 2713, 'frameshift mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4292, 2713, 'frameshift sequence variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4293, 2713, 'out of frame mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4294, 2714, 'plus 1 frameshift mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4295, 2714, 'sequence variant causing plus 1 frameshift mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4296, 2715, 'minus 1 frameshift mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4297, 2715, 'sequence variant causing minus 1 frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4298, 2716, 'plus 2 frameshift mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4299, 2716, 'sequence variant causing plus 2 frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4300, 2717, 'minus 2 frameshift mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4301, 2717, 'sequence variant causing minus 2 frameshift', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4302, 2718, 'mutation affecting transcript processing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4303, 2718, 'sequence variant affecting transcript processing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4304, 2719, 'mutation affecting splicing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4305, 2719, 'sequence variant affecting splicing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4306, 2720, 'mutation affecting splice donor', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4307, 2720, 'sequence variant affecting splice donor', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4308, 2720, 'splice donor mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4309, 2721, 'mutation affecting splicing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4310, 2721, 'sequence variant affecting splice acceptor', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4311, 2721, 'splice acceptor mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4312, 2722, 'cryptic splice activator sequence variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4313, 2722, 'mutation causing cryptic splice activator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4314, 2722, 'sequence variant causing cryptic splice activator', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4315, 2723, 'mutation affecting editing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4316, 2723, 'sequence variant affecting editing', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4317, 2724, 'mutation affecting transcription', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4318, 2724, 'sequence variant affecting transcription', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4319, 2725, 'mutation decreasing rate of transcription', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4320, 2725, 'sequence variation decreasing rate of transcription', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4321, 2726, 'mutation affecting transcript sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4322, 2726, 'sequence variation affecting transcript sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4323, 2727, 'mutation increasing rate of transcription', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4324, 2727, 'sequence variation increasing rate of transcription', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4325, 2728, 'mutation affecting rate of transcription', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4326, 2728, 'sequence variant affecting rate of transcription', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4327, 2729, 'mutation affecting transcript stability', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4328, 2729, 'sequence variant affecting transcript stability', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4329, 2730, 'mutation increasing transcript stability', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4330, 2730, 'sequence variant increasing transcript stability', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4331, 2731, 'mutation decreasing transcript stability', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4332, 2731, 'sequence variant decreasing transcript stability', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4333, 2732, 'mutation affecting level of transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4334, 2732, 'sequence variation affecting level of transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4335, 2733, 'mutation decreasing level of transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4336, 2733, 'sequence variation decreasing level of transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4337, 2734, 'mutation increasing level of transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4338, 2734, 'sequence variation increasing level of transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4339, 2735, 'mutation affecting translational product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4340, 2735, 'mutation causing partially characterised change of translational product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4341, 2735, 'mutation causing uncharacterised change of translational product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4342, 2735, 'sequence variant affecting translational product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4343, 2735, 'sequence variant causing partially characterised change of translational product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4344, 2735, 'sequence variant causing uncharacterised change of translational product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4345, 2735, 'sequence_variant_causing_partially_characterised_change_of_translational_product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4346, 2735, 'sequence_variant_causing_uncharacterised_change_of_translational_product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4347, 2736, 'mutation causing no change of translational product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4348, 2736, 'sequence variant causing no change of translational product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4349, 2737, 'mutation causing complex change of translational product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4350, 2737, 'sequence variant causing complex change of translational product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4351, 2738, 'mutation causing amino acid substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4352, 2738, 'sequence variant causing amino acid substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4353, 2739, 'mutation causing conservative amino acid substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4354, 2739, 'sequence variant causing conservative amino acid substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4355, 2740, 'mutation causing nonconservative amino acid substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4356, 2740, 'sequence variant causing nonconservative amino acid substitution', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4357, 2741, 'mutation causing amino acid insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4358, 2741, 'sequence variant causing amino acid insertion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4359, 2742, 'mutation causing amino acid deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4360, 2742, 'sequence variant causing amino acid deletion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4361, 2743, 'mutation causing polypeptide truncation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4362, 2743, 'sequence variant causing polypeptide truncation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4363, 2744, 'mutation causing polypeptide elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4364, 2744, 'sequence variant causing polypeptide elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4365, 2745, 'mutation causing polypeptide N terminal elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4366, 2745, 'polypeptide N-terminal elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4367, 2746, 'mutation causing polypeptide C terminal elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4368, 2746, 'polypeptide C-terminal elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4369, 2747, 'mutation affecting level of translational product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4370, 2747, 'sequence variant affecting level of translational product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4371, 2748, 'mutationdecreasing level of translation product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4372, 2748, 'sequence variant decreasing level of translation product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4373, 2749, 'mutationt increasing level of translation product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4374, 2749, 'sequence variant increasing level of translation product', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4375, 2750, 'mutation affecting polypeptide amino acid sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4376, 2750, 'sequence variant affecting polypeptide amino acid sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4377, 2751, 'inframe polypeptide N-terminal elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4378, 2751, 'mutation causing inframe polypeptide N terminal elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4379, 2752, 'mutation causing out of frame polypeptide N terminal elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4380, 2752, 'out of frame polypeptide N-terminal elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4381, 2753, 'inframe_polypeptide C-terminal elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4382, 2753, 'mutaton causing inframe polypeptide C terminal elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4383, 2754, 'mutation causing out of frame polypeptide C terminal elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4384, 2754, 'out of frame polypeptide C-terminal elongation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4385, 2755, 'frame restoring mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4386, 2755, 'frame restoring sequence variant', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4387, 2756, 'mutation affecting 3D structure of polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4388, 2756, 'mutation causing partially characterised 3D structural change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4389, 2756, 'mutation causing uncharacterised 3D structural change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4390, 2756, 'sequence variant affecting 3D structure of polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4391, 2756, 'sequence variant affecting 3D-structure of polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4392, 2756, 'sequence variant causing partially characterised 3D structural change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4393, 2756, 'sequence variant causing uncharacterised 3D structural change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4394, 2756, 'sequence_variant_causing_partially_characterised_3D_structural_change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4395, 2756, 'sequence_variant_causing_uncharacterised_3D_structural_change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4396, 2757, 'mutation causing no 3D structural change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4397, 2757, 'sequence variant causing no 3D structural change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4398, 2758, 'mutation causing complex 3D structural change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4399, 2758, 'sequence variant causing complex 3D structural change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4400, 2759, 'mutation causing conformational change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4401, 2759, 'sequence variant causing conformational change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4402, 2760, 'mutation affecting polypeptide function', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4403, 2760, 'sequence variant affecting polypeptide function', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4404, 2761, 'loss of function of polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4405, 2761, 'mutation causing loss of function of polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4406, 2761, 'sequence variant causing loss of function of polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4407, 2762, 'mutation causing inactive ligand binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4408, 2762, 'sequence variant causing inactive ligand binding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4409, 2763, 'mutation causing inactive catalytic site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4410, 2763, 'sequence variant causing inactive catalytic site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4411, 2764, 'mutation causing polypeptide localization change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4412, 2764, 'sequence variant causing polypeptide localization change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4413, 2765, 'mutation causing polypeptide post translational processing change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4414, 2765, 'polypeptide post-translational processing affected', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4415, 2765, 'sequence variant causing polypeptide post translational processing change', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4416, 2766, 'polypeptide_post-translational_processing_affected', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4417, 2767, 'mutation causing partial loss of function of polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4418, 2767, 'partial loss of function of polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4419, 2767, 'sequence variant causing partial loss of function of polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4420, 2768, 'gain of function of polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4421, 2768, 'mutation causing gain of function of polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4422, 2768, 'sequence variant causing gain of function of polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4423, 2769, 'mutation affecting transcript secondary structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4424, 2769, 'sequence variant affecting transcript secondary structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4425, 2770, 'mutation causing compensatory transcript secondary structure mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4426, 2770, 'sequence variant causing compensatory transcript secondary structure mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4427, 2771, 'sequence variant effect', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4428, 2772, 'mutation causing polypeptide fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4429, 2772, 'sequence variant causing polypeptide fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4430, 2773, '(Drosophila)A', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4431, 2773, 'autosynaptic chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4432, 2774, 'homo compound chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4433, 2774, 'homo-compound chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4434, 2775, 'hetero compound chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4435, 2775, 'hetero-compound chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4436, 2776, 'chromosome fission', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4437, 2777, 'dextrosynaptic chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4438, 2778, 'laevosynaptic chromosome', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4439, 2779, 'free duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4440, 2780, '(Drosophila)R', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4441, 2780, 'free ring duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4442, 2781, '(Drosophila)Df', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4443, 2781, '(Drosophila)DfT', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4444, 2781, 'deficient translocation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4445, 2782, '(Drosophila)InT', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4446, 2782, '(Drosophila)T', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4447, 2782, 'inversion cum translocation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4448, 2783, '(Drosophila)bDp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4449, 2783, 'bipartite duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4450, 2784, 'cyclic translocation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4451, 2785, '(Drosophila)bIn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4452, 2785, 'bipartite inversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4453, 2786, '(Drosophila)eDp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4454, 2786, 'uninverted insertional duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4455, 2788, '(Drosophila)iDp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4456, 2788, 'inverted insertional duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4457, 2787, '(Drosophila)Dpp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4458, 2787, 'insertional duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4459, 356, '(Drosophila)Tp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4460, 356, 'interchromosomal transposition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4461, 2789, '(Drosophila)iTp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4462, 2789, 'inverted interchromosomal transposition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4463, 2790, '(Drosophila)eTp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4464, 2790, 'uninverted interchromosomal transposition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4465, 2791, '(Drosophila)iTp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4466, 2791, 'inverted intrachromosomal transposition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4467, 2792, '(Drosophila)eTp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4468, 2792, 'uninverted intrachromosomal transposition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4469, 2793, '(Drosophila)uDp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4470, 2793, 'unoriented insertional duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4471, 2794, '(Drosophila)uTp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4472, 2794, 'unorientated interchromosomal transposition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4473, 2795, '(Drosophila)uTp', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4474, 2795, 'unorientated intrachromosomal transposition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4475, 2796, 'uncharacterized chromosomal mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4476, 2797, '(Drosophila)Df', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4477, 2797, '(Drosophila)DfIn', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4478, 2797, 'deficient inversion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4479, 2694, 'erverted', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4480, 2694, 'tandem duplication', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4481, 2798, 'partially characterized chromosomal mutation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4482, 2799, 'mutation affecting gene structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4483, 2799, 'sequence variant affecting gene structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4484, 2800, 'mutation causing gene fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4485, 2800, 'sequence variant causing gene fusion', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4486, 340, 'chromosome number variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4487, 340, 'Jannovar:chromosome_number_variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4488, 359, 'chromosome structure variation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4489, 359, 'snpEff:CHROMOSOME_LARGE_DELETION', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4490, 2801, 'mutation causes exon loss', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4491, 2801, 'sequence variant causes exon loss', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4492, 2802, 'mutation causes intron gain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4493, 2802, 'sequence variant causes intron gain', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4494, 2803, 'sequence variant causing cryptic splice donor activation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4495, 2804, 'sequence variant causing cryptic splice acceptor activation', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4496, 2805, 'alternatively spliced transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4497, 2806, 'encodes 1 polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4498, 2807, 'encodes greater than 1 polypeptide', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4499, 2808, 'encodes different polypeptides different stop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4500, 2810, 'encodes overlapping peptides different start', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4501, 2811, 'encodes disjoint polypeptides', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4502, 2812, 'encodes overlapping polypeptides different start and stop', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4503, 2809, 'encodes overlapping peptides', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4504, 1131, 'dicistronic primary transcript', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4505, 2815, 'member of regulon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4506, 2816, 'alternatively_spliced_transcript_encoding_greater_than_1_polypeptide_different_start_codon_different_stop_codon_coding_regions_non-overlapping', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4507, 2817, 'CDS independently known', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4508, 2818, 'orphan CDS', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4509, 2820, 'CDS supported by domain match data', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4510, 2361, 'CDS supported by sequence similarity data', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4511, 2819, 'CDS predicted', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4512, 2822, 'CDS supported by EST or cDNA data', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4513, 2823, 'internal Shine Dalgarno sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4514, 2823, 'internal Shine-Dalgarno sequence', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4515, 2824, 'recoded mRNA', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4516, 2825, 'minus 1 translationally frameshifted', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4517, 2826, 'plus 1 translationally frameshifted', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4518, 2827, 'mRNA recoded by translational bypass', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4519, 2828, 'mRNA recoded by codon redefinition', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4520, 962, 'INSDC_feature:regulatory', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4521, 962, 'INSDC_qualifier:recoding_stimulatory_region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4522, 962, 'recoding stimulatory region', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4523, 962, 'recoding stimulatory signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4524, 2831, '4bp start codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4525, 2831, 'four bp start codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4526, 2833, 'archaeal intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4527, 2834, 'pre-tRNA intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4528, 2834, 'tRNA intron', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4529, 2835, 'CTG start codon', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4530, 2836, 'SECIS element', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4531, 2838, 'three prime recoding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4532, 2839, 'three prime stem loop structure', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4533, 2840, 'five prime recoding site', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4534, 2841, 'flanking three prime quadruplet recoding signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4535, 2842, 'UAG stop codon signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4536, 2844, 'UAA stop codon signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4537, 2845, 'UGA stop codon signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4538, 2846, 'three prime repeat recoding signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4539, 2847, 'distant three prime recoding signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4540, 2843, 'stop codon signal', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4541, 2848, 'accession', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4542, 2848, 'databank entry', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4543, 2049, 'gene segment', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4544, 2852, 'division', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4545, 2857, 'subdivision', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4546, 2860, 'species complex', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4547, 2865, 'variety', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4548, 2875, 'form', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4549, 2876, 'superdivision', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4550, 2886, 'empire', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4551, 2889, 'infradivision', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4552, 2921, 'family_name', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4553, 2921, 'last_name', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4554, 2922, 'first_name', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4555, 2962, 'Patents', NULL);
INSERT INTO chado.cvtermsynonym VALUES (4556, 2967, 'Author List', NULL);
INSERT INTO chado.db2cv_mview VALUES (5, 'germplasm_ontology', 2, 'CO_010', 4);
INSERT INTO chado.db2cv_mview VALUES (8, 'efo', 8, 'EFO', 4);
INSERT INTO chado.db2cv_mview VALUES (9, 'ero', 9, 'ERO', 2);
INSERT INTO chado.db2cv_mview VALUES (13, 'IAO', 13, 'IAO', 3);
INSERT INTO chado.db2cv_mview VALUES (19, 'ncbitaxon', 20, 'NCBITaxon', 1);
INSERT INTO chado.db2cv_mview VALUES (18, 'ncit', 19, 'NCIT', 23);
INSERT INTO chado.db2cv_mview VALUES (10, 'OBCS', 10, 'OBCS', 1);
INSERT INTO chado.db2cv_mview VALUES (11, 'obi', 11, 'OBI', 2);
INSERT INTO chado.db2cv_mview VALUES (12, 'ogi', 12, 'OGI', 1);
INSERT INTO chado.db2cv_mview VALUES (14, 'sbo', 15, 'SBO', 3);
INSERT INTO chado.db2cv_mview VALUES (29, 'SIO', 30, 'SIO', 12);
INSERT INTO chado.db2cv_mview VALUES (22, 'sequence', 23, 'SO', 2386);
INSERT INTO chado.db2cv_mview VALUES (15, 'swo', 16, 'SWO', 1);
INSERT INTO chado.db2cv_mview VALUES (23, 'taxonomic_rank', 24, 'TAXRANK', 61);
INSERT INTO chado.db2cv_mview VALUES (24, 'tripal_contact', 25, 'TCONTACT', 28);
INSERT INTO chado.db2cv_mview VALUES (25, 'tripal_pub', 26, 'TPUB', 212);
INSERT INTO chado.db2cv_mview VALUES (17, 'uo', 18, 'UO', 1);
INSERT INTO chado.db2cv_mview VALUES (7, 'EDAM', 4, 'data', 21);
INSERT INTO chado.db2cv_mview VALUES (6, 'dc', 3, 'dc', 1);
INSERT INTO chado.db2cv_mview VALUES (26, 'hydra', 27, 'hydra', 6);
INSERT INTO chado.db2cv_mview VALUES (2, 'local', 14, 'local', 83);
INSERT INTO chado.db2cv_mview VALUES (1, 'null', 1, 'null', 1);
INSERT INTO chado.db2cv_mview VALUES (4, 'chado_properties', 1, 'null', 1);
INSERT INTO chado.db2cv_mview VALUES (7, 'EDAM', 6, 'operation', 5);
INSERT INTO chado.db2cv_mview VALUES (20, 'rdfs', 21, 'rdfs', 3);
INSERT INTO chado.db2cv_mview VALUES (27, 'schema', 28, 'schema', 8);
INSERT INTO chado.db2cv_mview VALUES (28, 'sep', 29, 'sep', 2);
INSERT INTO chado.db2cv_mview VALUES (31, 'synonym_type', 32, 'synonym_type', 4);
SELECT pg_catalog.setval('chado.cv_cv_id_seq', 31, true);
SELECT pg_catalog.setval('chado.cvterm_cvterm_id_seq', 3151, true);
SELECT pg_catalog.setval('chado.cvterm_dbxref_cvterm_dbxref_id_seq', 325, true);
SELECT pg_catalog.setval('chado.cvterm_relationship_cvterm_relationship_id_seq', 3430, true);
SELECT pg_catalog.setval('chado.cvtermprop_cvtermprop_id_seq', 1341, true);
SELECT pg_catalog.setval('chado.cvtermsynonym_cvtermsynonym_id_seq', 4556, true);
SELECT pg_catalog.setval('chado.db_db_id_seq', 41, true);
SELECT pg_catalog.setval('chado.dbxref_dbxref_id_seq', 3460, true);
SELECT pg_catalog.setval('chado.contact_contact_id_seq', 1, true);
SELECT pg_catalog.setval('chado.pub_pub_id_seq', 1, true);
